#ifndef _DB_CARD_H_
#define _DB_CARD_H_

#include "card.h"

/** Class to deal with a line of data or card from database. Each keyword
  * has set of cards. For the data from database, the index of the card is
  * stored to take care of the loop cards.
  */
class DBCard : public Card
{
public:
   /** Constructor to create this object
     * \param name Name of the card
     */
   DBCard(const char *name) : Card(name)
   {
   }

   /** Constructor to create this object
     * \param name Name of the card
     * \param _flag To store the names of fields or not
     */
   DBCard(const char *name, bool _flag) : Card(name, _flag)
   {
   }
  
   virtual ~DBCard(){}
public:
   /** stores the index of the card in a keyword */
   unsigned int index;
};

/** Class to take care of data from database. The data from database is stored
  * in this object. This class also stores the information about the loop cards
  * and index of the no card keyword and total number of cards in a keyword
  */
class ExportObject : public ImportObject
{
public:
   /** Constructor to create this object
     * \param keyword Name of keyword
     */
   ExportObject(char *keyword) : 
           ImportObject(keyword), loopCount(0), noCardsIndex(0)
   {
      setIOType(IMPORT_DB);
   }

   /** Constructor to create this object
     * \param keyword Name of keyword
     * \param kw_type Type of keyword
     */
   ExportObject(char *keyword, unsigned int & kw_type) : 
      ImportObject(keyword,kw_type),loopCount(0),noCardsIndex(0)
   {
      setIOType(IMPORT_DB);
   }

/*
   vector<unsigned int> *getIDList()
   {
      return &IDList;
   }

   vector<KWTypeIDPtr> *getKWTypeIDList()
   {
      return &kwTypeIDList;
   }

   virtual ~ExportObject()
   {
      refIDList.clear();
      IDList.clear();
      for(unsigned int i = 0; i < kwTypeIDList.size(); i++)
         delete kwTypeIDList[i];
      kwTypeIDList.clear();
   }

   void setShortKW(unsigned int kw_type)
   {
      kwShort = kw_type;
   }
*/

public:
   /** count of loop cards and total number of cards */
   unsigned int loopCount, cardCount;
   /** index of keyword which has no cards at all */
   unsigned int noCardsIndex;

/*
private:
   unsigned int kwShort;
   vector<unsigned int> refIDList;
   vector<unsigned int> IDList;
   vector<KWTypeIDPtr> kwTypeIDList;
*/
};

#endif

