#ifndef _MY_CONNECTION_H_
#define _MY_CONNECTION_H_

#include <stdio.h>
#include <string.h>
#include <string>
#include <iostream>
#include <map>
#include "expat.h"
#include "goldenconn.h"

#if defined(USE_MYSQL)
#include "mysqlconn.h"
#include <mysql/mysql.h>
#endif

#define UNSIGNED_INT_MAX_FLAG (((unsigned int)1)<<31)

using namespace std;

#ifdef XML_LARGE_SIZE
#if defined(XML_USE_MSC_EXTENSIONS) && _MSC_VER < 1400
#define XML_FMT_INT_MOD "I64"
#else
#define XML_FMT_INT_MOD "ll"
#endif
#else
#define XML_FMT_INT_MOD "l"
#endif

typedef std::pair<string, string> NVPair;

/** Class to get a connection to database from the details given in an XML file.
  * The file name is connection.xml. The path to the file is obtained from 
  * CONNECTION_FILE environment variable. To use this class for MySQL, -DUSE_MYSQL
  * define to be added to Makefile.
  */
class MyConnection
{
public:
   static void XMLCALL startElement
		       (
			  void *, 
			  const char *, 
			  const char **atts
		       )
   {
      int i = 0;

      for(;atts[i];i+=2)
      {
         nvMap.insert(NVPair(atts[i], atts[i+1]));
/**
	 if( !strcmp(atts[i], "vendor") )
	    vendor = atts[i+1];
	 else if( !strcmp(atts[i], "host") )
	    host = atts[i+1];
	 else if( !strcmp(atts[i], "db") )
	    db = atts[i+1];
	 else if( !strcmp(atts[i], "user") )
	    user = atts[i+1];
	 else if( !strcmp(atts[i], "password") )
	    password = atts[i+1];
	 else if( !strcmp(atts[i], "port") )
	    port = atoi(atts[i+1]);
	 else if( !strcmp(atts[i], "width") )
	    width = atoi(atts[i+1]);
	 else if( !strcmp(atts[i], "height") )
	    height = atoi(atts[i+1]);
**/
      }
   }

   /** Reads the details of database and user from file connection.xml.
     * \param conn_file Path to the connection file
     * \return 0 on success else greater than 0.
     */
   static int readXmlFile(const char *conn_file = NULL)
   {
      if( !conn_file )
         conn_file = getenv("CONNECTION_FILE");

      if( !conn_file )
      {
         cout << "Set CONNECTION_FILE environment variable" << endl;
         return 1;
      }

      FILE *fp = fopen(conn_file, "r");

      if( !fp )
      {
	 cout << "UNABLE to open connection file " << conn_file << endl;
	 return 2;
      }

      char buf[BUFSIZ];
      int done, depth = 0;

      XML_Parser parser = XML_ParserCreate(NULL);
      XML_SetUserData(parser, &depth);
      XML_SetElementHandler(parser, startElement, NULL);

      do 
      {
	 size_t len = fread(buf, 1, sizeof(buf), fp);
	 done = len < sizeof(buf);
	 if (XML_Parse(parser, buf, len, done) == XML_STATUS_ERROR) 
	 {
	    fprintf(stderr,
		   "%s at line %" XML_FMT_INT_MOD "u\n",
		   XML_ErrorString(XML_GetErrorCode(parser)),
		   XML_GetCurrentLineNumber(parser));
            XML_ParserFree(parser);
	    fclose(fp);
	    return 3;
	 }
      } while (!done);
      fclose(fp);
      XML_ParserFree(parser);

      return 0;
   }

   /** Gets details from the connection.xml file provided by CONNECTION_FILE
     * environment variable
     * \return Returns the GoldenConn object pointer
     */
   static GoldenConn *get()
   {
      if( readXmlFile() )
         return NULL;

#if defined(USE_MYSQL)
      const char *vendor = getParam("vendor");
      const char *db = getParam("db");
      const char *host = getParam("host");
      const char *user = getParam("user");
      const char *password = getParam("password");
      const char *port = getParam("port");
      unsigned int p = 3306;

      if( port )
	 p = atoi(port);

      if( !password )
         password = "";

      if( !strcmp(vendor, "mysql") )
      {
cout << "vendor=" << vendor << " db=" << db << " host=" << host
     << " user=" << user << " password=" << password << " port=" << p << endl;

         MySqlConn *my_conn = new MySqlConn(db, host, user, password, p);

         if( !my_conn->connect() )
            return my_conn;
      }
#else
    cout << "USE DATABASE VENDOR in Makefile like USE_MYSQL" << endl;
#endif

      return NULL;
   }

   /** Function to get a value of parameeter. After reading the XML file
     * the parameters are stored as name, value pairs. For a given parameter
     * the map is searched and return the value of parameter. If not found
     * NULL is returned.
     * \param name Name of parameter for which value is required
     * \return Returns the value of parameter
     */
   static const char *getParam(string name)
   {
      map<string, string>::iterator e = nvMap.end(), itr = nvMap.find(name);
      if( itr != e )
         return itr->second.data();
      
      return NULL;
   }

   static void Clear()
   {
       nvMap.clear();
   }

public:
   /** Name, value pair map */
   static map<string, string> nvMap;
};
 
#endif

