#include <iostream>
#include <time.h>
#include <set>
#include "elementmanager.h"
#include "elementexport.h"
#include "elementimport.h"
#include "myconnection.h"
#include "filepath.h"
#include "dynatobin.h"
#include "getincludesfilewise.h"
#include "filegeneric.h"
#include "transform.h"

using namespace std;
map<string, string> MyConnection::nvMap;
unsigned int Card::contFlag = 0;

int getElementsByFileName(const char *fileDir, const char *fileName, int fileIndex,
                          TransformPtr trans_ptr, ElementManager *element_man, GoldenConn *goldenConn)
{
        ElementExport *element_exp;
        char fileBuf[1024];
        if( !strstr(fileName, "MAIN") )
        {
           sprintf(fileBuf, "%s_%d", fileName, fileIndex);
           FilePath::set(fileDir, fileBuf, trans_ptr);
        }
        else
        {
           FilePath::set(fileDir, fileName, trans_ptr);
        }
        string model_name = fileName;
        model_name += "__";

        string select_query = "show table status like '";
        select_query += model_name;
        select_query += "_ELEMENTS';";

        if( goldenConn->executeQuery( select_query.data() ) )
        {
           cout << goldenConn->error() << endl;
           delete goldenConn;
           return 2;
        }

        if( !goldenConn->nextRow() )
        {
           cout << "WARNING: No element table for model=" << fileName << endl;
           return 3;
        }

        element_exp = new ElementExport((char *)model_name.data(),
                                                goldenConn, element_man);
        element_exp->dbReadElementsBySequence();
        delete element_exp;

        return 0;
}

int main(int argc, char* argv[])
{
   if( argc < 3 )
   {
      cout << "Usage: element dir_name model_name" << endl;
      return 1;
   }

   time_t			t1, t2;
   time(&t1);

   GoldenConn *goldenConn = MyConnection::get();

   if( !goldenConn )
      return 1;

   int                          num_files = 0, i;
   IncludeFileDetailsVector     incVector;
   GetIncludesDBFileWise       get_inc(argv[2], goldenConn);
   num_files = get_inc.fetch(incVector);
   
   if( !num_files )
   {
      cout << "No data for model " << argv[2] << endl;
      delete goldenConn;
      return 2;
   }

   ElementManager *element_man = ElementManager::create();

   Card::setFlag(SAVE_REFERENCES|SAVE_IDS);
   Card::clearFlag(SAVE_CARDS_FIELDS);//VIP getIncludeFiles makes it on

   for(i = num_files-1; i >= 0; i--)
   {
           if(i == 0)
           {
               TransformStr transStr;
               memset(&transStr, 0, sizeof(TransformStr));
               transStr.fileIndex = incVector[i].second->m_FileIndex;
               transStr.sX = transStr.sY = transStr.sZ = 1.0;

                getElementsByFileName(argv[1], incVector[i].second->m_TableName.data(), incVector[i].second->m_FileIndex, &transStr,
                                      element_man, goldenConn);
           }
            for(size_t j = 0; j < incVector[i].second->m_TablesList.size(); j++)
            {
                    getElementsByFileName(argv[1], incVector[i].second->m_TablesList[j].data(),  incVector[i].second->m_TransList[j]->fileIndex,
                           incVector[i].second->m_TransList[j],  element_man, goldenConn);
            }
   }

   string main_file = argv[2];
   if(!strstr(argv[2], "MAIN"))
   {
       unsigned int table_id;
       char *new_file = getMainTableNameFromFile((char *)argv[2], &table_id);
       main_file = new_file;
       if(!table_id)
          main_file += "MAIN";
       delete new_file;
   }

   DynaToBin dtob(argv[1], main_file.data(), element_man);
   dtob.write("element");

   ElementManager::reset();

   delete goldenConn;

   time(&t2);
   cout << "TIME FOR ELEMENT FROM DB= " << difftime(t2, t1) << endl;

   return 0;
}

