#include <iostream>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <sys/mman.h>
#include <stdlib.h>
#include <fstream>
#include "dbgetnodes.h"
#include "bufio.h"
#include "nodtype.h"
#include "gentime.h"
#include "GL/gl.h"
#include "math.h"

using namespace std;

#define COMPARE_FUNC( AXIS )                                   \
static int compare_axis_##AXIS( const void *a, const void *b )	\
{							\
   float t = ( (*(NodeStr *)a).coords[AXIS] -	\
               (*(NodeStr *)b).coords[AXIS] );	\
							\
   return (t > 0) ? 1 : (t < 0) ? -1 : 0;		\
}

COMPARE_FUNC(0)
COMPARE_FUNC(1)
COMPARE_FUNC(2)

int (*(compare[3]))( const void *a, const void *b ) =
{
   compare_axis_0,
   compare_axis_1,
   compare_axis_2,
};

static int compareIDs(const void *p1, const void *p2)
{
   return ( ((NodeStr *)p1)->id > ((NodeStr *)p2)->id ) ? 1 :
          ( ((NodeStr *)p1)->id < ((NodeStr *)p2)->id ) ? -1 : 0;
}

int DBGetNodes::byCountSort(float *exts, TransformPtr trans_ptr, map<unsigned int, Node *> *nodeMap)
{
unsigned long stime = GenTime::getCurrentMillis();
   time_t   t1, t2;
   char     buf[256];
   char     temp_buf[256];

   time(&t1);

   sprintf(buf, "show table status like '%s___NODES';", modelName);
   if( goldenConn->executeQuery(buf) )
   {
      cout << "UNABLE to execute query because " << goldenConn->error() <<endl;
      return 3;
   }

   if( !goldenConn->nextRow() )
      return 3;
unsigned long etime = GenTime::getCurrentMillis();
cout << "TIME for 1st qry=" << (etime-stime) << endl;

   sprintf(buf, "SELECT count(card_index) FROM `%s___NODES`;", modelName);
		
cout << "SELECT QUERY = " << buf << endl;

   if( goldenConn->executeQuery( buf ) )
   {
      cout << goldenConn->error() << endl;
      return 4;
   }

cout << "RX=" << trans_ptr->rotAngle << "," << trans_ptr->rX << ","
     << trans_ptr->rY << "," << trans_ptr->rZ << endl;
cout << "TX=" << trans_ptr->tX << ","
     << trans_ptr->tY << "," << trans_ptr->tZ << endl;
cout << "SX=" << trans_ptr->sX << ","
     << trans_ptr->sY << "," << trans_ptr->sZ << endl;

   exts[0] = 1.0e6, exts[2] = 1.0e6, exts[4] = 1.0e6;
   exts[1] = -1.0e6, exts[3] = -1.0e6, exts[5] = -1.0e6;
   fillRotationMatrix(trans_ptr->rotAngle, trans_ptr->rX, 
                                           trans_ptr->rY, trans_ptr->rZ);
   char **node_row = goldenConn->nextRow();

   numNodes = atoi(node_row[0]);

   if(numNodes == 0)
       return 5;

   cout << "NUM NODES FROM DB = " << numNodes << endl;
stime = GenTime::getCurrentMillis();
cout << "TIME for count qry=" << (stime-etime) << endl;

   NodePtr list_ptr = NULL;
   if(!nodeMap)
   {
      nodeList = new NodeStr[numNodes];
      list_ptr = nodeList;
   }
   else
       list_ptr= new NodeStr();
   unsigned int c, COUNT_LIMIT = 100000, total_nodes;
   unsigned int start = 0, limit = COUNT_LIMIT, total = 0;
   limit = (numNodes > COUNT_LIMIT ) ? COUNT_LIMIT : numNodes;
   total_nodes = numNodes;
   sprintf(temp_buf, "SELECT * FROM `%s___NODES` limit ", modelName);

   if(!nodeMap)
   {
       while(total_nodes > 0)
       {
           sprintf(buf, "%s%u offset %u;", temp_buf, limit, start);
           //cout << "Qry=" << buf << endl;

           if( goldenConn->executeQuery( buf ) )
           {
               cout << goldenConn->error() << endl;
               return 4;
           }

           node_row = goldenConn->nextRow();

           while( node_row )
           {
               c = atoi(node_row[1]);
               switch(c)
               {
               case NODE:
               case NODE_RIGID_SURFACE:
               {
                   list_ptr->id = atoi(node_row[2]) + trans_ptr->idnoff;
                   list_ptr->coords[0] = (node_row[3]) ? atof(node_row[3]) : 0.0f;
                   list_ptr->coords[1] = (node_row[4]) ? atof(node_row[4]) : 0.0f;
                   list_ptr->coords[2] = (node_row[5]) ? atof(node_row[5]) : 0.0f;

                   list_ptr->coords[0] *= trans_ptr->sX;
                   list_ptr->coords[1] *= trans_ptr->sY;
                   list_ptr->coords[2] *= trans_ptr->sZ;

                   rotate(list_ptr->coords);

                   list_ptr->coords[0] += trans_ptr->tX;
                   list_ptr->coords[1] += trans_ptr->tY;
                   list_ptr->coords[2] += trans_ptr->tZ;

                   if( list_ptr->coords[0] < exts[0] )
                       exts[0] = list_ptr->coords[0];
                   if( list_ptr->coords[0] > exts[1] )
                       exts[1] = list_ptr->coords[0];
                   if( list_ptr->coords[1] < exts[2] )
                       exts[2] = list_ptr->coords[1];
                   if( list_ptr->coords[1] > exts[3] )
                       exts[3] = list_ptr->coords[1];
                   if( list_ptr->coords[2] < exts[4] )
                       exts[4] = list_ptr->coords[2];
                   if( list_ptr->coords[2] > exts[5] )
                       exts[5] = list_ptr->coords[2];

                   list_ptr++;
                   total++;
                   node_row = goldenConn->nextRow();
               }
                   break;
               }
           }

           total_nodes -= limit;
           start += limit;
           limit = (total_nodes > COUNT_LIMIT ) ? COUNT_LIMIT : total_nodes;
       }
   }
   else
   {
       Node *node_ptr = NULL;
       while(total_nodes > 0)
       {
           sprintf(buf, "%s%u offset %u;", temp_buf, limit, start);
           //cout << "Qry=" << buf << endl;

           if( goldenConn->executeQuery( buf ) )
           {
               cout << goldenConn->error() << endl;
               return 4;
           }

           node_row = goldenConn->nextRow();

           while( node_row )
           {
               c = atoi(node_row[1]);
               switch(c)
               {
               case NODE:
               case NODE_RIGID_SURFACE:
               {
                   list_ptr->id = atoi(node_row[2]) + trans_ptr->idnoff;
                   list_ptr->coords[0] = (node_row[3]) ? atof(node_row[3]) : 0.0f;
                   list_ptr->coords[1] = (node_row[4]) ? atof(node_row[4]) : 0.0f;
                   list_ptr->coords[2] = (node_row[5]) ? atof(node_row[5]) : 0.0f;

                   list_ptr->coords[0] *= trans_ptr->sX;
                   list_ptr->coords[1] *= trans_ptr->sY;
                   list_ptr->coords[2] *= trans_ptr->sZ;

                   rotate(list_ptr->coords);

                   list_ptr->coords[0] += trans_ptr->tX;
                   list_ptr->coords[1] += trans_ptr->tY;
                   list_ptr->coords[2] += trans_ptr->tZ;

                   if( list_ptr->coords[0] < exts[0] )
                       exts[0] = list_ptr->coords[0];
                   if( list_ptr->coords[0] > exts[1] )
                       exts[1] = list_ptr->coords[0];
                   if( list_ptr->coords[1] < exts[2] )
                       exts[2] = list_ptr->coords[1];
                   if( list_ptr->coords[1] > exts[3] )
                       exts[3] = list_ptr->coords[1];
                   if( list_ptr->coords[2] < exts[4] )
                       exts[4] = list_ptr->coords[2];
                   if( list_ptr->coords[2] > exts[5] )
                       exts[5] = list_ptr->coords[2];

                   node_ptr = new Node(list_ptr->coords[0],list_ptr->coords[1],list_ptr->coords[2]);
                   nodeMap->insert( IDNodePtrPair(list_ptr->id, node_ptr) );

                   total++;
                   node_row = goldenConn->nextRow();
               }
               break;
               }
           }

           total_nodes -= limit;
           start += limit;
           limit = (total_nodes > COUNT_LIMIT ) ? COUNT_LIMIT : total_nodes;
       }
   }

cout << "TOTAL=" << total << endl;
   numNodes = total;

   if(!nodeMap)
       qsort(nodeList, numNodes, sizeof(NodeStr), compareIDs);

   time(&t2);
 
cout << "EXTS in byCountSort=" << exts[0] << "," << exts[1] << "," << exts[2] 
     << "," << exts[3] << "," << exts[4] << "," << exts[5] << endl;
   cout << "TIME TAKEN TO READ NODES FROM DB " << difftime(t2, t1) << endl;

   return 0;
}

int DBGetNodes::writeTwoFilesByBuf()
{
unsigned long stime = GenTime::getCurrentMillis();
   char ids_file[128], val_file[128];

   sprintf(ids_file, "%s/node_ids", dirName);
   sprintf(val_file, "%s/node_values", dirName);

   int ids_fd = open(ids_file, O_RDWR|O_TRUNC|O_CREAT,
                        S_IRWXU|S_IRGRP|S_IXGRP|S_IROTH|S_IXOTH);
   if( ids_fd < 0 )
   {
      cout << "Unable to open file " << ids_file << endl;
      return 1;
   }

   int val_fd = open(val_file, O_RDWR|O_TRUNC|O_CREAT,
                        S_IRWXU|S_IRGRP|S_IXGRP|S_IROTH|S_IXOTH);

   BufFilePtr ids_buf = BufFileOpenWrite(ids_fd);
   BufFilePtr val_buf = BufFileOpenWrite(val_fd);

   NodePtr list_ptr = nodeList;

   for(unsigned int i = 0; i < numNodes; i++)
   {
      BufFileWrite(ids_buf, (char *)&list_ptr->id, sizeof(int));
      BufFileWrite(val_buf, (char *)list_ptr->coords, sizeof(float)*3);
      list_ptr++;
   }

   BufFileClose(ids_buf, 0);
   close(ids_fd);

   BufFileClose(val_buf, 0);
   close(val_fd);

unsigned long etime = GenTime::getCurrentMillis();

cout << "time for buf file write=" << (etime-stime) << endl;
   return 0;
}

#define B(row,col)  b[(col*3)+row]
#define P(row,col)  values[(col*3)+row]

void DBGetNodes::rotate(float values[3])
{
   GLint i;
   GLfloat b[3];
#define A(row,col)  rotMatrix[(col*3)+row]
   memcpy(b, values, sizeof(float) * 3);
   for (i = 0; i < 3; i++) {
      const GLfloat ai0=A(i,0),  ai1=A(i,1),  ai2=A(i,2);
      P(i,0) = ai0 * B(0,0) + ai1 * B(1,0) + ai2 * B(2,0);
   }
#undef A
}

#undef B
#undef P

static GLfloat Identity[9] = {
   1.0, 0.0, 0.0,
   0.0, 1.0, 0.0,
   0.0, 0.0, 1.0,
};

void DBGetNodes::fillRotationMatrix(float angle, float x, float y, float z)
{
   GLfloat xx, yy, zz, xy, yz, zx, xs, ys, zs, one_c, s, c;
   GLboolean optimized;

   s = (GLfloat) sin( angle * DEG2RAD );
   c = (GLfloat) cos( angle * DEG2RAD );

   memcpy(rotMatrix, Identity, sizeof(GLfloat)*9);
   optimized = GL_FALSE;

#define M(row,col)  rotMatrix[col*3+row]

   if (x == 0.0F) {
      if (y == 0.0F) {
         if (z != 0.0F) {
            optimized = GL_TRUE;
            /* rotate only around z-axis */
            M(0,0) = c;
            M(1,1) = c;
            if (z < 0.0F) {
               M(0,1) = s;
               M(1,0) = -s;
            }
            else {
               M(0,1) = -s;
               M(1,0) = s;
            }
         }
      }
      else if (z == 0.0F) {
         optimized = GL_TRUE;
         /* rotate only around y-axis */
         M(0,0) = c;
         M(2,2) = c;
         if (y < 0.0F) {
            M(0,2) = -s;
            M(2,0) = s;
         }
         else {
            M(0,2) = s;
            M(2,0) = -s;
         }
      }
   }
   else if (y == 0.0F) {
      if (z == 0.0F) {
         optimized = GL_TRUE;
         /* rotate only around x-axis */
         M(1,1) = c;
         M(2,2) = c;
         if (x < 0.0F) {
            M(1,2) = s;
            M(2,1) = -s;
         }
         else {
            M(1,2) = -s;
            M(2,1) = s;
         }
      }
   }

   if (!optimized) {
      const GLfloat mag = sqrt(x * x + y * y + z * z);

      if (mag <= 1.0e-4) {
         /* no rotation, leave mat as-is */
         return;
      }

      x /= mag;
      y /= mag;
      z /= mag;


      /*
       *     Arbitrary axis rotation matrix.
       *
       *  This is composed of 5 matrices, Rz, Ry, T, Ry', Rz', multiplied
       *  like so:  Rz * Ry * T * Ry' * Rz'.  T is the final rotation
       *  (which is about the X-axis), and the two composite transforms
       *  Ry' * Rz' and Rz * Ry are (respectively) the rotations necessary
       *  from the arbitrary axis to the X-axis then back.  They are
       *  all elementary rotations.
       *
       *  Rz' is a rotation about the Z-axis, to bring the axis vector
       *  into the x-z plane.  Then Ry' is applied, rotating about the
       *  Y-axis to bring the axis vector parallel with the X-axis.  The
       *  rotation about the X-axis is then performed.  Ry and Rz are
       *  simply the respective inverse transforms to bring the arbitrary
       *  axis back to it's original orientation.  The first transforms
       *  Rz' and Ry' are considered inverses, since the data from the
       *  arbitrary axis gives you info on how to get to it, not how
       *  to get away from it, and an inverse must be applied.
       *
       *  The basic calculation used is to recognize that the arbitrary
       *  axis vector (x, y, z), since it is of unit length, actually
       *  represents the sines and cosines of the angles to rotate the
       *  X-axis to the same orientation, with theta being the angle about
       *  Z and phi the angle about Y (in the order described above)
       *  as follows:
       *
       *  cos ( theta ) = x / sqrt ( 1 - z^2 )
       *  sin ( theta ) = y / sqrt ( 1 - z^2 )
       *
       *  cos ( phi ) = sqrt ( 1 - z^2 )
       *  sin ( phi ) = z
       *
       *  Note that cos ( phi ) can further be inserted to the above
       *  formulas:
       *
       *  cos ( theta ) = x / cos ( phi )
       *  sin ( theta ) = y / sin ( phi )
       *
       *  ...etc.  Because of those relations and the standard trigonometric
       *  relations, it is pssible to reduce the transforms down to what
       *  is used below.  It may be that any primary axis chosen will give the
       *  same results (modulo a sign convention) using thie method.
       *
       *  Particularly nice is to notice that all divisions that might
       *  have caused trouble when parallel to certain planes or
       *  axis go away with care paid to reducing the expressions.
       *  After checking, it does perform correctly under all cases, since
       *  in all the cases of division where the denominator would have
       *  been zero, the numerator would have been zero as well, giving
       *  the expected result.
       */

      xx = x * x;
      yy = y * y;
      zz = z * z;
      xy = x * y;
      yz = y * z;
      zx = z * x;
      xs = x * s;
      ys = y * s;
      zs = z * s;
      one_c = 1.0F - c;

      M(0,0) = (one_c * xx) + c;
      M(0,1) = (one_c * xy) - zs;
      M(0,2) = (one_c * zx) + ys;

      M(1,0) = (one_c * xy) + zs;
      M(1,1) = (one_c * yy) + c;
      M(1,2) = (one_c * yz) - xs;

      M(2,0) = (one_c * zx) - ys;
      M(2,1) = (one_c * yz) + xs;
      M(2,2) = (one_c * zz) + c;
   }
#undef M
}

