#ifndef _DB_GET_NODES_H_
#define _DB_GET_NODES_H_

#include "goldenconn.h"
#include "transform.h"
#include "node.h"

#ifndef M_PI
#define M_PI (3.1415926536)
#endif

#define DEG2RAD (M_PI/180.0)

/** Represents a *NODE keyword */
typedef struct _Node
{
   /** ID of node */
   unsigned int id;
   /** x, y and z values of node */
   float coords[3];
}
  NodeStr, *NodePtr;

/** Class to get the *NODE keywords from database */
class DBGetNodes
{
public:
   /** Default constructor for creating this object
     * \param dir_name Name of the directory
     * \param model_name Name of the model
     * \param gold_conn Connection object to access database
     */
   DBGetNodes
   (
      const char *dir_name,
      const char *model_name,
      GoldenConn *gold_conn
   ) : numNodes(0), nodeList(NULL)
   {
      dirName = dir_name;
      modelName = model_name;
      goldenConn = gold_conn;
   }

   ~DBGetNodes()
   {
      goldenConn = NULL;

      if( numNodes )
	 delete nodeList;
   }

   /** Rotates a *NODE with a rotation matrix and returns the values
     * \param values Node values x, y and z
     */
   void rotate(float values[3]);

   /** Gets *NODE keywords from database and sort the nodes by their ID.
     * \param exts Extents of nodes as xmin, xmax, ymin, ymax, zmin and zmax
     * \param trans_ptr Transformation object pointer for node offset and for
     * transformations
     * \return Returns 0 on success else greater than 0
     */
   int byCountSort(float *exts, TransformPtr trans_ptr, map<unsigned int, Node *> *nodeMap = NULL);

   /** Writes the node data and node ids as two files and using buffer 
     * \return Returns 0 on success else greater than 0
     */
   int writeTwoFilesByBuf();
   /** Fills a rotation matrix using the x,y,z and angle of rotation
     * \return Returns 0 on success else greater than 0
     */
   void fillRotationMatrix(float angle, float x, float y, float z);
private:
   const char *dirName;
   const char *modelName;
   unsigned int numNodes;
   /** Rotation matrix be built */
   float rotMatrix[9];
   /** List of node objects */
   NodePtr nodeList;
   /** Connection object for acccessing the database */
   GoldenConn *goldenConn;
};

#endif

