#ifndef _DB_PUT_GEN_H_
#define _DB_PUT_GEN_H_

#include <string>
#include "card.h"
#include "manager.h"
#include "goldenconn.h"

using namespace std;

/** Generic function to insert the lines of data or cards of data into database
  * for all keywords except *NODE, *ELEMENT and *CONTACT. This function inserts
  * '$' character at the end of all cards or lines of data.
  * \param max_num_fields Maximum number of fields in all keywords of certain type
  * \param table_name Name of the table to which the lines data to be appeded
  * \param man_ptr Manager pointer from which the data is taken for the keywords
  * \param golden_conn GoldenConn connection object to access database
  */
static int insertIntoDBWithLastRowNull
	   (
	      int      max_num_fields,
	      string & table_name,
	      Manager  *man_ptr,
              GoldenConn *golden_conn
	   )
{
   vector<ImportObject *> & imp_arr = man_ptr->getImportObjectList();

   if( !imp_arr.size() )
      return 0;

cout << "SIZE OF IMP OBJECTs = " << imp_arr.size() << endl;
   vector<ImportObject *>::iterator b = imp_arr.begin(), e = imp_arr.end();

   ImportObject *imp_obj;
   vector<Card *>::iterator bc, ec;
   Card *card;
   vector<Data *>::iterator bv, ev;
   Data *data;

   char   buff[4096], buff1[256], *char_val, buff2[256];
   int    int_val, num_values = 0;
   unsigned int num_cards = 0, kw_type;
   double dbl_val;
   string create_query;

   golden_conn->executeQuery( "set AUTOCOMMIT=0;" );
   sprintf(buff1, "INSERT INTO %s VALUES (NULL,", table_name.data());

   while( b != e )
   {
      imp_obj = *b;

      vector<Card *> & card_arr = imp_obj->getCardList();
      bc = card_arr.begin();
      ec = card_arr.end();
      kw_type = imp_obj->getKeywordType();

      num_cards = 0;
      while( bc != ec )
      {
         card = *bc;
         vector<Data *> & var_values = card->getVarValues();
         bv = var_values.begin();
         ev = var_values.end();

if( strstr(imp_obj->getKeyword().data(), "*PART") )
{
cout << "NUM VALUES=" << var_values.size() << endl;
cout << "NUM CARDS=" << num_cards << endl;
}
         if( !num_cards && var_values.size() )
            sprintf(buff, "%s%u,", buff1, kw_type);

         if( !num_cards && !var_values.size() )
            sprintf(buff, "%s%u", buff1, kw_type);
 
         while(bv != ev)
         {
            data = *bv;
            switch(data->dataType)
            {
               case DATA_INT:
                  data->value(&int_val);
                  sprintf(buff2, "\"%d\"", int_val);
                  break;
               case DATA_DOUBLE:
                  data->value(&dbl_val);
                  sprintf(buff2, "\"%.9g\"", dbl_val);
                  break;
               case DATA_CHAR_ARRAY:
                  data->value(&char_val);
                  if( char_val[0] != '\0' )
                     sprintf(buff2, "\"%s\"", char_val);
                  else
                     sprintf(buff2, "NULL");
                  break;
               case DATA_BLANK:
                  sprintf(buff2, "\" \"");
                  break;
            }

            bv++;
            if( bv != ev )
            {
               strcat(buff, buff2);
               strcat(buff, ",");
            }
            else
               strcat(buff, buff2);
         }

         num_values = max_num_fields - var_values.size();
         
         if( var_values.size() )
         {
	    for(int i = 0; i < num_values; i++)
	       strcat(buff, ", NULL");
         }
         else //no values at all
         {
            if( num_cards )
               strcat(buff, "NULL");
            else
               strcat(buff, ", NULL");
	    for(int i = 1; i < num_values; i++)
	       strcat(buff, ", NULL");
         }

         num_cards++;
         bc++;

         if( num_cards < 10 && bc != ec )
         {
            sprintf(buff2, "), (NULL, %u,", kw_type);
            strcat(buff, buff2);
         }
         else
         {
            strcat(buff, ");");
            num_cards = 0;
	    //create_query = buff;
if( strstr(imp_obj->getKeyword().data(), "*PART") )
cout << "QUERY=" << buff << endl;
	    if( golden_conn->executeQuery( buff ) )
	    {
	       cout << golden_conn->error() << endl;
	       return 6;
	    }
         }
      }

      buff2[0] = '\0';
      num_values = max_num_fields - 1;

      for(int i = 0; i < num_values; i++)
         strcat(buff2, ", NULL");

      sprintf(buff, "%s%u, \"$\"%s);", buff1, kw_type, buff2);
      create_query = buff;
if( strstr(table_name.data(), "_PARTS") )
cout << "NULL QUERY = " << create_query << endl;

      if( golden_conn->executeQuery( create_query.data() ) )
      {
	 cout << golden_conn->error() << endl;
	 return 6;
      }
      b++;
   }

   golden_conn->executeQuery( "COMMIT;" );
   return 0;
}

#endif

