#include  "getdb.h"
#include  <iterator>
#include  <algorithm>
#include  <map>
#include  <vector>
#include  <set>
#include  <iostream>
#include  <fstream>
#include  <stdlib.h>
#include "node.h"
#include "shell.h"
#include "solid.h"
#include "part.h"
#include "nodtype.h"
#include "elementtype.h"
#include "includetype.h"
#include  <time.h>
#include  "gentime.h"
#include  "oglcmds.h"
#include "mathapis.h"

#include <boost/iostreams/filter/gzip.hpp>
#include <boost/iostreams/device/file.hpp>

using namespace std;
using namespace boost;

GetDB               *GetDB::m_GetDB = NULL;

GetDB::GetDB
(
   const char *model_name,
   GoldenConn *gold_conn
)
{
   modelName = model_name;
   if( !strstr(model_name, "___") )
      modelName += "___";
   goldenConn = gold_conn;
}

GetDB::GetDB(const char *model_name)
{
    modelName = model_name;
}

GetDB::~GetDB()
{
   goldenConn = NULL;

   IDNodePtrIterator b = nodeMap.begin(), e = nodeMap.end();
   for(; b != e;b++)
      delete b->second;
   nodeMap.clear();

   IDPartPtrIterator bp = partMap.begin(), ep = partMap.end();
   for(; bp != ep; bp++)
      delete bp->second;
   partMap.clear();
}

struct compareX
{
    bool operator() (const Node *n1, const Node *n2) const 
    {
       return n1->x < n2->x;
    }
};

struct compareY
{
    bool operator() (const Node *n1, const Node *n2) const 
    {
       return n1->y < n2->y;
    }
};

struct compareZ
{
    bool operator() (const Node *n1, const Node *n2) const 
    {
       return n1->z < n2->z;
    }
};

int  GetDB::nodes(float min_max[6])
{
   time_t   t1, t2;
   char     buf[512];

   time(&t1);

   sprintf(buf, "show table status like '%sNODES';", modelName.data());
   if( goldenConn->executeQuery(buf) )
   {
      cout << "UNABLE to execute query because " << goldenConn->error() <<endl;
      return 3;
   }

   if( !goldenConn->nextRow() )
      return 3;

   sprintf(buf, "SELECT * FROM `%sNODES` where KW_TYPE=%u;", 
			modelName.data(), NODE);
		
cout << "SELECT QUERY = " << buf << endl;

   if( goldenConn->executeQuery( buf ) )
   {
      cout << goldenConn->error() << endl;
      return 4;
   }

   Node *new_node = NULL;
   //vector<Node *> node_array;
   //unsigned int node_id;
   char **node_row = goldenConn->nextRow();

   cout << "NUM NODES FROM DB = " << goldenConn->numRows() << endl;
   while( node_row )
   {
      if(node_row[3] == NULL)
         node_row[3] = "0";
      if(node_row[4] == NULL)
         node_row[4] = "0";
      if(node_row[5] == NULL)
         node_row[5] = "0";
      new_node = new Node(node_row[3], node_row[4], node_row[5]); 
      //node_id = atoi(node_row[2]);
      nodeMap.insert( IDNodePtrPair(atoi(node_row[2]), new_node) );
      //node_array.push_back( new_node );
      node_row = goldenConn->nextRow();
   }

/**
   NodePtrIterator b = node_array.begin(), e = node_array.end();

   sort(b, e, compareX());
   min_max[0] = (*b)->x;
   e--;
   min_max[1] = (*e)->x;

   e = node_array.end();
   sort(b, e, compareY());
   min_max[2] = (*b)->y;
   e--;
   min_max[3] = (*e)->y;

   e = node_array.end();
   sort(b, e, compareZ());
   min_max[4] = (*b)->z;
   e--;
   min_max[5] = (*e)->z;

   node_array.clear();

cout << "XMIN=" << min_max[0] << "YMIN=" << min_max[2] << "ZMIN=" 
     << min_max[4] << endl;
cout << "XMAX=" << min_max[1] << "YMAX=" << min_max[3] << "ZMAX=" 
     << min_max[5] << endl;
**/
   time(&t2);
 
   cout << "TIME TAKEN TO READ NODES FROM DB " << difftime(t2, t1) << endl;

   return 0;
}

void GetDB::partExtents(Part *part_ptr, float min_max[])
{
   if( !part_ptr )
      return;

   set<Node *>::iterator bn = part_ptr->uniqueNodeList.begin(),
                         en = part_ptr->uniqueNodeList.end();

   vector<Node *> node_array;
   for_each(bn, en, insertInto(node_array));
   NodePtrIterator b = node_array.begin(), e = node_array.end();

   sort(b, e, compareX());
   min_max[0] = (*b)->x;
   e--;
   min_max[1] = (*e)->x;

   e = node_array.end();
   sort(b, e, compareY());
   min_max[2] = (*b)->y;
   e--;
   min_max[3] = (*e)->y;

   e = node_array.end();
   sort(b, e, compareZ());
   min_max[4] = (*b)->z;
   e--;
   min_max[5] = (*e)->z;

   node_array.clear();

cout << "XMIN=" << min_max[0] << "YMIN=" << min_max[2] << "ZMIN=" 
     << min_max[4] << endl;
cout << "XMAX=" << min_max[1] << "YMAX=" << min_max[3] << "ZMAX=" 
     << min_max[5] << endl;
}

void GetDB::nodeExtents(float min_max[])
{
   IDNodePtrIterator bm = nodeMap.begin(), em = nodeMap.end();
   
   if( bm == em )
      return;

   vector<Node *> node_array;
   for_each(bm, em, insertInto(node_array));
   NodePtrIterator b = node_array.begin(), e = node_array.end();

   sort(b, e, compareX());
   min_max[0] = (*b)->x;
   e--;
   min_max[1] = (*e)->x;

   e = node_array.end();
   sort(b, e, compareY());
   min_max[2] = (*b)->y;
   e--;
   min_max[3] = (*e)->y;

   e = node_array.end();
   sort(b, e, compareZ());
   min_max[4] = (*b)->z;
   e--;
   min_max[5] = (*e)->z;

   node_array.clear();
cout << "XMIN=" << min_max[0] << "YMIN=" << min_max[2] << "ZMIN=" 
     << min_max[4] << endl;
cout << "XMAX=" << min_max[1] << "YMAX=" << min_max[3] << "ZMAX=" 
     << min_max[5] << endl;
}

int GetDB::partsByElementType(unsigned int kw_type)
{
   time_t    t1, t2;
   char      buf[512];

   time(&t1);
   sprintf(buf, "show table status like '%sELEMENTS';",modelName.data());
   if( goldenConn->executeQuery(buf) )
   {
      cout << "UNABLE to execute query because " << goldenConn->error() <<endl;
      return 1;
   }

   if( !goldenConn->nextRow() )
      return 2;

   sprintf(buf, 
      "SELECT VALUE2 FROM `%sELEMENTS` where KW_TYPE=%u GROUP BY VALUE2;", 
                        modelName.data(), kw_type);

cout << "select query ELEMENTS = " << buf << endl;

   if( goldenConn->executeQuery( buf ) )
   {
      cout << goldenConn->error() << endl;
      return 3;
   }

cout << "NUM PARTS = " << goldenConn->numRows() << endl;
   char            buff[256];
   Part            *new_part = NULL;

   char **part_id_row = goldenConn->nextRow();
   //unsigned int part_id;

   while ( part_id_row )
   {
      buff[0] = '\0';
      sprintf(buff, "PART_%s", part_id_row[0]);
      new_part = new Part(buff, kw_type);
      //part_id = atoi(part_id_row[0]);
      partMap.insert( IDPartPtrPair(atoi(part_id_row[0]), new_part) );

      part_id_row = goldenConn->nextRow();
   }

   time(&t2);
cout << "TIME TAKEN TO READ PARTS FROM DB " << difftime(t2, t1) << endl;

   return 0;
}

int GetDB::solidElements(unsigned int nodeOffset)
{
   time_t    t1, t2;
   char      buf[512];

   time(&t1);

   if( !partMap.size() )
   {
      cout << "NO PARTS AVAILABLE in GetDB" << endl;
      cout << "USE getPartsByElementType then use this function" << endl;
      return 3;
   }

   //addding the elements to the respective part

   sprintf(buf, 
      "SELECT * FROM `%sELEMENTS` where KW_TYPE=%u;", 
                                modelName.data(), ELEMENT_SOLID);
cout << "select query ELEMENTS2 = " << buf << endl;

   if( goldenConn->executeQuery( buf ) )
   {
      cout << goldenConn->error() << endl;
      return 4;
   }

   Solid      *new_solid;
   Part       *solid_part = NULL;
   IDPartPtrIterator  part_itr, e = partMap.end(), b = partMap.begin();
   unsigned int     prev_id = 0;
   IDNodePtrIterator  nitr, en = nodeMap.end();
   char       **elm_row = goldenConn->nextRow();

cout << "NUM ELMS = " << goldenConn->numRows() << endl;

   while( elm_row )
   {
      new_solid = new Solid(elm_row[2], elm_row[3], elm_row[4], 
         elm_row[5], elm_row[6], elm_row[7], elm_row[8], elm_row[9], elm_row[10], elm_row[11], nodeOffset);

      if( prev_id != new_solid->pID )
      {
	 part_itr = partMap.find(new_solid->pID);

         if( part_itr != e )
	         solid_part = (*part_itr).second;
         else
            cout << "part id <" << new_solid->pID << "> is not found" << endl;
      }

      solid_part->elementList.push_back( new_solid );

      for(int i = 0; i < 8; i++)
      {
	      nitr = nodeMap.find(new_solid->NIDList[i]);

         if( nitr != en )
         {
	         new_solid->nodePtrList[i] = (*nitr).second;
	         solid_part->uniqueNodeList.insert((*nitr).second);
         }
         else
            cout << "node id <" << new_solid->NIDList[i] << "> is not found" << endl;
      }

      new_solid->computeNormals();
      
      prev_id = new_solid->pID;
      elm_row = goldenConn->nextRow();
   }

   time(&t2);

   cout << "TIME FOR ELEMENTS FROM DB " << difftime(t2, t1) << endl;

   return 0;
}

int GetDB::shellElements(unsigned int nodeOffset)
{
   time_t    t1, t2;
   char      buf[512];

   time(&t1);

   if( !partMap.size() )
   {
      cout << "NO PARTS AVAILABLE in GetDB" << endl;
      cout << "USE getPartsByElementType then use this function" << endl;
      return 3;
   }

   //addding the elements to the respective part

   sprintf(buf, 
      "SELECT * FROM `%sELEMENTS` where KW_TYPE=%u;", 
                                modelName.data(), ELEMENT_SHELL);
cout << "select query ELEMENTS2 = " << buf << endl;

   if( goldenConn->executeQuery( buf ) )
   {
      cout << goldenConn->error() << endl;
      return 4;
   }

   Shell      *new_shell;
   Part       *shell_part = NULL;
   IDPartPtrIterator  part_itr, e = partMap.end(), b = partMap.begin();
   unsigned int     prev_id = 0;
   IDNodePtrIterator  nitr, en = nodeMap.end();
   char       **elm_row = goldenConn->nextRow();

cout << "NUM ELMS = " << goldenConn->numRows() << endl;

   while( elm_row )
   {
      new_shell = new Shell(elm_row[2], elm_row[3], elm_row[4], 
         elm_row[5], elm_row[6], elm_row[7], nodeOffset);

      if( prev_id != new_shell->pID )
      {
	      part_itr = partMap.find(new_shell->pID);

         if( part_itr != e )
	         shell_part = (*part_itr).second;
         else
            cout << "part id <" << new_shell->pID << "> is not found" << endl;
      }

      shell_part->elementList.push_back( new_shell );

      for(int i = 0; i < 4; i++)
      {
	      nitr = nodeMap.find(new_shell->NIDList[i]);

         if( nitr != en )
         {
	         new_shell->nodePtrList[i] = (*nitr).second;
	         shell_part->uniqueNodeList.insert((*nitr).second);
         }
         else
         {
            cout << "node id <" << new_shell->NIDList[i] << "> is not found" << endl;
         }
      }

      new_shell->computeNormal();
      
      prev_id = new_shell->pID;
      elm_row = goldenConn->nextRow();
   }

   time(&t2);

   cout << "TIME FOR ELEMENTS FROM DB " << difftime(t2, t1) << endl;

   return 0;
}

int GetDB::writeDataToFiles
    (
       string  dir_name,
       unsigned int part_count,
       unsigned int draw_type,
       unsigned int compress_flag,
        string *partDetailsJSON,
        bool modifyFlag
    )
{
   char     buff[256];
   int      num_part_nodes, num_part_elms, i, j;
   Part     *part_ptr = NULL;
   Shell    *shell_ptr= NULL;
   Solid    *solid_ptr= NULL;
   Node     *node_ptr = NULL;
   string   nodes_string = "", elements_string = "", file_name; 

   IDPartPtrIterator bp_itr = partMap.begin(), ep_itr = partMap.end(), citr;
   set<Node *>::iterator  set_itr;

cout << "NUM PARTS = " << partMap.size() << endl;

   while( bp_itr != ep_itr )
   {
      part_ptr = (*bp_itr).second;

      num_part_nodes = part_ptr->uniqueNodeList.size();
      set_itr = part_ptr->uniqueNodeList.begin();

      sprintf(buff, "%s%d=[", PART_NODES_ARRAY_NAME, part_count); 
      nodes_string = buff;

      for(i = 0; i < num_part_nodes-1; i++)
      {
         node_ptr = *set_itr;
         sprintf(buff, "%g,%g,%g,",node_ptr->x, node_ptr->y, node_ptr->z);
         nodes_string += buff;
         node_ptr->idx = i;
         set_itr++;
      }

      node_ptr = *set_itr;
      sprintf(buff, "%g,%g,%g];\n",node_ptr->x, node_ptr->y, node_ptr->z);
      nodes_string += buff;
      node_ptr->idx = i;

      num_part_elms = part_ptr->elementList.size();

      sprintf(buff, "%s%d=[", PART_SHELLS_ARRAY_NAME, part_count); 

      nodes_string += buff;

      if(part_count)
         sprintf(buff, ",[%d,%d,%d,%d]", bp_itr->first, num_part_nodes, num_part_elms,part_ptr->partType);
      else
         sprintf(buff, "[%d,%d,%d,%d]", bp_itr->first, num_part_nodes, num_part_elms,part_ptr->partType);

      size_t foundPos = partDetailsJSON->find(&buff[1]);
      if(foundPos == string::npos)
           partDetailsJSON->append(buff);

      switch(draw_type)
      {
         case GL_QUADS:
            for(j = 0; j < num_part_elms-1; j++)
            {
               shell_ptr = (Shell *)part_ptr->elementList[j];
               sprintf(buff, "%d,%d,%d,%d,",shell_ptr->nodePtrList[0]->idx,
                  shell_ptr->nodePtrList[1]->idx, shell_ptr->nodePtrList[2]->idx,
                  shell_ptr->nodePtrList[3]->idx);
               nodes_string += buff;
            }
            shell_ptr = (Shell *)part_ptr->elementList[j];
            sprintf(buff, "%d,%d,%d,%d];\n",shell_ptr->nodePtrList[0]->idx,
               shell_ptr->nodePtrList[1]->idx, shell_ptr->nodePtrList[2]->idx,
               shell_ptr->nodePtrList[3]->idx);
            nodes_string += buff;
         break;
         case GL_TRIANGLE_STRIP:
            for(j = 0; j < num_part_elms-1; j++)
            {
               shell_ptr = (Shell *)part_ptr->elementList[j];
               sprintf(buff, "%d,%d,%d,%d,",shell_ptr->nodePtrList[0]->idx,
                  shell_ptr->nodePtrList[1]->idx, shell_ptr->nodePtrList[3]->idx,
                  shell_ptr->nodePtrList[2]->idx);
               nodes_string += buff;
            }
            shell_ptr = (Shell *)part_ptr->elementList[j];
            sprintf(buff, "%d,%d,%d,%d];\n",shell_ptr->nodePtrList[0]->idx,
               shell_ptr->nodePtrList[1]->idx, shell_ptr->nodePtrList[3]->idx,
               shell_ptr->nodePtrList[2]->idx);
            nodes_string += buff;
         break;
         case GL_TRIANGLES:
         {
            if(part_ptr->partType == ELEMENT_SHELL)
            {
               char  shell_buff[256];
               string shell_part_str;
               sprintf(shell_buff, "%s%d", PART_SHELLS_ARRAY_NAME, part_count); 
                for(j = 0; j < num_part_elms-1; j++)
                {
                   shell_ptr = (Shell *)part_ptr->elementList[j];
                   sprintf(buff, "%d,%d,%d,%d,%d,%d,",shell_ptr->nodePtrList[0]->idx,
                      shell_ptr->nodePtrList[1]->idx, shell_ptr->nodePtrList[3]->idx,
                      shell_ptr->nodePtrList[1]->idx, shell_ptr->nodePtrList[2]->idx,
                            shell_ptr->nodePtrList[3]->idx);
                   shell_part_str += buff;
                }
                shell_ptr = (Shell *)part_ptr->elementList[j];
                sprintf(buff, "%d,%d,%d,%d,%d,%d];\n",shell_ptr->nodePtrList[0]->idx,
                   shell_ptr->nodePtrList[1]->idx, shell_ptr->nodePtrList[3]->idx,
                   shell_ptr->nodePtrList[1]->idx, shell_ptr->nodePtrList[2]->idx,
                   shell_ptr->nodePtrList[3]->idx);
                shell_part_str += buff;
                nodes_string += shell_part_str;
            }
            else if(part_ptr->partType == ELEMENT_SOLID)
            {
               char  solid_buff[256];
               string solid_part_str;
               sprintf(solid_buff, "%s%d", PART_SHELLS_ARRAY_NAME, part_count); 
                for(j = 0; j < num_part_elms-1; j++)
                {
                   solid_ptr = (Solid *)part_ptr->elementList[j];
                   //bottom face
                   sprintf(buff, "%d,%d,%d,%d,%d,%d,",solid_ptr->nodePtrList[0]->idx,
                      solid_ptr->nodePtrList[1]->idx, solid_ptr->nodePtrList[3]->idx,
                      solid_ptr->nodePtrList[1]->idx, solid_ptr->nodePtrList[2]->idx,
                            solid_ptr->nodePtrList[3]->idx);
                   solid_part_str += buff;

                   //left face
                   sprintf(buff, "%d,%d,%d,%d,%d,%d,",solid_ptr->nodePtrList[0]->idx,
                      solid_ptr->nodePtrList[4]->idx, solid_ptr->nodePtrList[3]->idx,
                      solid_ptr->nodePtrList[4]->idx, solid_ptr->nodePtrList[7]->idx,
                            solid_ptr->nodePtrList[3]->idx);
                   solid_part_str += buff;

                   //back face
                   sprintf(buff, "%d,%d,%d,%d,%d,%d,",solid_ptr->nodePtrList[3]->idx,
                      solid_ptr->nodePtrList[7]->idx, solid_ptr->nodePtrList[2]->idx,
                      solid_ptr->nodePtrList[7]->idx, solid_ptr->nodePtrList[6]->idx,
                            solid_ptr->nodePtrList[2]->idx);
                   solid_part_str += buff;

                   //right face
                   sprintf(buff, "%d,%d,%d,%d,%d,%d,",solid_ptr->nodePtrList[2]->idx,
                      solid_ptr->nodePtrList[6]->idx, solid_ptr->nodePtrList[1]->idx,
                      solid_ptr->nodePtrList[6]->idx, solid_ptr->nodePtrList[5]->idx,
                            solid_ptr->nodePtrList[1]->idx);
                   solid_part_str += buff;
                   //front face
                   sprintf(buff, "%d,%d,%d,%d,%d,%d,",solid_ptr->nodePtrList[1]->idx,
                      solid_ptr->nodePtrList[5]->idx, solid_ptr->nodePtrList[0]->idx,
                      solid_ptr->nodePtrList[5]->idx, solid_ptr->nodePtrList[4]->idx,
                            solid_ptr->nodePtrList[0]->idx);
                   solid_part_str += buff;
                   //top face
                   sprintf(buff, "%d,%d,%d,%d,%d,%d,",solid_ptr->nodePtrList[4]->idx,
                      solid_ptr->nodePtrList[5]->idx, solid_ptr->nodePtrList[7]->idx,
                      solid_ptr->nodePtrList[5]->idx, solid_ptr->nodePtrList[6]->idx,
                            solid_ptr->nodePtrList[7]->idx);
                   solid_part_str += buff;
                }
                solid_ptr = (Solid *)part_ptr->elementList[j];
                //bottom face
                sprintf(buff, "%d,%d,%d,%d,%d,%d,",solid_ptr->nodePtrList[0]->idx,
                   solid_ptr->nodePtrList[1]->idx, solid_ptr->nodePtrList[3]->idx,
                   solid_ptr->nodePtrList[1]->idx, solid_ptr->nodePtrList[2]->idx,
                   solid_ptr->nodePtrList[3]->idx);
                solid_part_str += buff;
                //left face
                sprintf(buff, "%d,%d,%d,%d,%d,%d,",solid_ptr->nodePtrList[0]->idx,
                   solid_ptr->nodePtrList[4]->idx, solid_ptr->nodePtrList[3]->idx,
                   solid_ptr->nodePtrList[4]->idx, solid_ptr->nodePtrList[7]->idx,
                         solid_ptr->nodePtrList[3]->idx);
                solid_part_str += buff;

                //back face
                sprintf(buff, "%d,%d,%d,%d,%d,%d,",solid_ptr->nodePtrList[3]->idx,
                   solid_ptr->nodePtrList[7]->idx, solid_ptr->nodePtrList[2]->idx,
                   solid_ptr->nodePtrList[7]->idx, solid_ptr->nodePtrList[6]->idx,
                         solid_ptr->nodePtrList[2]->idx);
                solid_part_str += buff;

                //right face
                sprintf(buff, "%d,%d,%d,%d,%d,%d,",solid_ptr->nodePtrList[2]->idx,
                   solid_ptr->nodePtrList[6]->idx, solid_ptr->nodePtrList[1]->idx,
                   solid_ptr->nodePtrList[6]->idx, solid_ptr->nodePtrList[5]->idx,
                         solid_ptr->nodePtrList[1]->idx);
                solid_part_str += buff;
                //front face
                sprintf(buff, "%d,%d,%d,%d,%d,%d,",solid_ptr->nodePtrList[1]->idx,
                   solid_ptr->nodePtrList[5]->idx, solid_ptr->nodePtrList[0]->idx,
                   solid_ptr->nodePtrList[5]->idx, solid_ptr->nodePtrList[4]->idx,
                         solid_ptr->nodePtrList[0]->idx);
                solid_part_str += buff;
                //top face
                sprintf(buff, "%d,%d,%d,%d,%d,%d];\n",solid_ptr->nodePtrList[4]->idx,
                   solid_ptr->nodePtrList[5]->idx, solid_ptr->nodePtrList[7]->idx,
                   solid_ptr->nodePtrList[5]->idx, solid_ptr->nodePtrList[6]->idx,
                         solid_ptr->nodePtrList[7]->idx);
                solid_part_str += buff;
                nodes_string += solid_part_str;
            }
         }
         break;
      }

      if(partMap.size() > 10)
      {
            sprintf(buff, "var pNormalA%d=[];\n", part_count);
            nodes_string += buff;
      }
      else
      {
          sprintf(buff, "var pNormalA%d=[", part_count);
          nodes_string += buff;
          set_itr = part_ptr->uniqueNodeList.begin();
          for(i = 0; i < num_part_nodes-1; i++)
          {
             node_ptr = *set_itr;
             Normal *norm = node_ptr->getNormal();
             if(norm)
             {
                 sprintf(buff, "%g,%g,%g,",norm->x, norm->y, norm->z);
                 nodes_string += buff;
             }
             set_itr++;
          }

          node_ptr = *set_itr;
          Normal *norm = node_ptr->getNormal();
          if(norm)
          {
              sprintf(buff, "%g,%g,%g];\n",norm->x, norm->y, norm->z);
              nodes_string += buff;
          }
      }

      sprintf(buff, "%s/part_%d.js", dir_name.data(), part_count);
      file_name = buff;

      if(!modifyFlag)
           OglCmds::getPartCmd(part_count, nodes_string, draw_type);
      else
          OglCmds::getPartCmdModify(part_count, nodes_string, draw_type);

      writeGZIPFile(file_name, nodes_string);

      part_count++;
      bp_itr++;
   }

/******
   switch(compress_flag)
   {
      case GZIP_COMPRESSION:
         {
         string file_name = dir_name + "/node_array.js";
         writeGZIPFile(file_name, nodes_string);
         nodes_string.clear();
         file_name = dir_name + "/elm_array.js";
         writeGZIPFile(file_name, elements_string);
         elements_string.clear();
         }
         break;
      case NO_COMPRESSION:
         {
         string file_name = dir_name + "/node_array.js";
         writeFile(file_name, nodes_string);
         nodes_string.clear();

         file_name = dir_name + "/elm_array.js";
         writeFile(file_name, elements_string);
         elements_string.clear();
         }
         break;
   }
*******/

   return 0;
}

int GetDB::numPartsAndNodeExtents
    (
       int      *num_parts,
       float   exts[6]
    )
{
   *num_parts = partMap.size();
   nodeExtents(exts);
   return 0;
}

int GetDB::writeGZIPFile
    (
       string & file_name,
       string & buf
    )
{
   iostreams::gzip_params gzp;
   //gzp.file_name = file_name.data();

   file_name += ".gz";
   iostreams::file_sink snk(file_name, BOOST_IOS::trunc);

   if( !snk.is_open() )
   {
      cout << "Unable to open file in temp directory" << endl;
      return 1;
   }
   
   iostreams::gzip_compressor gzc(gzp);
   gzc.write(snk, buf.data(), buf.length());
   gzc.close(snk, BOOST_IOS::out);

   return 0;
}

int GetDB::writeFile
    (
       string & file_name,
       string & buf
    )
{
   ofstream out_file(file_name.data(), ios::trunc);

   if( !out_file.is_open() )
   {
      cout << "Unable to open file in temp directory" << endl;
      return 1;
   }

   out_file << buf;
   out_file.close();
 
   return 0;
}

/** Getting elements by part is very slow ****
int  GetDB::getShellElementsFromDB()
{
   time_t    t1, t2;
   char      buf[512];

   time(&t2);

   sprintf(buf, 
      "SELECT VALUE2 FROM %sELEMENTS where KW_TYPE=%u GROUP BY VALUE2;", 
                        modelName.data(), ELEMENT_SHELL);

   if( goldenConn->executeQuery( buf ) )
   {
      cout << goldenConn->error() << endl;
      return 4;
   }

cout << "NUM PARTS = " << goldenConn->numRows() << endl;
   char            buff[256];
   Part            *new_part, *shell_part;
   Shell           *new_shell;
   char **part_id_row = goldenConn->nextRow(), **elm_row;

   while ( part_id_row )
   {
      buff[0] = '\0';
      sprintf(buff, "PART_%s", part_id_row[0]); 
      new_part = new Part(buff, atoi(part_id_row[0]));
      partMap.insert( IDPartPtrPair(new_part->ID, new_part) );

      part_id_row = goldenConn->nextRow();
   }

   IDPartPtrIterator bp = partMap.begin(), be = partMap.end();
   IDNodePtrIterator  nitr, en = nodeMap.end();
   
   while(bp != be)
   {
      shell_part = bp->second;

cout << "GETTING ELMS for PART=" << shell_part->ID << endl;
      sprintf(buf,
	 "SELECT * FROM %sELEMENTS where VALUE2=%d;", 
				   modelName.data(), shell_part->ID);
      if( goldenConn->executeQuery( buf ) )
      {
	 cout << goldenConn->error() << endl;
	 return 4;
      }

      elm_row = goldenConn->nextRow();

      while( elm_row )
      {
	 new_shell = new Shell(elm_row[2], elm_row[3], elm_row[4], elm_row[5],
				   elm_row[6], elm_row[7]);  

	 shell_part->elementList.push_back( new_shell );

	 for(int i = 0; i < 4; i++)
	 {
	    nitr = nodeMap.find(new_shell->NIDList[i]);

	    if( nitr != en )
	    {
	       new_shell->nodePtrList[i] = (*nitr).second;
	       shell_part->uniqueNodeList.insert((*nitr).second);
	    }
	    else
           cout << "node id <" << new_shell->NIDList[i] << "> is not found" << endl;
	 }
	 
	 elm_row = goldenConn->nextRow();
      }

      bp++;
   }

   time(&t1);

   cout << "TIME FOR ELEMENTS FROM DB " << difftime(t1, t2) << endl;
   cout << "NUM PARTS IN GET ELM = " << partMap.size() << endl;

   return 0;
}
***/

int getIncludeFilesFromDB
    (
       const char *main_file,
       GoldenConn *golden_conn,   
       vector<string> & files_list
    )
{
   char buff[512];
   vector<string> local_file_list;

   char *dot = strrchr((char *)main_file, '.');
   if( dot )
      *dot = '\0';

   /**
   dot = strchr((char *)main_file, '-');
   while( dot )
   {
      *dot = '_';
      dot++;
      dot = strchr(dot, '-');
   }
   **/

   sprintf(buff, "show table status like '%s___INCLUDES';", 
                                                    main_file);
cout << "QRY=" << buff << endl;

   if( golden_conn->executeQuery(buff) )
   {
      cout << "UNABLE to execute query because " << golden_conn->error() <<endl;
      return 1;
   }

   if( !golden_conn->nextRow() )
   {
      files_list.push_back( main_file );
      return 1;
   }
   
   sprintf(buff, "SELECT VALUE1 FROM `%s___INCLUDES` where KW_TYPE=%u;",
                           main_file, INCLUDE);

   if( golden_conn->executeQuery(buff) )
   {
      cout << "UNABLE to execute query because " << golden_conn->error() <<endl;
      return 1;
   }

   char **inc_row = golden_conn->nextRow();

   while( inc_row )
   {
      local_file_list.push_back( inc_row[0] ); 
      inc_row = golden_conn->nextRow();
      if( inc_row[0][0] == '$' )
         inc_row = golden_conn->nextRow();
   }

   files_list.push_back( main_file );

   for(unsigned int i = 0; i < local_file_list.size(); i++)
      getIncludeFilesFromDB(local_file_list[i].data(), golden_conn, files_list);

   return 0;
}

void GetDB::writeStartEndFiles(unsigned int total_parts, float exts[6], unsigned int wh[2], const char *dir_name)
{
    float    rcolor = 0.7f, gcolor = 0.5f, bcolor = 0.3f, alpha = 1.0f;

    string pcolor_str = PART_COLOR_ARRAY_NAME, part_cmds;
    pcolor_str += "=[";

    float 	rgb[3];
    char     buff[1024];
    for(unsigned int j = 0; j < total_parts-1; j++)
    {
       randomColor(rgb);
       sprintf(buff, "[%.2f,%.2f,%.2f,%.2f],", rgb[0], rgb[1], rgb[2], alpha);
       pcolor_str += buff;
    }

    sprintf(buff, "[%g,%g,%g,%g]];", rcolor, gcolor, bcolor, alpha);
    pcolor_str += buff;

    string file_name = dir_name, init_str, end_str;
    file_name += "/part_start.js";

    float light0x = (exts[0] + exts[1])/2.0f;
    float light0y = -exts[1];
    float light0z = -exts[5];
    float light1x = 2 * exts[1];
    float light1y = 2 * exts[3];
    float light1z = 2 * exts[5];

    sprintf(buff, "\nNUM_PARTS=%d;\n", total_parts);
    pcolor_str += buff;
    sprintf(buff, "\nglobalLight0x=%g;globalLight0y=%g;globalLight0z=%g;",
        light0x, light0y, light0z);
    pcolor_str += buff;
    sprintf(buff, "\nglobalLight1x=%g;globalLight1y=%g;globalLight1z=%g;\n",
        light1x, light1y, light1z);
    pcolor_str += buff;
    sprintf(buff, "\nmodelExts=[%g,%g,%g,%g,%g,%g];\n",
        exts[0], exts[1],exts[2], exts[3], exts[4],exts[5]);
    pcolor_str += buff;

    pcolor_str += "function drawModel()\n{\n";
    OglCmds::getInitCmds(wh, exts, init_str);
    pcolor_str += init_str;
    pcolor_str += part_cmds;
    OglCmds::getEndCmds(end_str);
    pcolor_str += end_str;
    pcolor_str += "}\n";

    GetDB::writeGZIPFile(file_name, pcolor_str);

    file_name = dir_name;
    file_name += "/part_end.js";
    GetDB::writeGZIPFile(file_name, end_str);
}

void GetDB::randomColor(float rgb[3])
{
   int i = rand();
   rgb[0] = (float) (i % 1000) / 1000.0;

   i = rand();
   rgb[1] = (float) (i % 1000) / 1000.0;

   i = rand();
   rgb[2] = (float) (i % 1000) / 1000.0;
}
