//tag used to include this source code only one time
#ifndef _MONGO_DB_Header_File
#define _MONGO_DB_Header_File

#include <string>
#include <bsoncxx/builder/basic/document.hpp>
#include <bsoncxx/builder/basic/kvp.hpp>
#include <bsoncxx/builder/stream/document.hpp>
#include <bsoncxx/json.hpp>
#include <bsoncxx/types.hpp>
#include <mongocxx/client.hpp>
#include <mongocxx/instance.hpp>
#include <mongocxx/pool.hpp>
#include <mongocxx/uri.hpp>
#include "node.h"
#include "element.h"

#include <set>
#include <vector>

class MongoDB
{
public:
    MongoDB(const char *email, const char *model);
    MongoDB(const char *email, const char *host, const char *user, const char *password, const char *port = "27017");
    ~MongoDB();
    std::string IsExists(std::string & name, std::string & value, mongocxx::pool::entry & client);
    std::string Create(std::string & name, std::string & value);
    void CreateNodes(const char *timestep, const char *arrayName, set<Node *> & nodeset, int step);
    void CreateElements(const char *coll_name, const char *timestep, const char *arrayName,
            const char *arrayBuf, vector<Element*> & elmList, int step, int part_index);
    void Init();

    void GetData();

    void SetDirName(string & dir_name)
    {
        m_DirName = dir_name;
    }

    static MongoDB *Create(const char *email, const char *model)
    {
        if(m_MongoDB)
            return m_MongoDB;
        m_MongoDB = new MongoDB(email, model);
        return m_MongoDB;
    }

    static MongoDB *Get()
    {
        return m_MongoDB;
    }

    void CreateEntity(const char *coll_name, const char *array_name, vector<float> & enity_values, int part_index);

    void CreateEntityForTimeStep(const char *timestep, const char *array_name, int num_values, float *entity_array, int step);

    void GetAllGlobalResults();

    void GetGlobalResults(const char *collName, string & res_str);

    void GetPartResults(const char *collName, string & res_str, string & array_str);

    void GetAllPartResults();

private:
    mongocxx::instance  *m_DBInstance;
    mongocxx::pool      *m_DBPool;
    std::string     m_Host;
    std::string     m_User;
    std::string     m_Password;
    std::string     m_Port;
    std::string     m_ConnStr;
    std::string     m_MinPoolSize;
    std::string     m_MaxPoolSize;
    std::string     m_UserID;
    std::string     m_ModelID;
    std::string     m_DirName;
    static MongoDB             *m_MongoDB;
};

#endif
