#ifndef _SHELL_H_
#define _SHELL_H_

#include <iostream>
#include <vector>
#include <stdlib.h>
#include <string.h>
#include "node.h"
#include "element.h"
#include "elementtype.h"
#include "normal.h"

class Shell : public Element
{
public:

   friend std::ostream & operator<<(std::ostream & os, Shell *ptr)
   {
      os << "PID = " << ptr->pID << endl
	      << "N1 = " << ptr->NIDList[0] << endl
	      << "N2 = " << ptr->NIDList[1] << endl
	      << "N3 = " << ptr->NIDList[2] << endl
	      << "N4 = " << ptr->NIDList[3] << endl;
      return os;
   }

   ~Shell()
   {
   }

   unsigned int getNumNodes()
   {
      return 4;
   }

   const unsigned int *getNodeIDList()
   {
      return NIDList;
   }

   Node **getNodePtrList()
   {
      return nodePtrList;
   }

   Shell(char *_id, char *_pid, char *n1, char *n2, char *n3, char *n4, unsigned int nodeOff)
   {
      ID = atoi(_id);
      pID = atoi(_pid);
      NIDList[0] = atoi(n1) + nodeOff;
      NIDList[1] = atoi(n2) + nodeOff;
      NIDList[2] = atoi(n3) + nodeOff;
      NIDList[3] = atoi(n4) + nodeOff;
      m_Normal = NULL;
      memset(nodePtrList, 0, sizeof(Node*)*4);
   }

   Shell(unsigned int _id, unsigned int _pid, unsigned int n1, unsigned int n2, unsigned int n3, unsigned int n4, unsigned int nodeOff)
   {
      ID = (_id);
      pID = (_pid);
      NIDList[0] = (n1) + nodeOff;
      NIDList[1] = (n2) + nodeOff;
      NIDList[2] = (n3) + nodeOff;
      NIDList[3] = (n4) + nodeOff;
      m_Normal = NULL;
      memset(nodePtrList, 0, sizeof(Node*)*4);
   }

   void computeNormal()
   {
       float x, y, z, x1, y1, z1, x2, y2, z2, x3, y3, z3;

       x1 = nodePtrList[0]->x;
       y1 = nodePtrList[0]->y;
       z1 = nodePtrList[0]->z;

       x2 = nodePtrList[1]->x;
       y2 = nodePtrList[1]->y;
       z2 = nodePtrList[1]->z;

       unsigned int ndIndex = 2;
       if(nodePtrList[3] != NULL)
           ndIndex = 3;

       x3 = nodePtrList[ndIndex]->x;
       y3 = nodePtrList[ndIndex]->y;
       z3 = nodePtrList[ndIndex]->z;

       x = ((y2 - y1) * (z3 - z1)) - ((y3 - y1) * (z2 - z1));
       y = -((x2 - x1) * (z3 - z1)) + ((x3 - x1) * (z2 - z1));
       z = ((x2 - x1) * (y3 - y1)) - ((x3 - x1) * (y2 - y1));

    /* This is from the 'computer graphics' by Hearn and Baker
       x = y1 * (z2-z3) + y2 * (z3-z1) + y3 * (z1-z2);
       y = z1 * (x2-x3) + z2 * (x3-x1) + z3 * (x1-x2);
       z = x1 * (y2-y3) + x2 * (y3-y1) + x3 * (y1-y2);
    */

       if(m_Normal == NULL)
           m_Normal = new Normal(x, y, z);
       else
       {
           m_Normal->x = x;
           m_Normal->y = y;
           m_Normal->z = z;
       }
       m_Normal->normalize();
       for(int iIndex = 0; iIndex < 3; ++iIndex)
       {
            nodePtrList[iIndex]->AddNormal(m_Normal);
       }
       if(nodePtrList[3] != NULL)
           nodePtrList[3]->AddNormal(m_Normal);
   }

public:
   unsigned int	  NIDList[4];
   Node	          *nodePtrList[4];
   Normal          *m_Normal;
};

typedef std::pair<unsigned int, Shell *> IDShellPtrPair;
typedef std::vector<Shell *>::iterator ShellPtrIterator;
typedef std::map<unsigned int, Shell *>::iterator IDShellPtrIterator;

#endif

