#ifndef _SOLID_H_
#define _SOLID_H_

#include <iostream>
#include <string.h>
#include "node.h"
#include "element.h"
#include "normal.h"

using namespace std;

class Solid : public Element
{
   public:

   friend std::ostream & operator<<(std::ostream & os, Solid *ptr)
   {
      os << "PID = " << ptr->pID << endl
	      << "N1 = " << ptr->NIDList[0] << endl
	      << "N2 = " << ptr->NIDList[1] << endl
	      << "N3 = " << ptr->NIDList[2] << endl
	      << "N4 = " << ptr->NIDList[3] << endl
         << "N5 = " << ptr->NIDList[4] << endl
	      << "N6 = " << ptr->NIDList[5] << endl
	      << "N7 = " << ptr->NIDList[6] << endl
	      << "N8 = " << ptr->NIDList[7] << endl;
      return os;
   }

   unsigned int getNumNodes()
   {
      return 8;
   }


   ~Solid()
   {
   }

   const unsigned int *getNodeIDList()
   {
      return NIDList;
   }

   Node **getNodePtrList()
   {
      return nodePtrList;
   }

   Solid(char *_id, char *_pid, char *n1, char *n2, char *n3, char *n4, char *n5, char *n6, char *n7, char *n8, unsigned int nodeOff)
   {
      ID = atoi(_id);
      pID = atoi(_pid);
      NIDList[0] = atoi(n1) + nodeOff;
      NIDList[1] = atoi(n2) + nodeOff;
      NIDList[2] = atoi(n3) + nodeOff;
      NIDList[3] = atoi(n4) + nodeOff;
      NIDList[4] = atoi(n5) + nodeOff;
      NIDList[5] = atoi(n6) + nodeOff;
      m_NumFaces = 5;
      if(n7)
      {
         NIDList[6] = atoi(n7) + nodeOff;
         m_NumFaces = 6;
      }
      else
         NIDList[6] = 0;
      if(n8)
         NIDList[7] = atoi(n8) + nodeOff;
      else
         NIDList[7] = 0;
      memset(nodePtrList, 0, sizeof(Node*)*8);
      memset(m_Normals, 0, sizeof(Normal*)*6);
   }

   Solid(unsigned int _id, unsigned int _pid, unsigned int n1, unsigned int n2, unsigned int n3, unsigned int n4, unsigned int n5, unsigned int n6, unsigned int n7, unsigned int n8, unsigned int nodeOff)
   {
      ID = (_id);
      pID = (_pid);
      NIDList[0] = (n1) + nodeOff;
      NIDList[1] = (n2) + nodeOff;
      NIDList[2] = (n3) + nodeOff;
      NIDList[3] = (n4) + nodeOff;
      NIDList[4] = (n5) + nodeOff;
      NIDList[5] = (n6) + nodeOff;
      NIDList[6] = (n7) + nodeOff;
      NIDList[7] = (n8) + nodeOff;
      memset(nodePtrList, 0, sizeof(Node*)*8);
      memset(m_Normals, 0, sizeof(Normal*)*6);
   }

   void computeNormals()
   {
       for(unsigned int fIndex = 0; fIndex < m_NumFaces; ++fIndex)
       {
            computeFaceNormal(fIndex);
       }
   }

   void computeFaceNormal(int faceIndex)
   {
       float x, y, z, x1, y1, z1, x2, y2, z2, x3, y3, z3;

       int n1 = 0, n2 = 1, n3 = 3, n4 = 2;
       switch(m_NumFaces)
       {
       case 6:
           switch(faceIndex)
           {
                case 0:
                    //bottom face
                    break;
               case 1:
                       //front face
                       n1 = 0; n2 = 4; n3 = 3; n4 = 7;
                   break;
               case 2:
                    //right face
                    n1 = 3; n2 = 7; n3 = 2; n4 = 6;
               break;
               case 3:
               //back face
               n1 = 2; n2 = 6; n3 = 1; n4 = 5;
               break;
               case 4:
               //left face
               n1 = 1; n2 = 5; n3 = 0; n4 = 4;
               break;
               case 5:
               //top face
               n1 = 4; n2 = 5; n3 = 7; n4 = 6;
               break;
           }
           break;
       case 5:
           switch(faceIndex)
           {
                case 0:
                    //bottom face
                    break;
               case 1:
                       //front face
                       n1 = 0; n2 = 1; n3 = 4, n4 = -1;
                   break;
               case 2:
                    //right face
                    n1 = 1; n2 = 2; n3 = 4, n4 = 5;
                    if(NIDList[4] == NIDList[5])
                        n4 = -1;
               break;
               case 3:
               //back face
               n1 = 2; n2 = 3; n3 = 5; n4 = -1;
               break;
               case 4:
               //left face
               n1 = 3; n2 = 0; n3 = 5; n4 = 4;
               if(NIDList[4] == NIDList[5])
               {
                   n4 = -1; n3 = 4;
               }
               break;
           }
           break;
       case 4:
           switch(faceIndex)
           {
                case 0:
                    //bottom face
                    break;
               case 1:
                       //front face
                       n1 = 0; n2 = 1; n3 = 4, n4 = -1;
                   break;
               case 2:
                    //right face
                    n1 = 1; n2 = 2; n3 = 4, n4 = 5;
               break;
               case 3:
               //back face
               n1 = 2; n2 = 3; n3 = 5; n4 = -1;
               break;
           }
           break;
       }
       x1 = nodePtrList[n1]->x;
       y1 = nodePtrList[n1]->y;
       z1 = nodePtrList[n1]->z;

       x2 = nodePtrList[n2]->x;
       y2 = nodePtrList[n2]->y;
       z2 = nodePtrList[n2]->z;

       x3 = nodePtrList[n3]->x;
       y3 = nodePtrList[n3]->y;
       z3 = nodePtrList[n3]->z;

       x = ((y2 - y1) * (z3 - z1)) - ((y3 - y1) * (z2 - z1));
       y = -((x2 - x1) * (z3 - z1)) + ((x3 - x1) * (z2 - z1));
       z = ((x2 - x1) * (y3 - y1)) - ((x3 - x1) * (y2 - y1));

    /* This is from the 'computer graphics' by Hearn and Baker
       x = y1 * (z2-z3) + y2 * (z3-z1) + y3 * (z1-z2);
       y = z1 * (x2-x3) + z2 * (x3-x1) + z3 * (x1-x2);
       z = x1 * (y2-y3) + x2 * (y3-y1) + x3 * (y1-y2);
    */

       if(m_Normals[faceIndex] == NULL)
           m_Normals[faceIndex] = new Normal(x, y, z);
       else
       {
           m_Normals[faceIndex]->x = x;
           m_Normals[faceIndex]->y = y;
           m_Normals[faceIndex]->z = z;
       }
       m_Normals[faceIndex]->normalize();

       Normal *norm = m_Normals[faceIndex];

       Node *node1 = nodePtrList[n1];
       Node *node2 = nodePtrList[n2];
       Node *node3 = nodePtrList[n3];
       node1->AddNormal(norm);
       node2->AddNormal(norm);
       node3->AddNormal(norm);
       if(n4 > -1)
       {
           Node *node4 = nodePtrList[n4];
           node4->AddNormal(norm);
       }
   }

public:
   int      numNodes;
   Node		*nodePtrList[8];
   unsigned int	NIDList[8];
   Normal  *m_Normals[6];
   unsigned int     m_NumFaces;
};

#endif
