#ifndef _MATH_APIS_H_
#define _MATH_APIS_H_

#include <math.h>

namespace Mathapis
{
   class Dvector
   {
   public:
      double  x, y, z;

      Dvector(double _x, double _y, double _z)
      {
	 x = _x;
	 y = _y;
	 z = _z;
      }

      Dvector()
      {
	 x = y = z = 0.0;
      }

      void normalize()
      {
	 double len = sqrt(x * x + y * y + z *z);

	 if( len != 0.0 )
	 {
	    x = x/len;
	    y = y/len;
	    z = z/len;
	 }
      }

      void subtract(Dvector *v2, Dvector *sub_vect)
      {
	 sub_vect->x = this->x - v2->x;
	 sub_vect->y = this->y - v2->y;
	 sub_vect->z = this->z - v2->z;
      }

      void add(Dvector *v2, Dvector *add_vect)
      {
	 add_vect->x = this->x + v2->x;
	 add_vect->y = this->y + v2->y;
	 add_vect->z = this->z + v2->z;
      }

      double dotProduct(Dvector *v2)
      {
	 return ( (this->x * v2->x) + (this->y * v2->y) + (this->z * v2->z) );
      }

      void crossProduct(Dvector *v2, Dvector *cross_vect)
      {
	 cross_vect->x = (this->y * v2->z) - (this->z * v2->y);
	 cross_vect->y = -(this->x * v2->z) + (v2->x * this->z);
	 cross_vect->z = (this->x * v2->y) - (v2->x * this->y);
      }

      void getNormalVector(Dvector *v2, Dvector *v3, Dvector *norm_vect)
      {
	 Dvector  s1, s2;

	 v2->subtract(this, &s1);
	 v3->subtract(this, &s2);
	 s1.crossProduct(&s2, norm_vect);
	 norm_vect->normalize();
      }
   };
}

#endif
