#include  "fegetdb.h"
#include  "card.h"
#include  "manager_inc.h"
#include  "export_inc.h"
#include  "gentime.h"
#include  <iterator>
#include  <iostream>
#include  <map>

using namespace std;

FeGetDB::~FeGetDB()
{
   goldenConn = NULL;
}

unsigned int FeGetDB::getNodesFromDB()
{
   NodManager::reset();

   string select_query = "SELECT * FROM ";
   string table_name = "`" + modelName + "_NODES`;";
   select_query += table_name;

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      return 0;
   }

   NodManager *node_man = NodManager::create();
   NodExport nod_exp((char *)modelName.data(), goldenConn, node_man);

   return nod_exp.dbReadNods();
}

unsigned int FeGetDB::getElementsFromDB()
{
   ElementManager::reset();

   string select_query = "SELECT * FROM ";
   string table_name = "`" + modelName + "_ELEMENTS`;";
   select_query += table_name;

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      return 0;
   }

   ElementManager *elm_man = ElementManager::create();
   ElementExport elm_exp((char *)modelName.data(), goldenConn, elm_man);

   return elm_exp.dbReadElements();
}

unsigned int FeGetDB::getAirbagsFromDB()
{
   AirbagManager::reset();

   string select_query = "SELECT * FROM ";
   string table_name = "`" + modelName + "_AIRBAGS`;";
   select_query += table_name;

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      return 0;
   }

   AirbagManager *ab_man = AirbagManager::create();
   ABExport ab_exp((char *)modelName.data(), goldenConn, ab_man);

   return ab_exp.dbReadAirbags();
}

unsigned int FeGetDB::getAlesFromDB()
{
   ALEManager::reset();

   string select_query = "SELECT * FROM ";
   string table_name = "`" + modelName + "_ALES`;";
   select_query += table_name;

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      return 0;
   }

   ALEManager *ale_man = ALEManager::create();
   ALEExport ale_exp((char *)modelName.data(), goldenConn, ale_man);

   return ale_exp.dbReadALEs();
}

unsigned int FeGetDB::getBoundarysFromDB()
{
   BdryManager::reset();

   string select_query = "SELECT * FROM ";
   string table_name = "`" + modelName + "_BOUNDARYS`;";
   select_query += table_name;

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      return 0;
   }

   BdryManager *bdry_man = BdryManager::create();
   BdryExport bdry_exp((char *)modelName.data(), goldenConn, bdry_man);

   return bdry_exp.dbReadBdrys();
}

unsigned int FeGetDB::getComponentsFromDB()
{
   CompManager::reset();

   string select_query = "SELECT * FROM ";
   string table_name = "`" + modelName + "_COMPONENTS`;";
   select_query += table_name;

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      return 0;
   }

   CompManager *comp_man = CompManager::create();
   CompExport comp_exp((char *)modelName.data(), goldenConn, comp_man);

   return comp_exp.dbReadComps();
}

unsigned int FeGetDB::getConstsFromDB()
{
   ConstManager::reset();

   string select_query = "SELECT * FROM ";
   string table_name = "`" + modelName + "_CONSTRAINEDS`;";
   select_query += table_name;

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      return 0;
   }

   ConstManager *const_man = ConstManager::create();
   ConstExport const_exp((char *)modelName.data(), goldenConn, const_man);

   return const_exp.dbReadConsts();
}

unsigned int FeGetDB::getContactsFromDB()
{
   ContactManager::reset();

   string select_query = "SELECT * FROM ";
   string table_name = "`" + modelName + "_CONTACTS`;";
   select_query += table_name;

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      return 0;
   }

   ContactManager *contact_man = ContactManager::create();
   ContactExport contact_exp((char *)modelName.data(), goldenConn, contact_man);

   return contact_exp.dbReadContacts();
}

unsigned int FeGetDB::getControlsFromDB()
{
   ControlManager::reset();

   string select_query = "SELECT * FROM ";
   string table_name = "`" + modelName + "_CONTROLS`;";
   select_query += table_name;

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      return 0;
   }

   ControlManager *ctrl_man = ControlManager::create();

   KeywordExport key_exp((char *)modelName.data(), goldenConn, ctrl_man);
   key_exp.dbReadKWAndTitle();

   ControlExport ctrl_exp((char *)modelName.data(), goldenConn, ctrl_man);

   return ctrl_exp.dbReadControls();
}

unsigned int FeGetDB::getDampingsFromDB()
{
   DampingManager::reset();

   string select_query = "SELECT * FROM ";
   string table_name = "`" + modelName + "_DAMPINGS`;";
   select_query += table_name;

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      return 0;
   }

   DampingManager *damp_man = DampingManager::create();
   DampingExport damp_exp((char *)modelName.data(), goldenConn, damp_man);

   return damp_exp.dbReadDampings();
}

unsigned int FeGetDB::getDatabasesFromDB()
{
   DatabaseManager::reset();

   string select_query = "SELECT * FROM ";
   string table_name = "`" + modelName + "_DATABASES`;";
   select_query += table_name;

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      return 0;
   }

   DatabaseManager *db_man = DatabaseManager::create();
   DatabaseExport db_exp((char *)modelName.data(), goldenConn, db_man);

   return db_exp.dbReadDatabases();
}

unsigned int FeGetDB::getDefinesFromDB()
{
   DefineManager::reset();

   string select_query = "SELECT * FROM ";
   string table_name = "`" + modelName + "_DEFINES`;";
   select_query += table_name;

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      return 0;
   }

   DefineManager *def_man = DefineManager::create();
   DefineExport def_exp((char *)modelName.data(), goldenConn, def_man);

   return def_exp.dbReadDefines();
}

unsigned int FeGetDB::getDeformsFromDB()
{
   DeformManager::reset();

   string select_query = "SELECT * FROM ";
   string table_name = "`" + modelName + "_DEFORMS`;";
   select_query += table_name;

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      return 0;
   }

   DeformManager *def_man = DeformManager::create();
   DeformExport def_exp((char *)modelName.data(), goldenConn, def_man);

   return def_exp.dbReadDeforms();
}

unsigned int FeGetDB::getEfsFromDB()
{
   EFManager::reset();

   string select_query = "SELECT * FROM ";
   string table_name = "`" + modelName + "_EFS`;";
   select_query += table_name;

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      return 0;
   }

   EFManager *ef_man = EFManager::create();
   EFExport ef_exp((char *)modelName.data(), goldenConn, ef_man);

   return ef_exp.dbReadEFs();
}

unsigned int FeGetDB::getEossFromDB()
{
   EosManager::reset();

   string select_query = "SELECT * FROM ";
   string table_name = "`" + modelName + "_EOSS`;";
   select_query += table_name;

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      return 0;
   }

   EosManager *eos_man = EosManager::create();
   EosExport eos_exp((char *)modelName.data(), goldenConn, eos_man);

   return eos_exp.dbReadEoss();
}

unsigned int FeGetDB::getHgsFromDB()
{
   HgManager::reset();

   string select_query = "SELECT * FROM ";
   string table_name = "`" + modelName + "_HOURGLASSS`;";
   select_query += table_name;

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      return 0;
   }

   HgManager *hg_man = HgManager::create();
   HgExport hg_exp((char *)modelName.data(), goldenConn, hg_man);

   return hg_exp.dbReadHgs();
}

unsigned int FeGetDB::getIncludesFromDB()
{
   IncludeManager::reset();

   string select_query = "SELECT * FROM ";
   string table_name = "`" + modelName + "_INCLUDES`;";
   select_query += table_name;

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      return 0;
   }

   IncludeManager *inc_man = IncludeManager::create();
   IncludeExport inc_exp((char *)modelName.data(), goldenConn, inc_man);

   return inc_exp.dbReadIncludes();
}

unsigned int FeGetDB::getInitialsFromDB()
{
   InitialManager::reset();

   string select_query = "SELECT * FROM ";
   string table_name = "`" + modelName + "_INITIALS`;";
   select_query += table_name;

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      return 0;
   }

   InitialManager *init_man = InitialManager::create();
   InitialExport init_exp((char *)modelName.data(), goldenConn, init_man);

   return init_exp.dbReadInitials();
}

unsigned int FeGetDB::getIntegrationsFromDB()
{
   IntegrationManager::reset();

   string select_query = "SELECT * FROM ";
   string table_name = "`" + modelName + "_INTEGRATIONS`;";
   select_query += table_name;

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      return 0;
   }

   IntegrationManager *int_man = IntegrationManager::create();
   IntegrationExport int_exp((char *)modelName.data(), goldenConn, int_man);

   return int_exp.dbReadIntegrations();
}

unsigned int FeGetDB::getInterfacesFromDB()
{
   InterfaceManager::reset();

   string select_query = "SELECT * FROM ";
   string table_name = "`" + modelName + "_INTERFACES`;";
   select_query += table_name;

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      return 0;
   }

   InterfaceManager *inter_man = InterfaceManager::create();
   InterfaceExport inter_exp((char *)modelName.data(), goldenConn, inter_man);

   return inter_exp.dbReadInterfaces();
}

unsigned int FeGetDB::getLoadsFromDB()
{
   LoadManager::reset();

   string select_query = "SELECT * FROM ";
   string table_name = "`" + modelName + "_LOADS`;";
   select_query += table_name;

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      return 0;
   }

   LoadManager *load_man = LoadManager::create();
   LoadExport load_exp((char *)modelName.data(), goldenConn, load_man);

   return load_exp.dbReadLoads();
}

unsigned int FeGetDB::getMatsFromDB()
{
   MatManager::reset();

   string select_query = "SELECT * FROM ";
   string table_name = "`" + modelName + "_MATS`;";
   select_query += table_name;

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      return 0;
   }

   MatManager *mat_man = MatManager::create();
   MatExport mat_exp((char *)modelName.data(), goldenConn, mat_man);

   return mat_exp.dbReadMats();
}

unsigned int FeGetDB::getParametersFromDB()
{
   ParameterManager::reset();

   string select_query = "SELECT * FROM ";
   string table_name = "`" + modelName + "_PARAMETERS`;";
   select_query += table_name;

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      return 0;
   }

   ParameterManager *param_man = ParameterManager::create();
   ParameterExport param_exp((char *)modelName.data(), goldenConn, param_man);

   return param_exp.dbReadParameters();
}

unsigned int FeGetDB::getPartCsFromDB()
{
   PartCManager::reset();

   string select_query = "SELECT * FROM ";
   string table_name = "`" + modelName + "_PARTS`;";
   select_query += table_name;

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      return 0;
   }

   PartCManager *partc_man = PartCManager::create();
   PartCExport partc_exp((char *)modelName.data(), goldenConn, partc_man);

   return partc_exp.dbReadPartCs();
}

unsigned int FeGetDB::getPerturbsFromDB()
{
   PerturbManager::reset();

   string select_query = "SELECT * FROM ";
   string table_name = "`" + modelName + "_PERTURBATIONS`;";
   select_query += table_name;

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      return 0;
   }

   PerturbManager *pert_man = PerturbManager::create();
   PerturbExport pert_exp((char *)modelName.data(), goldenConn, pert_man);

   return pert_exp.dbReadPerturbs();
}

unsigned int FeGetDB::getRailsFromDB()
{
   RailManager::reset();

   string select_query = "SELECT * FROM ";
   string table_name = "`" + modelName + "_RAILS`;";
   select_query += table_name;

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      return 0;
   }

   RailManager *rail_man = RailManager::create();
   RailExport rail_exp((char *)modelName.data(), goldenConn, rail_man);

   return rail_exp.dbReadRails();
}

unsigned int FeGetDB::getRigidwallsFromDB()
{
   RigidwallManager::reset();

   string select_query = "SELECT * FROM ";
   string table_name = "`" + modelName + "_RIGIDWALLS`;";
   select_query += table_name;

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      return 0;
   }

   RigidwallManager *rw_man = RigidwallManager::create();
   RigidwallExport rw_exp((char *)modelName.data(), goldenConn, rw_man);

   return rw_exp.dbReadRigidwalls();
}

unsigned int FeGetDB::getSectionsFromDB()
{
   SectionManager::reset();

   string select_query = "SELECT * FROM ";
   string table_name = "`" + modelName + "_SECTIONS`;";
   select_query += table_name;

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      return 0;
   }

   SectionManager *sec_man = SectionManager::create();
   SectionExport sec_exp((char *)modelName.data(), goldenConn, sec_man);

   return sec_exp.dbReadSections();
}

unsigned int FeGetDB::getSetsFromDB()
{
   SetManager::reset();

   string select_query = "SELECT * FROM ";
   string table_name = "`" + modelName + "_SETS`;";
   select_query += table_name;

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      return 0;
   }

   SetManager *set_man = SetManager::create();
   SetExport set_exp((char *)modelName.data(), goldenConn, set_man);

   return set_exp.dbReadSets();
}

unsigned int FeGetDB::getSensorsFromDB()
{
   SensorManager::reset();

   string select_query = "SELECT * FROM ";
   string table_name = "`" + modelName + "_SENSORS`;";
   select_query += table_name;

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      return 0;
   }

   SensorManager *sens_man = SensorManager::create();
   SensorExport sens_exp((char *)modelName.data(), goldenConn, sens_man);

   return sens_exp.dbReadSensors();
}

unsigned int FeGetDB::getTermsFromDB()
{
   TermManager::reset();

   string select_query = "SELECT * FROM ";
   string table_name = "`" + modelName + "_TERMINATIONS`;";
   select_query += table_name;

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      return 0;
   }

   TermManager *term_man = TermManager::create();
   TermExport term_exp((char *)modelName.data(), goldenConn, term_man);

   return term_exp.dbReadTerms();
}

unsigned int FeGetDB::getUsersFromDB()
{
   UserManager::reset();

   string select_query = "SELECT * FROM ";
   string table_name = "`" + modelName + "_USERS`;";
   select_query += table_name;

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      return 0;
   }

   UserManager *user_man = UserManager::create();
   UserExport user_exp((char *)modelName.data(), goldenConn, user_man);

   return user_exp.dbReadUsers();
}

