#ifndef _FE_GET_DB_H_
#define _FE_GET_DB_H_

#include  <string>
#include "goldenconn.h"
#include "manager.h"

using namespace std;

/** Class to get data from the database for a given model. Provides services
  * to get data for different types of keywords of LSDYNA
  */
class FeGetDB
{
public:
   /** Constructor to create this object for a given model
     * \param model_name Name of the model
     * \param gold_conn Connection object to access database
     */
   FeGetDB
   (
      const char *model_name,
      GoldenConn *gold_conn
   )
   {
      modelName = model_name;
      modelName += "__";
      goldenConn = gold_conn;
   }

   ~FeGetDB();

   /** Gets *NODE keywords from database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   unsigned int getNodesFromDB();
   /** Gets *ELEMENT keywords from database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   unsigned int getElementsFromDB();
   /** Gets *AIRBAG keywords from database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   unsigned int getAirbagsFromDB();
   /** Gets *DEFORMABLE keywords from database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   unsigned int getDeformsFromDB();
   /** Gets *DEFINE keywords from database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   unsigned int getDefinesFromDB();
   /** Gets *DATABASE keywords from database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   unsigned int getDatabasesFromDB();
   /** Gets *DAMPING keywords from database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   unsigned int getDampingsFromDB();
   /** Gets *CONTROL keywords from database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   unsigned int getControlsFromDB();
   /** Gets *CONTACT keywords from database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   unsigned int getContactsFromDB();
   /** Gets *CONSTRAINED keywords from database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   unsigned int getConstsFromDB();
   /** Gets *COMPONENT keywords from database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   unsigned int getComponentsFromDB();
   /** Gets *BOUNDARY keywords from database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   unsigned int getBoundarysFromDB();
   /** Gets *ALE keywords from database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   unsigned int getAlesFromDB();
   /** Gets *USER keywords from database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   unsigned int getUsersFromDB();
   /** Gets *TERMINATION keywords from database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   unsigned int getTermsFromDB();
   /** Gets *SET keywords from database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   unsigned int getSetsFromDB();
   /** Gets *SECTION keywords from database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   unsigned int getSectionsFromDB();
   /** Gets *RIGIDWALL keywords from database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   unsigned int getRigidwallsFromDB();
   /** Gets *RAIL keywords from database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   unsigned int getRailsFromDB();
   /** Gets *PERTUBATION keywords from database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   unsigned int getPerturbsFromDB();
   /** Gets *PART keywords from database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   unsigned int getPartCsFromDB();
   /** Gets *PARAMETER keywords from database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   unsigned int getParametersFromDB();
   /** Gets *MAT keywords from database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   unsigned int getMatsFromDB();
   /** Gets *EF keywords from database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   unsigned int getEfsFromDB();
   /** Gets *EOS keywords from database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   unsigned int getEossFromDB();
   /** Gets *HOURGLASS keywords from database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   unsigned int getHgsFromDB();
   /** Gets *INCLUDE keywords from database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   unsigned int getIncludesFromDB();
   /** Gets *INITIAL keywords from database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   unsigned int getInitialsFromDB();
   /** Gets *INTEGRATION keywords from database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   unsigned int getIntegrationsFromDB();
   /** Gets *INTERFACE keywords from database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   unsigned int getInterfacesFromDB();
   /** Gets *LOAD keywords from database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   unsigned int getLoadsFromDB();
   /** Gets *SENSOR keywords from database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   unsigned int getSensorsFromDB();

private:
   string     modelName;
   GoldenConn *goldenConn;
};

#endif
