#ifndef _FE_PUT_DB_H_
#define _FE_PUT_DB_H_

#include  <string>
#include "goldenconn.h"
#include "manager.h"

using namespace std;

/** Class for inserting data into database for different types of keywords of
  * LSDYNA. Services are provided to insert a group of keywords to database.
  */
class FePutDB
{
public:
   /** Constructor to create this object
     * \param model_name Name of the model
     * \param gold_conn Connection object to access the database
     */
   FePutDB
   (
      const char *model_name,
      GoldenConn *gold_conn
   )
   {
      modelName = model_name;
      modelName += "__";
      goldenConn = gold_conn;
   }

   ~FePutDB();

   /** Puts *AIRBAG keywords into database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   int insertAirbagsIntoDB();
   /** Puts *ALE keywords into database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   int insertAlesIntoDB();
   /** Puts *BOUNDARY keywords into database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   int insertBoundarysIntoDB();
   /** Puts *COMPONENT keywords into database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   int insertComponentsIntoDB();
   /** Puts *CONSTRAINED keywords into database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   int insertConstraintsIntoDB();
   /** Puts *CONTACT keywords into database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   int insertContactsIntoDB();
   /** Puts *CONTROL keywords into database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   int insertControlsIntoDB();
   /** Puts *DAMPING keywords into database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   int insertDampingsIntoDB();
   /** Puts *DATABASE keywords into database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   int insertDatabasesIntoDB();
   /** Puts *DEFINE keywords into database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   int insertDefinesIntoDB();
   /** Puts *DEFORMABLE keywords into database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   int insertDeformsIntoDB();
   /** Puts *EF keywords into database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   int insertEfsIntoDB();
   /** Puts *EOS keywords into database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   int insertEossIntoDB();
   /** Puts *HOURGLASS keywords into database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   int insertHgsIntoDB();
   /** Puts *INCLUDE keywords into database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   int insertIncludesIntoDB();
   /** Puts *INITIAL keywords into database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   int insertInitialsIntoDB();
   /** Puts *INTEGRATION keywords into database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   int insertIntegrationsIntoDB();
   /** Puts *INTERFACE keywords into database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   int insertInterfacesIntoDB();
   /** Puts *LOAD keywords into database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   int insertLoadsIntoDB();
   /** Puts *MAT keywords into database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   int insertMatsIntoDB();
   /** Puts *PARAMETER keywords into database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   int insertParametersIntoDB();
   /** Puts *PART keywords into database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   int insertPartCsIntoDB();
   /** Puts *PERTUBATION keywords into database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   int insertPerturbsIntoDB();
   /** Puts *RAIL keywords into database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   int insertRailsIntoDB();
   /** Puts *RIGIDWALL keywords into database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   int insertRigidwallsIntoDB();
   /** Puts *SECTION keywords into database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   int insertSectionsIntoDB();
   /** Puts *SET keywords into database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   int insertSetsIntoDB();
   /** Puts *SENSOR keywords into database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   int insertSensorsIntoDB();
   /** Puts *TERMINATION keywords into database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   int insertTermsIntoDB();
   /** Puts *USER keywords into database
     * \return Returns 0 on SUCCESS else greater than 0
     */
   int insertUsersIntoDB();

   /** Inserts *CONTACT into database. For the last row or the last line '$' is 
     * added for each keyword 
     * \param max_num_fields Maximum number of fields in *CONTACT cards
     * \param table_name Name of table to which data is appended
     * \param man_ptr Manager pointer from which data is taken
     */
   int insertContactsIntoDBWithLastRowNull
       (
	  int      max_num_fields,
	  string & table_name,
	  Manager  *man_ptr
       );

   /** Not used */
   int insertModelDetailsIntoDB
       (
          const char *kw,
	  const char *title, 
	  const char *descr
       );

private:
   void getNullFields
	(
	   int & num_val, 
	   char *buff
	);

private:
   string        modelName;
   GoldenConn    *goldenConn;
};

#endif
