#ifndef _GET_DB_H_
#define _GET_DB_H_

#include  <string>
#include  <stdlib.h>
#include  <map>
#include  <GL/gl.h>
#include "goldenconn.h"
#include "node.h"
#include "shell.h"
#include "solid.h"
#include "part.h"
#include "mongodb.h"

using namespace std;

typedef enum _CompressionType
{
   NO_COMPRESSION,
   GZIP_COMPRESSION,
   BZIP_COMPRESSION
}
 CompressionType;

class GetDB
{
public:
   GetDB
   (
      const char *model_name,
      GoldenConn *gold_conn
   );

   GetDB(const char *model_name);

   ~GetDB();

   void setModelName(const char *model_name)
   {
       modelName = model_name;
       if( !strstr(model_name, "___") )
          modelName += "___";
   }

   int partsByElementType(unsigned int kw_type=ELEMENT_SHELL);

   int  shellElements(unsigned int nodeOffset);
   int  solidElements(unsigned int nodeOffset);

   int  nodes(float exts[6]);

   int writeDataToFiles
       (
           string    dir_name,
           unsigned int part_count,
           unsigned int draw_type = GL_QUADS,
           unsigned int compress_flag = GZIP_COMPRESSION,
           string *partDetailsJSON = NULL,
           bool modifyFlag = false,
           const char *timestep = NULL,
           int step = 0
       );

    int writeDataToFilesForResults
       (
           string    dir_name,
           unsigned int part_count,
           unsigned int draw_type = GL_QUADS,
           unsigned int compress_flag = GZIP_COMPRESSION,
           string *partDetailsJSON = NULL,
           bool modifyFlag = false,
           const char *timestep = NULL,
           int step = 0
       );

   int numPartsAndNodeExtents
       (
         int      *num_parts,
         float   exts[6]
       );

   static int writeGZIPFile
       (
         string & file_name,
         string & buf
       );

   static int writeFile
       (
         string & file_name,
         string & buf
       );

   void nodeExtents(float min_max[]);

   void partExtents(Part *part_ptr, float min_max[]);

   unsigned int numParts(){ return partMap.size(); }

   map<unsigned int, Node *> *GetNodeMap()
   {
       return &nodeMap;
   }

   map<unsigned int, Part *> *GetPartMap()
   {
       return &partMap;
   }

   static void deleteGetDB()
   {
       if(m_GetDB)
            delete m_GetDB;
       m_GetDB = NULL;
   }

   static void writeStartEndFiles(unsigned int total_parts, float exts[6], unsigned int wh[2], const char *dir_name);

   static void randomColor(float rgb[3]);
public:
   static GetDB               *m_GetDB;

private:
   string                     modelName;
   GoldenConn                *goldenConn;
   map<unsigned int, Node *> nodeMap;
   map<unsigned int, Part *> partMap;
   MongoDB                   *m_MongoDB;
};

class insertInto
{
public:
   insertInto(vector<Node *> & vect) : target(vect) {}
   void operator () (IDNodePtrPair iter)
   {
      target.push_back(iter.second);
   }

   void operator () (Node *iter)
   {
      target.push_back(iter);
   }

   vector<Node *> &target;
};

int getIncludeFilesFromDB
    (
       const char *main_file,
       GoldenConn *golden_conn,   
       vector<string> & files_list
    );

#endif

