#include <iostream>
#include <ostream>
#include <sstream>
#include <thread>
#include <vector>

#include "mongodb.h"
#include "oglcmds.h"
#include "getdb.h"
#include "filegeneric.h"

using bsoncxx::builder::basic::kvp;
using bsoncxx::builder::stream::finalize;
using bsoncxx::builder::stream::document;
using bsoncxx::builder::basic::make_document;
using bsoncxx::builder::basic::sub_array;
using bsoncxx::builder::stream::open_document;
using bsoncxx::builder::stream::close_document;

MongoDB             *MongoDB::m_MongoDB = NULL;

MongoDB::MongoDB(const char *email, const char *host, const char *user, const char *password, const char *port)
{
    if(host)
        m_Host = host;
    if(user)
        m_User = user;
    if(password)
        m_Password = password;   
    if(port)
        m_Port = port;
    m_MinPoolSize = "3";
    m_MaxPoolSize = "9";
    m_ConnStr = "mongodb://" + m_User + ":" + m_Password + "@" + m_Host + ":" + m_Port;
    m_ConnStr += "/?minPoolSize=" + m_MinPoolSize + "&maxPoolSize=" + m_MaxPoolSize;
    Init();
    std::string collName = "user";
    std::string sEMail = email;
    m_UserID = Create(collName, sEMail);
}

MongoDB::MongoDB(const char *email, const char *model)
{
    m_ConnStr = "mongodb://localhost:27017/?minPoolSize=3&maxPoolSize=9";
    Init();
    std::string collName = "user";
    std::string sEMail = email;
    m_UserID = Create(collName, sEMail);

    collName = "model";
    std::string sModel = model;
    m_ModelID = Create(collName, sModel);
}

MongoDB::~MongoDB()
{
}

void MongoDB::Init()
{
    // The mongocxx::instance constructor and destructor initialize and shut down the driver,
    // respectively. Therefore, a mongocxx::instance must be created before using the driver and
    // must remain alive for as long as the driver is in use.
    m_DBInstance = new mongocxx::instance{};
    mongocxx::uri uri{m_ConnStr};
    m_DBPool = new mongocxx::pool{uri};
}

std::string MongoDB::IsExists(std::string & name, std::string & value, mongocxx::pool::entry & client)
{
    auto coll = (*client)["caedb"][name + "s"];
    auto cursor = coll.find_one(document{} << name << value << finalize);
    if(cursor)
    {
        std::cout << value << " already exists" << std::endl;
        std::cout << bsoncxx::to_json(*cursor) << std::endl;
        std::cout << "ID=" << cursor->view()["_id"].get_oid().value.to_string();
        return cursor->view()["_id"].get_oid().value.to_string();
    }
    else
        return "";
}

std::string MongoDB::Create(std::string & coll_name, std::string & value)
{
    auto client = m_DBPool->acquire();
    auto oid_val = IsExists(coll_name, value, client);
    if(oid_val.empty())
    {
        auto coll = (*client)["caedb"][coll_name + "s"];
        auto ret_insert = coll.insert_one(bsoncxx::builder::basic::make_document(kvp(coll_name, value)));
        oid_val = ret_insert->inserted_id().get_oid().value.to_string();
    }
    return oid_val;
}

void MongoDB::CreateNodes(const char *timestep, const char *array_name, set<Node*> & nodeset, int step)
{
    auto client = m_DBPool->acquire();
    auto coll = (*client)["caedb"]["nodes"];
    std::string arrayName = array_name;
    
    auto cursor = coll.find_one(document{} << "timestep" << timestep 
            << "modelid" << m_ModelID << "userid" << m_UserID << "step" << step
            << arrayName << open_document << "$exists" << true << close_document
            << finalize);
    if(cursor)
        return;

    auto doc = bsoncxx::builder::basic::document{};
    //std::cout << "INSTEP=" << step << endl;
    doc.append(kvp(arrayName, [&](sub_array child) {
    set<Node*>::iterator bs_iter = nodeset.begin(), be_iter = nodeset.end();
    for (; bs_iter != be_iter; ++bs_iter) {
        child.append((*bs_iter)->x);
        child.append((*bs_iter)->y);
        child.append((*bs_iter)->z);
    }
    }), kvp("timestep", timestep), kvp("modelid", m_ModelID), kvp("userid", m_UserID),
        kvp("step", step));
    coll.insert_one(doc.view());
}

void MongoDB::CreateElements(const char *coll_name, const char *timestep, const char *array_name,
            const char *arrayBuf, vector<Element*> & elmList, int step, int part_index)
{
    auto client = m_DBPool->acquire();
    auto coll = (*client)["caedb"][coll_name];
    std::string sarray_name = array_name;
//cout << "COLL=" << coll_name << " timestep=" << timestep << " arry=" << array_name << " step=" << step << endl;
    auto cursor = coll.find_one(document{} << "timestep" << timestep << "arrayname" << array_name
            << "modelid" << m_ModelID << "userid" << m_UserID << "step" << step << "pindex" << part_index
            << sarray_name << open_document << "$exists" << true << close_document
            << finalize);
    if(cursor)
        return;

    auto doc = bsoncxx::builder::basic::document{};
    doc.append(kvp("nodeids", [&](sub_array child) {
    for (auto elm : elmList) {
        unsigned int num_nodes = elm->getNumNodes();
        const unsigned int *nodeIDList = elm->getNodeIDList();
        for(size_t nindex = 0; nindex < num_nodes; ++nindex) {
            child.append((int)nodeIDList[nindex]);
        }
    }
    }), kvp("timestep", timestep), kvp("modelid", m_ModelID), kvp("userid", m_UserID),
    kvp("step", step), kvp("arrayname", array_name), kvp("pindex", part_index), 
    kvp(sarray_name, arrayBuf));
    coll.insert_one(doc.view());
}

void MongoDB::CreateEntity(const char *coll_name, const char *array_name, vector<float> & enity_values, int part_index)
{
    //cout << "ARRAY=" << array_name << " PARTINDEX=" << part_index << endl;
    std::string arrayName = array_name;
    auto client = m_DBPool->acquire();
    auto coll = (*client)["caedb"][coll_name];
    
    auto cursor = coll.find_one(document{} << "modelid" << m_ModelID << "userid" << m_UserID 
            << "pindex" << part_index << "arrayname" << array_name
            << arrayName << open_document << "$exists" << true << close_document
            << finalize);
    if(cursor)
        return;

    auto doc = bsoncxx::builder::basic::document{};
    //std::cout << "INSTEP=" << step << endl;
    doc.append(kvp(arrayName, [&](sub_array child) {
    vector<float>::iterator bs_iter = enity_values.begin(), be_iter = enity_values.end();
    for (; bs_iter != be_iter; ++bs_iter) {
        child.append(*bs_iter);
    }
    }), kvp("modelid", m_ModelID), kvp("userid", m_UserID), kvp("arrayname", array_name), kvp("pindex", part_index));
    coll.insert_one(doc.view());
}

void MongoDB::CreateEntityForTimeStep(const char *timestep, const char *array_name, int num_values, float *entity_array, int step)
{
    auto client = m_DBPool->acquire();
    std::string arrayName = array_name;
    auto coll = (*client)["caedb"][arrayName];
    
    auto cursor = coll.find_one(document{} << "timestep" << timestep 
            << "modelid" << m_ModelID << "userid" << m_UserID << "step" << step
            << arrayName << open_document << "$exists" << true << close_document
            << finalize);
    if(cursor)
        return;

    auto doc = bsoncxx::builder::basic::document{};
    //std::cout << "INSTEP=" << step << endl;
    doc.append(kvp(arrayName, [&](sub_array child) {
    for (int iIndex = 0; iIndex < num_values; ++iIndex) {
        child.append(entity_array[iIndex]);
    }
    }), kvp("timestep", timestep), kvp("modelid", m_ModelID), kvp("userid", m_UserID),
        kvp("step", step));
    coll.insert_one(doc.view());
}

void MongoDB::GetData()
{
    auto node_client = m_DBPool->acquire();
    auto node_coll = (*node_client)["caedb"]["nodes"];
    auto node_cursor = node_coll.find(document{} << "userid" << m_UserID
                        << "modelid" << m_ModelID << finalize);

    auto shell_client = m_DBPool->acquire();
    auto shell_coll = (*shell_client)["caedb"]["shells"];

    auto solid_client = m_DBPool->acquire();
    auto solid_coll = (*solid_client)["caedb"]["solids"];

    unsigned int part_count = 0;
    int          intstep = 0;
    char    countBuf[64], valBuf[64];  
    for(auto doc : node_cursor)
    {
        auto array_key = doc.begin();
        ++array_key;
        auto keyStr = array_key->key();
        auto array_view = doc[keyStr].get_array().value;
        string node_str = keyStr.to_string() + "=[";
        for(auto elm : array_view)
        {
            sprintf(valBuf, "%g", elm.get_double().value);
            node_str += valBuf;
            node_str += ",";
        }
        node_str.pop_back();
        node_str += "];\n";
        auto timestep = doc["timestep"].get_utf8().value.to_string();
        auto step_int = doc["step"].type();
        string step;
        int newstep = -1;
        if(step_int == bsoncxx::type::k_decimal128)
            step = doc["step"].get_decimal128().value.to_string();
        else if(step_int == bsoncxx::type::k_int32)
        {
            newstep = doc["step"].get_int32().value;
            step = to_string(newstep);
        }
        else if(step_int == bsoncxx::type::k_int64)
            step = to_string(doc["step"].get_int64().value);

        if(newstep != intstep)
        {
            part_count = 0;
            intstep = newstep;
        }
    
        auto shell_doc = shell_coll.find_one(document{} << "userid" << m_UserID 
                        << "modelid" << m_ModelID << "step" << intstep 
                        << "timestep" << timestep << "pindex" << (int)part_count << finalize);

        if(shell_doc)
        {
            auto shell_view = shell_doc->view();
            auto key = shell_view["arrayname"].get_utf8().value.to_string();
            auto array_buf = shell_view[key].get_utf8().value.to_string();
            node_str += key + "=[" + array_buf;
        }
        else
        {
            auto solid_doc = solid_coll.find_one(document{} << "userid" << m_UserID 
                        << "modelid" << m_ModelID << "step" << intstep 
                        << "timestep" << timestep << "pindex" << (int)part_count << finalize);
            if(solid_doc)
            {
                auto solid_view = solid_doc->view();
                auto key = solid_view["arrayname"].get_utf8().value.to_string();
                auto array_buf = solid_view[key].get_utf8().value.to_string();
                node_str += key + "=[" + array_buf;
            }
        }

        if(!intstep)
            OglCmds::getPartCmd(part_count, node_str, GL_TRIANGLES);
        else
            OglCmds::getPartCmdModify(part_count, node_str, GL_TRIANGLES);

        sprintf(countBuf, "/part_%d.js", part_count);
        string dir_name = m_DirName + step;
        _mkdir(dir_name.data());
        string file_name = m_DirName + step + countBuf;
        //cout << "OUTFILENAME=" << file_name << " PART COUNT=" << part_count << endl;
        GetDB::writeGZIPFile(file_name, node_str);
        ++part_count;
    }
}

void MongoDB::GetAllGlobalResults()
{
    set<string> resultSet = {"Time Steps", "Global Kinetic Energy", "Global Internal Energy", 
	    "Global Total Energy", "Global X Velocity", "Global Y Velocity", "Global Z Velocity"};
    string res_str;
    for(auto coll : resultSet)
        GetGlobalResults(coll.data(), res_str);

    string file_name = m_DirName + string("global.js") ;
    GetDB::writeGZIPFile(file_name, res_str);
}

void MongoDB::GetGlobalResults(const char *collName, string & res_str)
{
    auto result_client = m_DBPool->acquire();
    auto res_coll = (*result_client)["caedb"][collName];

    auto res_cursor = res_coll.find(document{} << "userid" << m_UserID
                        << "modelid" << m_ModelID << finalize);
    char    valBuf[64];  

    for(auto doc : res_cursor)
    {
        auto array_key = doc.begin();
        ++array_key;
        auto keyStr = array_key->key();
        auto array_view = doc[keyStr].get_array().value;
        res_str += keyStr.to_string() + "=[";
        for(auto elm : array_view)
        {
            sprintf(valBuf, "%g", elm.get_double().value);
            res_str += valBuf;
            res_str += ",";
        }
        res_str.pop_back();
        res_str += "];\n";
    }
}

void MongoDB::GetAllPartResults()
{
    set<string> resultSet = {"Kinetic Energy", "Internal Energy", "HourGlass Energy",
        "X Velocity", "Y Velocity", "Z Velocity"};
    for(auto coll : resultSet)
    {
        string  coll_name = coll;
        auto end_iter = std::remove(coll_name.begin(), coll_name.end(), ' ');
        string  res_name(coll_name.begin(), end_iter);
        string  res_str, array_str = res_name + string("=[");
        GetPartResults(coll.data(), res_str, array_str);
	array_str += "];";
	res_str += array_str;
        string  file_name = m_DirName + res_name + string(".js");
        GetDB::writeGZIPFile(file_name, res_str);
    }
}

void MongoDB::GetPartResults(const char *collName, string & res_str, string & array_str)
{
    auto result_client = m_DBPool->acquire();
    auto ts_coll = (*result_client)["caedb"][collName];

    auto ts_cursor = ts_coll.find(document{} << "userid" << m_UserID
                        << "modelid" << m_ModelID << finalize);
    char    valBuf[64];  

    for(auto doc : ts_cursor)
    {
        auto array_key = doc.begin();
        ++array_key;
        auto keyStr = array_key->key();
        auto array_view = doc[keyStr].get_array().value;
        res_str += keyStr.to_string() + "=[";
	array_str += keyStr.to_string() + ",";
        for(auto elm : array_view)
        {
            sprintf(valBuf, "%g", elm.get_double().value);
            res_str += valBuf;
            res_str += ",";
        }
        res_str.pop_back();
        res_str += "];\n";
    }
    if(!array_str.empty())
	array_str.erase(array_str.size()-1);
}
