#include <iostream>
#include <time.h>
#include <set>
#include "bdrymanager.h"
#include "bdryexport.h"
#include "bdryimport.h"
#include "myconnection.h"
#include "filepath.h"
#include "filegeneric.h"
#include "dynatobin.h"

using namespace std;
map<string, string> MyConnection::nvMap;
unsigned int Card::contFlag = 0;

int main(int argc, char* argv[])
{
   if( argc < 3 )
   {
      cout << "Usage: boundary dir_name model_name" << endl;
      return 1;
   }

   time_t			t1, t2;
   time(&t1);

   GoldenConn *goldenConn = MyConnection::get();

   if( !goldenConn )
      return 1;

   FilePath::set(argv[1], argv[2]);
   unsigned int bdry_type = BDRY_NEW_TYPE, bdry_id;
   string select_query, model_name, kw_name = "*BOUNDARY";

   if( argc > 3 )
   {
      kw_name = "*";
      kw_name += argv[3];
      bdry_type = BdryImport::getBdryTypeFromKeyword(kw_name.data(), &bdry_id);
   }

   int file_idx = getFileName(argv[2], model_name);Card::setFlag(SAVE_IDS|SAVE_REFERENCES);
   model_name += "__";

   select_query = "show table status like \'";
   select_query += model_name;
   select_query += "_BOUNDARYS\';";

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      delete goldenConn;
      return 2;
   }

   if( !goldenConn->nextRow() ) 
   {
cout << "WARNING: No boundary table for model=" << argv[2] << endl;
      delete goldenConn;
      return 3;
   }

   TransformStr trans_str;
   if( file_idx )
   {
      getTransformPtr(FilePath::fPath, file_idx, &trans_str);
      FilePath::setTransPtr(&trans_str);
   }

   BdryManager *man_ptr = BdryManager::create();
   BdryExport bdry_exp((char *)model_name.data(), goldenConn, man_ptr);

   int num_bdry = bdry_exp.dbReadBdrys();

   if( !num_bdry )
   {
cout << "WARNING: No boundary kws available for model<" << argv[2] << ">\n";
      delete goldenConn;
      return 4;
   }

   DynaToBin dtob(argv[1], argv[2], man_ptr);
   dtob.write("boundary");

   FilePath::closeIDFile();
   FilePath::closeFile();
   BdryManager::reset();
   delete goldenConn;

   time(&t2);
   cout << "TIME FOR BDRY FROM DB= " << difftime(t2, t1) << endl;

   return 0;
}

