#include <iostream>
#include <time.h>
#include <set>
#include "controlmanager.h"
#include "controlexport.h"
#include "controlimport.h"
#include "myconnection.h"
#include "filepath.h"
#include "filegeneric.h"
#include "dynatobin.h"

using namespace std;
map<string, string> MyConnection::nvMap;
unsigned int Card::contFlag = 0;

int main(int argc, char* argv[])
{
   if( argc < 3 )
   {
      cout << "Usage: control dir_name model_name" << endl;
      return 1;
   }

   time_t			t1, t2;
   time(&t1);

   GoldenConn *goldenConn = MyConnection::get();

   if( !goldenConn )
      return 1;

   FilePath::set(argv[1], argv[2]);
   unsigned int control_type = CONTROL_NEW_TYPE, control_id;
   string select_query, model_name, kw_name = "*CONTROL";

   if( argc > 3 )
   {
      kw_name = "*";
      kw_name += argv[3];
      control_type = ControlImport::getControlTypeFromKeyword(
                                         kw_name.data(), &control_id);
   }

   int file_idx = getFileName(argv[2], model_name);Card::setFlag(SAVE_IDS|SAVE_REFERENCES);
   model_name += "__";

   select_query = "show table status like \'";
   select_query += model_name;
   select_query += "_CONTROLS\';";

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      delete goldenConn;
      return 2;
   }

   if( !goldenConn->nextRow() ) 
   {
cout << "WARNING: No control table for model=" << argv[2] << endl;
      delete goldenConn;
      return 3;
   }

   TransformStr trans_str;
   if( file_idx )
   {
      getTransformPtr(FilePath::fPath, file_idx, &trans_str);
      FilePath::setTransPtr(&trans_str);
   }

   ControlManager *control_man = ControlManager::create();
   ControlExport control_exp((char *)model_name.data(),goldenConn,control_man);

   int num_control = control_exp.dbReadControls();

   if( !num_control )
   {
cout << "WARNING: No control available for model<" << argv[2] << ">\n";
      delete goldenConn;
      return 4;
   }

   DynaToBin dtob(argv[1], argv[2], control_man);
   dtob.write("control");

   FilePath::closeIDFile();
   FilePath::closeFile();
   ControlManager::reset();
   delete goldenConn;

   time(&t2);
   cout << "TIME FOR CONTROLS FROM DB= " << difftime(t2, t1) << endl;

   return 0;
}

