#include <iostream>
#include <time.h>
#include <set>
#include "dampingmanager.h"
#include "dampingexport.h"
#include "dampingimport.h"
#include "myconnection.h"
#include "filepath.h"
#include "filegeneric.h"
#include "dynatobin.h"

using namespace std;
map<string, string> MyConnection::nvMap;
unsigned int Card::contFlag = 0;

int main(int argc, char* argv[])
{
   if( argc < 3 )
   {
      cout << "Usage: damping dir_name model_name" << endl;
      return 1;
   }

   time_t			t1, t2;
   time(&t1);

   GoldenConn *goldenConn = MyConnection::get();

   if( !goldenConn )
      return 1;

   FilePath::set(argv[1], argv[2]);
   unsigned int damping_type = DAMPING_NEW_TYPE, damping_id;
   string select_query, model_name, kw_name = "*DAMPING";

   if( argc > 3 )
   {
      kw_name = "*";
      kw_name += argv[3];
      damping_type = DampingImport::getDampingTypeFromKeyword(
                                           kw_name.data(), &damping_id);
   }

   int file_idx = getFileName(argv[2], model_name);Card::setFlag(SAVE_IDS|SAVE_REFERENCES);
   model_name += "__";

   select_query = "show table status like \'";
   select_query += model_name;
   select_query += "_DAMPINGS\';";

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      delete goldenConn;
      return 2;
   }

   if( !goldenConn->nextRow() ) 
   {
cout << "WARNING: No damping table for model=" << argv[2] << endl;
      delete goldenConn;
      return 3;
   }

   TransformStr trans_str;
   if( file_idx )
   {
      getTransformPtr(FilePath::fPath, file_idx, &trans_str);
      FilePath::setTransPtr(&trans_str);
   }

   DampingManager *damping_man = DampingManager::create();
   DampingExport damping_exp((char *)model_name.data(),goldenConn,damping_man);

   int num_damping = damping_exp.dbReadDampings();

   if( !num_damping )
   {
cout << "WARNING: No damping available for model<" << argv[2] << ">\n";
      delete goldenConn;
      return 4;
   }

   DynaToBin dtob(argv[1], argv[2], damping_man);
   dtob.write("damping");

   FilePath::closeIDFile();
   FilePath::closeFile();
   DampingManager::reset();
   delete goldenConn;

   time(&t2);
   cout << "TIME FOR DAMPING FROM DB= " << difftime(t2, t1) << endl;

   return 0;
}

