#include <iostream>
#include <time.h>
#include <set>
#include "definemanager.h"
#include "defineexport.h"
#include "defineimport.h"
#include "myconnection.h"
#include "filepath.h"
#include "filegeneric.h"
#include "dynatobin.h"

using namespace std;
map<string, string> MyConnection::nvMap;
unsigned int Card::contFlag = 0;

int main(int argc, char* argv[])
{
   if( argc < 3 )
   {
      cout << "Usage: define dir_name model_name" << endl;
      return 1;
   }

   time_t			t1, t2;
   time(&t1);

   GoldenConn *goldenConn = MyConnection::get();

   if( !goldenConn )
      return 1;

   FilePath::set(argv[1], argv[2]);
   unsigned int define_type = DEFINE_NEW_TYPE, define_id;
   string select_query, model_name, kw_name = "*DEFINE";

   if( argc > 3 )
   {
      kw_name = "*";
      kw_name += argv[3];
      define_type = DefineImport::getDefineTypeFromKeyword(
                                           kw_name.data(), &define_id);
      if( strstr(kw_name.data(), "_TITL") )
         define_type += TITLE_CARD; 
   }

   int file_idx = getFileName(argv[2], model_name);Card::setFlag(SAVE_IDS|SAVE_REFERENCES);
   model_name += "__";

   select_query = "show table status like \'";
   select_query += model_name;
   select_query += "_DEFINES\';";

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      delete goldenConn;
      return 2;
   }

   if( !goldenConn->nextRow() ) 
   {
cout << "WARNING: No define table for model=" << argv[2] << endl;
      delete goldenConn;
      return 3;
   }

   TransformStr trans_str;
   if( file_idx )
   {
      getTransformPtr(FilePath::fPath, file_idx, &trans_str);
      FilePath::setTransPtr(&trans_str);
   }

   DefineManager *define_man = DefineManager::create();
   DefineExport define_exp((char *)model_name.data(), goldenConn, define_man);

   int num_define = define_exp.dbReadDefines();

cout << "NUM DEFINES=" << num_define << endl;

   if( !num_define )
   {
cout << "WARNING: No define available for model<" << argv[2] << ">\n";
      delete goldenConn;
      return 4;
   }

   DynaToBin dtob(argv[1], argv[2], define_man);
   dtob.write("define");

   FilePath::closeIDFile();
   FilePath::closeFile();
   DefineManager::reset();
   delete goldenConn;

   time(&t2);
   cout << "TIME FOR DEFINE FROM DB= " << difftime(t2, t1) << endl;

   return 0;
}

