#include <iostream>
#include <time.h>
#include <set>
#include "eosmanager.h"
#include "eosexport.h"
#include "eosimport.h"
#include "myconnection.h"
#include "filepath.h"
#include "filegeneric.h"
#include "dynatobin.h"

using namespace std;
map<string, string> MyConnection::nvMap;
unsigned int Card::contFlag = 0;

int main(int argc, char* argv[])
{
   if( argc < 3 )
   {
      cout << "Usage: eos dir_name model_name" << endl;
      return 1;
   }

   time_t	t1, t2;
   time(&t1);

   GoldenConn *goldenConn = MyConnection::get();

   if( !goldenConn )
      return 1;

   FilePath::set(argv[1], argv[2]);
   unsigned int eos_type = EOS_NEW_TYPE, eos_id;
   string select_query, model_name, kw_name = "*EOS";

   if( argc > 3 )
   {
      kw_name = "*";
      kw_name += argv[3];
      eos_type = EosImport::getEosTypeFromKeyword(kw_name.data(), &eos_id);
      if( strstr(kw_name.data(), "_TITL") )
         eos_type += TITLE_CARD;
   }

   int file_idx = getFileName(argv[2], model_name);Card::setFlag(SAVE_IDS|SAVE_REFERENCES);
   model_name += "__";

   select_query = "show table status like \'";
   select_query += model_name;
   select_query += "_EOSS\';";

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      delete goldenConn;
      return 2;
   }

   if( !goldenConn->nextRow() ) 
   {
cout << "WARNING: No eos table for model=" << argv[2] << endl;
      delete goldenConn;
      return 3;
   }

   TransformStr trans_str;
   if( file_idx )
   {
      getTransformPtr(FilePath::fPath, file_idx, &trans_str);
      FilePath::setTransPtr(&trans_str);
   }

   EosManager *eos_man = EosManager::create();
   EosExport eos_exp((char *)model_name.data(), goldenConn, eos_man);

   int num_eos = eos_exp.dbReadEoss();

   if( !num_eos )
   {
cout << "WARNING: No eos available for model<" << argv[2] << ">\n";
      delete goldenConn;
      return 4;
   }

   DynaToBin dtob(argv[1], argv[2], eos_man);
   dtob.write("eos");

   FilePath::closeIDFile();
   FilePath::closeFile();
   EosManager::reset();
   delete goldenConn;

   time(&t2);
   cout << "TIME FOR EOS FROM DB= " << difftime(t2, t1) << endl;

   return 0;
}

