#include <iostream>
#include <time.h>
#include <set>
#include "integrationmanager.h"
#include "integrationexport.h"
#include "integrationimport.h"
#include "myconnection.h"
#include "filepath.h"
#include "filegeneric.h"
#include "dynatobin.h"

using namespace std;
map<string, string> MyConnection::nvMap;
unsigned int Card::contFlag = 0;

int main(int argc, char* argv[])
{
   if( argc < 3 )
   {
      cout << "Usage: integration dir_name model_name" << endl;
      return 1;
   }

   time_t			t1, t2;
   time(&t1);

   GoldenConn *goldenConn = MyConnection::get();

   if( !goldenConn )
      return 1;

   FilePath::set(argv[1], argv[2]);
   unsigned int integration_type = INTEGRATION_NEW_TYPE, integration_id;
   string select_query, model_name, kw_name = "*INTEGRATION";

   if( argc > 3 )
   {
      kw_name = "*";
      kw_name += argv[3];
      integration_type = IntegrationImport::getIntegrationTypeFromKeyword(
                                        kw_name.data(), &integration_id);
   }

   int file_idx = getFileName(argv[2], model_name);Card::setFlag(SAVE_IDS|SAVE_REFERENCES);
   model_name += "__";

   select_query = "show table status like \'";
   select_query += model_name;
   select_query += "_INTEGRATIONS\';";

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      delete goldenConn;
      return 2;
   }

   if( !goldenConn->nextRow() ) 
   {
cout << "WARNING: No integration table for model=" << argv[2] << endl;
      delete goldenConn;
      return 3;
   }

   TransformStr trans_str;
   if( file_idx )
   {
      getTransformPtr(FilePath::fPath, file_idx, &trans_str);
      FilePath::setTransPtr(&trans_str);
   }

   IntegrationManager *integration_man = IntegrationManager::create();
   IntegrationExport integration_exp((char *)model_name.data(), goldenConn, integration_man);

   int num_integration = integration_exp.dbReadIntegrations();

   if( !num_integration )
   {
cout << "WARNING: No integration available for model<" << argv[2] << ">\n";
      delete goldenConn;
      return 4;
   }

   DynaToBin dtob(argv[1], argv[2], integration_man);
   dtob.write("integration");

   FilePath::closeIDFile();
   FilePath::closeFile();
   IntegrationManager::reset();
   delete goldenConn;

   time(&t2);
   cout << "TIME FOR INTEGRATION FROM DB= " << difftime(t2, t1) << endl;

   return 0;
}

