#include <iostream>
#include <time.h>
#include <set>
#include "matmanager.h"
#include "matexport.h"
#include "matimport.h"
#include "myconnection.h"
#include "filepath.h"
#include "filegeneric.h"
#include "dynatobin.h"

using namespace std;
map<string, string> MyConnection::nvMap;
unsigned int Card::contFlag = 0;

int main(int argc, char* argv[])
{
   if( argc < 3 )
   {
      cout << "Usage: mat dir_name model_name" << endl;
      return 1;
   }

   time_t			t1, t2;
   time(&t1);

   GoldenConn *goldenConn = MyConnection::get();

   if( !goldenConn )
      return 1;

   FilePath::set(argv[1], argv[2]);
   unsigned int mat_type = MAT_NEW_TYPE, mat_id;
   string kw_name = "*MAT", select_query, model_name;

   if( argc > 3 )
   {
      kw_name = "*";
      kw_name += argv[3];
      mat_type = MatImport::getMatTypeFromKeyword(kw_name.data(), &mat_id);
      if( strstr(kw_name.data(), "_TITL") )
         mat_type += TITLE_CARD;
   }

   int file_idx = getFileName(argv[2], model_name);Card::setFlag(SAVE_IDS|SAVE_REFERENCES);
   model_name += "__";

   select_query = "show table status like \'";
   select_query += model_name;
   select_query += "_MATS\';";

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      delete goldenConn;
      return 2;
   }

   if( !goldenConn->nextRow() ) 
   {
cout << "WARNING: No mat table for model=" << argv[2] << endl;
      delete goldenConn;
      return 3;
   }

   TransformStr trans_str;
   if( file_idx )
   {
      getTransformPtr(FilePath::fPath, file_idx, &trans_str);
      FilePath::setTransPtr(&trans_str);
   }

   MatManager *mat_man = MatManager::create();
   MatExport mat_exp((char *)model_name.data(), goldenConn, mat_man);

   int num_mat = mat_exp.dbReadMats();

   if( !num_mat )
   {
cout << "WARNING: No mat available for model<" << argv[2] << ">\n";
      delete goldenConn;
      return 4;
   }

   DynaToBin dtob(argv[1], argv[2], mat_man);
   dtob.write("mat");

   FilePath::closeIDFile();
   FilePath::closeFile();
   MatManager::reset();
   delete goldenConn;

   time(&t2);
   cout << "TIME FOR MAT FROM DB= " << difftime(t2, t1) << endl;

   return 0;
}

