#include <iostream>
#include <time.h>
#include <set>
#include "perturbmanager.h"
#include "perturbexport.h"
#include "perturbimport.h"
#include "myconnection.h"
#include "filepath.h"
#include "filegeneric.h"
#include "dynatobin.h"

using namespace std;
map<string, string> MyConnection::nvMap;
unsigned int Card::contFlag = 0;

int main(int argc, char* argv[])
{
   if( argc < 3 )
   {
      cout << "Usage: perturb dir_name model_name" << endl;
      return 1;
   }

   time_t			t1, t2;
   time(&t1);

   GoldenConn *goldenConn = MyConnection::get();

   if( !goldenConn )
      return 1;

   FilePath::set(argv[1], argv[2]);
   unsigned int perturb_type = PERTURB_NEW_TYPE, perturb_id;
   string kw_name = "*PERTURBATION", select_query, model_name;

   if( argc > 3 )
   {
      kw_name = "*";
      kw_name += argv[3];
      perturb_type = PerturbImport::getPerturbTypeFromKeyword(
                                        kw_name.data(), &perturb_id);
   }

   int file_idx = getFileName(argv[2], model_name);Card::setFlag(SAVE_IDS|SAVE_REFERENCES);
   model_name += "__";

   select_query = "show table status like \'";
   select_query += model_name;
   select_query += "_PERTURBATIONS\';";

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      delete goldenConn;
      return 2;
   }

   if( !goldenConn->nextRow() ) 
   {
cout << "WARNING: No perturb table for model=" << argv[2] << endl;
      delete goldenConn;
      return 3;
   }

   TransformStr trans_str;
   if( file_idx )
   {
      getTransformPtr(FilePath::fPath, file_idx, &trans_str);
      FilePath::setTransPtr(&trans_str);
   }

   PerturbManager *perturb_man = PerturbManager::create();
   PerturbExport perturb_exp((char *)model_name.data(), goldenConn, perturb_man);

   int num_perturb = perturb_exp.dbReadPerturbs();

   if( !num_perturb )
   {
cout << "WARNING: No perturb available for model<" << argv[2] << ">\n";
      delete goldenConn;
      return 4;
   }

   DynaToBin dtob(argv[1], argv[2], perturb_man);
   dtob.write("perturbation");

   FilePath::closeIDFile();
   FilePath::closeFile();
   PerturbManager::reset();
   delete goldenConn;

   time(&t2);
   cout << "TIME FOR PERTURBATION FROM DB= " << difftime(t2, t1) << endl;

   return 0;
}

