#include <iostream>
#include <time.h>
#include <set>
#include "rigidwallmanager.h"
#include "rigidwallexport.h"
#include "rigidwallimport.h"
#include "myconnection.h"
#include "filepath.h"
#include "filegeneric.h"
#include "dynatobin.h"

using namespace std;
map<string, string> MyConnection::nvMap;
unsigned int Card::contFlag = 0;

int main(int argc, char* argv[])
{
   if( argc < 3 )
   {
      cout << "Usage: rigidwall dir_name model_name" << endl;
      return 1;
   }

   time_t			t1, t2;
   time(&t1);

   GoldenConn *goldenConn = MyConnection::get();

   if( !goldenConn )
      return 1;

   FilePath::set(argv[1], argv[2]);
   unsigned int rigidwall_type = RIGIDWALL_NEW_TYPE;
   string kw_name = "*RIGIDWALL", select_query, model_name;

   if( argc > 3 )
   {
      kw_name = "*";
      kw_name += argv[3];
      RigidwallImport::getRigidwallTypeFromKeyword(
                                    kw_name.data(), &rigidwall_type);
   }

   int file_idx = getFileName(argv[2], model_name);Card::setFlag(SAVE_IDS|SAVE_REFERENCES);
   model_name += "__";

   select_query = "show table status like \'";
   select_query += model_name;
   select_query += "_RIGIDWALLS\';";

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      delete goldenConn;
      return 2;
   }

   if( !goldenConn->nextRow() ) 
   {
cout << "WARNING: No rigidwall table for model=" << argv[2] << endl;
      delete goldenConn;
      return 3;
   }

   TransformStr trans_str;
   if( file_idx )
   {
      getTransformPtr(FilePath::fPath, file_idx, &trans_str);
      FilePath::setTransPtr(&trans_str);
   }

   RigidwallManager *rigidwall_man = RigidwallManager::create();
   RigidwallExport rigidwall_exp((char *)model_name.data(), goldenConn, rigidwall_man);

   int num_rigidwall = rigidwall_exp.dbReadRigidwalls();

   if( !num_rigidwall )
   {
cout << "WARNING: No rigidwall available for model<" << argv[2] << ">\n";
      delete goldenConn;
      return 4;
   }

   DynaToBin dtob(argv[1], argv[2], rigidwall_man);
   dtob.write("rigidwall");

   FilePath::closeIDFile();
   FilePath::closeFile();
   RigidwallManager::reset();
   delete goldenConn;

   time(&t2);
   cout << "TIME FOR RIGIDWALL FROM DB= " << difftime(t2, t1) << endl;

   return 0;
}

