#include <iostream>
#include <time.h>
#include <set>
#include "sensormanager.h"
#include "sensorexport.h"
#include "sensorimport.h"
#include "myconnection.h"
#include "filepath.h"
#include "filegeneric.h"
#include "dynatobin.h"

using namespace std;
map<string, string> MyConnection::nvMap;
unsigned int Card::contFlag = 0;

int main(int argc, char* argv[])
{
   if( argc < 3 )
   {
      cout << "Usage: sensor dir_name model_name" << endl;
      return 1;
   }

   time_t			t1, t2;
   time(&t1);

   GoldenConn *goldenConn = MyConnection::get();

   if( !goldenConn )
      return 1;

   FilePath::set(argv[1], argv[2]);
   unsigned int sensor_type = SENSOR_NEW_TYPE, sensor_id;
   string kw_name = "*SENSOR", select_query, model_name;

   if( argc > 3 )
   {
      kw_name = "*";
      kw_name += argv[3];
      sensor_type = SensorImport::getSensorTypeFromKeyword(
                                       kw_name.data(), &sensor_id);
   }

   int file_idx = getFileName(argv[2], model_name);Card::setFlag(SAVE_IDS|SAVE_REFERENCES);
   model_name += "__";

   select_query = "show table status like \'";
   select_query += model_name;
   select_query += "_SENSORS\';";

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      delete goldenConn;
      return 2;
   }

   if( !goldenConn->nextRow() ) 
   {
cout << "WARNING: No sensor table for model=" << argv[2] << endl;
      delete goldenConn;
      return 3;
   }

   TransformStr trans_str;
   if( file_idx )
   {
      getTransformPtr(FilePath::fPath, file_idx, &trans_str);
      FilePath::setTransPtr(&trans_str);
   }

   SensorManager *sensor_man = SensorManager::create();
   SensorExport sensor_exp((char *)model_name.data(), goldenConn, sensor_man);

   int num_sensor = sensor_exp.dbReadSensors();

   if( !num_sensor )
   {
cout << "WARNING: No sensor available for model<" << argv[2] << ">\n";
      delete goldenConn;
      return 4;
   }

   DynaToBin dtob(argv[1], argv[2], sensor_man);
   dtob.write("sensor");

   FilePath::closeIDFile();
   FilePath::closeFile();
   SensorManager::reset();
   delete goldenConn;

   time(&t2);
   cout << "TIME FOR SENSOR FROM DB= " << difftime(t2, t1) << endl;

   return 0;
}

