#include <iostream>
#include <time.h>
#include <set>
#include "termmanager.h"
#include "termexport.h"
#include "termimport.h"
#include "myconnection.h"
#include "filepath.h"
#include "filegeneric.h"
#include "dynatobin.h"

using namespace std;
map<string, string> MyConnection::nvMap;
unsigned int Card::contFlag = 0;

int main(int argc, char* argv[])
{
   if( argc < 3 )
   {
      cout << "Usage: term dir_name model_name" << endl;
      return 1;
   }

   time_t			t1, t2;
   time(&t1);

   GoldenConn *goldenConn = MyConnection::get();

   if( !goldenConn )
      return 1;

   FilePath::set(argv[1], argv[2]);
   unsigned int term_type = TERM_NEW_TYPE, term_id;
   string select_query, model_name, kw_name = "*TERMINATION";

   if( argc > 3 )
   {
      kw_name = "*";
      kw_name += argv[3];
      term_type = TermImport::getTermTypeFromKeyword(kw_name.data(), &term_id);
   }

   int file_idx = getFileName(argv[2], model_name);Card::setFlag(SAVE_IDS|SAVE_REFERENCES);
   model_name += "__";

   select_query = "show table status like \'";
   select_query += model_name;
   select_query += "_TERMINATIONS\';";

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      delete goldenConn;
      return 2;
   }

   if( !goldenConn->nextRow() ) 
   {
cout << "WARNING: No term table for model=" << argv[2] << endl;
      delete goldenConn;
      return 3;
   }

   TransformStr trans_str;
   if( file_idx )
   {
      getTransformPtr(FilePath::fPath, file_idx, &trans_str);
      FilePath::setTransPtr(&trans_str);
   }

   TermManager *term_man = TermManager::create();
   TermExport term_exp((char *)model_name.data(), goldenConn, term_man);

   int num_term = term_exp.dbReadTerms();

   if( !num_term )
   {
cout << "WARNING: No term available for model<" << argv[2] << ">\n";
      delete goldenConn;
      return 4;
   }

   DynaToBin dtob(argv[1], argv[2], term_man);
   dtob.write("termination");

   FilePath::closeIDFile();
   FilePath::closeFile();
   TermManager::reset();
   delete goldenConn;

   time(&t2);
   cout << "TIME FOR TERM FROM DB= " << difftime(t2, t1) << endl;

   return 0;
}

