#ifndef _DB_TO_HTML_GEN_H_
#define _DB_TO_HTML_GEN_H_

#include <set>
#include <string>
#include "manager.h"
#include "myconnection.h"
#include "filegeneric.h"

#define COUNT_LIMIT 1000

using namespace std;

typedef map<string, unsigned int> StrUIMap;
typedef map<string, unsigned int>::iterator StrUIIterator;
typedef pair<string, unsigned int> StrUIPair;

/** Class to generate HTML and JavaScript code. The data from database is assigned
  * to SESSION using PHP code. The html shown in Entity List Frame in web
  * interface is generated by this class.
  */
class DBToHtml
{
public:
   /** Constructor to create this object
     * \param man_ptr Manager pointer to which the keyword belongs to.
     * \param kw_list List of keywords available for the group
     */
   DBToHtml(Manager *man_ptr, StrUIMap *kw_list = NULL)
   {
      manPtr = man_ptr;
      if( !kw_list )
         getKeywords();
      else
         kwListMap = kw_list;
   }

   /** Function to get the list of entities as JavaScript
     * \param script_str String to which the JavaScript code to be appended
     */
   void getKeywordsJSCode(string & script_str);

   /** Function to get the count from the given range. For nodes and elements
     * the ranges are shown based on their count
     * \param count Count of entities
     * \param count_str List of ranges in string form to return
     */
   void getRangeFromCount
	(
	   unsigned int & count, 
	   string & count_str
	);

   /** Function to get JavaScript code for showing the list of model entity
     * groups, model keywords and a list for a particular keyword type. The
     * Edit, Delete, HL, Sel, ON/OFF buttons code is written in html here
     * \param kw_type Type of Keyword for which the entity list is required
     * \param input_kw Name of the keyword
     * \param html_str The string to which the html code is to be appended
     * \param total_ent Total number of entities in a particular keyword. Based
     * this count, ranges are decided.
     * \param edit_index Card index of the entity selected for editing on web
     * interface
     * \param edit_str The PHP code for editing the selected entity
     */
   ImportObject* getJSCode
	(
           unsigned int & kw_type,
	   string & input_kw,
	   string & html_str,
	   unsigned int total_ent = COUNT_LIMIT,
           unsigned int edit_index = 0,
           string *edit_str = NULL
	);

   /** Builds a map for keywords and keyword types */
   void getKeywords();

   /** Clears the memory and writes a blank page when there no entities
     * for a particular type of keyword
     * \param dir_name Name of the directory
     * \param conn GoldenConn object for accessing the database
     * \param fp File pointer to which this blank page to write
     * \param title Name of the keyword
     */
   static void cleanAndWriteBlankPage
	       (
                  char *dir_name,
                  GoldenConn *conn,
		  FILE     *fp,
		  string title
	       );

   /** Creates the HTML code for the given model keyword and edit entity index
     * to show in Entity List Frame and to fill the data from database for
     * editing
     * \param user_str String to which the HTML code is appended
     * \param kw_type Type of keyword
     * \param edit_index Card index for the entity to edit
     * \param ret_card_idx Index of the card in database
     * \param total Total number of cards in database
     * \param ret_obj The ImportObject in which the edit object is located
     */
   void getHtml
	(
	   string & user_str,
	   unsigned int & kw_type,
	   unsigned int edit_index = 0,
	   unsigned int *ret_card_idx = NULL,
	   unsigned int *total = NULL,
	   ImportObject **ret_obj = NULL
	);

   /** Function to create an edit file with PHP code for editing the entity
     * \param card_index Index of the card in database
     * \param total Total number of cards in database
     * \param imp_obj ImportObject to which this entity belongs to
     * \param edit_str String to return the edit php code
     */
   void createEditFile
	(
	   unsigned int & card_index, 
	   unsigned int & total, 
	   ImportObject *imp_obj,
           string *edit_str
	);

   /** Converts the card data to session data using PHP code
     * \param idx Index of the card which is to be converted
     * \param imp_obj Object which has the data
     * \param card Card object which has the data
     * \param edit_str String that holds the return php code
     */
   void getCardStr
	(
	   unsigned int & idx, 
	   ImportObject *imp_obj, 
	   Card *card, 
	   string *edit_str
	);

   /** Converts the field data into string
     * \param fld_idx Index of the field
     * \param card_name Name of the card
     * \param vname Name of variable or field
     * \param buf Data is converted to string and returned in this
     * \param data Value of field or variable
     */
   void getStr
	(
	   unsigned int & fld_idx,
	   const char *card_name, 
	   const char *vname, 
	   char *buf,
	   Data *data
	);

private:
   /** Pointer to store the reference to Manager */
   Manager  *manPtr;
   /** A map between the list of keywords and keyword types */
   StrUIMap *kwListMap;
};

#endif

