#include "includemanager.h"
#include "includeexport.h"
#include "definemanager.h"
#include "defineexport.h"
#include "filegeneric.h"
#include "getincludes.h"
#include <set>
#include <string>
#include <libgen.h>

using namespace std;

GetIncludesDB::GetIncludesDB(const char *main_file, GoldenConn *gold_conn) :
        mainFile(main_file), numTrans(0), goldenConn(gold_conn)
{
}

GetIncludesDB::~GetIncludesDB()
{
}

int GetIncludesDB::fetchTablesAndFiles
    (
       vector<string> *tables_list,
       vector<string> *files_list
    )
{
   filesList = files_list;
   tablesList = tables_list;

   Add(mainFile);

   if( !getIncludesFromDB(mainFile) )
      return 0;

   char mod_file[256], *comb, *main_ptr;

   strcpy(mod_file, mainFile);
   main_ptr = strstr(mod_file, "MAIN");
   if( main_ptr ) *main_ptr = '\0';

   for(unsigned int i = 1; i < tablesList->size(); i++)
   {
      comb = getCombinedTableName(mod_file, (*tablesList)[i].data());
      (*tablesList)[i] = comb;
      delete comb;
   }

   return tablesList->size();
}

int GetIncludesDB::getIncludesFromDB
    (
       const char *main_file,
       unsigned int inTableId,
       const char *parent_dir
    )
{
   char buff[512];
   vector<string> local_files_list;
   vector<string> parent_dir_list;
   vector<unsigned int> table_id_list;

//cout << "MAIN FILE=" << main_file << endl;

   if(!inTableId)
       sprintf(buff, "show table status like '%s___INCLUDES';", main_file);
   else
       sprintf(buff, "show table status like '%u___INCLUDES';", inTableId);
//cout << "QRY=" << buff << endl;

   if( goldenConn->executeQuery(buff) )
   {
      cout << "UNABLE to execute query because " << goldenConn->error() << endl;
      return 0;
   }

   if( !goldenConn->nextRow() )
   {
      AddTable( main_file );
      return 1;
   }

   Card::setFlag(SAVE_CARDS_FIELDS);

   string model_name = main_file;
   model_name += "__";

   IncludeManager *inc_man = IncludeManager::create();
   IncludeExport inc_exp((char *)model_name.data(), goldenConn, inc_man);
   inc_exp.dbReadIncludes();

   vector<ImportObject *> & impobj_list = inc_man->getImportObjectList();
   char *file_name = NULL, *tab_name;
   unsigned int inc_type;

   unsigned int num_imp = impobj_list.size(), i;
   for(i = 0; i < num_imp; i++)
   {
      inc_type = impobj_list[i]->getKeywordType();
      switch(inc_type)
      {
         case INCLUDE:
         case INCLUDE_TRANSFORM:
         {
        vector<Card *> & card_list = impobj_list[i]->getCardList();

        file_name = card_list[0]->stringValue("FILENAME");
        Generic::RemoveLeadingAndTrailingBlanks(file_name);
            filesList->push_back(file_name);
            string new_file_name = file_name;
            char *pdir = dirname((char *)new_file_name.data());
            if(pdir)
            {
                string new_dir = pdir;
                /*if(parent_dir)
                {
                    new_dir = parent_dir;
                    new_dir += "/";
                    new_dir += pdir;
                }*/
                parent_dir_list.push_back(new_dir);
            }
            else
            {
                string new_dir;
                /*if(parent_dir)
                    new_dir = parent_dir;*/
                parent_dir_list.push_back(new_dir);
            }
            unsigned int table_id;
            tab_name = getTableNameFromFile(file_name, &table_id, parent_dir);
            table_id_list.push_back(table_id);
            local_files_list.push_back(tab_name);
            delete tab_name;
         }
         break;
      }
   }

   AddTable( main_file );
   inc_man->reset();
   Card::clearFlag(SAVE_CARDS_FIELDS);

   for(unsigned int i = 0; i < local_files_list.size(); i++)
   {
cout << "FNAME" << local_files_list[i].data() << " TABID=" << table_id_list[i] << " PARENT=" << parent_dir_list[i].data() << endl;
      getIncludesFromDB(local_files_list[i].data(), table_id_list[i], parent_dir_list[i].data());
   }

   return tablesList->size();
}

int GetIncludesDB::fetch
    (
       vector<string> *files_list,
       int *num_trans,
       TransformPtr *trans_list
    )
{
   filesList = files_list;
   *trans_list = (TransformPtr) malloc(sizeof(TransformStr) * 1000);
   transList = *trans_list;

   TransformPtr trans_ptr = &transList[numTrans];
   numTrans++;
   memset(trans_ptr, 0, sizeof(TransformStr));
   trans_ptr->fileIndex = 0;
   trans_ptr->sX = trans_ptr->sY = trans_ptr->sZ = 1.0;

   char mod_file[256];
   strcpy(mod_file, mainFile);

   char *main_ptr = strstr(mod_file, "MAIN");
   if( !main_ptr )
   {
      char *us_ptr = strrchr(mod_file, '_');
      us_ptr++;
      trans_ptr->fileIndex = atoi(us_ptr);
      us_ptr--;
      *us_ptr = '\0';
   }

   if( !getIncludeFilesFromDB(mod_file) )
   {
      free(trans_list);
      *num_trans = 0;
      return 0;
   }

   *num_trans = numTrans;
   *trans_list = (TransformPtr) realloc(*trans_list,
                               sizeof(TransformStr) * (numTrans));
/*
   unsigned int i, j;
   vector<string>::iterator iter;
   for(i = 0; i < filesList->size(); i++)
   {
      for(j = i+1; j < filesList->size(); j++)
      {
         if( (*filesList)[i] == (*filesList)[j] )
         {
//cout << "REMOV dup j = " << (*filesList)[j] << endl;
            iter = (vector<string>::iterator)&((*filesList)[j]);
            filesList->erase(iter);
            j--;
         }
      }
   }
*/

   char *comb;
   if( main_ptr )
      *main_ptr = '\0';
   for(unsigned int i = 1; i < files_list->size(); i++)
   {
      comb = getCombinedTableName(mod_file, (*files_list)[i].data());
      (*files_list)[i] = comb;
      delete comb;
   }

   return files_list->size();
}

int GetIncludesDB::getIncludeFilesFromDB
    (
       const char *main_file,
       unsigned int inTableId,
       const char *parent_dir,
       const char *sub_inc_file 
    )
{
   char buff[512];
   vector<string> local_files_list;
   vector<string> parent_dir_list;
   vector<string> tab_name_list;
   vector<unsigned int> table_id_list;

cout << "MAIN FILE=" << main_file << endl;

   if(!inTableId)
      sprintf(buff, "show table status like '%%%s___INCLUDES';", main_file);
   else
      sprintf(buff, "show table status like '%%%u___INCLUDES';", inTableId);
cout << "QRY=" << buff << endl;

   if( goldenConn->executeQuery(buff) )
   {
      cout << "UNABLE to execute query because " << goldenConn->error() << endl;
      return 0;
   }

   char **rowData = goldenConn->nextRow();

   if( !rowData )
   {
      Add( main_file );
      return 1;
   }

   Card::setFlag(SAVE_CARDS_FIELDS);

   string model_name = main_file;
   model_name += "__";

   if(inTableId && rowData)
   {
       string tableName = rowData[0];
       size_t incKeyLoc = tableName.find("_INCLUDES");
       if(incKeyLoc != string::npos)
       {
           model_name = tableName.substr(0, incKeyLoc);
cout << "MODNAME=" << model_name << endl;
       }
   }

   IncludeManager *inc_man = IncludeManager::create();
   IncludeExport inc_exp((char *)model_name.data(), goldenConn, inc_man);
   inc_exp.dbReadIncludes();

   vector<ImportObject *> & impobj_list = inc_man->getImportObjectList();
   char *file_name = NULL, *tab_name;
   unsigned int inc_type;
   int trans_id;
   TransformPtr trans_ptr;

   unsigned int num_imp = impobj_list.size(), i;
   cout << "NUM INCLUDES=" << num_imp << endl;
   for(i = 0; i < num_imp; i++)
   {
      inc_type = impobj_list[i]->getKeywordType();
      switch(inc_type)
      {
         case INCLUDE:
         case INCLUDE_TRANSFORM:
         {
            vector<Card *> & card_list = impobj_list[i]->getCardList();

            file_name = card_list[0]->stringValue("FILENAME");
            Generic::RemoveLeadingAndTrailingBlanks(file_name);
            unsigned int table_id;
            string new_file_name = file_name;
            char *pdir = dirname((char *)new_file_name.data());
            if(pdir)
            {
                string newdir = pdir;
                /*if(parent_dir)
                {
                    newdir = parent_dir;
                    newdir += "/";
                    newdir += pdir;
                    parent_dir_list.push_back(newdir);
                }*/

                parent_dir_list.push_back(newdir);

cout << "PDIR=" << pdir << endl;
            }
            else
            {
                /*if(parent_dir)
                    parent_dir_list.push_back(parent_dir);
                else*/
                    parent_dir_list.push_back("");
            }
		tab_name = getTableNameFromFile(file_name, &table_id, parent_dir);
		table_id_list.push_back(table_id);
		local_files_list.push_back(tab_name);
		delete tab_name;

        trans_ptr = &transList[numTrans];
		memset(trans_ptr, 0, sizeof(TransformStr));
        trans_ptr->fileIndex = transList[numTrans-1].fileIndex + 1;
		trans_ptr->sX = trans_ptr->sY = trans_ptr->sZ = 1.0;
        numTrans++;

	    if( inc_type == INCLUDE )
	       continue;

	    trans_ptr->idnoff = card_list[1]->intValue("IDNOFF");
	    trans_ptr->ideoff = card_list[1]->intValue("IDEOFF");
	    trans_ptr->idpoff = card_list[1]->intValue("IDPOFF");
	    trans_ptr->idmoff = card_list[1]->intValue("IDMOFF");
	    trans_ptr->idsoff = card_list[1]->intValue("IDSOFF");
	    trans_ptr->idfoff = card_list[1]->intValue("IDFOFF");
	    trans_ptr->iddoff = card_list[1]->intValue("IDDOFF");
	    trans_ptr->idroff = card_list[2]->intValue("IDROFF");
	    trans_id = card_list[4]->intValue("TRANID");
    cout << "TRANSID=" << trans_id << endl;

	    getDetailsFromID(model_name.data(), trans_id, trans_ptr);
	    print(trans_ptr);
         }
         break;
      }
   }

   Add( main_file );
   inc_man->reset();
   Card::clearFlag(SAVE_CARDS_FIELDS);

   for(unsigned int i = 0; i < local_files_list.size(); i++)
   {
cout << "FNAME" << local_files_list[i].data() << " TABID=" << table_id_list[i] << " PARENT=" << parent_dir_list[i].data() << endl;
      getIncludeFilesFromDB(local_files_list[i].data(), table_id_list[i], parent_dir_list[i].data());
   }

   return filesList->size();
}

void GetIncludesDB::print(TransformPtr tptr)
{
   cout << "FILE INDEX=" << tptr->fileIndex << "\n"
        << "ROT=" << tptr->rotAngle << "," << tptr->rX << "," << tptr->rY
        << "," << tptr->rZ << "\n"
        << "TRANS=" << tptr->tX << "," << tptr->tY << "," << tptr->tZ << "\n";
}

void GetIncludesDB::getDetailsFromID
     (
        const char    *model_name,
        int           trans_id,
        TransformPtr  trans_ptr
     )
{
   char *option;
   int tid, ptid;
   unsigned int j, k;

   DefineManager *def_man = DefineManager::create();
   DefineExport def_exp((char *)model_name, goldenConn, def_man);
   def_exp.dbReadDefines(DEFINE_TRANSFORMATION);

   vector<ImportObject *> & imp_list = def_man->getImportObjectList();
   PointMap point_map;
   for(j = 0; j < imp_list.size(); j++)
   {
      vector<Card *> & card_list = imp_list[j]->getCardList();
      if( !card_list.size() )
         continue;

      tid = card_list[0]->intValue("TRANID");
      if( trans_id == tid )
      {
     for(k = 1; k < card_list.size(); k++)
     {
        option = card_list[k]->stringValue("OPTION");
cout << "OPTION=" << option << endl;
            Generic::RemoveLeadingAndTrailingBlanks(option);
cout << "OPTION=" << option << endl;
        if( !strcmp(option, "TRANSL") )
        {
           trans_ptr->tX = card_list[k]->doubleValue("A1");
           trans_ptr->tY = card_list[k]->doubleValue("A2");
           trans_ptr->tZ = card_list[k]->doubleValue("A3");
        }
        else if( !strcmp(option, "POINT") )
        {
           PointStr pt;
           ptid = (int)card_list[k]->doubleValue("A1");
           pt.x = (float)card_list[k]->doubleValue("A2");
           pt.y = (float)card_list[k]->doubleValue("A3");
           pt.z = (float)card_list[k]->doubleValue("A4");
           point_map.insert(PointPair(ptid, pt));
        }
        else if( !strcmp(option, "ROTATE") )
        {
           float a1, a2, a3, a4, a5, a6, a7;
           a1 = (float)card_list[k]->doubleValue("A1");
           a2 = (float)card_list[k]->doubleValue("A2");
           a3 = (float)card_list[k]->doubleValue("A3");
           a7 = (float)card_list[k]->doubleValue("A7");
           if( a7 == 0.0f )
           {
          ptid = (int)a1;
          PointMapIter e = point_map.end(),iter = point_map.find(ptid);
          if( iter != e )
          {
             PointStr pt1 = iter->second, pt2;
             ptid = (int)a2;
             iter = point_map.find(ptid);
             if( iter != e )
             {
            pt2 = iter->second;
            trans_ptr->rX = pt1.x - pt2.x;
            trans_ptr->rY = pt1.y - pt2.y;
            trans_ptr->rZ = pt1.z - pt2.z;
            trans_ptr->rotAngle = a3;
             }
          }
           }
           else
           {
          a4 = (float)card_list[k]->doubleValue("A4");
          a5 = (float)card_list[k]->doubleValue("A5");
          a6 = (float)card_list[k]->doubleValue("A6");

          trans_ptr->rX = a1 - a4;
          trans_ptr->rY = a2 - a5;
          trans_ptr->rZ = a3 - a6;
          trans_ptr->rotAngle = a7;
           }
        }
        else if( !strcmp(option, "SCALE") )
        {
           trans_ptr->sX = (float)card_list[k]->doubleValue("A1");
           trans_ptr->sY = (float)card_list[k]->doubleValue("A2");
           trans_ptr->sZ = (float)card_list[k]->doubleValue("A3");
               if( trans_ptr->sX == 0.0 ) trans_ptr->sX = 1.0;
               if( trans_ptr->sY == 0.0 ) trans_ptr->sY = 1.0;
               if( trans_ptr->sZ == 0.0 ) trans_ptr->sZ = 1.0;
            }
     }
      }
   }

   def_man->reset();
}

