#ifndef _GET_INCLUDES_H_
#define _GET_INCLUDES_H_

#include <vector>
#include <set>
#include <map>
#include <string>
#include <algorithm>
#include "myconnection.h"
#include "transform.h"
#define LAST_BIT_ON (1<<31)

using namespace std;

/** Class for getting all the include files from the given main file */
class GetIncludesDB
{
public:
   /** Constrctor for creating this object
     * \param main_file Name of the main file given
     * \param gold_conn Connection object for accessing the database
     */
   GetIncludesDB
   (
      const char *main_file, 
      GoldenConn *gold_conn
   );

   ~GetIncludesDB();

   /** Gets the pointer to the list of all files to be imported and a pointer
     * to the names of tables for files
     * \param tables_list Pointer to the list of table names. Table name is
     * generated as main file(20) + include file(20). For main file 'MAIN'
     * word is added for indentification
     * \param files_list Pointer to the list of generated file names
     * \return Returns number of files on success else 0
     */
   int fetchTablesAndFiles
       (
	  vector<string> *tables_list,
	  vector<string> *files_list
       );

   /** Gets the all include files from the database for *INCLUDE keywords
     * \param main_file Name of the main file
     * \return Returns the number of files on success else zero
     */
   int getIncludesFromDB
       (
	  const char *main_file,
          unsigned int inTableId = 0,
          const char *parent_dir = NULL
       );

   /** Fetches a pointer to the list of files and a pointer to tranformation 
     * objects
     * \param files_list Pointer to the list of files
     * \param num_trans Number of tranformation objects
     * \param trans_list Pointer to list of transformation objects
     * \return Returns the number of files on success or 0
     */
   int fetch
       (
          vector<string> *files_list, 
          int *num_trans, 
          TransformPtr *trans_list
       );

   /** Gets the all include files from the database for *INCLUDE keywords and
     * also gets the transformation objects for *DEFINE_TRANSFORMATION keywords
     * \param main_file Name of the main file
     * \return Returns the number of files on success else zero
     */
   int getIncludeFilesFromDB
       (
          const char *main_file,
          unsigned  int table_id = 0,
          const char *parent_dir = NULL,
          const char *sub_inc_file = NULL
       );

   /** Prints the transfromation object details
     * \param tptr Transformation object pointer to print
     */
   void print(TransformPtr tptr);

   /** Gets the transformation object pointer for the given *DEFINE_TRANSFORMATION
     * keyword
     * \param model_name Name of the model
     * \param trans_id ID of the transformation object
     * \param trans_ptr Transfromation object pointer. The details are filled here
     */
   void getDetailsFromID
	(
	   const char    *model_name,
	   int           trans_id,
	   TransformPtr  trans_ptr
	);

   void Add(const char *fileName)
   {
       vector<string>::iterator findIter = find(filesList->begin(), filesList->end(), fileName);
       //if(findIter == filesList->end())
           filesList->push_back(fileName);
   }

   void AddTable(const char *tableName)
   {
       vector<string>::iterator findIter = find(tablesList->begin(), tablesList->end(), tableName);
       //if(findIter == tablesList->end())
           tablesList->push_back(tableName);
   }

private:
   /** Name of the main file */
   const char     *mainFile;
   /** Number of transformations */
   int            numTrans;
   /** Connection object for accessing the database */
   GoldenConn     *goldenConn;
   /** Pointer to the list of Transformation objects */
   TransformPtr   transList;
   /** Pointer to the list of file names */
   vector<string> *filesList;
   /** Pointer to the list of table names */
   vector<string> *tablesList;
};

#endif

