#include "includemanager.h"
#include "includeexport.h"
#include "definemanager.h"
#include "defineexport.h"
#include "filegeneric.h"
#include "getincludesfilewise.h"
#include <set>
#include <string>
#include <libgen.h>

using namespace std;

GetIncludesDBFileWise::GetIncludesDBFileWise(const char *main_file, GoldenConn *gold_conn) : m_MainFile(main_file), m_GoldenConn(gold_conn), m_FileIndex(0), m_TableIndex(0)
{
    if(!strstr(main_file, "MAIN"))
    {
        char *comb = getMainTableNameFromFile((char *)main_file, &m_TableIndex);
        m_MainFile = comb;
        if(!m_TableIndex)
            m_MainFile += "MAIN";
        delete comb;
    }
}

GetIncludesDBFileWise::~GetIncludesDBFileWise()
{
}

int GetIncludesDBFileWise::fetchTablesAndFiles
    (
        IncludeFileDetailsVector & incFileVector
    )
{
    incFileVector = m_IncludeFileVector;

   if( !getIncludesFromDB(m_MainFile.data(),  m_TableIndex) )
      return 0;

   char mod_file[256], *comb, *main_ptr;

   strcpy(mod_file, m_MainFile.data());
   main_ptr = strstr(mod_file, "MAIN");
   if( main_ptr ) *main_ptr = '\0';

   for(unsigned int i = 0; i < m_IncludeFileVector.size(); i++)
   {
       for(unsigned int j = 0; j < m_IncludeFileVector[i].second->m_TablesList.size(); j++)
       {
           comb = getCombinedTableName(mod_file, m_IncludeFileVector[i].second->m_TablesList[j].data());
           m_IncludeFileVector[i].second->m_TablesList[j] = comb;
           delete comb;
       }
   }

   return m_IncludeFileVector.size();
}

int GetIncludesDBFileWise::getIncludesFromDB
    (
       const char *main_file,
       unsigned int inTableId,
       const char *parent_dir
    )
{
   char buff[512];
   vector<string> local_files_list;
   vector<string> table_name_list;
   vector<string> parent_dir_list;
   vector<unsigned int> table_id_list;

cout << "MAIN FILE=" << main_file << endl;

   if(!inTableId)
       sprintf(buff, "show table status like '%s___INCLUDES';", main_file);
   else
       sprintf(buff, "show table status like '%u___INCLUDES';", inTableId);
//cout << "QRY=" << buff << endl;

   IncludeFileDetails *incDetails = new IncludeFileDetails();
   incDetails->m_FileIndex = m_FileIndex;

   if( m_GoldenConn->executeQuery(buff) )
   {
      cout << "UNABLE to execute query because " << m_GoldenConn->error() << endl;
      return 0;
   }

   if( !m_GoldenConn->nextRow() )
   {
       if(!parent_dir)
       {
           m_IncludeFileVector.push_back(IncludeFileDetailsPair(main_file, incDetails));
           m_FileIndex++;
       }
       else
           delete incDetails;
      return 1;
   }

   m_IncludeFileVector.push_back(IncludeFileDetailsPair(main_file, incDetails));
   m_FileIndex++;

   Card::setFlag(SAVE_CARDS_FIELDS);

   string model_name = main_file;
   model_name += "__";

   IncludeManager *inc_man = IncludeManager::create();
   IncludeExport inc_exp((char *)model_name.data(), m_GoldenConn, inc_man);
   inc_exp.dbReadIncludes();

   vector<ImportObject *> & impobj_list = inc_man->getImportObjectList();
   char *file_name = NULL, *tab_name;
   unsigned int inc_type;

   unsigned int num_imp = impobj_list.size(), i;
   for(i = 0; i < num_imp; i++)
   {
      inc_type = impobj_list[i]->getKeywordType();
      switch(inc_type)
      {
         case INCLUDE:
         case INCLUDE_TRANSFORM:
         {
            vector<Card *> & card_list = impobj_list[i]->getCardList();

            file_name = card_list[0]->stringValue("FILENAME");
            Generic::RemoveLeadingAndTrailingBlanks(file_name);
            local_files_list.push_back(file_name);
            string new_file_name = file_name;
            char *pdir = dirname((char *)new_file_name.data());
            if(pdir)
            {
                string new_dir = pdir;
                /*if(parent_dir)
                {
                    new_dir = parent_dir;
                    new_dir += "/";
                    new_dir += pdir;
                }*/
                parent_dir_list.push_back(new_dir);
            }
            else
            {
                string new_dir;
                /*if(parent_dir)
                    new_dir = parent_dir;*/
                parent_dir_list.push_back(new_dir);
            }
            unsigned int table_id;
            tab_name = getTableNameFromFile(file_name, &table_id, parent_dir);
            table_id_list.push_back(table_id);
            table_name_list.push_back(tab_name);
            delete tab_name;
         }
         break;
      }
   }

   inc_man->reset();
   Card::clearFlag(SAVE_CARDS_FIELDS);

   incDetails->m_FilesList = local_files_list;
   incDetails->m_TablesList = table_name_list;

   for(unsigned int i = 0; i < local_files_list.size(); i++)
   {
cout << "FNAME" << local_files_list[i].data() << " TABID=" << table_id_list[i] << " PARENT=" << parent_dir_list[i].data() << endl;
          getIncludesFromDB(local_files_list[i].data(), table_id_list[i], parent_dir_list[i].data());
   }

   return m_IncludeFileVector.size();
}

int GetIncludesDBFileWise::fetch
    (
        IncludeFileDetailsVector & incFileVector
    )
{
   char mod_file[256];
   strcpy(mod_file, m_MainFile.data());

   char *main_ptr = strstr(mod_file, "MAIN");
   string   hashStr;
   if(main_ptr)
   {
        *main_ptr = '\0';
        hashStr = mod_file;
   }

   incFileVector = m_IncludeFileVector;
   m_FileIndex = 0;

   string selectQry = "select model_path from `cae_models_list` where model_uuid=";
   selectQry += hashStr + string(";");
   if (m_GoldenConn->executeQuery(selectQry.data()))
   {
      cout << "query error=" << m_GoldenConn->error() << endl;
      return 0;
   }
   char **nextRow = m_GoldenConn->nextRow();
   string parentDir;
   if(nextRow)
   {
        string modelPath = nextRow[0];
        parentDir = dirname(modelPath.data());
   }

   if(parentDir.empty())
   {
       cout << "Main Model path not found\n";
       return 0;
   }

   if( !getIncludeFilesFromDB(m_MainFile.data(), m_TableIndex, parentDir.data(), m_MainFile.data()) )
   {
      return 0;
   }

   char *comb;
   if( main_ptr )
      *main_ptr = '\0';
   for(unsigned int i = 0; i < m_IncludeFileVector.size(); i++)
   {
       if(i != 0)
       {
           comb = getCombinedTableName(mod_file, m_IncludeFileVector[i].second->m_TableName.data());
           m_IncludeFileVector[i].second->m_TableName = comb;
           delete comb;
       }

       for(unsigned int j = 0; j < m_IncludeFileVector[i].second->m_FilesList.size(); j++)
       {
           comb = getCombinedTableName(mod_file, m_IncludeFileVector[i].second->m_TablesList[j].data());
           m_IncludeFileVector[i].second->m_TablesList[j] = comb;
           delete comb;
       }
   }

   incFileVector = m_IncludeFileVector;
   return m_IncludeFileVector.size();
}

int GetIncludesDBFileWise::getIncludeFilesFromDB
    (
       const char *main_file,
       unsigned int inTableId,
       const char *parent_dir,
       const char *inTableName,
       int        inFileIndex
    )
{
   char buff[512];
   vector<string> local_files_list;
   vector<string> parent_dir_list;
   vector<string> tab_name_list;
   vector<unsigned int> table_id_list;
   char *tab_name;
   unsigned int local_table_id;

   IncludeFileDetails *incDetails = new IncludeFileDetails();
   incDetails->m_FileIndex = m_FileIndex;
   if(parent_dir)
   {
      //tab_name = getTableNameFromFile((char *)main_file, &local_table_id, parent_dir);
      incDetails->m_TableName = inTableName;
      //delete tab_name;
      incDetails->m_FileIndex = inFileIndex;
   }
   else
       incDetails->m_TableName = main_file;


cout << "MAIN FILE=" << main_file << endl;

   if(!inTableId)
      sprintf(buff, "show table status like '%%%s___INCLUDES';", main_file);
   else
      sprintf(buff, "show table status like '%%%u___INCLUDES';", inTableId);
cout << "QRY=" << buff << endl;

   if( m_GoldenConn->executeQuery(buff) )
   {
      cout << "UNABLE to execute query because " << m_GoldenConn->error() << endl;
      return 0;
   }

   char **rowData = m_GoldenConn->nextRow();

   if( !rowData )
   {
      //if(!parent_dir)
      {
          m_FileIndex++;
          m_IncludeFileVector.push_back(IncludeFileDetailsPair(main_file, incDetails));
      }
      //else
          //delete incDetails;
      return 1;
   }

   m_FileIndex++;
   m_IncludeFileVector.push_back(IncludeFileDetailsPair(main_file, incDetails));

   Card::setFlag(SAVE_CARDS_FIELDS);

   string model_name = main_file;
   model_name += "__";

   if(inTableId && rowData)
   {
       string tableName = rowData[0];
       size_t incKeyLoc = tableName.find("_INCLUDES");
       if(incKeyLoc != string::npos)
       {
           model_name = tableName.substr(0, incKeyLoc);
cout << "MODNAME=" << model_name << endl;
       }
   }

   IncludeManager *inc_man = IncludeManager::create();
   IncludeExport inc_exp((char *)model_name.data(), m_GoldenConn, inc_man);
   inc_exp.dbReadIncludes();

   vector<ImportObject *> & impobj_list = inc_man->getImportObjectList();
   char *file_name = NULL;
   unsigned int inc_type;
   int trans_id;
   TransformPtr trans_ptr;

   unsigned int num_imp = impobj_list.size(), i;
   cout << "NUM INCLUDES=" << num_imp << endl;
   for(i = 0; i < num_imp; i++)
   {
      inc_type = impobj_list[i]->getKeywordType();
      switch(inc_type)
      {
         case INCLUDE:
         case INCLUDE_TRANSFORM:
         {
            vector<Card *> & card_list = impobj_list[i]->getCardList();

            file_name = card_list[0]->stringValue("FILENAME");
            Generic::RemoveLeadingAndTrailingBlanks(file_name);
            unsigned int table_id;
            string new_file_name = file_name;
            char *pdir = dirname((char *)new_file_name.data());
            if(pdir)
            {
                string newdir = pdir;
                if(parent_dir)
                {
                     newdir = parent_dir;
                     newdir += "/";
                     newdir += pdir;
                     parent_dir_list.push_back(newdir);
                }
                else
                      parent_dir_list.push_back(newdir);

cout << "PDIR=" << pdir << endl;
            }
            else
            {
                if(parent_dir)
                    parent_dir_list.push_back(parent_dir);
                else
                    parent_dir_list.push_back("");
            }
            tab_name = getTableNameFromFile(file_name, &table_id, parent_dir);
            table_id_list.push_back(table_id);
            local_files_list.push_back(file_name);
            tab_name_list.push_back(tab_name);
            delete tab_name;

            trans_ptr = new TransformStr;
            memset(trans_ptr, 0, sizeof(TransformStr));
            trans_ptr->fileIndex = m_FileIndex;
            trans_ptr->sX = trans_ptr->sY = trans_ptr->sZ = 1.0;
            m_FileIndex++;
            incDetails->m_TransList.push_back(trans_ptr);

            if( inc_type == INCLUDE )
               continue;

            trans_ptr->idnoff = card_list[1]->intValue("IDNOFF");
            trans_ptr->ideoff = card_list[1]->intValue("IDEOFF");
            trans_ptr->idpoff = card_list[1]->intValue("IDPOFF");
            trans_ptr->idmoff = card_list[1]->intValue("IDMOFF");
            trans_ptr->idsoff = card_list[1]->intValue("IDSOFF");
            trans_ptr->idfoff = card_list[1]->intValue("IDFOFF");
            trans_ptr->iddoff = card_list[1]->intValue("IDDOFF");
            trans_ptr->idroff = card_list[2]->intValue("IDROFF");
            trans_id = card_list[4]->intValue("TRANID");
         cout << "TRANSID=" << trans_id << endl;

            getDetailsFromID(model_name.data(), trans_id, trans_ptr);
            print(trans_ptr);
         }
         break;
      }
   }

   inc_man->reset();
   Card::clearFlag(SAVE_CARDS_FIELDS);


   incDetails->m_FilesList = local_files_list;
   incDetails->m_TablesList = tab_name_list;

   for(unsigned int i = 0; i < local_files_list.size(); i++)
   {
cout << "FNAME" << local_files_list[i].data() << " TABID=" << table_id_list[i] << " PARENT=" << parent_dir_list[i].data() << 
      " TABNAME=" << tab_name_list[i] << endl;
      getIncludeFilesFromDB(local_files_list[i].data(), table_id_list[i], parent_dir_list[i].data(), tab_name_list[i].data(),
                     incDetails->m_TransList[i]->fileIndex);
   }

   return m_IncludeFileVector.size();
}

void GetIncludesDBFileWise::print(TransformPtr tptr)
{
   cout << "FILE INDEX=" << tptr->fileIndex << "\n"
        << "ROT=" << tptr->rotAngle << "," << tptr->rX << "," << tptr->rY
        << "," << tptr->rZ << "\n"
        << "TRANS=" << tptr->tX << "," << tptr->tY << "," << tptr->tZ << "\n";
}

void GetIncludesDBFileWise::getDetailsFromID
     (
        const char    *model_name,
        int           trans_id,
        TransformPtr  trans_ptr
     )
{
   char *option;
   int tid, ptid;
   unsigned int j, k;

   DefineManager *def_man = DefineManager::create();
   DefineExport def_exp((char *)model_name, m_GoldenConn, def_man);
   def_exp.dbReadDefines(DEFINE_TRANSFORMATION);

   vector<ImportObject *> & imp_list = def_man->getImportObjectList();
   PointMap point_map;
   for(j = 0; j < imp_list.size(); j++)
   {
      vector<Card *> & card_list = imp_list[j]->getCardList();
      if( !card_list.size() )
         continue;

      tid = card_list[0]->intValue("TRANID");
      if( trans_id == tid )
      {
     for(k = 1; k < card_list.size(); k++)
     {
        option = card_list[k]->stringValue("OPTION");
cout << "OPTION=" << option << endl;
            Generic::RemoveLeadingAndTrailingBlanks(option);
cout << "OPTION=" << option << endl;
        if( !strcmp(option, "TRANSL") )
        {
           trans_ptr->tX = card_list[k]->doubleValue("A1");
           trans_ptr->tY = card_list[k]->doubleValue("A2");
           trans_ptr->tZ = card_list[k]->doubleValue("A3");
        }
        else if( !strcmp(option, "POINT") )
        {
           PointStr pt;
           ptid = (int)card_list[k]->doubleValue("A1");
           pt.x = (float)card_list[k]->doubleValue("A2");
           pt.y = (float)card_list[k]->doubleValue("A3");
           pt.z = (float)card_list[k]->doubleValue("A4");
           point_map.insert(PointPair(ptid, pt));
        }
        else if( !strcmp(option, "ROTATE") )
        {
           float a1, a2, a3, a4, a5, a6, a7;
           a1 = (float)card_list[k]->doubleValue("A1");
           a2 = (float)card_list[k]->doubleValue("A2");
           a3 = (float)card_list[k]->doubleValue("A3");
           a7 = (float)card_list[k]->doubleValue("A7");
           if( a7 == 0.0f )
           {
          ptid = (int)a1;
          PointMapIter e = point_map.end(),iter = point_map.find(ptid);
          if( iter != e )
          {
             PointStr pt1 = iter->second, pt2;
             ptid = (int)a2;
             iter = point_map.find(ptid);
             if( iter != e )
             {
            pt2 = iter->second;
            trans_ptr->rX = pt1.x - pt2.x;
            trans_ptr->rY = pt1.y - pt2.y;
            trans_ptr->rZ = pt1.z - pt2.z;
            trans_ptr->rotAngle = a3;
             }
          }
           }
           else
           {
          a4 = (float)card_list[k]->doubleValue("A4");
          a5 = (float)card_list[k]->doubleValue("A5");
          a6 = (float)card_list[k]->doubleValue("A6");

          trans_ptr->rX = a1 - a4;
          trans_ptr->rY = a2 - a5;
          trans_ptr->rZ = a3 - a6;
          trans_ptr->rotAngle = a7;
           }
        }
        else if( !strcmp(option, "SCALE") )
        {
           trans_ptr->sX = (float)card_list[k]->doubleValue("A1");
           trans_ptr->sY = (float)card_list[k]->doubleValue("A2");
           trans_ptr->sZ = (float)card_list[k]->doubleValue("A3");
               if( trans_ptr->sX == 0.0 ) trans_ptr->sX = 1.0;
               if( trans_ptr->sY == 0.0 ) trans_ptr->sY = 1.0;
               if( trans_ptr->sZ == 0.0 ) trans_ptr->sZ = 1.0;
            }
     }
      }
   }

   def_man->reset();
}

