#ifndef _GET_INCLUDES_H_
#define _GET_INCLUDES_H_

#include <vector>
#include <set>
#include <map>
#include <string>
#include <algorithm>
#include "myconnection.h"
#include "transform.h"
#define LAST_BIT_ON (1<<31)

using namespace std;

struct IncludeFileDetails
{
    /** Pointer to the list of Transformation objects */
    vector<TransformPtr>   m_TransList;
    /** Pointer to the list of file names */
    vector<string> m_FilesList;
    /** Pointer to the list of table names */
    vector<string> m_TablesList;
    int            m_FileIndex;
    string       m_TableName;
};

typedef pair<string, IncludeFileDetails *> IncludeFileDetailsPair;
typedef vector<IncludeFileDetailsPair> IncludeFileDetailsVector;

/** Class for getting all the include files from the given main file */
class GetIncludesDBFileWise
{
public:
   /** Constrctor for creating this object
     * \param main_file Name of the main file given
     * \param gold_conn Connection object for accessing the database
     */
   GetIncludesDBFileWise
   (
      const char *main_file, 
      GoldenConn *gold_conn
   );

   ~GetIncludesDBFileWise();

   /** Gets the pointer to the list of all files to be imported and a pointer
     * to the names of tables for files
     * \param tables_list Pointer to the list of table names. Table name is
     * generated as main file(20) + include file(20). For main file 'MAIN'
     * word is added for indentification
     * \param files_list Pointer to the list of generated file names
     * \return Returns number of files on success else 0
     */
   int fetchTablesAndFiles
       (
            IncludeFileDetailsVector & incFileVector
       );

   /** Gets the all include files from the database for *INCLUDE keywords
     * \param main_file Name of the main file
     * \return Returns the number of files on success else zero
     */
   int getIncludesFromDB
       (
	  const char *main_file,
          unsigned int inTableId = 0,
          const char *parent_dir = NULL
       );

   /** Fetches a pointer to the list of files and a pointer to tranformation 
     * objects
     * \param files_list Pointer to the list of files
     * \param num_trans Number of tranformation objects
     * \param trans_list Pointer to list of transformation objects
     * \return Returns the number of files on success or 0
     */
   int fetch
       (
          IncludeFileDetailsVector & incFileVector
       );

   /** Gets the all include files from the database for *INCLUDE keywords and
     * also gets the transformation objects for *DEFINE_TRANSFORMATION keywords
     * \param main_file Name of the main file
     * \return Returns the number of files on success else zero
     */
   int getIncludeFilesFromDB
       (
          const char *main_file,
          unsigned  int table_id = 0,
          const char *parent_dir = NULL,
          const char *inTableName = NULL,
          int inFileIndex = 0
       );

   /** Prints the transfromation object details
     * \param tptr Transformation object pointer to print
     */
   void print(TransformPtr tptr);

   /** Gets the transformation object pointer for the given *DEFINE_TRANSFORMATION
     * keyword
     * \param model_name Name of the model
     * \param trans_id ID of the transformation object
     * \param trans_ptr Transfromation object pointer. The details are filled here
     */
   void getDetailsFromID
	(
	   const char    *model_name,
	   int           trans_id,
	   TransformPtr  trans_ptr
	);

private:
   /** Name of the main file */
   string 	  m_MainFile;
   /** Connection object for accessing the database */
   GoldenConn     *m_GoldenConn;
   IncludeFileDetailsVector    m_IncludeFileVector;
   int                  m_FileIndex;
   unsigned int         m_TableIndex;
};

#endif

