#ifndef _DYNA_TO_BIN_H_
#define _DYNA_TO_BIN_H_

#include <iostream>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include "bufio.h"
#include "manager.h"
#include "filegeneric.h"

using namespace std;

/** Class for converting the referred IDs of a keyword or entity into a binary
  * file for display. The file written is entity_display.bin. This file has the
  * the reference ids. That means, the set object contains node ids or element 
  * ids or part ids. The airbag contains set id and load curve ids. So the 
  * airbag_display.bin file contains kw_type | kw | id sequentially for all 
  * referred objects for a particular type of object. 
  * num. of objects | repeat(num. of references | repeat (kw_type | kw | id))
  * ex. num_airbags | repeat(num of ref | repeat(kw_type|kw|id))
  * ex. 2 | 3 | (SET | SET_NODE_LIST | 1234) | (DEFINE | DEFINE_CURVE | 2345) |
  *             (DEFINE | DEFINE_VECTOR | 345) | 1 (SET | SET_BEAM_LIST | 456)
  * the references can be set, load curve, vector etc
  */
class DynaToBin
{
public:
   /** Constructor for creating this object
     * \param dir Name of the directory
     * \param model Name of the model
     * \param man Manager pointer from which the data is obtained
     */
   DynaToBin(const char *dir, const char *model, Manager *man) : dirName(dir),
         modelName(model), manPtr(man)
   {
   }
  
   ~DynaToBin(){}
   
   /** Writes the file to disk for the given group
     * \param ent_name Name of the group of keywords
     * \param idx_list List of card indices for which the data is required. This
     * function saves the data which is required only.
     * \return Returns 0 on success else greater than 0
     */
   int write
       (
	  const char *ent_name,
	  vector<unsigned int> *idx_list = NULL
       );

private:
   const char *dirName; /** Name of the directory */
   const char *modelName; /** Name of the model name */
   Manager *manPtr; /** Manager pointer for getting the data */
};

#endif

