#include <iostream>
#include <time.h>
#include <set>
#include "integrationmanager.h"
#include "integrationexport.h"
#include "integrationimport.h"
#include "dynatobin.h"
#include "myconnection.h"
#include "dbtohtmlgen.h"
#include "dataloc.h"

using namespace std;
map<string, string> MyConnection::nvMap;
unsigned int Card::contFlag = 0;

int main(int argc, char* argv[])
{
   if( argc < 3 )
   {
      cout << "Usage: integration dir_name model_name" << endl;
      return 1;
   }

   time_t			t1, t2;
   time(&t1);

   GoldenConn *goldenConn = MyConnection::get();

   if( !goldenConn )
      return 1;

   string file_name = argv[1];
   file_name += "/";
   file_name += argv[2];
   file_name += "_integration_lsd.php"; 
   FILE *fp = fopen(file_name.data(), "rb");

   if( !fp )
   {
      cout << "Unable to open the file " << file_name << endl;
      delete goldenConn;
      return 1;
   }

   unsigned int integration_type = INTEGRATION_NEW_TYPE, integration_id;
   string select_query, model_name, kw_name = "*INTEGRATION";

   if( argc > 3 )
   {
      kw_name = "*";
      kw_name += argv[3];
      integration_type = IntegrationImport::getIntegrationTypeFromKeyword(
                                        kw_name.data(), &integration_id);
   }

   IntegrationManager::reset();
   model_name = argv[2];
   model_name += "__";

   select_query = "show table status like \'";
   select_query += model_name;
   select_query += "_INTEGRATIONS\';";

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      DBToHtml::cleanAndWriteBlankPage(argv[1], goldenConn, fp, "*INTEGRATION");
      return 2;
   }

   if( !goldenConn->nextRow() ) 
   {
cout << "WARNING: No integration table for model=" << argv[2] << endl;
      DBToHtml::cleanAndWriteBlankPage(argv[1], goldenConn, fp, "*INTEGRATION");
      return 3;
   }

   Card::setFlag(SAVE_REFERENCES);
   DataLoc data_loc(fp);

   IntegrationManager *integration_man = IntegrationManager::create();
   IntegrationImport integration_imp(fp, &data_loc, integration_man);

   int num_integration = integration_imp.readIntegrations();

   if( !num_integration )
   {
cout << "WARNING: No integration available for model<" << argv[2] << ">\n";
      DBToHtml::cleanAndWriteBlankPage(argv[1], goldenConn, fp, "*INTEGRATION");
      return 4;
   }

   unsigned int total = 0, edit_index = 0;
   string html_str, edit_str = "<?php\nfunction loadData($kw_short, $kw)\n{\n";

   if( argc > 6 )
      edit_index = atoi(argv[6]);

cout << "EDIT ID=" << edit_index << endl;

   DBToHtml dbtohtml(integration_man);
   dbtohtml.getJSCode(integration_type, kw_name, html_str, total, edit_index, &edit_str);
   edit_str += "}\n?>\n";
cout << "EDIT=" << edit_str << endl;

   IntegrationManager::reset();

   fputs(html_str.data(), fp);
   fclose(fp);
   delete goldenConn;

   file_name = argv[1];
   file_name += "/data_lsd.php";
   fp = fopen(file_name.data(), "rb");
   fputs(edit_str.data(), fp);
   fclose(fp);

   time(&t2);
   cout << "TIME FOR INTEGRATION FROM DB= " << difftime(t2, t1) << endl;

   return 0;
}

