#include <iostream>
#include <time.h>
#include <set>
#include "perturbmanager.h"
#include "perturbexport.h"
#include "perturbimport.h"
#include "dynatobin.h"
#include "myconnection.h"
#include "dbtohtmlgen.h"
#include "dataloc.h"

using namespace std;
map<string, string> MyConnection::nvMap;
unsigned int Card::contFlag = 0;

int main(int argc, char* argv[])
{
   if( argc < 3 )
   {
      cout << "Usage: perturb dir_name model_name" << endl;
      return 1;
   }

   time_t			t1, t2;
   time(&t1);

   GoldenConn *goldenConn = MyConnection::get();

   if( !goldenConn )
      return 1;

   string file_name = argv[1];
   file_name += "/";
   file_name += argv[2];
   file_name += "_perturbation_lsd.php"; 
   FILE *fp = fopen(file_name.data(), "rb");

   if( !fp )
   {
      cout << "Unable to open the file " << file_name << endl;
      delete goldenConn;
      return 1;
   }

   unsigned int perturb_type = PERTURB_NEW_TYPE, perturb_id;
   string kw_name = "*PERTURBATION", select_query, model_name;

   if( argc > 3 )
   {
      kw_name = "*";
      kw_name += argv[3];
      perturb_type = PerturbImport::getPerturbTypeFromKeyword(
                                        kw_name.data(), &perturb_id);
   }

   PerturbManager::reset();
   model_name = argv[2];
   model_name += "__";

   select_query = "show table status like \'";
   select_query += model_name;
   select_query += "_PERTURBATIONS\';";

   if( goldenConn->executeQuery( select_query.data() ) )
   {
      cout << goldenConn->error() << endl;
      DBToHtml::cleanAndWriteBlankPage(argv[1], goldenConn, fp, "*PERTURBATION");
      return 2;
   }

   if( !goldenConn->nextRow() ) 
   {
cout << "WARNING: No perturb table for model=" << argv[2] << endl;
      DBToHtml::cleanAndWriteBlankPage(argv[1], goldenConn, fp, "*PERTURBATION");
      return 3;
   }

   PerturbManager *perturb_man = PerturbManager::create();
   DataLoc data_loc(fp);
   PerturbImport perturb_imp(fp, &data_loc, perturb_man);

   int num_perturb = perturb_imp.readPerturbs();

   if( !num_perturb )
   {
cout << "WARNING: No perturb available for model<" << argv[2] << ">\n";
      DBToHtml::cleanAndWriteBlankPage(argv[1], goldenConn, fp, "*PERTURBATION");
      return 4;
   }

   unsigned int total = 0, edit_index = 0;
   string html_str, edit_str = "<?php\nfunction loadData($kw_short, $kw)\n{\n";

   if( argc > 6 )
      edit_index = atoi(argv[6]);

cout << "EDIT ID=" << edit_index << endl;

   DBToHtml dbtohtml(perturb_man);
   dbtohtml.getJSCode(perturb_type, kw_name, html_str, total, edit_index, &edit_str);
   edit_str += "}\n?>\n";
cout << "EDIT=" << edit_str << endl;

   PerturbManager::reset();

   fputs(html_str.data(), fp);
   fclose(fp);
   delete goldenConn;

   file_name = argv[1];
   file_name += "/data_lsd.php";
   fp = fopen(file_name.data(), "rb");
   fputs(edit_str.data(), fp);
   fclose(fp);

   time(&t2);
   cout << "TIME FOR PERTURBATION FROM DB= " << difftime(t2, t1) << endl;

   return 0;
}

