#include <iostream>
#include <fstream>
#include <time.h>
#include <gentime.h>
#include <algorithm>
#include <map>
#include <libgen.h>
#include "dataloc.h"
#include "myconnection.h"
#include "filegeneric.h"
#include "dynatodbgen.h"
#include "card.h"
#include "goldenconn.h"
#include "includemanager.h"
#include "includeimport.h"
#include <boost/functional/hash.hpp>
#include <boost/filesystem/path.hpp>

DynaToDBGen::DynaToDBGen()
{
}

DynaToDBGen::~DynaToDBGen()
{
   fileList.clear();
   for(unsigned int i = 0; i < datalocList.size(); i++)
      delete datalocList[i];
   datalocList.clear();
   tabnameList.clear();
}

int DynaToDBGen::checkAndGet
    (
       const char *main_file,
       const char *,
       GoldenConn * goldenConn
    )
{
   Card::setFlag(SAVE_CARDS_FIELDS);

   char *main_tab, *comb;//, qry[512];
   unsigned int error_flag = 0, i, j;
   string name_str;
   string inMainFile = main_file;
   main_tab = getMainTableNameFromFile((char *)inMainFile.data());
   // MAIN is added to first file for identification purposes in GUI
   name_str = name_str + main_tab + "MAIN";
   tabnameList.push_back(name_str);
   string parent_dir = dirname((char*)inMainFile.data());
   
   checkAndInsertIntoModelList(main_file, true, goldenConn);

   if( getIncludeFilesFromDyna(main_file, parent_dir.data()) )
      return 1;

   //remove duplicate file names
   vector<string>::iterator iter;
   vector<DataLoc *>::iterator dit;
   for(i = 0; i < fileList.size(); i++)
   {
      for(j = i+1; j < fileList.size(); j++)
      {
         if( fileList[i] == fileList[j] )
         {
cout << "Removing the duplicate*************************\n";
            iter = (vector<string>::iterator)&fileList[i];
            fileList.erase(iter);
            iter = (vector<string>::iterator)&tabnameList[i];
            tabnameList.erase(iter);
            dit = (vector<DataLoc *>::iterator)&datalocList[i];
            datalocList.erase(dit);
            j--;
         }
      }
   }

   for(i = 0; i < fileList.size(); i++)
   {
      if( access(fileList[i].data(), R_OK) )
      {
         cout << "Not found or no permission for file=" << fileList[i] << endl;
         error_flag = 1;
      }


      if( i )
      {
         comb = getCombinedTableName(main_tab, tabnameList[i].data());
cout << "MAIN NAME=" << main_tab << endl;
cout << "COMB=" << comb << endl;
         name_str = comb;
         tabnameList[i] = comb;
         delete comb;
      }

/*
      sprintf(qry, "show table status like '%%%s___%s%%';", 
                                                name_str.data(), ent_name);
//cout << "QRY=" << qry << endl;
      if( gold_conn->executeQuery(qry) )
      {
	 cout << "query error=" << gold_conn->error() <<endl;
	 return 2;
      }

      if( gold_conn->nextRow() )
      {
         cout << "DB table exists with file name=" << fileList[i] << endl;
         cout << "change the file name and then execute\n";
         error_flag = 1;
      }
*/
   }

   delete main_tab;

   if( error_flag )
      return 3;

   return 0;
}

int DynaToDBGen::getIncludeFilesFromDyna
    (
       const char *main_file,
       const char *parent_dir,
       const char *in_table_name
    )
{
   vector<string> local_files_list;
   vector<string> parent_dir_list;
   vector<string> tab_name_list;

   changeBackSlash((char *)main_file);
//cout << "AFTER CAHNGE BAKCSLASH=" << main_file << endl;

   FILE *main_fp = fopen(main_file, "rb");

   if( !main_fp )
   {
      cout << "Unable to open file <" << main_file << ">" << endl;
      return 1;
   }

//cout << "MAIN FILE=" << main_file << endl;

   DataLoc *data_loc = new DataLoc(main_fp);

   IncludeManager *inc_man = IncludeManager::create();
   IncludeImport inc_imp(main_fp, data_loc, inc_man);

   inc_imp.readIncludes();

   vector<ImportObject *> & impobj_list = inc_man->getImportObjectList();
   vector<ImportObject *>::iterator b = impobj_list.begin(), iter,
				    e = impobj_list.end();
   char *file_name, local_file[256], *table_name, *pdir;
   ImportObject *imp_obj = NULL;
   Card *card = NULL;
   string inc_file;
   strcpy(local_file, main_file);
   string file_dir = dirname(local_file);
//cout << "FILE DIR=" << file_dir << endl;
//cout << "MAIN FILE=" << main_file << endl;

cout << "PARENT FROM ARG=" << parent_dir << endl;
   for(; b != e; b++)
   {
      imp_obj = *b;
      card = imp_obj->findCard("Card1");
      if( !card )
          continue;
      file_name = card->stringValue("FILENAME");
      Generic::RemoveTrailingBlanks(file_name);
      changeBackSlash(file_name);
      unsigned int table_id;
      string new_file_name = file_name; 
     
      pdir = dirname((char *)new_file_name.data());
      if(pdir)
      {
          string new_parent_dir = parent_dir + string("/") + pdir;
          parent_dir_list.push_back(new_parent_dir);
      }
      else
          parent_dir_list.push_back(parent_dir);
      table_name = getTableNameFromFile(file_name, &table_id, parent_dir);
      tab_name_list.push_back(table_name);

      delete table_name;
      if( file_name[0] != '\0' )
      {
         inc_file = file_dir;
         inc_file += "/";
         inc_file += file_name;
         local_files_list.push_back(inc_file);
      }
      else
      {
         cout << "No filename specified with *INCLUDE\n";
      }
   }

   fileList.push_back( main_file );
   datalocList.push_back( data_loc );
   if(in_table_name)
       tabnameList.push_back(in_table_name);

   inc_man->reset();
   fclose(main_fp);

   for(unsigned int i = 0; i < local_files_list.size(); i++)
      getIncludeFilesFromDyna(local_files_list[i].data(), parent_dir_list[i].data(), tab_name_list[i].data());
   return 0;
}

size_t DynaToDBGen::checkAndInsertIntoModelList
     (
         const char *fileName,
         bool  mainFileFlag,
         GoldenConn *goldConn
     )
{
    string createQry = "create table if not exists `cae_models_list` (MODEL_INDEX int not null primary key auto_increment, model_path varchar(1024) not null, model_name varchar(1024) not null, email varchar(64), model_uuid bigint unsigned not null, mainfile bool);";

    if (goldConn->executeQuery(createQry.data()))
    {
       cout << "query error=" << goldConn->error() << endl;
       return 1;
    }

   boost::hash<std::string> uuid_hasher;
   size_t intHash = uuid_hasher(fileName);
   char hashBuf[256];
   sprintf(hashBuf, "%zu", intHash);
   string selectQry = "select model_path from `cae_models_list` where model_uuid=";
   selectQry += hashBuf + string(";");
   if (goldConn->executeQuery(selectQry.data()))
   {
      cout << "query error=" << goldConn->error() << endl;
      return 1;
   }
   char **nextRow = goldConn->nextRow();
   if (nextRow == NULL)
   {
      const char *email = MyConnection::getParam("email");
      if(email == NULL)
         email="";
      boost::filesystem::path filePath(fileName);
      boost::filesystem::path parentPath = filePath.parent_path().filename();
      char *onlyFile = basename((char*)fileName);
      string lastDir = parentPath.c_str() + string("/") + onlyFile;
      string insertQry = "insert into cae_models_list values(NULL,";
      insertQry += string("'") + fileName + string("',");
      insertQry += string("'") + lastDir + string("',");
      insertQry += string("'") + email + string("',");
      sprintf(hashBuf, "%zu,%u);", intHash, mainFileFlag);
      insertQry += hashBuf;
      if (goldConn->executeQuery(insertQry.data()))
      {
         cout << "query error=" << goldConn->error() << endl;
         return 2;
      }
   }

   return intHash;
}
