#ifndef _DYNA_TO_DB_GEN_H_
#define _DYNA_TO_DB_GEN_H_

/** Class for converting the LSDYNA native data to binary format for rendering */
class DynaToDBGen
{
public:
   /** Default constructor */
   DynaToDBGen();
   /** Default destructor */
   ~DynaToDBGen();
   
   /** Gets the pointer to the list of files
     * \return Returns the pointer to the list of files
     */
   vector<string> *getFileList()
   {
      return &fileList;
   }

   /** Gets the pointer to the list of table names. For each file and each group
     * of keywords, there is table in database.
     * \return Pointer the list of table names
     */
   vector<string> *getTabNameList()
   {
      return &tabnameList;
   }
    
   /** Gets a pointer to the list of keywords and their locations in each file 
     * \return Pointer to list of keywords and their locations in each file
     */
   vector<DataLoc *> *getDataLocList()
   {
      return &datalocList;
   }
    
   /** Gets the the list of all files including the main file and removes the
     * duplicate names. The main file name length is taken as 40 chars.
     * The combined length of main and an include file is 20 + 20. The combined
     * lengths of table names are stored here.
     * \param main_file Name of main file
     * \param ent_name Name of the entity Not used inside the function
     * \param gold_conn Connection object to access database
     * \return Returns 0 on success else greated than 0
     */
   int checkAndGet
       (
	        const char *main_file,
	        const char *ent_name,
	        GoldenConn *gold_conn
       );

   /** Gets all the include files from a given main file
     * \param main_file Name of main file
     * \return Returns 0 on success else greater than 0
     */
   int getIncludeFilesFromDyna
       (
	        const char *main_file,
          const char *parent_dir = NULL,
          const char *in_table_name = NULL
       );

   size_t checkAndInsertIntoModelList
          (
              const char *fileName,
              bool  mainFileFlag,
              GoldenConn *goldConn
          );

private:
   /** List of file names including the main file */
   vector<string> fileList;
   /** List of names of tables */
   vector<string> tabnameList;
   /** List of pointer to keywords and their locations in each file */
   vector<DataLoc *> datalocList;
};

#endif

