#include <iostream>
#include <fstream>
#include <time.h>
#include <gentime.h>
#include <algorithm>
#include <map>
#include <libgen.h>
#include "dataloc.h"
#include "manager_inc.h"
#include "import_inc.h"
#include "myconnection.h"
#include "dynatodb.h"
#include "feputdb.h"
#include "filegeneric.h"
#include "dynatodbgen.h"
#include <boost/filesystem/path.hpp>
#include <boost/filesystem.hpp>

unsigned int Card::contFlag = 0;
map<string, string> MyConnection::nvMap;

using namespace boost::filesystem;

int main(int argc, char *argv[])
{
   if( argc < 2 )
   {
      cout << "Usage: dynatodb input_filename" << endl;
      return 1;
   }

   path filePath(argv[1]);
   if(!exists(filePath))
   {
       cout << "File <" << argv[1] << "> not found\n";  
       return 0;
   }
   path absPath = canonical(filePath);
   cout << "ABSPATH=" << absPath.c_str() << endl;

   GoldenConn *gold_conn = MyConnection::get();

   if( !gold_conn )
      return 1;

   DynaToDBGen dyna_db;
   if( dyna_db.checkAndGet(absPath.c_str(), "ALL", gold_conn) )
      return 2;

   vector<string> *file_list = dyna_db.getFileList();
   vector<string> *tab_name_list = dyna_db.getTabNameList();
   vector<DataLoc *> *dataloc_list = dyna_db.getDataLocList();
   FILE *fp;

cout << "NUM FILES = " << file_list->size() << endl;

   for(unsigned int i = 0; i < file_list->size(); i++)
   {
      fp = fopen((*file_list)[i].data(), "rb");
      importDynaFile(fp, (*dataloc_list)[i]);
      fclose(fp);
      insertDataIntoDB((*tab_name_list)[i].data(), gold_conn);
      resetAllManagers();
   }

   delete gold_conn;

   return 0;
}

void importDynaFile(FILE *fp, DataLoc *data_loc)
{
   unsigned long    start_millis = GenTime::getCurrentMillis();
   IncludeManager     *includeman = IncludeManager::create();
   IncludeImport      includeimport(fp, data_loc, includeman);
   includeimport.readIncludes();

   vector<ImportObject *> & impobj_list = includeman->getImportObjectList();
   vector<ImportObject *>::iterator b = impobj_list.begin(),
				    e = impobj_list.end();
   char *file_name;
   ImportObject *imp_obj = NULL;
   Card *card = NULL;
   for(; b != e; b++)
   {
      imp_obj = *b;
      card = imp_obj->findCard("Card1");
      if( !card )
	 continue;
      file_name = card->stringValue("FILENAME");
      Generic::RemoveTrailingBlanks(file_name);
      changeBackSlash(file_name);
   }

   DefineManager     *defineman = DefineManager::create();
   DefineImport      defineimport(fp, data_loc, defineman);
   defineimport.readDefines();

   SectionManager *sectionman = SectionManager::create();
   SectionImport  sectionimport(fp, data_loc, sectionman);
   sectionimport.readSections();

   MatManager *matman = MatManager::create();
   MatImport matimport(fp, data_loc, matman);
   matimport.readMats();

   EosManager     *eosman = EosManager::create();
   EosImport      eosimport(fp, data_loc, eosman);
   eosimport.readEoss();

   HgManager     *hgman = HgManager::create();
   HgImport      hgimport(fp, data_loc, hgman);
   hgimport.readHgs();

   PartCManager     *partcman = PartCManager::create();
   PartCImport      partcimport(fp, data_loc, partcman);
   partcimport.readPartCs();

   AirbagManager *abman = AirbagManager::create();
   ABImport      abimport(fp, data_loc, abman);
   abimport.readAirbags();

   ALEManager    *aleman = ALEManager::create();
   ALEImport      aleimport(fp, data_loc, aleman);
   aleimport.readALEs();

   BdryManager    *bdryman = BdryManager::create();
   BdryImport      bdryimport(fp, data_loc, bdryman);
   bdryimport.readBdrys();

   CompManager    *compman = CompManager::create();
   CompImport      compimport(fp, data_loc, compman);
   compimport.readComps();

   ConstManager    *constman = ConstManager::create();
   ConstImport      constimport(fp, data_loc, constman);
   constimport.readConsts();

   ContactManager    *contactman = ContactManager::create();
   ContactImport      contactimport(fp, data_loc, contactman);
   contactimport.readContacts();

   ControlManager    *controlman = ControlManager::create();
   ControlImport      controlimport(fp, data_loc, controlman);
   controlimport.readControls();

   KeywordImport      kw_imp(fp, data_loc, controlman);
   kw_imp.readKWAndTitle();
cout << "KEYWORD TYPE=" << KEYWORD << endl;

   DampingManager    *dampingman = DampingManager::create();
   DampingImport      dampingimport(fp, data_loc, dampingman);
   dampingimport.readDampings();

   DatabaseManager    *databaseman = DatabaseManager::create();
   DatabaseImport      databaseimport(fp, data_loc, databaseman);
   databaseimport.readDatabases();

   DeformManager     *deformman = DeformManager::create();
   DeformImport      deformimport(fp, data_loc, deformman);
   deformimport.readDeforms();

   EFManager     *efman = EFManager::create();
   EFImport      efimport(fp, data_loc, efman);
   efimport.readEFs();

   InitialManager     *initialman = InitialManager::create();
   InitialImport      initialimport(fp, data_loc, initialman);
   initialimport.readInitials();

   IntegrationManager *integrationman = IntegrationManager::create();
   IntegrationImport  integrationimport(fp, data_loc, integrationman);
   integrationimport.readIntegrations();

   InterfaceManager *interfaceman = InterfaceManager::create();
   InterfaceImport  interfaceimport(fp, data_loc, interfaceman);
   interfaceimport.readInterfaces();

   LoadManager *loadman = LoadManager::create();
   LoadImport  loadimport(fp, data_loc, loadman);
   loadimport.readLoads();

   ParameterManager *parameterman = ParameterManager::create();
   ParameterImport  parameterimport(fp, data_loc, parameterman);
   parameterimport.readParameters();

   PerturbManager     *perturbman = PerturbManager::create();
   PerturbImport      perturbimport(fp, data_loc, perturbman);
   perturbimport.readPerturbs();

   RailManager     *railman = RailManager::create();
   RailImport      railimport(fp, data_loc, railman);
   railimport.readRails();

   RigidwallManager *rigidwallman = RigidwallManager::create();
   RigidwallImport  rigidwallimport(fp, data_loc, rigidwallman);
   rigidwallimport.readRigidwalls();

   SensorManager *sensorman = SensorManager::create();
   SensorImport  sensorimport(fp, data_loc, sensorman);
   sensorimport.readSensors();

   TermManager *termman = TermManager::create();
   TermImport  termimport(fp, data_loc, termman);
   termimport.readTerms();

   UserManager *userman = UserManager::create();
   UserImport  userimport(fp, data_loc, userman);
   userimport.readUsers();

   unsigned long end_millis = GenTime::getCurrentMillis();
   cout << "TIME TAKEN FOR ALL ENTITIES = "
	<< (end_millis - start_millis) << " ms\n";
}

void insertDataIntoDB(const char *table_name, GoldenConn *gold_conn)
{
   FePutDB put_db(table_name, gold_conn);

   put_db.insertAirbagsIntoDB();
   put_db.insertAlesIntoDB();
   put_db.insertBoundarysIntoDB();
   put_db.insertComponentsIntoDB();
   put_db.insertConstraintsIntoDB();
   put_db.insertContactsIntoDB();
   put_db.insertControlsIntoDB();
   put_db.insertDampingsIntoDB();
   put_db.insertDatabasesIntoDB();
   put_db.insertDefinesIntoDB();
   put_db.insertDeformsIntoDB();
   put_db.insertEfsIntoDB();
   put_db.insertEossIntoDB();
   put_db.insertHgsIntoDB();
   put_db.insertIncludesIntoDB();
   put_db.insertInitialsIntoDB();
   put_db.insertIntegrationsIntoDB();
   put_db.insertInterfacesIntoDB();
   put_db.insertLoadsIntoDB();
   put_db.insertMatsIntoDB();
   put_db.insertParametersIntoDB();
   put_db.insertPartCsIntoDB();
   put_db.insertPerturbsIntoDB();
   put_db.insertRailsIntoDB();
   put_db.insertRigidwallsIntoDB();
   put_db.insertSectionsIntoDB();
   put_db.insertSensorsIntoDB();
   put_db.insertTermsIntoDB();
   put_db.insertUsersIntoDB();
}

void resetAllManagers()
{
   AirbagManager::reset();
//cout << "AFTER 1" << endl;
   ALEManager::reset();
//cout << "AFTER 2" << endl;
   BdryManager::reset();
//cout << "AFTER 3" << endl;
   CompManager::reset();
//cout << "AFTER 4" << endl;
   ConstManager::reset();
//cout << "AFTER 5" << endl;
   ContactManager::reset();
//cout << "AFTER 6" << endl;
   ControlManager::reset();
//cout << "AFTER 7" << endl;
   DampingManager::reset();
//cout << "AFTER 8" << endl;
   DatabaseManager::reset();
//cout << "AFTER 9" << endl;
   DefineManager::reset();
//cout << "AFTER 10" << endl;
   DeformManager::reset();
//cout << "AFTER 11" << endl;
   EFManager::reset();
//cout << "AFTER 12" << endl;
   EosManager::reset();
//cout << "AFTER 13" << endl;
   HgManager::reset();
//cout << "AFTER 14" << endl;
   IncludeManager::reset();
//cout << "AFTER 15" << endl;
   InitialManager::reset();
//cout << "AFTER 16" << endl;
   IntegrationManager::reset();
//cout << "AFTER 17" << endl;
   InterfaceManager::reset();
//cout << "AFTER 18" << endl;
   LoadManager::reset();
//cout << "AFTER 19" << endl;
   //NodManager::reset();
//cout << "AFTER 20" << endl;
   ParameterManager::reset();
//cout << "AFTER 21" << endl;
   PartCManager::reset();
   PerturbManager::reset();
//cout << "AFTER 22" << endl;
   RailManager::reset();
//cout << "AFTER 23" << endl;
   RigidwallManager::reset();
//cout << "AFTER 24" << endl;
   SectionManager::reset();
//cout << "AFTER 25" << endl;
   SensorManager::reset();
//cout << "AFTER 26" << endl;
   //SetManager::reset();
//cout << "AFTER 27" << endl;
   TermManager::reset();
//cout << "AFTER 28" << endl;
   UserManager::reset();
//cout << "AFTER 29" << endl;
   //ElementManager::reset();
//cout << "AFTER 30" << endl;
   MatManager::reset();
//cout << "AFTER 31" << endl;
}

