#include <iostream>
#include <time.h>
#include "dataloc.h"
#include "elms.h"
#include "gentime.h"
#include "elementmanager.h"
#include "elementimport.h"
#include "dbputelm.h"
#include "myconnection.h"
#include "dynatodbgen.h"
#include <boost/filesystem/path.hpp>
#include <boost/filesystem.hpp>

using namespace std;
using namespace boost::filesystem;

map<string, string> MyConnection::nvMap;
unsigned int Card::contFlag = 0;

int main(int argc, char* argv[])
{
   if( argc < 2 )
   {
      cout << "Usage: elms input_filename" << endl;
      return 1;
   }

   path filePath(argv[1]);
   if(!exists(filePath))
   {
       cout << "File <" << argv[1] << "> not found\n";
       return 0;
   }
   path absPath = canonical(filePath);
   cout << "ABSPATH=" << absPath.c_str() << endl;

   unsigned long    start_millis = GenTime::getCurrentMillis();
   GoldenConn *gold_conn = MyConnection::get();

   if( !gold_conn )
      return 1;

   DynaToDBGen dyna_db;
   if( dyna_db.checkAndGet(absPath.c_str(), "ELEMENTS", gold_conn) )
      return 2;

   vector<string> *file_list = dyna_db.getFileList();
   vector<string> *tab_name_list = dyna_db.getTabNameList();
   vector<DataLoc *> *dataloc_list = dyna_db.getDataLocList();
   FILE *fp;

cout << "NUM FILES = " << file_list->size() << endl;

   for(unsigned int i = 0; i < file_list->size(); i++)
   {
      fp = fopen((*file_list)[i].data(), "rb");
      importElementCards(fp, (*dataloc_list)[i]);
      fclose(fp);
      DBPutElements::insert((*tab_name_list)[i].data(), gold_conn);
      ElementManager::reset();
   }

   delete gold_conn;
   unsigned long    end_millis = GenTime::getCurrentMillis();

cout << "TIME TO INSERT ELEMENTS INTO DB " 
     << (end_millis-start_millis) << " ms\n";

   return 0;
}

int importElementCards(FILE *fp, DataLoc *data_loc)
{
   ElementManager *elmman = ElementManager::create();
   ElementImport  elmimport(fp, data_loc, elmman);

   unsigned int num_elms = elmimport.readElements();

   cout << "NUM Elements = " << num_elms << endl;
   cout << "NUM Elements FROM MANAGER = " << elmman->length() << endl;

   return num_elms;
}

