#include <iostream>
#include <fstream>
#include <time.h>
#include <libgen.h>
#include "dataloc.h"
#include "nodes.h"
#include "nodmanager.h"
#include "nodimport.h"
#include "dbputnodes.h"
#include "myconnection.h"
#include "dynatodbgen.h"
#include "gentime.h"
#include <boost/filesystem/path.hpp>
#include <boost/filesystem.hpp>

using namespace std;
using namespace boost::filesystem;

map<string, string> MyConnection::nvMap;
unsigned int Card::contFlag;

int main(int argc, char* argv[])
{
   if( argc < 2 )
   {
      cout << "Usage: nodes input_filename" << endl;
      return 1;
   }

   path filePath(argv[1]);
   if(!exists(filePath))
   {
       cout << "File <" << argv[1] << "> not found\n";  
       return 0;
   }
   path absPath = canonical(filePath);
   cout << "ABSPATH=" << absPath.c_str() << endl;

   unsigned long start_millis = GenTime::getCurrentMillis();
   GoldenConn *gold_conn = MyConnection::get();

   if( !gold_conn )
      return 1;

   DynaToDBGen dyna_db;
   if( dyna_db.checkAndGet(absPath.c_str(), "NODES", gold_conn) )
      return 2;

   vector<string> *file_list = dyna_db.getFileList();
   vector<string> *tab_name_list = dyna_db.getTabNameList();
   vector<DataLoc *> *dataloc_list = dyna_db.getDataLocList();
   FILE *fp;

   char *file_dir = dirname(argv[1]);
   if(file_dir)
   {
       string modelName = file_dir;
       modelName += "/MODELNAME";
       std::ofstream modelStream(modelName.data());
       modelStream << tab_name_list->at(0);
       modelStream.close();
   }

cout << "NUM FILES = " << file_list->size() << endl;

   for(unsigned int i = 0; i < file_list->size(); i++)
   {
      fp = fopen((*file_list)[i].data(), "rb");
      importNodCards(fp, (*dataloc_list)[i]);
      fclose(fp);
      DBPutNodes::insert((*tab_name_list)[i].data(), gold_conn);
      NodManager::reset();
   }

   delete gold_conn;
   unsigned long end_millis = GenTime::getCurrentMillis();

cout << "TIME TO INSERT ELEMENTS INTO DB " 
     << (end_millis-start_millis) << " ms\n";

   return 0;
}

int importNodCards(FILE *fp, DataLoc *data_loc)
{
   NodManager *nodman = NodManager::create();
   NodImport  nodimport(fp, data_loc, nodman);

   unsigned int num_nods = nodimport.readNods();

   cout << "NUM Nods = " << num_nods << endl;
   cout << "NUM Nods FROM MANAGER = " << nodman->length() << endl;

   return num_nods;
}

