#include <iostream>
#include <time.h>
#include "dataloc.h"
#include "setmanager.h"
#include "setimport.h"
#include "dbputsets.h"
#include "myconnection.h"
#include "sets.h"
#include "gentime.h"
#include "dynatodbgen.h"
#include <boost/filesystem/path.hpp>
#include <boost/filesystem.hpp>

using namespace std;
using namespace boost::filesystem;

map<string, string> MyConnection::nvMap;
unsigned int Card::contFlag = 0;

int main(int argc, char* argv[])
{
   if( argc < 2 )
   {
      cout << "Usage: sets input_filename" << endl;
      return 1;
   }

   path filePath(argv[1]);
   if(!exists(filePath))
   {
       cout << "File <" << argv[1] << "> not found\n";
       return 0;
   }
   path absPath = canonical(filePath);
   cout << "ABSPATH=" << absPath.c_str() << endl;

   unsigned long    start_millis = GenTime::getCurrentMillis();
   GoldenConn *gold_conn = MyConnection::get();

   if( !gold_conn )
      return 1;

   DynaToDBGen dyna_db;
   if( dyna_db.checkAndGet(absPath.c_str(), "SETS", gold_conn) )
      return 2;

   vector<string> *file_list = dyna_db.getFileList();
   vector<string> *tab_name_list = dyna_db.getTabNameList();
   vector<DataLoc *> *dataloc_list = dyna_db.getDataLocList();
   FILE *fp;

cout << "NUM FILES = " << file_list->size() << endl;

   for(unsigned int i = 0; i < file_list->size(); i++)
   {
      fp = fopen((*file_list)[i].data(), "rb");
      importSetCards(fp, (*dataloc_list)[i]);
      fclose(fp);
      DBPutSets::insert((*tab_name_list)[i].data(), gold_conn);
      SetManager::reset();
   }

   delete gold_conn;
   unsigned long    end_millis = GenTime::getCurrentMillis();

cout << "TIME TO INSERT SETS INTO DB " 
     << (end_millis-start_millis) << " ms\n";

   return 0;
}

int importSetCards(FILE *fp, DataLoc *data_loc)
{
   SetManager *setman = SetManager::create();
   SetImport  setimport(fp, data_loc, setman);

   unsigned int num_sets = setimport.readSets();

   cout << "NUM Sets = " << num_sets << endl;
   cout << "NUM Sets FROM MANAGER = " << setman->length() << endl;
   vector<ImportObject *> & imp_list = setman->getImportObjectList();
   ImportObject *new_obj;
   for(unsigned int i = 0; i < num_sets; i++)
   {
      switch(imp_list[i]->getKeywordType())
      {
         case SET_NODE:
         case SET_NODE_LIST:
         {
	    if( imp_list[i]->length() > 100 )
	    {
               char *kw = "*SET_NODE_LIST_GENERATE";
               unsigned int kw_type = SET_NODE_LIST_GENERATE;
               new_obj = new ImportObject(kw, kw_type);
	       createListObject(imp_list[i], new_obj);
               imp_list[i] = new_obj;
	    }
         }
         break;
         case SET_SHELL:
         case SET_SHELL_LIST:
         {
	    if( imp_list[i]->length() > 100 )
	    {
               char *kw = "*SET_SHELL_LIST_GENERATE";
               unsigned int kw_type = SET_SHELL_LIST_GENERATE;

               new_obj = new ImportObject(kw, kw_type);
	       createListObject(imp_list[i], new_obj);
               imp_list[i] = new_obj;
	    }
         }
         break;
      }
   }

   return num_sets;
}

void createListObject(ImportObject *imp_obj, ImportObject *new_obj)
{
   unsigned int i, j;
   int first, prev, cur;
   vector<Card *> & card_list = imp_obj->getCardList();
   IIMap ranges;

   new_obj->addCard(card_list[0]);

cout << "NUM CARDS=" << card_list.size() << endl;

   vector<Data *> & values = card_list[1]->getVarValues();
   values[0]->value(&first);
   prev = first - 1;
   for(i = 1; i < card_list.size(); i++)
   {
      vector<Data *> & values = card_list[i]->getVarValues();
      for(j = 0; j < values.size(); j++)
      {
         values[j]->value(&cur);
         if(cur != (prev+1))
         {
            ranges.insert(IIPair(first, prev));
            first = cur;
         }
         prev = cur;
      }
      delete card_list[i];
   }

   ranges.insert(IIPair(first, prev));

   card_list.clear();

cout << "GOT RANGES " << (int)(1 + ranges.size()/4.0) << endl;

   int id;
   Card *card_obj;
   Integer *int_obj;

   IIIterator b = ranges.begin(), e = ranges.end();
   for(i = 0; i < ranges.size(); i += 4)
   {
      card_obj = new Card("CardLoop");
      for(j = 0; b != e; j++)
      {
         if( j > 3 )
            break;
         id = b->first;
	 int_obj = new Integer(id);
	 card_obj->addField("B1BEG", int_obj);
	 int_obj = new Integer(b->second);
	 card_obj->addField("B1END", int_obj);
	 b++;
      }
      new_obj->addCard(card_obj);
      if( !i )
         Card::clearFlag();
   }

//cout << "REACHED" << ranges.size() << endl;

   //string str;
   //new_obj->tostring(str);
   //cout << str;
}

