﻿#include "filelist.h"
#include "dataloc.h"
#include "mysqlite.h"
#include <iostream>
#include <stdio.h>
#include <boost/filesystem.hpp>
#include <sstream>
#include <set>
#include <string>
#include <omp.h>

using namespace std;
using namespace boost;
using namespace boost::filesystem;

void getAll(const path& root, const string& ext, vector<path>& ret);

int main (int argc, char *argv[])
{
    if(argc < 2)
    {
        cout << "Usage: dynsearch dir_name\n";
        return 1;
    }

    MySqlite sqliteObj("/home/krishna/impexp/dynsearch/dyna.sqlite");

    sqlite3_int64  fileType = 0;
    int            qryIndex;
    if(sqliteObj.GetOpenStatus())
    {
        return 1;
    }
    else
    {
        //qryIndex = sqliteObj.PrepareStatement("drop table FileTypeList");
        //sqliteObj.Execute(qryIndex);
        //qryIndex = sqliteObj.PrepareStatement("drop table FileList");
        //sqliteObj.Execute(qryIndex);
        //qryIndex = sqliteObj.PrepareStatement("drop table KWList");
        //sqliteObj.Execute(qryIndex);

        //files table
        qryIndex = sqliteObj.PrepareStatement("create table if not exists FileTypeList (FType TEXT)");
        sqliteObj.Execute(qryIndex);

        qryIndex = sqliteObj.PrepareStatement("insert into FileTypeList values('LS-DYNA KEYWORD')");
        sqliteObj.Execute(qryIndex);
        fileType = sqliteObj.GetLastRowId();

        qryIndex = sqliteObj.PrepareStatement("create table if not exists FileList (Name TEXT, FileType integer, foreign key(FileType) references FileTypeList(ROWID))");
        sqliteObj.Execute(qryIndex);

        qryIndex = sqliteObj.PrepareStatement("create table if not exists KWList (Name TEXT not null primary key, FileType integer, foreign key(FileType) references FileTypeList(ROWID))");
        sqliteObj.Execute(qryIndex);
        qryIndex = sqliteObj.PrepareStatement("create table if not exists FileTypeList (FType TEXT)");

        sqliteObj.Execute(qryIndex);
        qryIndex = sqliteObj.PrepareStatement("create table if not exists FieldList (Name TEXT not null primary key, FieldStart integer, FieldWidth integer");
        sqliteObj.Execute(qryIndex);

        qryIndex = sqliteObj.PrepareStatement("create table if not exists FieldKWList (KeywordIndex integer, FieldIndex integer, FileType integer, foreign key (KeywordIndex) references KWList(ROWID), foreign key (FieldIndex) references FieldList(ROWID), foreign key(FileType) references FileTypeList(ROWID))");
        sqliteObj.Execute(qryIndex);

        qryIndex = sqliteObj.PrepareStatement("create table if not exists FileKWList (FileIndex integer, KWIndex integer, KWLocation integer, foreign key(FileIndex) references FileList(ROWID), foreign key(KWIndex) references KWList(ROWID))");
        sqliteObj.Execute(qryIndex);
    }

    path dirPath(argv[1]);
    vector<path> filePathList;
    string extStr = ".key|.k|.dyn";

    getAll(dirPath, extStr, filePathList);
    sqlite3_int64 fileIndex;

    string fileListQry = "insert into FileList Values(?,?)";
    string kwListQry = "insert into KWList Values(?,?)";
    string fileKWInsertQry = "insert into FileKWList values(?,?,?)";
    int fileInsertQryIndex = sqliteObj.PrepareStatement(fileListQry.data());
    int kwInsertQryIndex = sqliteObj.PrepareStatement(kwListQry.data());
    int fileKWInsertQryIndex = sqliteObj.PrepareStatement(fileKWInsertQry.data());
    string beginQry = "BEGIN;";
    int bIndex = sqliteObj.PrepareStatement(beginQry.data());
    string endQry = "END;";
    int eIndex = sqliteObj.PrepareStatement(endQry.data());

//#pragma omp parallel for
    for(size_t iIndex = 0; iIndex < filePathList.size(); iIndex++)
    {
        string fileName = filePathList[iIndex].c_str();
cout << fileName << endl;
        FILE *fp = fopen(fileName.data(), "rb");
        if(!fp)
           continue;

        sqliteObj.Execute(bIndex);
        sqliteObj.Reset(fileInsertQryIndex);
        sqliteObj.Bind(1, fileName.data(), fileName.size(), fileInsertQryIndex);
        sqliteObj.Bind(2, (int)fileType, fileInsertQryIndex);
        sqliteObj.Execute(fileInsertQryIndex);
        fileIndex = sqliteObj.GetLastRowId();

        DataLoc dataLoc(fp);
        int 	kwIndex;
        for(size_t jIndex = 0; jIndex < dataLoc.keywordList.size(); jIndex++)
        {
cout << dataLoc.keywordList[jIndex] << endl;
            kwIndex = sqliteObj.IsKeywordExists(dataLoc.keywordList[jIndex].data(), dataLoc.keywordList[jIndex].size());
            if(!kwIndex)
            {
                sqliteObj.Reset(kwInsertQryIndex);
                sqliteObj.Bind(1, dataLoc.keywordList[jIndex].data(), dataLoc.keywordList[jIndex].size(), kwInsertQryIndex);
                sqliteObj.Bind(2, (int)fileType, kwInsertQryIndex);
	        sqliteObj.Execute(kwInsertQryIndex);
                kwIndex = sqliteObj.GetLastRowId();
            }
	    sqliteObj.Reset(fileKWInsertQryIndex);
	    sqliteObj.Bind(1, (int)fileIndex, fileKWInsertQryIndex);
	    sqliteObj.Bind(2, kwIndex, fileKWInsertQryIndex);
	    sqliteObj.Bind(3, (int)dataLoc.slocList[jIndex], fileKWInsertQryIndex);
	    sqliteObj.Execute(fileKWInsertQryIndex);
        }
        fclose(fp);
        sqliteObj.Execute(eIndex);
    }

    return 0;
}

// return the filenames of all files that have the specified extension
// in the specified directory and all subdirectories
void getAll(const path& root, const string& ext, vector<path>& ret)
{
    if(!exists(root) || !is_directory(root)) 
       return;

    istringstream strStream(ext);
    set<string>   filterList;
    string 	  filterStr;
    while(getline(strStream, filterStr, '|'))
    {
       filterList.insert(filterStr);
    }
 
    set<string>::iterator endIter = filterList.end();

    recursive_directory_iterator it(root);
    recursive_directory_iterator endit;

    while(it != endit)
    {
	if(is_regular_file(*it))
        {
           string extStr = it->path().extension().c_str(); 
           transform(extStr.begin(), extStr.end(), extStr.begin(), ::tolower);
           set<string>::iterator setIter = filterList.find(extStr);
           if(setIter != endIter)
              ret.push_back(it->path());
        }
	++it;
    }
}

