#include "mysqlite.h"
#include <string.h>
#include <iostream>
#include <stdlib.h>

MySqlite::MySqlite(const char *fileName) : m_SelKWIndex(-1)
{
   m_OpenStatus = sqlite3_open_v2(fileName, &m_MySqlite, SQLITE_OPEN_CREATE|SQLITE_OPEN_READWRITE|SQLITE_OPEN_FULLMUTEX|SQLITE_OPEN_SHAREDCACHE, NULL);

   cout << "OPEN STATUS=" << m_OpenStatus << endl;
}

int MySqlite::PrepareStatement(const char *stmt)
{
    cout << stmt << endl;
    sqlite3_stmt	   *m_SqliteStmt;
    m_StmtStatus = sqlite3_prepare_v2(m_MySqlite, stmt, strlen(stmt), 
							&m_SqliteStmt, NULL);
    cout << "PREPARE " << m_StmtStatus << endl;

    int curIndex = -1;
    if(m_StmtStatus == 0)
    {
       curIndex = (int)m_StmtArray.size();
       m_StmtArray.push_back(m_SqliteStmt);
       m_StmtMap.insert(StrIntPair(stmt, m_StmtMap.size()));
    }

    return curIndex;
}

int MySqlite::Bind(int paramNum, int intValue, int qryIndex)
{
    if(qryIndex >= (int)m_StmtArray.size())
        return -1;

    m_BindStatus = sqlite3_bind_int(m_StmtArray[qryIndex], paramNum, intValue);

    //cout << "BIND INT " << m_BindStatus << endl;

    return m_BindStatus;
}

int MySqlite::Bind(int paramNum, double dblValue, int qryIndex)
{
    if(qryIndex >= (int)m_StmtArray.size())
        return -1;

    m_BindStatus = sqlite3_bind_double(m_StmtArray[qryIndex], paramNum, dblValue);
    //cout << "BIND DOUBLE " << m_BindStatus << endl;

    return m_BindStatus;
}

int MySqlite::Bind(int paramNum, const char *strValue, int strLen, int qryIndex)
{
    if(qryIndex >= (int)m_StmtArray.size())
        return -1;

    m_BindStatus = sqlite3_bind_text(m_StmtArray[qryIndex], paramNum, strValue, strLen, NULL);

    //cout << "BIND STRING " << m_BindStatus << endl;
    return m_BindStatus;
}

int MySqlite::Bind(int paramNum, int qryIndex)
{
    if(qryIndex >= (int)m_StmtArray.size())
        return -1;

    m_BindStatus = sqlite3_bind_null(m_StmtArray[qryIndex], paramNum);

    //cout << "BIND NULL " << m_BindStatus << endl;
    return m_BindStatus;
}

int MySqlite::Reset(int qryIndex)
{
    if(qryIndex >= (int)m_StmtArray.size())
        return -1;

    m_BindStatus = sqlite3_reset(m_StmtArray[qryIndex]);
    
    return m_BindStatus;
}

int MySqlite::Execute(int qryIndex)
{
    if(qryIndex >= (int)m_StmtArray.size())
        return -1;
    
    m_ExeStatus = sqlite3_step(m_StmtArray[qryIndex]);

    //cout << "EXE STAT =" << m_ExeStatus << endl;
    return m_ExeStatus;
}

const char *MySqlite::GetColumnValue(int qryIndex, int colIndex)
{
    if(qryIndex >= (int)m_StmtArray.size())
        return NULL;

    if(m_ExeStatus == SQLITE_ROW)
    {
	const char *resVal = (const char *)sqlite3_column_text(m_StmtArray[qryIndex], colIndex);
	int stepStatus = sqlite3_step(m_StmtArray[qryIndex]);
//cout << "STEP STAT=" << stepStatus << endl;
	if(stepStatus == SQLITE_DONE || stepStatus == SQLITE_ROW)
	    return resVal;
    }

    return NULL;
}

MySqlite::~MySqlite()
{
}

sqlite3_int64 MySqlite::GetLastRowId()
{
    return sqlite3_last_insert_rowid(m_MySqlite); 
}

int MySqlite::IsKeywordExists(const char *kwName, int kwLen)
{
    if(m_SelKWIndex < 0)
    {
        string fileListQry = "select ROWID from KWList where Name=?";
        m_SelKWIndex = PrepareStatement(fileListQry.data());
cout << "STMT INDEX=" << m_SelKWIndex << endl;
    }

    Reset(m_SelKWIndex);
    Bind(1, kwName, kwLen, m_SelKWIndex);
    int exeStatus = Execute(m_SelKWIndex);
    if(exeStatus == SQLITE_ROW)
    {
        const char *colVal = GetColumnValue(m_SelKWIndex, 0);
//cout << "ROWID=" << colVal << endl;
        if(colVal && colVal[0] != '\0')
            return atoi(colVal);
    }

    return 0;
}

