#ifndef _DBABADVANCEDALE_H_
#define _DBABADVANCEDALE_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *AIRBAG_ADVANCED_ALE
  * keyword */

class DBABAdvancedALE : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBABAdvancedALE(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBABAdvancedALE()
   {
   }

public:
/** Function to get BagIDs details for *AIRBAG_ADVANCED_ALE
  * keyword from database */
   void dbReadBagIDs(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"BAGID1","BAGID2","BAGID3","BAGID4","BAGID5","BAGID6","BAGID7","BAGID8",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, 3, 4, 5, 6, 7, };
      unsigned int man_types[] = {DEFINE, DEFINE, DEFINE, DEFINE, DEFINE, DEFINE, DEFINE, DEFINE, };
      unsigned int kw_types[] = {ALEBAG, ALEBAG, ALEBAG, ALEBAG, ALEBAG, ALEBAG, ALEBAG, ALEBAG, };
      unsigned int num_indices = 8;
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, AIRBAG, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("BagIDs");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","BagIDs",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get HoleIDs details for *AIRBAG_ADVANCED_ALE
  * keyword from database */
   void dbReadHoleIDs(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"HOLEID1","HOLEID2","HOLEID3","HOLEID4","HOLEID5","HOLEID6","HOLEID7","HOLEID8",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, 3, 4, 5, 6, 7, };
      unsigned int man_types[] = {DEFINE, DEFINE, DEFINE, DEFINE, DEFINE, DEFINE, DEFINE, DEFINE, };
      unsigned int kw_types[] = {BAGHOLE, BAGHOLE, BAGHOLE, BAGHOLE, BAGHOLE, BAGHOLE, BAGHOLE, BAGHOLE, };
      unsigned int num_indices = 8;
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, AIRBAG, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("HoleIDs");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","HoleIDs",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get InflIDs details for *AIRBAG_ADVANCED_ALE
  * keyword from database */
   void dbReadInflIDs(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"INFLID1","INFLID2","INFLID3","INFLID4","INFLID5","INFLID6","INFLID7","INFLID8",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, 3, 4, 5, 6, 7, };
      unsigned int man_types[] = {DEFINE, DEFINE, DEFINE, DEFINE, DEFINE, DEFINE, DEFINE, DEFINE, };
      unsigned int kw_types[] = {INFLATOR, INFLATOR, INFLATOR, INFLATOR, INFLATOR, INFLATOR, INFLATOR, INFLATOR, };
      unsigned int num_indices = 8;
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("InflIDs");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","InflIDs",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get ALEMesh details for *AIRBAG_ADVANCED_ALE
  * keyword from database */
   void dbReadALEMesh(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"NX","NY","NZ","UNUSED","ARSNID","IDCENT","EXSID",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_UNUSED, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 7;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_REFERENCES) )
         airbagAdvancedAle(&wordArray[2], numFields, 0, impObj);
      nx = 0;
      if( wordArray[2] )
         nx = atoi(wordArray[2]);
      ny = 0;
      if( wordArray[3] )
         ny = atoi(wordArray[3]);
      nz = 0;
      if( wordArray[4] )
         nz = atoi(wordArray[4]);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("ALEMesh");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","ALEMesh",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get MeshDetails details for *AIRBAG_ADVANCED_ALE
  * keyword from database */
   void dbReadMeshDetails(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"LX","LY","LZ","ITRANS","UIDAIR",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {3, 4, };
      unsigned int man_types[] = {DEFINE, PARTC, };
      unsigned int kw_types[] = {TRANS, 9999, };
      unsigned int num_indices = 2;
      numFields = 5;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("MeshDetails");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","MeshDetails",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get CVCard1 details for *AIRBAG_ADVANCED_ALE
  * keyword from database */
   void dbReadCVCard1(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"ATMOST","ATMOSP","UNUSED","GC","CC","UNUSED","MWD","SPSF",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_UNUSED, DATA_DOUBLE, DATA_DOUBLE, DATA_UNUSED, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("CVCard1");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","CVCard1",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get CVCard2 details for *AIRBAG_ADVANCED_ALE
  * keyword from database */
   int dbReadCVCard2(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"SWTIME","UNUSED","HG","NAIR",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_UNUSED, DATA_DOUBLE, DATA_INT, };
      numFields = 4;
      unsigned int field_widths[] = {10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return 0;
      }
      nair = 0;
      if( wordArray[5] )
         nair = atoi(wordArray[5]);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("CVCard2");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","CVCard2",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
      if( wordArray[5] )
         return atoi(wordArray[5]);
      else
         return 0;
   }

/** Function to get AirCard details for *AIRBAG_ADVANCED_ALE
  * keyword from database */
   void dbReadAirCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"UNUSED","UNUSED","UNUSED","MWAIR","INITM","AIRA","AIRB","AIRC",};
      unsigned int field_types[] = {DATA_UNUSED, DATA_UNUSED, DATA_UNUSED, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      unsigned int end_loop;
      end_loop = nair;
      for(loop_count = 0; loop_count < end_loop; loop_count++)
      {
         numFields = 8;
         wordArray = goldenConn->nextCard();
         if( !wordArray )
         {
            numFields = 0;
         return;
         }
         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","AirCard",loop_count);
            cardObj = new DBCard(name_buf);
            ((DBCard *)cardObj)->index = atoi(wordArray[0]);
            cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
            impObj->addCard(cardObj);
         }
         impObj->cardCount++;
      }
   }

/** Function to import all the cards of keyword *AIRBAG_ADVANCED_ALE
  * from database */
   unsigned int importDBABAdvancedALE()
   {
      int nair = 0;
      dbReadBagIDs();
      dbReadHoleIDs();
      dbReadInflIDs();
      dbReadALEMesh();
      if(nx && ny && nz)
      {
         dbReadMeshDetails();
      }
      dbReadCVCard1();
      nair = dbReadCVCard2();
      dbReadAirCard();
      return 0;
   }
public:
   int nx;
   int ny;
   int nz;
   int nair;
};

#endif

