#ifndef _DBABALE_H_
#define _DBABALE_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *AIRBAG_ALE
  * keyword */

class DBABALE : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBABALE(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBABALE()
   {
   }

public:
/** Function to get SetInfo details for *AIRBAG_ALE
  * keyword from database */
   void dbReadSetInfo(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"SID","SIDTYP","UNUSED","UNUSED","UNUSED","UNUSED","MWD","SPSF",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_UNUSED, DATA_UNUSED, DATA_UNUSED, DATA_UNUSED, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, AIRBAG, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         airbagFind(&wordArray[2], numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("SetInfo");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","SetInfo",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get AmbientCard details for *AIRBAG_ALE
  * keyword from database */
   void dbReadAmbientCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"ATMOST","ATMOSP","UNUSED","GC","CC","TNKVOL","TNKFINP",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_UNUSED, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 7;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, AIRBAG, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("AmbientCard");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","AmbientCard",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Coupling details for *AIRBAG_ALE
  * keyword from database */
   void dbReadCoupling(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"NQUAD","CTYPE","PFAC","FRIC","FRCMIN","NORMTYP","ILEAK","PLEAK",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_DOUBLE, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Coupling");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Coupling",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get VentHole details for *AIRBAG_ALE
  * keyword from database */
   void dbReadVentHole(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"IVSETID","IVTYPE","IBLOCK","VNTCOF",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, };
      numFields = 4;
      unsigned int field_widths[] = {10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_REFERENCES) )
         airbagVentHoleFind(&wordArray[2], numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("VentHole");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","VentHole",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get ALEMesh details for *AIRBAG_ALE
  * keyword from database */
   int dbReadALEMesh(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"NX","NY","NZ","MOVERN","ZOOM",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 5;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return 0;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("ALEMesh");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","ALEMesh",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
      if( wordArray[4] )
         return atoi(wordArray[4]);
      else
         return 0;
   }

/** Function to get Card5a details for *AIRBAG_ALE
  * keyword from database */
   void dbReadCard5a(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"X0","Y0","Z0","X1","Y1","Z1","IPAIR","IPGAS",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card5a");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card5a",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card5b details for *AIRBAG_ALE
  * keyword from database */
   void dbReadCard5b(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"X2","Y2","Z2","X3","Y3","Z3",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card5b");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card5b",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get ALEToCV details for *AIRBAG_ALE
  * keyword from database */
   void dbReadALEToCV(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"SWTIME","UNUSED","HG","NAIR","NGAS","NORIF","LCVEL","LCT",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_UNUSED, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {6, 7, };
      unsigned int man_types[] = {DEFINE, DEFINE, };
      unsigned int kw_types[] = {CURVE, CURVE, };
      unsigned int num_indices = 2;
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      nair = 0;
      if( wordArray[5] )
         nair = atoi(wordArray[5]);
      ngas = 0;
      if( wordArray[6] )
         ngas = atoi(wordArray[6]);
      norif = 0;
      if( wordArray[7] )
         norif = atoi(wordArray[7]);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("ALEToCV");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","ALEToCV",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get AirCard details for *AIRBAG_ALE
  * keyword from database */
   void dbReadAirCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"UNUSED","UNUSED","UNUSED","MWAIR","INITM","AIRA","AIRB","AIRC",};
      unsigned int field_types[] = {DATA_UNUSED, DATA_UNUSED, DATA_UNUSED, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      unsigned int end_loop;
      end_loop = nair;
      for(loop_count = 0; loop_count < end_loop; loop_count++)
      {
         numFields = 8;
         wordArray = goldenConn->nextCard();
         if( !wordArray )
         {
            numFields = 0;
         return;
         }
         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","AirCard",loop_count);
            cardObj = new DBCard(name_buf);
            ((DBCard *)cardObj)->index = atoi(wordArray[0]);
            cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
            impObj->addCard(cardObj);
         }
         impObj->cardCount++;
      }
   }

/** Function to get GasCard details for *AIRBAG_ALE
  * keyword from database */
   void dbReadGasCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"LCMF","UNUSED","UNUSED","MWGAS","UNUSED","GASA","GASB","GASC",};
      unsigned int field_types[] = {DATA_INT, DATA_UNUSED, DATA_UNUSED, DATA_DOUBLE, DATA_UNUSED, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {DEFINE, };
      unsigned int kw_types[] = {CURVE, };
      unsigned int num_indices = 1;
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      unsigned int end_loop;
      end_loop = ngas;
      for(loop_count = 0; loop_count < end_loop; loop_count++)
      {
         numFields = 8;
         wordArray = goldenConn->nextCard();
         if( !wordArray )
         {
            numFields = 0;
         return;
         }
         if( Card::isFlagOn(SAVE_REFERENCES) )
            addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","GasCard",loop_count);
            cardObj = new DBCard(name_buf);
            ((DBCard *)cardObj)->index = atoi(wordArray[0]);
            cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
            impObj->addCard(cardObj);
         }
         impObj->cardCount++;
      }
   }

/** Function to get OrifCard details for *AIRBAG_ALE
  * keyword from database */
   void dbReadOrifCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"NODEID","VECID","ORIFARE",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, 1, };
      unsigned int man_types[] = {NOD, DEFINE, };
      unsigned int kw_types[] = {9999, VECTOR, };
      unsigned int num_indices = 2;
      numFields = 3;
      unsigned int field_widths[] = {10, 10, 10, };
      unsigned int end_loop;
      end_loop = norif;
      for(loop_count = 0; loop_count < end_loop; loop_count++)
      {
         numFields = 3;
         wordArray = goldenConn->nextCard();
         if( !wordArray )
         {
            numFields = 0;
         return;
         }
         if( Card::isFlagOn(SAVE_REFERENCES) )
            addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","OrifCard",loop_count);
            cardObj = new DBCard(name_buf);
            ((DBCard *)cardObj)->index = atoi(wordArray[0]);
            cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
            impObj->addCard(cardObj);
         }
         impObj->cardCount++;
      }
   }

/** Function to import all the cards of keyword *AIRBAG_ALE
  * from database */
   unsigned int importDBABALE()
   {
      int nz = 0;
      dbReadSetInfo();
      dbReadAmbientCard();
      dbReadCoupling();
      dbReadVentHole();
      nz = dbReadALEMesh();
      if( nz > 0 )
      {
         dbReadCard5a();
         dbReadCard5b();
      }
      dbReadALEToCV();
      dbReadAirCard();
      dbReadGasCard();
      dbReadOrifCard();
      return 0;
   }
public:
   int nair;
   int ngas;
   int norif;
};

#endif

