#ifndef _DBABREFERENCEGEOMETRY_H_
#define _DBABREFERENCEGEOMETRY_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *AIRBAG_REFERENCE_GEOMETRY
  * keyword */

class DBABReferenceGeometry : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBABReferenceGeometry(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBABReferenceGeometry()
   {
   }

public:
/** Function to get NodeInfo details for *AIRBAG_REFERENCE_GEOMETRY
  * keyword from database */
   void dbReadNodeInfo(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"NID","X","Y","Z",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {NOD, };
      unsigned int kw_types[] = {9999, };
      unsigned int num_indices = 1;
      numFields = 4;
      unsigned int field_widths[] = {8, 16, 16, 16, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, AIRBAG, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("NodeInfo");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","NodeInfo",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *AIRBAG_REFERENCE_GEOMETRY
  * from database */
   unsigned int importDBABReferenceGeometry()
   {
      unsigned int loop_count = 0;
      dbReadNodeInfo(loop_count);
      loop_count++;
      while(numFields)
      {
         dbReadNodeInfo(loop_count);
         loop_count++;
      }
      ((ExportObject *)impObj)->loopCount = loop_count-1;
      return 0;
   }
};

#endif

