#ifndef _DBABSHELLREFGEOMETRY_H_
#define _DBABSHELLREFGEOMETRY_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *AIRBAG_SHELL_REFERENCE_GEOMETRY
  * keyword */

class DBABShellRefGeometry : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBABShellRefGeometry(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBABShellRefGeometry()
   {
   }

public:
/** Function to get ShellInfo details for *AIRBAG_SHELL_REFERENCE_GEOMETRY
  * keyword from database */
   void dbReadShellInfo(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"EID","PID","N1","N2","N3","N4",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, 3, 4, 5, };
      unsigned int man_types[] = {ELEMENT, PARTC, NOD, NOD, NOD, NOD, };
      unsigned int kw_types[] = {SHELL, 9999, 9999, 9999, 9999, 9999, };
      unsigned int num_indices = 6;
      numFields = 6;
      unsigned int field_widths[] = {8, 8, 8, 8, 8, 8, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, AIRBAG, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("ShellInfo");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","ShellInfo",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *AIRBAG_SHELL_REFERENCE_GEOMETRY
  * from database */
   unsigned int importDBABShellRefGeometry()
   {
      unsigned int loop_count = 0;
      dbReadShellInfo(loop_count);
      loop_count++;
      while(numFields)
      {
         dbReadShellInfo(loop_count);
         loop_count++;
      }
      ((ExportObject *)impObj)->loopCount = loop_count-1;
      return 0;
   }
};

#endif

