#include <iostream>
#include <algorithm>
#include "generic.h"
#include "abtype.h"
#include "abexport.h"
#include <stdlib.h>

using namespace std;

ABExport::ABExport
(
   char          *model_name,
   GoldenConn    *gold_conn,
   AirbagManager *ab_man
)
{
   abManPtr = ab_man;
   goldenConn = gold_conn;
   modelName = model_name;

   initExportSimpleTypesAndFunctions();
   initExportABALETypesAndFunctions();
   initExportHybridTypesAndFunctions();
   initExportWangTypesAndFunctions();
   initExportChemkinTypesAndFunctions();
}

int  ABExport::getKeywordFromType
     (
        unsigned int ab_type,
        string & kw_str
     )
{
   switch(ab_type)
   {
      case AIRBAG_SIMPLE_PRESSURE_VOLUME:
         kw_str = "*AIRBAG_SIMPLE_PRESSURE_VOLUME";
         break;
      case AIRBAG_SIMPLE_AIRBAG_MODEL:
         kw_str = "*AIRBAG_SIMPLE_AIRBAG_MODEL";
         break;
      case AIRBAG_ADIABATIC_GAS_MODEL:
         kw_str = "*AIRBAG_ADIABATIC_GAS_MODEL";
         break;
      case AIRBAG_WANG_NEFSKE:
         kw_str = "*AIRBAG_WANG_NEFSKE";
         break;
      case AIRBAG_WANG_NEFSKE_JETTING:
         kw_str = "*AIRBAG_WANG_NEFSKE_JETTING";
         break;
      case AIRBAG_WANG_NEFSKE_MULTIPLE_JETTING:
         kw_str = "*AIRBAG_WANG_NEFSKE_MULTIPLE_JETTING";
         break;
      case AIRBAG_LOAD_CURVE:
         kw_str = "*AIRBAG_LOAD_CURVE";
         break;
      case AIRBAG_LINEAR_FLUID:
         kw_str = "*AIRBAG_LINEAR_FLUID";
         break;
      case AIRBAG_HYBRID:
         kw_str = "*AIRBAG_HYBRID";
         break;
      case AIRBAG_HYBRID_JETTING:
         kw_str = "*AIRBAG_HYBRID_JETTING";
         break;
      case AIRBAG_HYBRID_CHEMKIN:
         kw_str = "*AIRBAG_HYBRID_CHEMKIN";
         break;
      case AIRBAG_WANG_NEFSKE_POP:
         kw_str = "*AIRBAG_WANG_NEFSKE_POP";
         break;
      case AIRBAG_WANG_NEFSKE_JETTING_CM:
         kw_str = "*AIRBAG_WANG_NEFSKE_JETTING_CM";
         break;
      case AIRBAG_WANG_NEFSKE_MULTIPLE_JETTING_CM:
         kw_str = "*AIRBAG_WANG_NEFSKE_MULTIPLE_JETTING_CM";
         break;
      case AIRBAG_HYBRID_JETTING_CM:
         kw_str = "*AIRBAG_HYBRID_JETTING_CM";
         break;
      case AIRBAG_SIMPLE_PRESSURE_VOLUME_ID:
         kw_str = "*AIRBAG_SIMPLE_PRESSURE_VOLUME_ID";
         break;
      case AIRBAG_SIMPLE_AIRBAG_MODEL_ID:
         kw_str = "*AIRBAG_SIMPLE_AIRBAG_MODEL_ID";
         break;
      case AIRBAG_ADIABATIC_GAS_MODEL_ID:
         kw_str = "*AIRBAG_ADIABATIC_GAS_MODEL_ID";
         break;
      case AIRBAG_WANG_NEFSKE_ID:
         kw_str = "*AIRBAG_WANG_NEFSKE_ID";
         break;
      case AIRBAG_WANG_NEFSKE_JETTING_ID:
         kw_str = "*AIRBAG_WANG_NEFSKE_JETTING_ID";
         break;
      case AIRBAG_WANG_NEFSKE_MULTIPLE_JETTING_ID:
         kw_str = "*AIRBAG_WANG_NEFSKE_MULTIPLE_JETTING_ID";
         break;
      case AIRBAG_LOAD_CURVE_ID:
         kw_str = "*AIRBAG_LOAD_CURVE_ID";
         break;
      case AIRBAG_LINEAR_FLUID_ID:
         kw_str = "*AIRBAG_LINEAR_FLUID_ID";
         break;
      case AIRBAG_HYBRID_ID:
         kw_str = "*AIRBAG_HYBRID_ID";
         break;
      case AIRBAG_HYBRID_JETTING_ID:
         kw_str = "*AIRBAG_HYBRID_JETTING_ID";
         break;
      case AIRBAG_HYBRID_CHEMKIN_ID:
         kw_str = "*AIRBAG_HYBRID_CHEMKIN_ID";
         break;
      case AIRBAG_WANG_NEFSKE_POP_ID:
         kw_str = "*AIRBAG_WANG_NEFSKE_POP_ID";
         break;
      case AIRBAG_WANG_NEFSKE_JETTING_CM_ID:
         kw_str = "*AIRBAG_WANG_NEFSKE_JETTING_CM_ID";
         break;
      case AIRBAG_WANG_NEFSKE_MULTIPLE_JETTING_CM_ID:
         kw_str = "*AIRBAG_WANG_NEFSKE_MULTIPLE_JETTING_CM_ID";
         break;
      case AIRBAG_HYBRID_JETTING_CM_ID:
         kw_str = "*AIRBAG_HYBRID_JETTING_CM_ID";
         break;
      case AIRBAG_ADVANCED_ALE:
         kw_str = "*AIRBAG_ADVANCED_ALE";
         break;
      case AIRBAG_ALE:
         kw_str = "*AIRBAG_ALE";
         break;
      case AIRBAG_INTERACTION:
         kw_str = "*AIRBAG_INTERACTION";
         break;
      case AIRBAG_SHELL_REFERENCE_GEOMETRY:
         kw_str = "*AIRBAG_SHELL_REFERENCE_GEOMETRY";
         break;
      case AIRBAG_REFERENCE_GEOMETRY:
         kw_str = "*AIRBAG_REFERENCE_GEOMETRY";
         break;
      case AIRBAG_REFERENCE_GEOMETRY_BIRTH:
         kw_str = "*AIRBAG_REFERENCE_GEOMETRY_BIRTH";
         break;
      case AIRBAG_REFERENCE_GEOMETRY_RDT:
         kw_str = "*AIRBAG_REFERENCE_GEOMETRY_RDT";
         break;
      case AIRBAG_REFERENCE_GEOMETRY_BIRTH_RDT:
         kw_str = "*AIRBAG_REFERENCE_GEOMETRY_BIRTH_RDT";
         break;
      case AB_NEW_TYPE:
      default:
         return 1;
   }

   return 0;
}

unsigned int ABExport::dbReadAirbags()
{
   char         **row_data, buf[16];
   unsigned int	i, num_abs = 0, total_abs = 0, num_kw_types = 0;
   expTypeFuncIterator eexp_iter = expTypeFuncMap.end(), exp_iter;

   string       qry = "select kw_type from ", kw_str;
   string table_name = "`" + modelName + "_AIRBAGS`";
   qry += table_name;
   qry += " group by kw_type;";

cout << "KW QRY = " << qry << endl;

   if( goldenConn->executeQuery( qry.data() ) )
      return 0;

   num_kw_types = goldenConn->numRows();

   if( !num_kw_types )
      return 0;

   unsigned int *kw_types = new unsigned int[num_kw_types];

   for(i = 0; i < num_kw_types; i++)
   {
      row_data = goldenConn->nextRow();
      kw_types[i] = atoi( row_data[0] );
cout << "KW AB TYPE = " << kw_types[i] << endl;
   }

   for(i = 0; i < num_kw_types; i++)
   {
      qry = "select * from ";
      qry += table_name;
      qry += " where kw_type=";
      sprintf(buf, "%u", kw_types[i]);
      qry += buf;
      qry += " order by card_index;";

cout << "AB QRY = " << qry << endl;

      if( getKeywordFromType(kw_types[i], kw_str) )
         continue;

cout << "AB KW = " << kw_str << endl;

      if( goldenConn->executeQuery( qry.data() ) )
	 break;

      exp_iter = expTypeFuncMap.find(kw_types[i]);

      if( exp_iter == eexp_iter )
      {
	 cout << "AB TYPE NOT FOUND" << endl;
         continue;
      }

      num_abs = 0;
      while( goldenConn->rowsLeft() )
      {
	 impObj = new ExportObject((char *)kw_str.data(), kw_types[i]);
         goldenConn->clearFlag(KW_DATA_END);
	 (exp_iter->second)(goldenConn, impObj);
         if( impObj->cardCount )
         {
	    abManPtr->add(kw_str.data(), impObj);
	    num_abs++;
         }
         else
            delete impObj;
      }

      total_abs += num_abs;
   }

cout << "NUM ABS in EXPORT=" << total_abs << endl;

   delete kw_types;

   return total_abs;
}

