#ifndef _AB_EXPORT_H_
#define _AB_EXPORT_H_

#include "airbagmanager.h"
#include <string>
#include <map>
#include "goldenconn.h"
#include "dbcard.h"
#include "abtype.h"
#include "exptypemap.h"

/** Class to get data from database for *AIRBAG keywords */
class ABExport
{
public:
   /** Constructor for creating this object
     * \param model_name Name of the model for which the data to be obtained
     * \param gold_conn Connection object for accessing the database
     * \param ab_man Manager pointer to store the data obtained
     */
   ABExport
   (
      char          *model_name,
      GoldenConn    *gold_conn,
      AirbagManager *ab_man
   );

   ~ABExport()
   {
      abManPtr = NULL;
      goldenConn = NULL;
      expTypeFuncMap.clear();
   }

   /** Gets the name of keyword from its type. Type is stored in the database
     * \param ab_type Type of keyword
     * \param kw_str Keyword name is stored in this string
     * \return Returns 0 if keyword is found for the given type else 1
     */
   int  getKeywordFromType
	(
	   unsigned int ab_type,
	   string & kw_str
	);

   /** Imports the *AIRBAG keywords from database
     * \return Returns the number of *AIRBAG keywords imported
     */
   unsigned int dbReadAirbags();

   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *AIRBAG keyword types and their function pointers
     */
   void initExportSimpleTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *AIRBAG keyword types and their function pointers
     */
   void initExportHybridTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *AIRBAG keyword types and their function pointers
     */
   void initExportABALETypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *AIRBAG keyword types and their function pointers
     */
   void initExportWangTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *AIRBAG keyword types and their function pointers
     */
   void initExportChemkinTypesAndFunctions();

private:
   string        modelName;
   AirbagManager *abManPtr;
   /** Connection object for accessing the data */
   GoldenConn    *goldenConn;
   /** Object to store the data imported from database */
   ImportObject  *impObj;
   /** A map between type of keyword and pointer to the function to be called */
   map<unsigned int, ExportFunctionPtr>  expTypeFuncMap;
};

#endif

