#ifndef _DBABHYBRIDCHEMKIN_H_
#define _DBABHYBRIDCHEMKIN_H_

#include "manager.h"
#include "dispexport.h"
#include "dbairbag.h"

/** Class used for getting data from database for *AIRBAG_HYBRID_CHEMKIN
  * keyword */

class DBABHybridChemkin : public DBAirbag
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBABHybridChemkin(GoldenConn *gold_conn, ImportObject *imp_obj) : DBAirbag (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBABHybridChemkin()
   {
   }

public:
/** Function to get GasCard details for *AIRBAG_HYBRID_CHEMKIN
  * keyword from database */
   int dbReadGasCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"LCIDM","LCIDT","NGAS","DATA","ATMT","ATMP","RG",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, 1, };
      unsigned int man_types[] = {DEFINE, DEFINE, };
      unsigned int kw_types[] = {CURVE, CURVE, };
      unsigned int num_indices = 2;
      numFields = 7;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return 0;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, AIRBAG, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      data = 0;
      if( wordArray[5] )
         data = atoi(wordArray[5]);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("GasCard");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","GasCard",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
      if( wordArray[4] )
         return atoi(wordArray[4]);
      else
         return 0;
   }

/** Function to get HeatCard details for *AIRBAG_HYBRID_CHEMKIN
  * keyword from database */
   void dbReadHeatCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"HCONV",};
      unsigned int field_types[] = {DATA_DOUBLE, };
      numFields = 1;
      unsigned int field_widths[] = {10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, AIRBAG, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("HeatCard");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","HeatCard",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get VentOrifice details for *AIRBAG_HYBRID_CHEMKIN
  * keyword from database */
   void dbReadVentOrifice(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"C23","A23",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 2;
      unsigned int field_widths[] = {10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("VentOrifice");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","VentOrifice",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get ControlCard details for *AIRBAG_HYBRID_CHEMKIN
  * keyword from database */
   void dbReadControlCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"CHNAME","MW","LCIDN","FMOLE","FMOLET",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {2, };
      unsigned int man_types[] = {DEFINE, };
      unsigned int kw_types[] = {CURVE, };
      unsigned int num_indices = 1;
      numFields = 5;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("ControlCard");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","ControlCard",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get DATA_EQ_1_Card1 details for *AIRBAG_HYBRID_CHEMKIN
  * keyword from database */
   void dbReadDATA_EQ_1_Card1(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"TLOW","TMID","THIGH",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 3;
      unsigned int field_widths[] = {10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("DATA_EQ_1_Card1");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","DATA_EQ_1_Card1",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get DATA_EQ_1_Card2 details for *AIRBAG_HYBRID_CHEMKIN
  * keyword from database */
   void dbReadDATA_EQ_1_Card2(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"a_low","b_low","c_low","d_low","e_low","f_low","h_low",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 7;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("DATA_EQ_1_Card2");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","DATA_EQ_1_Card2",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get DATA_EQ_1_Card3 details for *AIRBAG_HYBRID_CHEMKIN
  * keyword from database */
   void dbReadDATA_EQ_1_Card3(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"a_high","b_high","c_high","d_high","e_high","f_high","h_high",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 7;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("DATA_EQ_1_Card3");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","DATA_EQ_1_Card3",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get DATA_EQ_3_Card details for *AIRBAG_HYBRID_CHEMKIN
  * keyword from database */
   void dbReadDATA_EQ_3_Card(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"a","b","c","d","e",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 5;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("DATA_EQ_3_Card");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","DATA_EQ_3_Card",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *AIRBAG_HYBRID_CHEMKIN
  * from database */
   unsigned int importDBABHybridChemkin()
   {
      int ngas = 0;
      importDBAirbag();
      ngas = dbReadGasCard();
      dbReadHeatCard();
      dbReadVentOrifice();
      if(data == 1)
      {
         for(int i = 0; i < ngas; i++)
         {
            dbReadControlCard();
            dbReadDATA_EQ_1_Card1();
            dbReadDATA_EQ_1_Card2();
            dbReadDATA_EQ_1_Card3();
         }
      }
      else if(data == 3)
      {
         for(int i = 0; i < ngas; i++)
         {
            dbReadControlCard();
            dbReadDATA_EQ_3_Card();
         }
      }
      else if(data == 2)
      {
         for(int i = 0; i < ngas; i++)
         {
            dbReadControlCard();
         }
      }
      return 0;
   }
public:
   int data;
};

#endif

