#ifndef _DBABHYBRID_H_
#define _DBABHYBRID_H_

#include "manager.h"
#include "dispexport.h"
#include "dbairbag.h"

/** Class used for getting data from database for *AIRBAG_HYBRID
  * keyword */

class DBABHybrid : public DBAirbag
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBABHybrid(GoldenConn *gold_conn, ImportObject *imp_obj) : DBAirbag (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBABHybrid()
   {
   }

public:
/** Function to get AtmosCard details for *AIRBAG_HYBRID
  * keyword from database */
   void dbReadAtmosCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"ATMOST","ATMOSP","ATMOSD","GC","CC",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 5;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, AIRBAG, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("AtmosCard");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","AtmosCard",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get ExitHole details for *AIRBAG_HYBRID
  * keyword from database */
   void dbReadExitHole(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"C23","LCC23","A23","LCA23","CP23","LCCP23","AP23","LCAP23",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_INT, };
      unsigned int field_indices[] = {1, 3, 5, 7, };
      unsigned int man_types[] = {DEFINE, DEFINE, DEFINE, DEFINE, };
      unsigned int kw_types[] = {CURVE, CURVE, CURVE, CURVE, };
      unsigned int num_indices = 4;
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, AIRBAG, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("ExitHole");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","ExitHole",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get VentOption details for *AIRBAG_HYBRID
  * keyword from database */
   int dbReadVentOption(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"OPT","PVENT","NGAS",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, DATA_INT, };
      numFields = 3;
      unsigned int field_widths[] = {10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return 0;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("VentOption");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","VentOption",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
      if( wordArray[4] )
         return atoi(wordArray[4]);
      else
         return 0;
   }

/** Function to get GasCard details for *AIRBAG_HYBRID
  * keyword from database */
   void dbReadGasCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"LCIDM","LCIDT","UNUSED","MW","INITM","A","B","C",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_UNUSED, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, 1, };
      unsigned int man_types[] = {DEFINE, DEFINE, };
      unsigned int kw_types[] = {CURVE, CURVE, };
      unsigned int num_indices = 2;
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("GasCard");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","GasCard",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get MassCard details for *AIRBAG_HYBRID
  * keyword from database */
   void dbReadMassCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"FMASS",};
      unsigned int field_types[] = {DATA_DOUBLE, };
      numFields = 1;
      unsigned int field_widths[] = {10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("MassCard");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","MassCard",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *AIRBAG_HYBRID
  * from database */
   unsigned int importDBABHybrid()
   {
      int ngas = 0;
      importDBAirbag();
      dbReadAtmosCard();
      dbReadExitHole();
      ngas = dbReadVentOption();
      if( ngas != 0 )
      {
         for(int i = 0; i < ngas; i++)
         {
            dbReadGasCard();
            dbReadMassCard();
         }
      }
      return 0;
   }
};

#endif

