#ifndef _DBABHYBRIDJETTING_H_
#define _DBABHYBRIDJETTING_H_

#include "manager.h"
#include "dispexport.h"
#include "dbabhybrid.h"

/** Class used for getting data from database for *AIRBAG_HYBRID_JETTING
  * keyword */

class DBABHybridJetting : public DBABHybrid
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBABHybridJetting(GoldenConn *gold_conn, ImportObject *imp_obj) : DBABHybrid (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBABHybridJetting()
   {
   }

public:
/** Function to get FocalPoint1 details for *AIRBAG_HYBRID_JETTING
  * keyword from database */
   void dbReadFocalPoint1(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"XJFP","YJFP","ZJFP","XJVH","YJVH","ZJVH","CA","BETA",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, AIRBAG, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("FocalPoint1");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","FocalPoint1",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get FocalPoint2 details for *AIRBAG_HYBRID_JETTING
  * keyword from database */
   void dbReadFocalPoint2(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"XSJFP","YSJFP","ZSJFP","PSID","UNUSED","NODE1","NODE2","NODE3",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_UNUSED, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {3, 5, 6, 7, };
      unsigned int man_types[] = {SET, NOD, NOD, NOD, };
      unsigned int kw_types[] = {9999, 9999, 9999, 9999, };
      unsigned int num_indices = 4;
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, AIRBAG, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("FocalPoint2");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","FocalPoint2",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *AIRBAG_HYBRID_JETTING
  * from database */
   unsigned int importDBABHybridJetting()
   {
      importDBABHybrid();
      dbReadFocalPoint1();
      dbReadFocalPoint2();
      return 0;
   }
};

#endif

