#ifndef _DBABLINEARFLUID_H_
#define _DBABLINEARFLUID_H_

#include "manager.h"
#include "dispexport.h"
#include "dbairbag.h"

/** Class used for getting data from database for *AIRBAG_LINEAR_FLUID
  * keyword */

class DBABLinearFluid : public DBAirbag
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBABLinearFluid(GoldenConn *gold_conn, ImportObject *imp_obj) : DBAirbag (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBABLinearFluid()
   {
   }

public:
/** Function to get Fluid details for *AIRBAG_LINEAR_FLUID
  * keyword from database */
   void dbReadFluid(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"BULK","RO","LCINT","LCOUTT","LCOUTP","LCFIT","LCBULK","LCID",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {2, 3, 4, 5, 6, 7, };
      unsigned int man_types[] = {DEFINE, DEFINE, DEFINE, DEFINE, DEFINE, DEFINE, };
      unsigned int kw_types[] = {CURVE, CURVE, CURVE, CURVE, CURVE, CURVE, };
      unsigned int num_indices = 6;
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, AIRBAG, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Fluid");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Fluid",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *AIRBAG_LINEAR_FLUID
  * from database */
   unsigned int importDBABLinearFluid()
   {
      importDBAirbag();
      dbReadFluid();
      return 0;
   }
};

#endif

