#ifndef _DBABSIMPLEPRESSUREVOLUME_H_
#define _DBABSIMPLEPRESSUREVOLUME_H_

#include "manager.h"
#include "dispexport.h"
#include "dbairbag.h"

/** Class used for getting data from database for *AIRBAG_SIMPLE_PRESSURE_VOLUME
  * keyword */

class DBABSimplePressureVolume : public DBAirbag
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBABSimplePressureVolume(GoldenConn *gold_conn, ImportObject *imp_obj) : DBAirbag (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBABSimplePressureVolume()
   {
   }

public:
/** Function to get SPVolume details for *AIRBAG_SIMPLE_PRESSURE_VOLUME
  * keyword from database */
   void dbReadSPVolume(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"CN","BETA","LCID","LCIDDR",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {2, 3, };
      unsigned int man_types[] = {DEFINE, DEFINE, };
      unsigned int kw_types[] = {CURVE, CURVE, };
      unsigned int num_indices = 2;
      numFields = 4;
      unsigned int field_widths[] = {10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, AIRBAG, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("SPVolume");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","SPVolume",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *AIRBAG_SIMPLE_PRESSURE_VOLUME
  * from database */
   unsigned int importDBABSimplePressureVolume()
   {
      importDBAirbag();
      dbReadSPVolume();
      return 0;
   }
};

#endif

