#ifndef _DBAIRBAG_H_
#define _DBAIRBAG_H_

#include "manager.h"
#include "dispexport.h"
#include "goldenconn.h"
#include "dbcard.h"

/** Class used for getting data from database for *AIRBAG
  * keyword */

class DBAirbag
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBAirbag(GoldenConn *gold_conn, ImportObject *imp_obj)
   {
      goldenConn = gold_conn;
      impObj = imp_obj;
      numFields = 0;
      wordArray = NULL;
      cardObj = NULL;
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBAirbag()
   {
      goldenConn = NULL;
      impObj = NULL;
      numFields = 0;
      wordArray = NULL;
      cardObj = NULL;
   }

public:
/** Number of fields in each card */
   unsigned int   numFields;
/** List of field values read from database */
   char           **wordArray;
/** Object to save the imported data from database */
   ImportObject   *impObj;
/** Object to connect to database */
   GoldenConn     *goldenConn;
/** Object to store the fields and their values */
   Card           *cardObj;

public:
/** Function to get AirbagDetails details for *AIRBAG
  * keyword from database */
   void dbReadAirbagDetails(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"ABID","HEADING",};
      unsigned int field_types[] = {DATA_INT, DATA_CHAR_ARRAY, };
      numFields = 2;
      unsigned int field_widths[] = {10, 70, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 2, AIRBAG, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("AirbagDetails");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","AirbagDetails",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get SetInfo details for *AIRBAG
  * keyword from database */
   int dbReadSetInfo(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"SID","SIDTYP","RBID","VSCA","PSCA","VINI","MWD","SPSF",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return 0;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, AIRBAG, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         airbagFind(&wordArray[2], numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("SetInfo");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","SetInfo",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
      if( wordArray[4] )
         return atoi(wordArray[4]);
      else
         return 0;
   }

/** Function to get NumInputParams details for *AIRBAG
  * keyword from database */
   int dbReadNumInputParams(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"N",};
      unsigned int field_types[] = {DATA_INT, };
      numFields = 1;
      unsigned int field_widths[] = {10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return 0;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, AIRBAG, impObj);
      n = 0;
      if( wordArray[2] )
         n = atoi(wordArray[2]);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("NumInputParams");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","NumInputParams",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
      if( wordArray[2] )
         return atoi(wordArray[2]);
      else
         return 0;
   }

/** Function to get InputParams details for *AIRBAG
  * keyword from database */
   void dbReadInputParams(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"C1","C2","C3","C4","C5","C6","C7","C8",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      unsigned int end_loop;
      end_loop = ((n%8) ? (n/8)+1 : n/8);
      for(loop_count = 0; loop_count < end_loop; loop_count++)
      {
         numFields = 8;
         wordArray = goldenConn->nextCard();
         if( !wordArray )
         {
            numFields = 0;
         return;
         }
         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","InputParams",loop_count);
            cardObj = new DBCard(name_buf);
            ((DBCard *)cardObj)->index = atoi(wordArray[0]);
            cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
            impObj->addCard(cardObj);
         }
         impObj->cardCount++;
      }
   }

/** Function to get RBID_LT_0_Card1 details for *AIRBAG
  * keyword from database */
   void dbReadRBID_LT_0_Card1(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"AX","AY","AZ","AMAG","TDUR",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 5;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("RBID_LT_0_Card1");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","RBID_LT_0_Card1",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get RBID_LT_0_Card2 details for *AIRBAG
  * keyword from database */
   void dbReadRBID_LT_0_Card2(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"DVX","DVY","DVZ","DVMAG",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 4;
      unsigned int field_widths[] = {10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("RBID_LT_0_Card2");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","RBID_LT_0_Card2",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get RBID_LT_0_Card3 details for *AIRBAG
  * keyword from database */
   void dbReadRBID_LT_0_Card3(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"UX","UY","UZ","UMAG",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 4;
      unsigned int field_widths[] = {10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("RBID_LT_0_Card3");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","RBID_LT_0_Card3",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *AIRBAG
  * from database */
   unsigned int importDBAirbag()
   {
      int rbid = 0;
      int n = 0;
      if( strstr(impObj->getKeyword().data(), "_ID") )
      {
         dbReadAirbagDetails();
      }
      rbid = dbReadSetInfo();
      if( rbid > 0 )
      {
         n = dbReadNumInputParams();
         dbReadInputParams();
      }
      else if( rbid < 0 )
      {
         dbReadRBID_LT_0_Card1();
         dbReadRBID_LT_0_Card2();
         dbReadRBID_LT_0_Card3();
      }
      return 0;
   }
public:
   int n;
};

#endif

