#ifndef _DBABWANGNEFSKE_H_
#define _DBABWANGNEFSKE_H_

#include "manager.h"
#include "dispexport.h"
#include "dbairbag.h"

/** Class used for getting data from database for *AIRBAG_WANG_NEFSKE
  * keyword */

class DBABWangNefske : public DBAirbag
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBABWangNefske(GoldenConn *gold_conn, ImportObject *imp_obj) : DBAirbag (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBABWangNefske()
   {
   }

public:
/** Function to get GasCard details for *AIRBAG_WANG_NEFSKE
  * keyword from database */
   int dbReadGasCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"CV","CP","T","LCT","LCMT","TVOL","LCDT","IABT",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, };
      unsigned int field_indices[] = {3, 4, 6, };
      unsigned int man_types[] = {DEFINE, DEFINE, DEFINE, };
      unsigned int kw_types[] = {CURVE, CURVE, CURVE, };
      unsigned int num_indices = 3;
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return 0;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, AIRBAG, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      cv = 0;
      if( wordArray[2] )
         cv = atof(wordArray[2]);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("GasCard");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","GasCard",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
      if( wordArray[6] )
         return atoi(wordArray[6]);
      else
         return 0;
   }

/** Function to get ExitHole details for *AIRBAG_WANG_NEFSKE
  * keyword from database */
   void dbReadExitHole(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"C23","LCC23","A23","LCA23","CP23","LCCP23","AP23","LCAP23",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_INT, };
      unsigned int field_indices[] = {1, 3, 5, 7, };
      unsigned int man_types[] = {DEFINE, DEFINE, DEFINE, DEFINE, };
      unsigned int kw_types[] = {CURVE, CURVE, CURVE, CURVE, };
      unsigned int num_indices = 4;
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, AIRBAG, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("ExitHole");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","ExitHole",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get AmbientCard details for *AIRBAG_WANG_NEFSKE
  * keyword from database */
   void dbReadAmbientCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"PE","RO","GC","LCEFR","POVER","PPOP","OPT","KNKDN",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {3, };
      unsigned int man_types[] = {DEFINE, };
      unsigned int kw_types[] = {CURVE, };
      unsigned int num_indices = 1;
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("AmbientCard");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","AmbientCard",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get LCMT_EQ_0 details for *AIRBAG_WANG_NEFSKE
  * keyword from database */
   void dbReadLCMT_EQ_0(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"IOC","IOA","IVOL","IRO","IT","LCBF",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, };
      unsigned int field_indices[] = {5, };
      unsigned int man_types[] = {DEFINE, };
      unsigned int kw_types[] = {CURVE, };
      unsigned int num_indices = 1;
      numFields = 6;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("LCMT_EQ_0");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","LCMT_EQ_0",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get CV_EQ_0 details for *AIRBAG_WANG_NEFSKE
  * keyword from database */
   void dbReadCV_EQ_0(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"TEXT","A","B","MW","GASC",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 5;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("CV_EQ_0");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","CV_EQ_0",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *AIRBAG_WANG_NEFSKE
  * from database */
   unsigned int importDBABWangNefske()
   {
      int lcmt = 0;
      importDBAirbag();
      lcmt = dbReadGasCard();
      dbReadExitHole();
      dbReadAmbientCard();
      if( !lcmt )
      {
         dbReadLCMT_EQ_0();
      }
      if( cv == 0.0 )
      {
         dbReadCV_EQ_0();
      }
      return 0;
   }
public:
   double cv;
};

#endif

