#ifndef _DBABWANGNEFSKEPOP_H_
#define _DBABWANGNEFSKEPOP_H_

#include "manager.h"
#include "dispexport.h"
#include "dbabwangnefske.h"

/** Class used for getting data from database for *AIRBAG_WANG_NEFSKE_POP
  * keyword */

class DBABWangNefskePop : public DBABWangNefske
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBABWangNefskePop(GoldenConn *gold_conn, ImportObject *imp_obj) : DBABWangNefske (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBABWangNefskePop()
   {
   }

public:
/** Function to get PopCard details for *AIRBAG_WANG_NEFSKE_POP
  * keyword from database */
   void dbReadPopCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"TDP","AXP","AYP","AZP","AMAGP","TDURP","TDA","RBIDP",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, AIRBAG, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("PopCard");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","PopCard",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *AIRBAG_WANG_NEFSKE_POP
  * from database */
   unsigned int importDBABWangNefskePop()
   {
      importDBABWangNefske();
      dbReadPopCard();
      return 0;
   }
};

#endif

