#ifndef _DBALEFSIPROJECTION_H_
#define _DBALEFSIPROJECTION_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *ALE_FSI_PROJECTION
  * keyword */

class DBAleFsiProjection : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBAleFsiProjection(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBAleFsiProjection()
   {
   }

public:
/** Function to get SetInfo details for *ALE_FSI_PROJECTION
  * keyword from database */
   void dbReadSetInfo(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"LAGSID","ALESID","LSIDTYP","ASIDTYP","SMMGID","ICORREC","INORM",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 7;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, ALE, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         aleFsiFind(&wordArray[2], numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("SetInfo");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","SetInfo",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Couple details for *ALE_FSI_PROJECTION
  * keyword from database */
   void dbReadCouple(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"BIRTH","DEATH",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 2;
      unsigned int field_widths[] = {10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, ALE, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Couple");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Couple",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *ALE_FSI_PROJECTION
  * from database */
   unsigned int importDBAleFsiProjection()
   {
      dbReadSetInfo();
      dbReadCouple();
      return 0;
   }
};

#endif

