#ifndef _DBALEFSISWITCHMMG_H_
#define _DBALEFSISWITCHMMG_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *ALE_FSI_SWITCH_MMG
  * keyword */

class DBAleFsiSwitchMmg : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBAleFsiSwitchMmg(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBAleFsiSwitchMmg()
   {
   }

public:
/** Function to get IDCard details for *ALE_FSI_SWITCH_MMG
  * keyword from database */
   void dbReadIDCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"ID",};
      unsigned int field_types[] = {DATA_INT, };
      numFields = 1;
      unsigned int field_widths[] = {10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 2, ALE, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("IDCard");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","IDCard",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Title details for *ALE_FSI_SWITCH_MMG
  * keyword from database */
   void dbReadTitle(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"UNUSED","TITLE",};
      unsigned int field_types[] = {DATA_UNUSED, DATA_CHAR_ARRAY, };
      numFields = 2;
      unsigned int field_widths[] = {10, 70, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, ALE, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Title");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Title",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get SetInfo details for *ALE_FSI_SWITCH_MMG
  * keyword from database */
   void dbReadSetInfo(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"SID","STYPE","NQUAD","XOFF","BTIME","DTIME","NFREQ","NFOLD",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, ALE, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         airbagVentHoleFind(&wordArray[2], numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("SetInfo");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","SetInfo",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get MmgCard details for *ALE_FSI_SWITCH_MMG
  * keyword from database */
   void dbReadMmgCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"FR_MMG","TO_MMG","XLEN",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, 1, };
      unsigned int man_types[] = {SET, SET, };
      unsigned int kw_types[] = {MMG, MMG, };
      unsigned int num_indices = 2;
      numFields = 3;
      unsigned int field_widths[] = {10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("MmgCard");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","MmgCard",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *ALE_FSI_SWITCH_MMG
  * from database */
   unsigned int importDBAleFsiSwitchMmg()
   {
      if( strstr(impObj->getKeyword().data(), "_ID") )
      {
         dbReadIDCard();
      }
      if( strstr(impObj->getKeyword().data(), "_TITLE") )
      {
         dbReadTitle();
      }
      dbReadSetInfo();
      dbReadMmgCard();
      return 0;
   }
};

#endif

