#ifndef _DBALEREFSYSGROUP_H_
#define _DBALEREFSYSGROUP_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *ALE_REFERENCE_SYSTEM_GROUP
  * keyword */

class DBAleRefSysGroup : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBAleRefSysGroup(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBAleRefSysGroup()
   {
   }

public:
/** Function to get SetInfo details for *ALE_REFERENCE_SYSTEM_GROUP
  * keyword from database */
   void dbReadSetInfo(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"SID","STYPE","PRTYPE","PRID","BCTRAN","BCEXP","BCROT","ICR/NID",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, ALE, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         aleRefGroupFind(&wordArray[2], numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("SetInfo");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","SetInfo",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get MeshCard details for *ALE_REFERENCE_SYSTEM_GROUP
  * keyword from database */
   void dbReadMeshCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"XC","YC","ZC","EXPLIM","EFAC","UNUSED","FRCPAD","IEXPND",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_UNUSED, DATA_DOUBLE, DATA_INT, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, ALE, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("MeshCard");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","MeshCard",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get SetExclude details for *ALE_REFERENCE_SYSTEM_GROUP
  * keyword from database */
   void dbReadSetExclude(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"IPIDXCL","IPIDTYPE",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, };
      numFields = 2;
      unsigned int field_widths[] = {10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_REFERENCES) )
         airbagVentHoleFind(&wordArray[2], numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("SetExclude");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","SetExclude",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *ALE_REFERENCE_SYSTEM_GROUP
  * from database */
   unsigned int importDBAleRefSysGroup()
   {
      dbReadSetInfo();
      dbReadMeshCard();
      dbReadSetExclude();
      return 0;
   }
};

#endif

