#ifndef _DBALEREFSYSSWITCH_H_
#define _DBALEREFSYSSWITCH_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *ALE_REFERENCE_SYSTEM_SWITCH
  * keyword */

class DBAleRefSysSwitch : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBAleRefSysSwitch(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBAleRefSysSwitch()
   {
   }

public:
/** Function to get SwitchID details for *ALE_REFERENCE_SYSTEM_SWITCH
  * keyword from database */
   void dbReadSwitchID(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"ID",};
      unsigned int field_types[] = {DATA_INT, };
      numFields = 1;
      unsigned int field_widths[] = {10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 2, ALE, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("SwitchID");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","SwitchID",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get TimesCard details for *ALE_REFERENCE_SYSTEM_SWITCH
  * keyword from database */
   void dbReadTimesCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"T1","T2","T3","T4","T5","T6","T7",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 7;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, ALE, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("TimesCard");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","TimesCard",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get SysTypes details for *ALE_REFERENCE_SYSTEM_SWITCH
  * keyword from database */
   void dbReadSysTypes(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"TYPE1","TYPE2","TYPE3","TYPE4","TYPE5","TYPE6","TYPE7","TYPE8",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, ALE, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("SysTypes");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","SysTypes",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get PRIDs details for *ALE_REFERENCE_SYSTEM_SWITCH
  * keyword from database */
   void dbReadPRIDs(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"ID1","ID2","ID3","ID4","ID5","ID6","ID7","ID8",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("PRIDs");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","PRIDs",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *ALE_REFERENCE_SYSTEM_SWITCH
  * from database */
   unsigned int importDBAleRefSysSwitch()
   {
      dbReadSwitchID();
      dbReadTimesCard();
      dbReadSysTypes();
      dbReadPRIDs();
      return 0;
   }
};

#endif

