#ifndef _DBALEUPSWITCH_H_
#define _DBALEUPSWITCH_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *ALE_UP_SWITCH
  * keyword */

class DBAleUpSwitch : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBAleUpSwitch(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBAleUpSwitch()
   {
   }

public:
/** Function to get UpCard details for *ALE_UP_SWITCH
  * keyword from database */
   int dbReadUpCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"UPID","SWTIME",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {AIRBAG, };
      unsigned int kw_types[] = {9999, };
      unsigned int num_indices = 1;
      numFields = 2;
      unsigned int field_widths[] = {10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return 0;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, ALE, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("UpCard");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","UpCard",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
      if( wordArray[2] )
         return atoi(wordArray[2]);
      else
         return 0;
   }

/** Function to get FsiIDs details for *ALE_UP_SWITCH
  * keyword from database */
   void dbReadFsiIDs(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"FSI_ID1","FSI_ID2","FSI_ID3","FSI_ID4","FSI_ID5","FSI_ID6","FSI_ID7","FSI_ID8",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, 3, 4, 5, 6, 7, };
      unsigned int man_types[] = {CONST, CONST, CONST, CONST, CONST, CONST, CONST, CONST, };
      unsigned int kw_types[] = {9999, 9999, 9999, 9999, 9999, 9999, 9999, 9999, };
      unsigned int num_indices = 8;
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, ALE, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("FsiIDs");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","FsiIDs",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get SetInfo details for *ALE_UP_SWITCH
  * keyword from database */
   void dbReadSetInfo(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"SID","SIDTYPE","MMGAIR","MMGGAS",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 4;
      unsigned int field_widths[] = {10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_REFERENCES) )
         aleUpSwitchFind(&wordArray[2], numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("SetInfo");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","SetInfo",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *ALE_UP_SWITCH
  * from database */
   unsigned int importDBAleUpSwitch()
   {
      int upid = 0;
      upid = dbReadUpCard();
      dbReadFsiIDs();
      if( !upid )
      {
         dbReadSetInfo();
      }
      return 0;
   }
};

#endif

