#include <iostream>
#include <algorithm>
#include "generic.h"
#include "aletype.h"
#include "aleexport.h"
#include <stdlib.h>

using namespace std;

ALEExport::ALEExport
(
   char         *model_name,
   GoldenConn   *gold_conn,
   ALEManager   *ale_man
)
{
   modelName = model_name;
   aleManPtr = ale_man;
   goldenConn = gold_conn;

   initExportAleTypesAndFunctions();
}

int ALEExport::getKeywordFromType
    (
       unsigned int ale_type,
       string     & kw_str
    )
{
   switch(ale_type)
   {
      case ALE_FSI_PROJECTION:
         kw_str = "*ALE_FSI_PROJECTION";
         break;
      case ALE_FSI_SWITCH_MMG:
         kw_str = "*ALE_FSI_SWITCH_MMG";
         break;
      case ALE_FSI_SWITCH_MMG_ID:
         kw_str = "*ALE_FSI_SWITCH_MMG_ID";
         break;
      case ALE_FSI_SWITCH_MMG_TITLE:
         kw_str = "*ALE_FSI_SWITCH_MMG_TITLE";
         break;
      case ALE_MULTI_MATERIAL_GROUP:
         kw_str = "*ALE_MULTI_MATERIAL_GROUP";
         break;
      case ALE_REFERENCE_SYSTEM_CURVE:
         kw_str = "*ALE_REFERENCE_SYSTEM_CURVE";
         break;
      case ALE_REFERENCE_SYSTEM_GROUP:
         kw_str = "*ALE_REFERENCE_SYSTEM_GROUP";
         break;
      case ALE_REFERENCE_SYSTEM_NODE:
         kw_str = "*ALE_REFERENCE_SYSTEM_NODE";
         break;
      case ALE_REFERENCE_SYSTEM_SWITCH:
         kw_str = "*ALE_REFERENCE_SYSTEM_SWITCH";
         break;
      case ALE_SMOOTHING:
         kw_str = "*ALE_SMOOTHING";
         break;
      case ALE_TANK_TEST:
         kw_str = "*ALE_TANK_TEST";
         break;
      case ALE_UP_SWITCH:
         kw_str = "*ALE_UP_SWITCH";
         break;
      case ALE_NEW_TYPE:
      default:
         return 1;
   }
   return 0;
}

unsigned int ALEExport::dbReadALEs()
{
   char         **row_data, buf[16];
   unsigned int	i, num_ales = 0, total_ales = 0, num_kw_types = 0;
   expTypeFuncIterator eexp_iter = expTypeFuncMap.end(), exp_iter;

   string       qry = "select kw_type from ", kw_str;
   string table_name = "`" + modelName + "_ALES`";
   qry += table_name;
   qry += " group by kw_type;";

cout << "KW QRY = " << qry << endl;

   if( goldenConn->executeQuery( qry.data() ) )
      return 0;

   num_kw_types = goldenConn->numRows();

   if( !num_kw_types )
      return 0;

   unsigned int *kw_types = new unsigned int[num_kw_types];

   for(i = 0; i < num_kw_types; i++)
   {
      row_data = goldenConn->nextRow();
      kw_types[i] = atoi( row_data[0] );
cout << "KW ALE TYPE = " << kw_types[i] << endl;
   }

   for(i = 0; i < num_kw_types; i++)
   {
      if( getKeywordFromType(kw_types[i], kw_str) )
         continue;

cout << "ALE KW = " << kw_str << endl;

      qry = "select * from ";
      qry += table_name;
      qry += " where kw_type=";
      sprintf(buf, "%u", kw_types[i]);
      qry += buf;
      qry += " order by card_index;";

cout << "ALE QRY = " << qry << endl;

      if( goldenConn->executeQuery( qry.data() ) )
	 break;

      exp_iter = expTypeFuncMap.find(kw_types[i]);

      if( exp_iter == eexp_iter )
      {
	 cout << "ALE TYPE NOT FOUND" << endl;
         continue;
      }

      num_ales = 0;
      while( goldenConn->rowsLeft() )
      {
	 impObj = new ExportObject((char *)kw_str.data(), kw_types[i]);
         goldenConn->clearFlag(KW_DATA_END);
	 (exp_iter->second)(goldenConn, impObj);
         if( impObj->cardCount )
         {
	    aleManPtr->add(kw_str.data(), impObj);
	    num_ales++;
         }
         else
            delete impObj;
      }

      total_ales += num_ales;
   }

   delete kw_types;

   return total_ales;
}

