#ifndef _ALE_EXPORT_H_
#define _ALE_EXPORT_H_

#include <string>
#include <map>
#include "goldenconn.h"
#include "alemanager.h"
#include "dbcard.h"
#include "aletype.h"
#include "exptypemap.h"

/** Class to get data from database for *ALE keywords */
class ALEExport
{
public:
   /** Constructor for creating this object
     * \param model_name Name of the model for which the data to be obtained
     * \param gold_conn Connection object for accessing the database
     * \param ale_man Manager pointer to store the data obtained
     */
   ALEExport
   (
      char         *model_name,
      GoldenConn   *gold_conn,
      ALEManager   *ale_man
   );

   ~ALEExport()
   {
      aleManPtr = NULL;
      goldenConn = NULL;
      expTypeFuncMap.clear();
   }

   /** Gets the name of keyword from its type. Type is stored in the database
     * \param ale_type Type of keyword
     * \param kw_str Keyword name is stored in this string
     * \return Returns 0 if found else 1
     */
   int getKeywordFromType
       (
	  unsigned int ale_type,
	  string     & kw_str
       );

   /** Fetches the *ALE keywords from database and returns 0 if not found 
     * else number of keywords obtained
     */
   unsigned int dbReadALEs();

   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *ALE keyword types and their function pointers
     */
   void initExportAleTypesAndFunctions();

private:
   string        modelName;
   ALEManager    *aleManPtr;
   /** Connection object for accessing the data */
   GoldenConn    *goldenConn;
   /** Object to store the data imported from database */
   ImportObject  *impObj;
   /** A map between type of keyword and pointer to the function to be called */
   map<unsigned int, ExportFunctionPtr>  expTypeFuncMap;
};

#endif

