#include <iostream>
#include <algorithm>
#include "generic.h"
#include "bdrytype.h"
#include "bdryexport.h"
#include <stdlib.h>

using namespace std;

BdryExport::BdryExport
(
   char         *model_name,
   GoldenConn   *gold_conn,
   BdryManager    *bdry_man
)
{
   modelName = model_name;
   bdryManPtr = bdry_man;
   goldenConn = gold_conn;

   initExportSimpleTypesAndFunctions();
   initExportBEMTypesAndFunctions();
   initExportOrientTypesAndFunctions();
   initExportPrescribedTypesAndFunctions();
   initExportRadiationTypesAndFunctions();
   initExportSpcTypesAndFunctions();
   initExportTemperatureTypesAndFunctions();
   initExportOutflowTypesAndFunctions();
   initExportConvectionTypesAndFunctions();
   initExportFluxTypesAndFunctions();
}

int BdryExport::getKeywordFromType
    (
       unsigned int bdry_type,
       string &     key_word
    )
{
   switch(bdry_type)
   {
      case BOUNDARY_ACOUSTIC_COUPLING:
         key_word = "*BOUNDARY_ACOUSTIC_COUPLING";
         break;
      case BOUNDARY_AMBIENT_EOS:
         key_word = "*BOUNDARY_AMBIENT_EOS";
         break;
      case BOUNDARY_CONVECTION_SEGMENT:
         key_word = "*BOUNDARY_CONVECTION_SEGMENT";
         break;
      case BOUNDARY_CONVECTION_SET:
         key_word = "*BOUNDARY_CONVECTION_SET";
         break;
      case BOUNDARY_CYCLIC:
         key_word = "*BOUNDARY_CYCLIC";
         break;
      case BOUNDARY_FLUX_SEGMENT:
         key_word = "*BOUNDARY_FLUX_SEGMENT";
         break;
      case BOUNDARY_FLUX_SET:
         key_word = "*BOUNDARY_FLUX_SET";
         break;
      case BOUNDARY_MCOL:
         key_word = "*BOUNDARY_MCOL";
         break;
      case BOUNDARY_NON_REFLECTING:
         key_word = "*BOUNDARY_NON_REFLECTING";
         break;
      case BOUNDARY_NON_REFLECTING_2D:
         key_word = "*BOUNDARY_NON_REFLECTING_2D";
         break;
      case BOUNDARY_PRESCRIBED_ACCELEROMETER_RIGID:
         key_word = "*BOUNDARY_PRESCRIBED_ACCELEROMETER_RIGID";
         break;
      case BOUNDARY_SLIDING_PLANE:
         key_word = "*BOUNDARY_SLIDING_PLANE";
         break;
      case BOUNDARY_SPH_FLOW:
         key_word = "*BOUNDARY_SPH_FLOW";
         break;
      case BOUNDARY_SPH_SYMMETRY_PLANE:
         key_word = "*BOUNDARY_SPH_SYMMETRY_PLANE";
         break;
      case BOUNDARY_SYMMETRY_FAILURE:
         key_word = "*BOUNDARY_SYMMETRY_FAILURE";
         break;
      case BOUNDARY_TEMPERATURE_NODE:
         key_word = "*BOUNDARY_TEMPERATURE_NODE";
         break;
      case BOUNDARY_TEMPERATURE_SET:
         key_word = "*BOUNDARY_TEMPERATURE_SET";
         break;
      case BOUNDARY_THERMAL_WELD:
         key_word = "*BOUNDARY_THERMAL_WELD";
         break;
      case BOUNDARY_USA_SURFACE:
         key_word = "*BOUNDARY_USA_SURFACE";
         break;
      case BOUNDARY_PRESSURE_OUTFLOW_SEGMENT:
         key_word = "*BOUNDARY_PRESSURE_OUTFLOW_SEGMENT";
         break;
      case BOUNDARY_PRESSURE_OUTFLOW_SET:
         key_word = "*BOUNDARY_PRESSURE_OUTFLOW_SET";
         break;
      case BOUNDARY_ELEMENT_METHOD_ACOUSTIC:
         key_word = "*BOUNDARY_ELEMENT_METHOD_ACOUSTIC";
         break;
      case BOUNDARY_ELEMENT_METHOD_CONTROL:
         key_word = "*BOUNDARY_ELEMENT_METHOD_CONTROL";
         break;
      case BOUNDARY_ELEMENT_METHOD_FLOW:
         key_word = "*BOUNDARY_ELEMENT_METHOD_FLOW";
         break;
      case BOUNDARY_ELEMENT_METHOD_SYMMETRY:
         key_word = "*BOUNDARY_ELEMENT_METHOD_SYMMETRY";
         break;
      case BOUNDARY_ELEMENT_METHOD_NEIGHBOR:
         key_word = "*BOUNDARY_ELEMENT_METHOD_NEIGHBOR";
         break;
      case BOUNDARY_ELEMENT_METHOD_WAKE:
         key_word = "*BOUNDARY_ELEMENT_METHOD_WAKE";
         break;
      case BOUNDARY_PRESCRIBED_ORIENTATION_RIGID_ANGLES:
         key_word = "*BOUNDARY_PRESCRIBED_ORIENTATION_RIGID_ANGLES";
         break;
      case BOUNDARY_PRESCRIBED_ORIENTATION_RIGID_DIRCOS:
         key_word = "*BOUNDARY_PRESCRIBED_ORIENTATION_RIGID_DIRCOS";
         break;
      case BOUNDARY_PRESCRIBED_ORIENTATION_RIGID_EULERP:
         key_word = "*BOUNDARY_PRESCRIBED_ORIENTATION_RIGID_EULERP";
         break;
      case BOUNDARY_PRESCRIBED_MOTION_NODE:
         key_word = "*BOUNDARY_PRESCRIBED_MOTION_NODE";
         break;
      case BOUNDARY_PRESCRIBED_MOTION_NODE_ID:
         key_word = "*BOUNDARY_PRESCRIBED_MOTION_NODE_ID";
         break;
      case BOUNDARY_PRESCRIBED_MOTION_RIGID:
         key_word = "*BOUNDARY_PRESCRIBED_MOTION_RIGID";
         break;
      case BOUNDARY_PRESCRIBED_MOTION_RIGID_ID:
         key_word = "*BOUNDARY_PRESCRIBED_MOTION_RIGID_ID";
         break;
      case BOUNDARY_PRESCRIBED_MOTION_RIGID_LOCAL:
         key_word = "*BOUNDARY_PRESCRIBED_MOTION_RIGID_LOCAL";
         break;
      case BOUNDARY_PRESCRIBED_MOTION_RIGID_LOCAL_ID:
         key_word = "*BOUNDARY_PRESCRIBED_MOTION_RIGID_LOCAL_ID";
         break;
      case BOUNDARY_PRESCRIBED_MOTION_SET:
         key_word = "*BOUNDARY_PRESCRIBED_MOTION_SET";
         break;
      case BOUNDARY_PRESCRIBED_MOTION_SET_ID:
         key_word = "*BOUNDARY_PRESCRIBED_MOTION_SET_ID";
         break;
      case BOUNDARY_RADIATION_SEGMENT:
         key_word = "*BOUNDARY_RADIATION_SEGMENT";
         break;
      case BOUNDARY_RADIATION_SEGMENT_VF_READ:
         key_word = "*BOUNDARY_RADIATION_SEGMENT_VF_READ";
         break;
      case BOUNDARY_RADIATION_SEGMENT_VF_CALCULATE:
         key_word = "*BOUNDARY_RADIATION_SEGMENT_VF_CALCULATE";
         break;
      case BOUNDARY_RADIATION_SET:
         key_word = "*BOUNDARY_RADIATION_SET";
         break;
      case BOUNDARY_RADIATION_SET_EF_READ:
         key_word = "*BOUNDARY_RADIATION_SET_EF_READ";
         break;
      case BOUNDARY_RADIATION_SET_EF_CALCULATE:
         key_word = "*BOUNDARY_RADIATION_SET_EF_CALCULATE";
         break;
      case BOUNDARY_RADIATION_SET_VF_READ:
         key_word = "*BOUNDARY_RADIATION_SET_VF_READ";
         break;
      case BOUNDARY_RADIATION_SET_VF_CALCULATE:
         key_word = "*BOUNDARY_RADIATION_SET_VF_CALCULATE";
         break;
      case BOUNDARY_SPC_NODE:
         key_word = "*BOUNDARY_SPC_NODE";
         break;
      case BOUNDARY_SPC_NODE_ID:
         key_word = "*BOUNDARY_SPC_NODE_ID";
         break;
      case BOUNDARY_SPC_SET:
         key_word = "*BOUNDARY_SPC_SET";
         break;
      case BOUNDARY_SPC_SET_ID:
         key_word = "*BOUNDARY_SPC_SET_ID";
         break;
      case BDRY_NEW_TYPE:
      default:
         return 1;
   }
   return 0;
}

unsigned int BdryExport::dbReadBdrys()
{
   char         **row_data, buf[16];
   unsigned int	i, num_bdrys = 0, total_bdrys = 0, num_kw_types = 0;
   expTypeFuncIterator eexp_iter = expTypeFuncMap.end(), exp_iter;

   string       qry = "select kw_type from ", kw_str;
   string table_name = "`" + modelName + "_BOUNDARYS`";
   qry += table_name;
   qry += " group by kw_type;";

cout << "KW QRY = " << qry << endl;

   if( goldenConn->executeQuery( qry.data() ) )
      return 0;

   num_kw_types = goldenConn->numRows();

   if( !num_kw_types )
      return 0;

   unsigned int *kw_types = new unsigned int[num_kw_types];

   for(i = 0; i < num_kw_types; i++)
   {
      row_data = goldenConn->nextRow();
      kw_types[i] = atoi( row_data[0] );
cout << "KW BOUNDARY TYPE = " << kw_types[i] << endl;
   }

   for(i = 0; i < num_kw_types; i++)
   {
      qry = "select * from ";
      qry += table_name;
      qry += " where kw_type=";
      sprintf(buf, "%u", kw_types[i]);
      qry += buf;
      qry += " order by card_index;";

cout << "BOUNDARY QRY = " << qry << endl;

      if( getKeywordFromType(kw_types[i], kw_str) )
         continue;

cout << "BOUNDARY KW = " << kw_str << endl;

      if( goldenConn->executeQuery( qry.data() ) )
	 break;

      exp_iter = expTypeFuncMap.find(kw_types[i]);

      if( exp_iter == eexp_iter )
      {
	 cout << "BOUNDARY TYPE NOT FOUND" << endl;
         continue;
      }

      num_bdrys = 0;
      while( goldenConn->rowsLeft() )
      {
	 impObj = new ExportObject((char *)kw_str.data(), kw_types[i]);
         goldenConn->clearFlag(KW_DATA_END);
	 (exp_iter->second)(goldenConn, impObj);
	 if( impObj->cardCount )
         {
	    bdryManPtr->add(kw_str.data(), impObj);
	    num_bdrys++;
         }
	 else
	    delete impObj;
      }

      total_bdrys += num_bdrys;
   }

   delete kw_types;

   return total_bdrys;
}

