#ifndef _Bdry_EXPORT_H_
#define _Bdry_EXPORT_H_

#include <string>
#include <map>
#include "goldenconn.h"
#include "bdrymanager.h"
#include "dataline.h"
#include "dbcard.h"
#include "bdrytype.h"
#include "exptypemap.h"

/** Class to get data from database for *BOUNDARY keywords */
class BdryExport
{
public:
   /** Constructor for creating this object
     * \param model_name Name of the model for which the data to be obtained
     * \param gold_conn Connection object for accessing the database
     * \param bdry_man Manager pointer to store the data obtained
     */
   BdryExport
   (
      char           *model_name,
      GoldenConn     *gold_conn,
      BdryManager    *bdry_man
   );

   ~BdryExport()
   {
      
      bdryManPtr = NULL;
      goldenConn = NULL;
      expTypeFuncMap.clear();
   }

   /** Gets the name of keyword from its type. Type is stored in the database
     * \param bdry_type Type of keyword
     * \param key_word Keyword name is stored in this string
     */
   int getKeywordFromType
       (
	  unsigned int bdry_type,
	  string &     key_word
       );

   /** Fetches the *BOUNDARY keywords from database and returns 0 if not found 
     * else number of keywords obtained
     */
   unsigned int dbReadBdrys();

   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *BOUNDARY keyword types and their function pointers
     */
   void initExportSimpleTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *BOUNDARY keyword types and their function pointers
     */
   void initExportBEMTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *BOUNDARY keyword types and their function pointers
     */
   void initExportOrientTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *BOUNDARY keyword types and their function pointers
     */
   void initExportPrescribedTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *BOUNDARY keyword types and their function pointers
     */
   void initExportRadiationTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *BOUNDARY keyword types and their function pointers
     */
   void initExportSpcTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *BOUNDARY keyword types and their function pointers
     */
   void initExportTemperatureTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *BOUNDARY keyword types and their function pointers
     */
   void initExportOutflowTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *BOUNDARY keyword types and their function pointers
     */
   void initExportConvectionTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *BOUNDARY keyword types and their function pointers
     */
   void initExportFluxTypesAndFunctions();

private:
   string         modelName;
   BdryManager    *bdryManPtr;
   /** Connection object for accessing the data */
   GoldenConn     *goldenConn;
   /** Object to store the data imported from database */
   ImportObject   *impObj;
   /** A map between type of keyword and pointer to the function to be called */
   map<unsigned int, ExportFunctionPtr>  expTypeFuncMap;
};

#endif

