#ifndef _DBBEMACOUSTIC_H_
#define _DBBEMACOUSTIC_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *BOUNDARY_ELEMENT_METHOD_ACOUSTIC
  * keyword */

class DBBEMAcoustic : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBBEMAcoustic(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBBEMAcoustic()
   {
   }

public:
/** Function to get Fluid details for *BOUNDARY_ELEMENT_METHOD_ACOUSTIC
  * keyword from database */
   void dbReadFluid(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"DENS","SP","MIN_FREQ","MAX_FREQ","NFREQ","NORM","DT","PREF",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, BDRY, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Fluid");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Fluid",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Segment details for *BOUNDARY_ELEMENT_METHOD_ACOUSTIC
  * keyword from database */
   int dbReadSegment(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"SSID","SSTYPE","LCID","OUTID","OUTTYPE","METHOD","IWINDOW",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 7;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return 0;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, BDRY, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         bemAcousticFind(&wordArray[2], numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Segment");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Segment",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
      if( wordArray[7] )
         return atoi(wordArray[7]);
      else
         return 0;
   }

/** Function to get Iterative details for *BOUNDARY_ELEMENT_METHOD_ACOUSTIC
  * keyword from database */
   void dbReadIterative(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"IDIM","MAX_ITER","RES",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, };
      numFields = 3;
      unsigned int field_widths[] = {10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Iterative");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Iterative",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *BOUNDARY_ELEMENT_METHOD_ACOUSTIC
  * from database */
   unsigned int importDBBEMAcoustic()
   {
      int method = 0;
      dbReadFluid();
      method = dbReadSegment();
      if( method == 1 )
      {
         dbReadIterative();
      }
      return 0;
   }
};

#endif

