#ifndef _DBBEMSYMMETRY_H_
#define _DBBEMSYMMETRY_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *BOUNDARY_ELEMENT_METHOD_SYMMETRY
  * keyword */

class DBBEMSymmetry : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBBEMSymmetry(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBBEMSymmetry()
   {
   }

public:
/** Function to get Sym details for *BOUNDARY_ELEMENT_METHOD_SYMMETRY
  * keyword from database */
   void dbReadSym(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"BEMSYM",};
      unsigned int field_types[] = {DATA_INT, };
      numFields = 1;
      unsigned int field_widths[] = {10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, BDRY, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Sym");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Sym",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *BOUNDARY_ELEMENT_METHOD_SYMMETRY
  * from database */
   unsigned int importDBBEMSymmetry()
   {
      dbReadSym();
      return 0;
   }
};

#endif

