#ifndef _DBBEMWAKE_H_
#define _DBBEMWAKE_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *BOUNDARY_ELEMENT_METHOD_WAKE
  * keyword */

class DBBEMWake : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBBEMWake(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBBEMWake()
   {
   }

public:
/** Function to get Wake details for *BOUNDARY_ELEMENT_METHOD_WAKE
  * keyword from database */
   void dbReadWake(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"NELEM","NSIDE",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, };
      unsigned int man_types[] = {ELEMENT, ELEMENT, };
      unsigned int kw_types[] = {SHELL, SHELL, };
      unsigned int num_indices = 2;
      numFields = 2;
      unsigned int field_widths[] = {10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, BDRY, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Wake");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Wake",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *BOUNDARY_ELEMENT_METHOD_WAKE
  * from database */
   unsigned int importDBBEMWake()
   {
      unsigned int loop_count = 0;
      dbReadWake(loop_count);
      loop_count++;
      while(numFields)
      {
         dbReadWake(loop_count);
         loop_count++;
      }
      ((ExportObject *)impObj)->loopCount = loop_count-1;
      return 0;
   }
};

#endif

