#ifndef _DBBDRYCONVECSET_H_
#define _DBBDRYCONVECSET_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *BOUNDARY_CONVECTION_SET
  * keyword */

class DBBdryConvecSet : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBBdryConvecSet(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBBdryConvecSet()
   {
   }

public:
/** Function to get SetCard details for *BOUNDARY_CONVECTION_SET
  * keyword from database */
   void dbReadSetCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"SSID",};
      unsigned int field_types[] = {DATA_INT, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {SET, };
      unsigned int kw_types[] = {SEGMENT, };
      unsigned int num_indices = 1;
      numFields = 1;
      unsigned int field_widths[] = {10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, BDRY, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("SetCard");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","SetCard",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get HeatCard details for *BOUNDARY_CONVECTION_SET
  * keyword from database */
   void dbReadHeatCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"HLCID","HMULT","TLCID","TMULT","LOC",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_INT, };
      unsigned int field_indices[] = {0, 2, };
      unsigned int man_types[] = {DEFINE, DEFINE, };
      unsigned int kw_types[] = {CURVE, CURVE, };
      unsigned int num_indices = 2;
      numFields = 5;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, BDRY, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("HeatCard");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","HeatCard",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *BOUNDARY_CONVECTION_SET
  * from database */
   unsigned int importDBBdryConvecSet()
   {
      dbReadSetCard();
      dbReadHeatCard();
      return 0;
   }
};

#endif

