#ifndef _DBBDRYPRESMOTION_H_
#define _DBBDRYPRESMOTION_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *BOUNDARY_PRESCRIBED_MOTION_NODE
  * keyword */

class DBBdryPresMotion : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBBdryPresMotion(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBBdryPresMotion()
   {
   }

public:
/** Function to get Details details for *BOUNDARY_PRESCRIBED_MOTION_NODE
  * keyword from database */
   void dbReadDetails(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"ID","HEADING",};
      unsigned int field_types[] = {DATA_INT, DATA_CHAR_ARRAY, };
      numFields = 2;
      unsigned int field_widths[] = {10, 70, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 2, BDRY, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Details");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Details",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get DOFCard details for *BOUNDARY_PRESCRIBED_MOTION_NODE
  * keyword from database */
   void dbReadDOFCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"typeID","DOF","VAD","LCID","SF","VID","DEATH","BIRTH",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, BDRY, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         bdryPresMotionFind(&wordArray[2], numFields, 0, impObj);
      dof = 0;
      if( wordArray[3] )
         dof = atoi(wordArray[3]);
      vad = 0;
      if( wordArray[4] )
         vad = atoi(wordArray[4]);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("DOFCard");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","DOFCard",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Offset details for *BOUNDARY_PRESCRIBED_MOTION_NODE
  * keyword from database */
   void dbReadOffset(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"OFFSET1","OFFSET2","MRB","NODE1","NODE2",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {3, 4, };
      unsigned int man_types[] = {NOD, NOD, };
      unsigned int kw_types[] = {9999, 9999, };
      unsigned int num_indices = 2;
      numFields = 5;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, BDRY, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Offset");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Offset",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *BOUNDARY_PRESCRIBED_MOTION_NODE
  * from database */
   unsigned int importDBBdryPresMotion()
   {
      if( strstr(impObj->getKeyword().data(), "_ID") )
      {
         dbReadDetails();
      }
      dbReadDOFCard();
      if( (abs(dof) >= 9) || (vad == 4) )
      {
         dbReadOffset();
      }
      return 0;
   }
public:
   int dof;
   int vad;
};

#endif

