#ifndef _DBBDRYRADIATIONSEGMENTVF_H_
#define _DBBDRYRADIATIONSEGMENTVF_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *BOUNDARY_RADIATION_SEGMENT_VF_READ
  * keyword */

class DBBdryRadiationSegmentVF : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBBdryRadiationSegmentVF(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBBdryRadiationSegmentVF()
   {
   }

public:
/** Function to get Segment details for *BOUNDARY_RADIATION_SEGMENT_VF_READ
  * keyword from database */
   void dbReadSegment(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"N1","N2","N3","N4","TYPE","BLOCK","NINT",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, 3, };
      unsigned int man_types[] = {NOD, NOD, NOD, NOD, };
      unsigned int kw_types[] = {9999, 9999, 9999, 9999, };
      unsigned int num_indices = 4;
      numFields = 7;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, BDRY, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Segment");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Segment",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Factor details for *BOUNDARY_RADIATION_SEGMENT_VF_READ
  * keyword from database */
   void dbReadFactor(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"SELCID","SEMULT",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {DEFINE, };
      unsigned int kw_types[] = {CURVE, };
      unsigned int num_indices = 1;
      numFields = 2;
      unsigned int field_widths[] = {10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, BDRY, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Factor");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Factor",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *BOUNDARY_RADIATION_SEGMENT_VF_READ
  * from database */
   unsigned int importDBBdryRadiationSegmentVF()
   {
      dbReadSegment();
      dbReadFactor();
      return 0;
   }
};

#endif

