#ifndef _DBBDRYCYCLIC_H_
#define _DBBDRYCYCLIC_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *BOUNDARY_CYCLIC
  * keyword */

class DBBdryCyclic : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBBdryCyclic(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBBdryCyclic()
   {
   }

public:
/** Function to get VecCard details for *BOUNDARY_CYCLIC
  * keyword from database */
   void dbReadVecCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"XC","YC","ZC","NSID1","NSID2","IGLOBAL","ISORT",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {3, 4, };
      unsigned int man_types[] = {SET, SET, };
      unsigned int kw_types[] = {NOD, NOD, };
      unsigned int num_indices = 2;
      numFields = 7;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, BDRY, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("VecCard");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","VecCard",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *BOUNDARY_CYCLIC
  * from database */
   unsigned int importDBBdryCyclic()
   {
      dbReadVecCard();
      return 0;
   }
};

#endif

