#ifndef _DBBDRYMCOL_H_
#define _DBBDRYMCOL_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *BOUNDARY_MCOL
  * keyword */

class DBBdryMCOL : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBBdryMCOL(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBBdryMCOL()
   {
   }

public:
/** Function to get Ship details for *BOUNDARY_MCOL
  * keyword from database */
   int dbReadShip(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"NMCOL","MXSTEP","ENDTMCOL","TSUBC","PRTMCOL",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 5;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return 0;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, BDRY, impObj);
      nmcol = 0;
      if( wordArray[2] )
         nmcol = atoi(wordArray[2]);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Ship");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Ship",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
      if( wordArray[2] )
         return atoi(wordArray[2]);
      else
         return 0;
   }

/** Function to get MCol details for *BOUNDARY_MCOL
  * keyword from database */
   void dbReadMCol(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"RBMCOL","MCOLFILE",};
      unsigned int field_types[] = {DATA_INT, DATA_CHAR_ARRAY, };
      numFields = 2;
      unsigned int field_widths[] = {10, 60, };
      unsigned int end_loop;
      end_loop = nmcol;
      for(loop_count = 0; loop_count < end_loop; loop_count++)
      {
         numFields = 2;
         wordArray = goldenConn->nextCard();
         if( !wordArray )
         {
            numFields = 0;
         return;
         }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, BDRY, impObj);
         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","MCol",loop_count);
            cardObj = new DBCard(name_buf);
            ((DBCard *)cardObj)->index = atoi(wordArray[0]);
            cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
            impObj->addCard(cardObj);
         }
         impObj->cardCount++;
      }
   }

/** Function to import all the cards of keyword *BOUNDARY_MCOL
  * from database */
   unsigned int importDBBdryMCOL()
   {
      int nmcol = 0;
      nmcol = dbReadShip();
      if( nmcol != 0 )
      {
         dbReadMCol();
      }
      return 0;
   }
public:
   int nmcol;
};

#endif

