#ifndef _DBBDRYPRESACCELRIGID_H_
#define _DBBDRYPRESACCELRIGID_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *BOUNDARY_PRESCRIBED_ACCELEROMETER_RIGID
  * keyword */

class DBBdryPresAccelRigid : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBBdryPresAccelRigid(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBBdryPresAccelRigid()
   {
   }

public:
/** Function to get Part details for *BOUNDARY_PRESCRIBED_ACCELEROMETER_RIGID
  * keyword from database */
   void dbReadPart(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"PID",};
      unsigned int field_types[] = {DATA_INT, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {PARTC, };
      unsigned int kw_types[] = {9999, };
      unsigned int num_indices = 1;
      numFields = 1;
      unsigned int field_widths[] = {10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, BDRY, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Part");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Part",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Accelerometer details for *BOUNDARY_PRESCRIBED_ACCELEROMETER_RIGID
  * keyword from database */
   void dbReadAccelerometer(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"NID","CID","LCIDX","LCIDY","LCIDZ",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, 3, 4, };
      unsigned int man_types[] = {NOD, DEFINE, DEFINE, DEFINE, DEFINE, };
      unsigned int kw_types[] = {9999, COORDINATE, CURVE, CURVE, CURVE, };
      unsigned int num_indices = 5;
      numFields = 5;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, BDRY, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Accelerometer");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Accelerometer",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *BOUNDARY_PRESCRIBED_ACCELEROMETER_RIGID
  * from database */
   unsigned int importDBBdryPresAccelRigid()
   {
      dbReadPart();
      unsigned int loop_count = 0;
      dbReadAccelerometer(loop_count);
      loop_count++;
      while(numFields)
      {
         dbReadAccelerometer(loop_count);
         loop_count++;
      }
      ((ExportObject *)impObj)->loopCount = loop_count-1;
      return 0;
   }
};

#endif

