#ifndef _DBBDRYSPC_H_
#define _DBBDRYSPC_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *BOUNDARY_SPC_NODE
  * keyword */

class DBBdrySpc : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBBdrySpc(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBBdrySpc()
   {
   }

public:
/** Function to get Details details for *BOUNDARY_SPC_NODE
  * keyword from database */
   void dbReadDetails(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"ID","HEADING",};
      unsigned int field_types[] = {DATA_INT, DATA_CHAR_ARRAY, };
      numFields = 2;
      unsigned int field_widths[] = {10, 70, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 2, BDRY, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Details");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Details",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get DOFCard details for *BOUNDARY_SPC_NODE
  * keyword from database */
   void dbReadDOFCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"NID/NSID","CID","DOFX","DOFY","DOFZ","DOFRX","DOFRY","DOFRZ",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, BDRY, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         bdrySpcFind(&wordArray[2], numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("DOFCard");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","DOFCard",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *BOUNDARY_SPC_NODE
  * from database */
   unsigned int importDBBdrySpc()
   {
      if( strstr(impObj->getKeyword().data(), "_ID") )
      {
         dbReadDetails();
      }
      dbReadDOFCard();
      return 0;
   }
};

#endif

