#ifndef _DBBDRYTEMPERATURE_H_
#define _DBBDRYTEMPERATURE_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *BOUNDARY_TEMPERATURE_NODE
  * keyword */

class DBBdryTemperature : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBBdryTemperature(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBBdryTemperature()
   {
   }

public:
/** Function to get Node details for *BOUNDARY_TEMPERATURE_NODE
  * keyword from database */
   void dbReadNode(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"NID/SID","LCID","CMULT","LOC",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, DATA_INT, };
      numFields = 4;
      unsigned int field_widths[] = {10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, BDRY, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         bdryTempFind(&wordArray[2], numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Node");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Node",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *BOUNDARY_TEMPERATURE_NODE
  * from database */
   unsigned int importDBBdryTemperature()
   {
      dbReadNode();
      return 0;
   }
};

#endif

