#ifndef _DBBDRYTHERMALWELD_H_
#define _DBBDRYTHERMALWELD_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *BOUNDARY_THERMAL_WELD
  * keyword */

class DBBdryThermalWeld : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBBdryThermalWeld(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBBdryThermalWeld()
   {
   }

public:
/** Function to get Part details for *BOUNDARY_THERMAL_WELD
  * keyword from database */
   int dbReadPart(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"PID","PTYP","NID","NFLAG","X0","Y0","Z0","N2ID",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return 0;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, BDRY, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         bdryThermalFind(&wordArray[2], numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Part");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Part",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
      if( wordArray[9] )
         return atoi(wordArray[9]);
      else
         return 0;
   }

/** Function to get Weld details for *BOUNDARY_THERMAL_WELD
  * keyword from database */
   void dbReadWeld(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"a","b","cf","cr","LCID","Q","Ff","Fr",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {4, };
      unsigned int man_types[] = {DEFINE, };
      unsigned int kw_types[] = {CURVE, };
      unsigned int num_indices = 1;
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, BDRY, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Weld");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Weld",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Vector details for *BOUNDARY_THERMAL_WELD
  * keyword from database */
   void dbReadVector(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"tx","ty","tz",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 3;
      unsigned int field_widths[] = {10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Vector");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Vector",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *BOUNDARY_THERMAL_WELD
  * from database */
   unsigned int importDBBdryThermalWeld()
   {
      int n2id = 0;
      n2id = dbReadPart();
      dbReadWeld();
      if( n2id == -1 )
      {
         dbReadVector();
      }
      return 0;
   }
};

#endif

