#include <iostream>
#include <algorithm>
#include "generic.h"
#include "comptype.h"
#include "compexport.h"
#include <stdlib.h>

using namespace std;

CompExport::CompExport
(
   char         *model_name,
   GoldenConn   *gold_conn,
   CompManager    *comp_man
)
{
   modelName = model_name;
   compManPtr = comp_man;
   goldenConn = gold_conn;
   
   initExportCompTypesAndFunctions();
}

int CompExport::getKeywordFromType
    (
       unsigned int comp_type,
       string & key_word
    )
{
   switch(comp_type)
   {
      case COMPONENT_GEBOD_CHILD:
         key_word = "*COMPONENT_GEBOD_CHILD";
         break;
      case COMPONENT_GEBOD_FEMALE:
         key_word = "*COMPONENT_GEBOD_FEMALE";
         break;
      case COMPONENT_GEBOD_JOINT_LEFT_ANKLE:
         key_word = "*COMPONENT_GEBOD_JOINT_LEFT_ANKLE";
         break;
      case COMPONENT_GEBOD_JOINT_LEFT_ELBOW:
         key_word = "*COMPONENT_GEBOD_JOINT_LEFT_ELBOW";
         break;
      case COMPONENT_GEBOD_JOINT_LEFT_HIP:
         key_word = "*COMPONENT_GEBOD_JOINT_LEFT_HIP";
         break;
      case COMPONENT_GEBOD_JOINT_LEFT_KNEE:
         key_word = "*COMPONENT_GEBOD_JOINT_LEFT_KNEE";
         break;
      case COMPONENT_GEBOD_JOINT_LEFT_SHOULDER:
         key_word = "*COMPONENT_GEBOD_JOINT_LEFT_SHOULDER";
         break;
      case COMPONENT_GEBOD_JOINT_LOWER_NECK:
         key_word = "*COMPONENT_GEBOD_JOINT_LOWER_NECK";
         break;
      case COMPONENT_GEBOD_JOINT_PELVIS:
         key_word = "*COMPONENT_GEBOD_JOINT_PELVIS";
         break;
      case COMPONENT_GEBOD_JOINT_RIGHT_ANKLE:
         key_word = "*COMPONENT_GEBOD_JOINT_RIGHT_ANKLE";
         break;
      case COMPONENT_GEBOD_JOINT_RIGHT_ELBOW:
         key_word = "*COMPONENT_GEBOD_JOINT_RIGHT_ELBOW";
         break;
      case COMPONENT_GEBOD_JOINT_RIGHT_HIP:
         key_word = "*COMPONENT_GEBOD_JOINT_RIGHT_HIP";
         break;
      case COMPONENT_GEBOD_JOINT_RIGHT_KNEE:
         key_word = "*COMPONENT_GEBOD_JOINT_RIGHT_KNEE";
         break;
      case COMPONENT_GEBOD_JOINT_RIGHT_SHOULDER:
         key_word = "*COMPONENT_GEBOD_JOINT_RIGHT_SHOULDER";
         break;
      case COMPONENT_GEBOD_JOINT_UPPER_NECK:
         key_word = "*COMPONENT_GEBOD_JOINT_UPPER_NECK";
         break;
      case COMPONENT_GEBOD_JOINT_WAIST:
         key_word = "*COMPONENT_GEBOD_JOINT_WAIST";
         break;
      case COMPONENT_GEBOD_MALE:
         key_word = "*COMPONENT_GEBOD_MALE";
         break;
      case COMPONENT_HYBRIDIII:
         key_word = "*COMPONENT_HYBRIDIII";
         break;
      case COMPONENT_HYBRIDIII_JOINT_LEFT_ANKLE:
         key_word = "*COMPONENT_HYBRIDIII_JOINT_LEFT_ANKLE";
         break;
      case COMPONENT_HYBRIDIII_JOINT_LEFT_ELBOW:
         key_word = "*COMPONENT_HYBRIDIII_JOINT_LEFT_ELBOW";
         break;
      case COMPONENT_HYBRIDIII_JOINT_LEFT_HIP:
         key_word = "*COMPONENT_HYBRIDIII_JOINT_LEFT_HIP";
         break;
      case COMPONENT_HYBRIDIII_JOINT_LEFT_KNEE:
         key_word = "*COMPONENT_HYBRIDIII_JOINT_LEFT_KNEE";
         break;
      case COMPONENT_HYBRIDIII_JOINT_LEFT_KNEE_SLIDER:
         key_word = "*COMPONENT_HYBRIDIII_JOINT_LEFT_KNEE_SLIDER";
         break;
      case COMPONENT_HYBRIDIII_JOINT_LEFT_SHOULDER:
         key_word = "*COMPONENT_HYBRIDIII_JOINT_LEFT_SHOULDER";
         break;
      case COMPONENT_HYBRIDIII_JOINT_LEFT_WRIST:
         key_word = "*COMPONENT_HYBRIDIII_JOINT_LEFT_WRIST";
         break;
      case COMPONENT_HYBRIDIII_JOINT_LOWER_NECK:
         key_word = "*COMPONENT_HYBRIDIII_JOINT_LOWER_NECK";
         break;
      case COMPONENT_HYBRIDIII_JOINT_LUMBAR:
         key_word = "*COMPONENT_HYBRIDIII_JOINT_LUMBAR";
         break;
      case COMPONENT_HYBRIDIII_JOINT_RIGHT_ANKLE:
         key_word = "*COMPONENT_HYBRIDIII_JOINT_RIGHT_ANKLE";
         break;
      case COMPONENT_HYBRIDIII_JOINT_RIGHT_ELBOW:
         key_word = "*COMPONENT_HYBRIDIII_JOINT_RIGHT_ELBOW";
         break;
      case COMPONENT_HYBRIDIII_JOINT_RIGHT_HIP:
         key_word = "*COMPONENT_HYBRIDIII_JOINT_RIGHT_HIP";
         break;
      case COMPONENT_HYBRIDIII_JOINT_RIGHT_KNEE:
         key_word = "*COMPONENT_HYBRIDIII_JOINT_RIGHT_KNEE";
         break;
      case COMPONENT_HYBRIDIII_JOINT_RIGHT_KNEE_SLIDER:
         key_word = "*COMPONENT_HYBRIDIII_JOINT_RIGHT_KNEE_SLIDER";
         break;
      case COMPONENT_HYBRIDIII_JOINT_RIGHT_SHOULDER:
         key_word = "*COMPONENT_HYBRIDIII_JOINT_RIGHT_SHOULDER";
         break;
      case COMPONENT_HYBRIDIII_JOINT_RIGHT_WRIST:
         key_word = "*COMPONENT_HYBRIDIII_JOINT_RIGHT_WRIST";
         break;
      case COMPONENT_HYBRIDIII_JOINT_STERNUM:
         key_word = "*COMPONENT_HYBRIDIII_JOINT_STERNUM";
         break;
      case COMPONENT_HYBRIDIII_JOINT_UPPER_NECK:
         key_word = "*COMPONENT_HYBRIDIII_JOINT_UPPER_NECK";
         break;
      case COMP_NEW_TYPE:
      default:
         return 1;
   }
   return 0;
}

unsigned int CompExport::dbReadComps()
{
   char         **row_data, buf[16];
   unsigned int	i, num_comps = 0, total_comps = 0, num_kw_types = 0;
   expTypeFuncIterator eexp_iter = expTypeFuncMap.end(), exp_iter;

   string       qry = "select kw_type from ", kw_str;
   string table_name = "`" + modelName + "_COMPONENTS`";
   qry += table_name;
   qry += " group by kw_type;";

cout << "KW QRY = " << qry << endl;

   if( goldenConn->executeQuery( qry.data() ) )
      return 0;

   num_kw_types = goldenConn->numRows();

   if( !num_kw_types )
      return 0;

   unsigned int *kw_types = new unsigned int[num_kw_types];

   for(i = 0; i < num_kw_types; i++)
   {
      row_data = goldenConn->nextRow();
      kw_types[i] = atoi( row_data[0] );
cout << "KW COMPONENT TYPE = " << kw_types[i] << endl;
   }

   for(i = 0; i < num_kw_types; i++)
   {
      qry = "select * from ";
      qry += table_name;
      qry += " where kw_type=";
      sprintf(buf, "%u", kw_types[i]);
      qry += buf;
      qry += " order by card_index;";

cout << "COMPONENT QRY = " << qry << endl;

      if( getKeywordFromType(kw_types[i], kw_str) )
         continue;

cout << "COMPONENT KW = " << kw_str << endl;

      if( goldenConn->executeQuery( qry.data() ) )
	 break;

      exp_iter = expTypeFuncMap.find(kw_types[i]);

      if( exp_iter == eexp_iter )
      {
	 cout << "COMPONENT TYPE NOT FOUND" << endl;
         continue;
      }

      num_comps = 0;
      while( goldenConn->rowsLeft() )
      {
	 impObj = new ExportObject((char *)kw_str.data(), kw_types[i]);
         goldenConn->clearFlag(KW_DATA_END);
	 (exp_iter->second)(goldenConn, impObj);
         if( impObj->cardCount )
         {
	    compManPtr->add(kw_str.data(), impObj);
	    num_comps++;
         }
         else
            delete impObj;
      }

      total_comps += num_comps;
   }

   delete kw_types;

   return total_comps;
}

