#ifndef _Comp_EXPORT_H_
#define _Comp_EXPORT_H_

#include <string>
#include <map>
#include "goldenconn.h"
#include "compmanager.h"
#include "dataline.h"
#include "dbcard.h"
#include "comptype.h"
#include "exptypemap.h"

/** Class to get data from database for *COMPONENT keywords */
class CompExport
{
public:
   /** Constructor for creating this object
     * \param model_name Name of the model for which the data to be obtained
     * \param gold_conn Connection object for accessing the database
     * \param comp_man Manager pointer to store the data obtained
     */
   CompExport
   (
      char         *model_name,
      GoldenConn   *gold_conn,
      CompManager  *comp_man
   );

   ~CompExport()
   {
      
      compManPtr = NULL;
      goldenConn = NULL;
      expTypeFuncMap.clear();
   }

   /** Gets the name of keyword from its type. Type is stored in the database
     * \param comp_type Type of keyword
     * \param key_word Keyword name is stored in this string
     */
   int getKeywordFromType
       (
	  unsigned int comp_type,
	  string & key_word
       );

   /** Fetches the *COMPONENT keywords from database and returns 0 if not found 
     * else number of keywords obtained
     */
   unsigned int dbReadComps();

   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *COMPONENT keyword types and their function pointers
     */
   void initExportCompTypesAndFunctions();

private:
   string         modelName;
   CompManager    *compManPtr;
   /** Connection object for accessing the data */
   GoldenConn     *goldenConn;
   /** Object to store the data imported from database */
   ImportObject   *impObj;
   /** A map between type of keyword and pointer to the function to be called */
   map<unsigned int, ExportFunctionPtr>  expTypeFuncMap;
};

#endif

