#ifndef _DBCOMPONENTGEBODJOINT_H_
#define _DBCOMPONENTGEBODJOINT_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *COMPONENT_GEBOD_JOINT_PELVIS
  * keyword */

class DBComponentGebodJoint : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBComponentGebodJoint(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBComponentGebodJoint()
   {
   }

public:
/** Function to get IDCard details for *COMPONENT_GEBOD_JOINT_PELVIS
  * keyword from database */
   void dbReadIDCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"DID","LC1","LC2","LC3","SCF1","SCF2","SCF3",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, 1, 2, 3, };
      unsigned int man_types[] = {COMP, DEFINE, DEFINE, DEFINE, };
      unsigned int kw_types[] = {9999, CURVE, CURVE, CURVE, };
      unsigned int num_indices = 4;
      numFields = 7;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, COMP, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("IDCard");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","IDCard",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Viscosity details for *COMPONENT_GEBOD_JOINT_PELVIS
  * keyword from database */
   void dbReadViscosity(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"C1","C2","C3","NEUT1","NEUT2","NEUT3",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, COMP, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Viscosity");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Viscosity",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get StopAngle details for *COMPONENT_GEBOD_JOINT_PELVIS
  * keyword from database */
   void dbReadStopAngle(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"LOSA1","HISA1","LOSA2","HISA2","LOSA3","HISA3",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("StopAngle");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","StopAngle",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Stiffness details for *COMPONENT_GEBOD_JOINT_PELVIS
  * keyword from database */
   void dbReadStiffness(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"UNK1","UNK2","UNK3",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 3;
      unsigned int field_widths[] = {10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Stiffness");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Stiffness",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *COMPONENT_GEBOD_JOINT_PELVIS
  * from database */
   unsigned int importDBComponentGebodJoint()
   {
      dbReadIDCard();
      dbReadViscosity();
      dbReadStopAngle();
      dbReadStiffness();
      return 0;
   }
};

#endif

