#ifndef _DBCOMPONENTHYBRIDIII_H_
#define _DBCOMPONENTHYBRIDIII_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *COMPONENT_HYBRIDIII
  * keyword */

class DBComponentHybridIII : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBComponentHybridIII(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBComponentHybridIII()
   {
   }

public:
/** Function to get IDCard details for *COMPONENT_HYBRIDIII
  * keyword from database */
   void dbReadIDCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"DID","SIZE","UNITS","DEFRM","VX","VY","VZ",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 7;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 2, COMP, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("IDCard");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","IDCard",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get HPoint details for *COMPONENT_HYBRIDIII
  * keyword from database */
   void dbReadHPoint(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"HX","HY","HZ","RX","RY","RZ",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, COMP, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("HPoint");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","HPoint",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *COMPONENT_HYBRIDIII
  * from database */
   unsigned int importDBComponentHybridIII()
   {
      dbReadIDCard();
      dbReadHPoint();
      return 0;
   }
};

#endif

