#include <iostream>
#include <algorithm>
#include "generic.h"
#include "consttype.h"
#include "constexport.h"
#include <stdlib.h>

using namespace std;

ConstExport::ConstExport
(
   char         *model_name,
   GoldenConn   *gold_conn,
   ConstManager    *const_man
)
{
   modelName = model_name;
   constManPtr = const_man;
   goldenConn = gold_conn;

   initExportSimpleTypesAndFunctions();
   initExportJointTypesAndFunctions();
   initExportWeldTypesAndFunctions();
   initExportCouplingTypesAndFunctions();
   initExportStiffnessTypesAndFunctions();
   initExportNodalTypesAndFunctions();
}

int ConstExport::getKeywordFromType
    (
       unsigned int kw_type,
       string & key_word
    )
{
   switch(kw_type)
   {
      case CONSTRAINED_LAGRANGE_IN_SOLID:
	 key_word = "*CONSTRAINED_LAGRANGE_IN_SOLID";
	 break;
      case CONSTRAINED_LAGRANGE_IN_SOLID_EDGE:
	 key_word = "*CONSTRAINED_LAGRANGE_IN_SOLID_EDGE";
	 break;
      case CONSTRAINED_LAGRANGE_IN_SOLID_EDGE_TITLE:
	 key_word = "*CONSTRAINED_LAGRANGE_IN_SOLID_EDGE_TITLE";
	 break;
      case CONSTRAINED_LAGRANGE_IN_SOLID_TITLE:
	 key_word = "*CONSTRAINED_LAGRANGE_IN_SOLID_TITLE";
	 break;
      case CONSTRAINED_LINEAR_GLOBAL:
	 key_word = "*CONSTRAINED_LINEAR_GLOBAL";
	 break;
      case CONSTRAINED_LINEAR_LOCAL:
	 key_word = "*CONSTRAINED_LINEAR_LOCAL";
	 break;
      case CONSTRAINED_LOCAL:
	 key_word = "*CONSTRAINED_LOCAL";
	 break;
      case CONSTRAINED_RIGID_BODIES:
	 key_word = "*CONSTRAINED_RIGID_BODIES";
	 break;
      case CONSTRAINED_RIGID_BODY_STOPPERS:
	 key_word = "*CONSTRAINED_RIGID_BODY_STOPPERS";
	 break;
      case CONSTRAINED_JOINT_CYLINDRICAL_ID_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_CYLINDRICAL_ID_FAILURE";
	 break;
      case CONSTRAINED_JOINT_CYLINDRICAL_ID_FAILURE_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_CYLINDRICAL_ID_FAILURE_LOCAL";
	 break;
      case CONSTRAINED_JOINT_CYLINDRICAL_ID_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_CYLINDRICAL_ID_LOCAL";
	 break;
      case CONSTRAINED_JOINT_CYLINDRICAL_ID_LOCAL_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_CYLINDRICAL_ID_LOCAL_FAILURE";
	 break;
      case CONSTRAINED_JOINT_CYLINDRICAL_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_CYLINDRICAL_FAILURE";
	 break;
      case CONSTRAINED_JOINT_CYLINDRICAL_FAILURE_ID:
	 key_word = "*CONSTRAINED_JOINT_CYLINDRICAL_FAILURE_ID";
	 break;
      case CONSTRAINED_JOINT_CYLINDRICAL_FAILURE_ID_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_CYLINDRICAL_FAILURE_ID_LOCAL";
	 break;
      case CONSTRAINED_JOINT_CYLINDRICAL_FAILURE_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_CYLINDRICAL_FAILURE_LOCAL";
	 break;
      case CONSTRAINED_JOINT_CYLINDRICAL_FAILURE_LOCAL_ID:
	 key_word = "*CONSTRAINED_JOINT_CYLINDRICAL_FAILURE_LOCAL_ID";
	 break;
      case CONSTRAINED_JOINT_CYLINDRICAL:
	 key_word = "*CONSTRAINED_JOINT_CYLINDRICAL";
	 break;
      case CONSTRAINED_JOINT_CYLINDRICAL_ID:
	 key_word = "*CONSTRAINED_JOINT_CYLINDRICAL_ID";
	 break;
      case CONSTRAINED_JOINT_CYLINDRICAL_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_CYLINDRICAL_LOCAL";
	 break;
      case CONSTRAINED_JOINT_CYLINDRICAL_LOCAL_ID:
	 key_word = "*CONSTRAINED_JOINT_CYLINDRICAL_LOCAL_ID";
	 break;
      case CONSTRAINED_JOINT_CYLINDRICAL_LOCAL_ID_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_CYLINDRICAL_LOCAL_ID_FAILURE";
	 break;
      case CONSTRAINED_JOINT_CYLINDRICAL_LOCAL_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_CYLINDRICAL_LOCAL_FAILURE";
	 break;
      case CONSTRAINED_JOINT_CYLINDRICAL_LOCAL_FAILURE_ID:
	 key_word = "*CONSTRAINED_JOINT_CYLINDRICAL_LOCAL_FAILURE_ID";
	 break;
      case CONSTRAINED_JOINT_GEARS:
	 key_word = "*CONSTRAINED_JOINT_GEARS";
	 break;
      case CONSTRAINED_JOINT_GEARS_ID:
	 key_word = "*CONSTRAINED_JOINT_GEARS_ID";
	 break;
      case CONSTRAINED_JOINT_GEARS_ID_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_GEARS_ID_FAILURE";
	 break;
      case CONSTRAINED_JOINT_GEARS_ID_FAILURE_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_GEARS_ID_FAILURE_LOCAL";
	 break;
      case CONSTRAINED_JOINT_GEARS_ID_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_GEARS_ID_LOCAL";
	 break;
      case CONSTRAINED_JOINT_GEARS_ID_LOCAL_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_GEARS_ID_LOCAL_FAILURE";
	 break;
      case CONSTRAINED_JOINT_GEARS_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_GEARS_FAILURE";
	 break;
      case CONSTRAINED_JOINT_GEARS_FAILURE_ID:
	 key_word = "*CONSTRAINED_JOINT_GEARS_FAILURE_ID";
	 break;
      case CONSTRAINED_JOINT_GEARS_FAILURE_ID_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_GEARS_FAILURE_ID_LOCAL";
	 break;
      case CONSTRAINED_JOINT_GEARS_FAILURE_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_GEARS_FAILURE_LOCAL";
	 break;
      case CONSTRAINED_JOINT_GEARS_FAILURE_LOCAL_ID:
	 key_word = "*CONSTRAINED_JOINT_GEARS_FAILURE_LOCAL_ID";
	 break;
      case CONSTRAINED_JOINT_GEARS_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_GEARS_LOCAL";
	 break;
      case CONSTRAINED_JOINT_GEARS_LOCAL_ID:
	 key_word = "*CONSTRAINED_JOINT_GEARS_LOCAL_ID";
	 break;
      case CONSTRAINED_JOINT_GEARS_LOCAL_ID_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_GEARS_LOCAL_ID_FAILURE";
	 break;
      case CONSTRAINED_JOINT_GEARS_LOCAL_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_GEARS_LOCAL_FAILURE";
	 break;
      case CONSTRAINED_JOINT_GEARS_LOCAL_FAILURE_ID:
	 key_word = "*CONSTRAINED_JOINT_GEARS_LOCAL_FAILURE_ID";
	 break;
      case CONSTRAINED_JOINT_LOCKING:
	 key_word = "*CONSTRAINED_JOINT_LOCKING";
	 break;
      case CONSTRAINED_JOINT_LOCKING_ID:
	 key_word = "*CONSTRAINED_JOINT_LOCKING_ID";
	 break;
      case CONSTRAINED_JOINT_LOCKING_ID_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_LOCKING_ID_FAILURE";
	 break;
      case CONSTRAINED_JOINT_LOCKING_ID_FAILURE_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_LOCKING_ID_FAILURE_LOCAL";
	 break;
      case CONSTRAINED_JOINT_LOCKING_ID_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_LOCKING_ID_LOCAL";
	 break;
      case CONSTRAINED_JOINT_LOCKING_ID_LOCAL_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_LOCKING_ID_LOCAL_FAILURE";
	 break;
      case CONSTRAINED_JOINT_LOCKING_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_LOCKING_FAILURE";
	 break;
      case CONSTRAINED_JOINT_LOCKING_FAILURE_ID:
	 key_word = "*CONSTRAINED_JOINT_LOCKING_FAILURE_ID";
	 break;
      case CONSTRAINED_JOINT_LOCKING_FAILURE_ID_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_LOCKING_FAILURE_ID_LOCAL";
	 break;
      case CONSTRAINED_JOINT_LOCKING_FAILURE_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_LOCKING_FAILURE_LOCAL";
	 break;
      case CONSTRAINED_JOINT_LOCKING_FAILURE_LOCAL_ID:
	 key_word = "*CONSTRAINED_JOINT_LOCKING_FAILURE_LOCAL_ID";
	 break;
      case CONSTRAINED_JOINT_LOCKING_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_LOCKING_LOCAL";
	 break;
      case CONSTRAINED_JOINT_LOCKING_LOCAL_ID:
	 key_word = "*CONSTRAINED_JOINT_LOCKING_LOCAL_ID";
	 break;
      case CONSTRAINED_JOINT_LOCKING_LOCAL_ID_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_LOCKING_LOCAL_ID_FAILURE";
	 break;
      case CONSTRAINED_JOINT_LOCKING_LOCAL_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_LOCKING_LOCAL_FAILURE";
	 break;
      case CONSTRAINED_JOINT_LOCKING_LOCAL_FAILURE_ID:
	 key_word = "*CONSTRAINED_JOINT_LOCKING_LOCAL_FAILURE_ID";
	 break;
      case CONSTRAINED_JOINT_PLANAR_ID_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_PLANAR_ID_FAILURE";
	 break;
      case CONSTRAINED_JOINT_PLANAR_ID_FAILURE_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_PLANAR_ID_FAILURE_LOCAL";
	 break;
      case CONSTRAINED_JOINT_PLANAR_ID_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_PLANAR_ID_LOCAL";
	 break;
      case CONSTRAINED_JOINT_PLANAR_ID_LOCAL_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_PLANAR_ID_LOCAL_FAILURE";
	 break;
      case CONSTRAINED_JOINT_PLANAR:
	 key_word = "*CONSTRAINED_JOINT_PLANAR";
	 break;
      case CONSTRAINED_JOINT_PLANAR_ID:
	 key_word = "*CONSTRAINED_JOINT_PLANAR_ID";
	 break;
      case CONSTRAINED_JOINT_PLANAR_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_PLANAR_FAILURE";
	 break;
      case CONSTRAINED_JOINT_PLANAR_FAILURE_ID:
	 key_word = "*CONSTRAINED_JOINT_PLANAR_FAILURE_ID";
	 break;
      case CONSTRAINED_JOINT_PLANAR_FAILURE_ID_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_PLANAR_FAILURE_ID_LOCAL";
	 break;
      case CONSTRAINED_JOINT_PLANAR_FAILURE_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_PLANAR_FAILURE_LOCAL";
	 break;
      case CONSTRAINED_JOINT_PLANAR_FAILURE_LOCAL_ID:
	 key_word = "*CONSTRAINED_JOINT_PLANAR_FAILURE_LOCAL_ID";
	 break;
      case CONSTRAINED_JOINT_PLANAR_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_PLANAR_LOCAL";
	 break;
      case CONSTRAINED_JOINT_PLANAR_LOCAL_ID:
	 key_word = "*CONSTRAINED_JOINT_PLANAR_LOCAL_ID";
	 break;
      case CONSTRAINED_JOINT_PLANAR_LOCAL_ID_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_PLANAR_LOCAL_ID_FAILURE";
	 break;
      case CONSTRAINED_JOINT_PLANAR_LOCAL_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_PLANAR_LOCAL_FAILURE";
	 break;
      case CONSTRAINED_JOINT_PLANAR_LOCAL_FAILURE_ID:
	 key_word = "*CONSTRAINED_JOINT_PLANAR_LOCAL_FAILURE_ID";
	 break;
      case CONSTRAINED_JOINT_PULLEY:
	 key_word = "*CONSTRAINED_JOINT_PULLEY";
	 break;
      case CONSTRAINED_JOINT_PULLEY_ID:
	 key_word = "*CONSTRAINED_JOINT_PULLEY_ID";
	 break;
      case CONSTRAINED_JOINT_PULLEY_ID_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_PULLEY_ID_FAILURE";
	 break;
      case CONSTRAINED_JOINT_PULLEY_ID_FAILURE_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_PULLEY_ID_FAILURE_LOCAL";
	 break;
      case CONSTRAINED_JOINT_PULLEY_ID_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_PULLEY_ID_LOCAL";
	 break;
      case CONSTRAINED_JOINT_PULLEY_ID_LOCAL_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_PULLEY_ID_LOCAL_FAILURE";
	 break;
      case CONSTRAINED_JOINT_PULLEY_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_PULLEY_FAILURE";
	 break;
      case CONSTRAINED_JOINT_PULLEY_FAILURE_ID:
	 key_word = "*CONSTRAINED_JOINT_PULLEY_FAILURE_ID";
	 break;
      case CONSTRAINED_JOINT_PULLEY_FAILURE_ID_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_PULLEY_FAILURE_ID_LOCAL";
	 break;
      case CONSTRAINED_JOINT_PULLEY_FAILURE_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_PULLEY_FAILURE_LOCAL";
	 break;
      case CONSTRAINED_JOINT_PULLEY_FAILURE_LOCAL_ID:
	 key_word = "*CONSTRAINED_JOINT_PULLEY_FAILURE_LOCAL_ID";
	 break;
      case CONSTRAINED_JOINT_PULLEY_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_PULLEY_LOCAL";
	 break;
      case CONSTRAINED_JOINT_PULLEY_LOCAL_ID:
	 key_word = "*CONSTRAINED_JOINT_PULLEY_LOCAL_ID";
	 break;
      case CONSTRAINED_JOINT_PULLEY_LOCAL_ID_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_PULLEY_LOCAL_ID_FAILURE";
	 break;
      case CONSTRAINED_JOINT_PULLEY_LOCAL_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_PULLEY_LOCAL_FAILURE";
	 break;
      case CONSTRAINED_JOINT_PULLEY_LOCAL_FAILURE_ID:
	 key_word = "*CONSTRAINED_JOINT_PULLEY_LOCAL_FAILURE_ID";
	 break;
      case CONSTRAINED_JOINT_RACK_AND_PINION:
	 key_word = "*CONSTRAINED_JOINT_RACK_AND_PINION";
	 break;
      case CONSTRAINED_JOINT_RACK_AND_PINION_ID:
	 key_word = "*CONSTRAINED_JOINT_RACK_AND_PINION_ID";
	 break;
      case CONSTRAINED_JOINT_RACK_AND_PINION_ID_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_RACK_AND_PINION_ID_FAILURE";
	 break;
      case CONSTRAINED_JOINT_RACK_AND_PINION_ID_FAILURE_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_RACK_AND_PINION_ID_FAILURE_LOCAL";
	 break;
      case CONSTRAINED_JOINT_RACK_AND_PINION_ID_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_RACK_AND_PINION_ID_LOCAL";
	 break;
      case CONSTRAINED_JOINT_RACK_AND_PINION_ID_LOCAL_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_RACK_AND_PINION_ID_LOCAL_FAILURE";
	 break;
      case CONSTRAINED_JOINT_RACK_AND_PINION_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_RACK_AND_PINION_FAILURE";
	 break;
      case CONSTRAINED_JOINT_RACK_AND_PINION_FAILURE_ID:
	 key_word = "*CONSTRAINED_JOINT_RACK_AND_PINION_FAILURE_ID";
	 break;
      case CONSTRAINED_JOINT_RACK_AND_PINION_FAILURE_ID_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_RACK_AND_PINION_FAILURE_ID_LOCAL";
	 break;
      case CONSTRAINED_JOINT_RACK_AND_PINION_FAILURE_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_RACK_AND_PINION_FAILURE_LOCAL";
	 break;
      case CONSTRAINED_JOINT_RACK_AND_PINION_FAILURE_LOCAL_ID:
	 key_word = "*CONSTRAINED_JOINT_RACK_AND_PINION_FAILURE_LOCAL_ID";
	 break;
      case CONSTRAINED_JOINT_RACK_AND_PINION_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_RACK_AND_PINION_LOCAL";
	 break;
      case CONSTRAINED_JOINT_RACK_AND_PINION_LOCAL_ID:
	 key_word = "*CONSTRAINED_JOINT_RACK_AND_PINION_LOCAL_ID";
	 break;
      case CONSTRAINED_JOINT_RACK_AND_PINION_LOCAL_ID_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_RACK_AND_PINION_LOCAL_ID_FAILURE";
	 break;
      case CONSTRAINED_JOINT_RACK_AND_PINION_LOCAL_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_RACK_AND_PINION_LOCAL_FAILURE";
	 break;
      case CONSTRAINED_JOINT_RACK_AND_PINION_LOCAL_FAILURE_ID:
	 key_word = "*CONSTRAINED_JOINT_RACK_AND_PINION_LOCAL_FAILURE_ID";
	 break;
      case CONSTRAINED_JOINT_REVOLUTE_ID_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_REVOLUTE_ID_FAILURE";
	 break;
      case CONSTRAINED_JOINT_REVOLUTE_ID_FAILURE_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_REVOLUTE_ID_FAILURE_LOCAL";
	 break;
      case CONSTRAINED_JOINT_REVOLUTE_ID_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_REVOLUTE_ID_LOCAL";
	 break;
      case CONSTRAINED_JOINT_REVOLUTE_ID_LOCAL_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_REVOLUTE_ID_LOCAL_FAILURE";
	 break;
      case CONSTRAINED_JOINT_REVOLUTE_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_REVOLUTE_FAILURE";
	 break;
      case CONSTRAINED_JOINT_REVOLUTE_FAILURE_ID:
	 key_word = "*CONSTRAINED_JOINT_REVOLUTE_FAILURE_ID";
	 break;
      case CONSTRAINED_JOINT_REVOLUTE_FAILURE_ID_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_REVOLUTE_FAILURE_ID_LOCAL";
	 break;
      case CONSTRAINED_JOINT_REVOLUTE_FAILURE_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_REVOLUTE_FAILURE_LOCAL";
	 break;
      case CONSTRAINED_JOINT_REVOLUTE_FAILURE_LOCAL_ID:
	 key_word = "*CONSTRAINED_JOINT_REVOLUTE_FAILURE_LOCAL_ID";
	 break;
      case CONSTRAINED_JOINT_REVOLUTE_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_REVOLUTE_LOCAL";
	 break;
      case CONSTRAINED_JOINT_REVOLUTE_LOCAL_ID:
	 key_word = "*CONSTRAINED_JOINT_REVOLUTE_LOCAL_ID";
	 break;
      case CONSTRAINED_JOINT_REVOLUTE_LOCAL_ID_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_REVOLUTE_LOCAL_ID_FAILURE";
	 break;
      case CONSTRAINED_JOINT_REVOLUTE_LOCAL_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_REVOLUTE_LOCAL_FAILURE";
	 break;
      case CONSTRAINED_JOINT_REVOLUTE_LOCAL_FAILURE_ID:
	 key_word = "*CONSTRAINED_JOINT_REVOLUTE_LOCAL_FAILURE_ID";
	 break;
      case CONSTRAINED_JOINT_REVOLUTE:
	 key_word = "*CONSTRAINED_JOINT_REVOLUTE";
	 break;
      case CONSTRAINED_JOINT_REVOLUTE_ID:
	 key_word = "*CONSTRAINED_JOINT_REVOLUTE_ID";
	 break;
      case CONSTRAINED_JOINT_ROTATIONAL_MOTOR:
	 key_word = "*CONSTRAINED_JOINT_ROTATIONAL_MOTOR";
	 break;
      case CONSTRAINED_JOINT_ROTATIONAL_MOTOR_ID:
	 key_word = "*CONSTRAINED_JOINT_ROTATIONAL_MOTOR_ID";
	 break;
      case CONSTRAINED_JOINT_ROTATIONAL_MOTOR_ID_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_ROTATIONAL_MOTOR_ID_FAILURE";
	 break;
      case CONSTRAINED_JOINT_ROTATIONAL_MOTOR_ID_FAILURE_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_ROTATIONAL_MOTOR_ID_FAILURE_LOCAL";
	 break;
      case CONSTRAINED_JOINT_ROTATIONAL_MOTOR_ID_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_ROTATIONAL_MOTOR_ID_LOCAL";
	 break;
      case CONSTRAINED_JOINT_ROTATIONAL_MOTOR_ID_LOCAL_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_ROTATIONAL_MOTOR_ID_LOCAL_FAILURE";
	 break;
      case CONSTRAINED_JOINT_ROTATIONAL_MOTOR_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_ROTATIONAL_MOTOR_FAILURE";
	 break;
      case CONSTRAINED_JOINT_ROTATIONAL_MOTOR_FAILURE_ID:
	 key_word = "*CONSTRAINED_JOINT_ROTATIONAL_MOTOR_FAILURE_ID";
	 break;
      case CONSTRAINED_JOINT_ROTATIONAL_MOTOR_FAILURE_ID_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_ROTATIONAL_MOTOR_FAILURE_ID_LOCAL";
	 break;
      case CONSTRAINED_JOINT_ROTATIONAL_MOTOR_FAILURE_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_ROTATIONAL_MOTOR_FAILURE_LOCAL";
	 break;
      case CONSTRAINED_JOINT_ROTATIONAL_MOTOR_FAILURE_LOCAL_ID:
	 key_word = "*CONSTRAINED_JOINT_ROTATIONAL_MOTOR_FAILURE_LOCAL_ID";
	 break;
      case CONSTRAINED_JOINT_ROTATIONAL_MOTOR_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_ROTATIONAL_MOTOR_LOCAL";
	 break;
      case CONSTRAINED_JOINT_ROTATIONAL_MOTOR_LOCAL_ID:
	 key_word = "*CONSTRAINED_JOINT_ROTATIONAL_MOTOR_LOCAL_ID";
	 break;
      case CONSTRAINED_JOINT_ROTATIONAL_MOTOR_LOCAL_ID_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_ROTATIONAL_MOTOR_LOCAL_ID_FAILURE";
	 break;
      case CONSTRAINED_JOINT_ROTATIONAL_MOTOR_LOCAL_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_ROTATIONAL_MOTOR_LOCAL_FAILURE";
	 break;
      case CONSTRAINED_JOINT_ROTATIONAL_MOTOR_LOCAL_FAILURE_ID:
	 key_word = "*CONSTRAINED_JOINT_ROTATIONAL_MOTOR_LOCAL_FAILURE_ID";
	 break;
      case CONSTRAINED_JOINT_SCREW:
	 key_word = "*CONSTRAINED_JOINT_SCREW";
	 break;
      case CONSTRAINED_JOINT_SCREW_ID:
	 key_word = "*CONSTRAINED_JOINT_SCREW_ID";
	 break;
      case CONSTRAINED_JOINT_SCREW_ID_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_SCREW_ID_FAILURE";
	 break;
      case CONSTRAINED_JOINT_SCREW_ID_FAILURE_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_SCREW_ID_FAILURE_LOCAL";
	 break;
      case CONSTRAINED_JOINT_SCREW_ID_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_SCREW_ID_LOCAL";
	 break;
      case CONSTRAINED_JOINT_SCREW_ID_LOCAL_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_SCREW_ID_LOCAL_FAILURE";
	 break;
      case CONSTRAINED_JOINT_SCREW_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_SCREW_FAILURE";
	 break;
      case CONSTRAINED_JOINT_SCREW_FAILURE_ID:
	 key_word = "*CONSTRAINED_JOINT_SCREW_FAILURE_ID";
	 break;
      case CONSTRAINED_JOINT_SCREW_FAILURE_ID_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_SCREW_FAILURE_ID_LOCAL";
	 break;
      case CONSTRAINED_JOINT_SCREW_FAILURE_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_SCREW_FAILURE_LOCAL";
	 break;
      case CONSTRAINED_JOINT_SCREW_FAILURE_LOCAL_ID:
	 key_word = "*CONSTRAINED_JOINT_SCREW_FAILURE_LOCAL_ID";
	 break;
      case CONSTRAINED_JOINT_SCREW_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_SCREW_LOCAL";
	 break;
      case CONSTRAINED_JOINT_SCREW_LOCAL_ID:
	 key_word = "*CONSTRAINED_JOINT_SCREW_LOCAL_ID";
	 break;
      case CONSTRAINED_JOINT_SCREW_LOCAL_ID_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_SCREW_LOCAL_ID_FAILURE";
	 break;
      case CONSTRAINED_JOINT_SCREW_LOCAL_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_SCREW_LOCAL_FAILURE";
	 break;
      case CONSTRAINED_JOINT_SCREW_LOCAL_FAILURE_ID:
	 key_word = "*CONSTRAINED_JOINT_SCREW_LOCAL_FAILURE_ID";
	 break;
      case CONSTRAINED_JOINT_SPHERICAL_ID_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_SPHERICAL_ID_FAILURE";
	 break;
      case CONSTRAINED_JOINT_SPHERICAL_ID_FAILURE_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_SPHERICAL_ID_FAILURE_LOCAL";
	 break;
      case CONSTRAINED_JOINT_SPHERICAL_ID_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_SPHERICAL_ID_LOCAL";
	 break;
      case CONSTRAINED_JOINT_SPHERICAL_ID_LOCAL_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_SPHERICAL_ID_LOCAL_FAILURE";
	 break;
      case CONSTRAINED_JOINT_SPHERICAL_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_SPHERICAL_FAILURE";
	 break;
      case CONSTRAINED_JOINT_SPHERICAL_FAILURE_ID:
	 key_word = "*CONSTRAINED_JOINT_SPHERICAL_FAILURE_ID";
	 break;
      case CONSTRAINED_JOINT_SPHERICAL_FAILURE_ID_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_SPHERICAL_FAILURE_ID_LOCAL";
	 break;
      case CONSTRAINED_JOINT_SPHERICAL_FAILURE_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_SPHERICAL_FAILURE_LOCAL";
	 break;
      case CONSTRAINED_JOINT_SPHERICAL_FAILURE_LOCAL_ID:
	 key_word = "*CONSTRAINED_JOINT_SPHERICAL_FAILURE_LOCAL_ID";
	 break;
      case CONSTRAINED_JOINT_SPHERICAL:
	 key_word = "*CONSTRAINED_JOINT_SPHERICAL";
	 break;
      case CONSTRAINED_JOINT_SPHERICAL_ID:
	 key_word = "*CONSTRAINED_JOINT_SPHERICAL_ID";
	 break;
      case CONSTRAINED_JOINT_SPHERICAL_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_SPHERICAL_LOCAL";
	 break;
      case CONSTRAINED_JOINT_SPHERICAL_LOCAL_ID:
	 key_word = "*CONSTRAINED_JOINT_SPHERICAL_LOCAL_ID";
	 break;
      case CONSTRAINED_JOINT_SPHERICAL_LOCAL_ID_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_SPHERICAL_LOCAL_ID_FAILURE";
	 break;
      case CONSTRAINED_JOINT_SPHERICAL_LOCAL_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_SPHERICAL_LOCAL_FAILURE";
	 break;
      case CONSTRAINED_JOINT_SPHERICAL_LOCAL_FAILURE_ID:
	 key_word = "*CONSTRAINED_JOINT_SPHERICAL_LOCAL_FAILURE_ID";
	 break;
      case CONSTRAINED_JOINT_TRANSLATIONAL:
	 key_word = "*CONSTRAINED_JOINT_TRANSLATIONAL";
	 break;
      case CONSTRAINED_JOINT_TRANSLATIONAL_ID:
	 key_word = "*CONSTRAINED_JOINT_TRANSLATIONAL_ID";
	 break;
      case CONSTRAINED_JOINT_TRANSLATIONAL_ID_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_TRANSLATIONAL_ID_FAILURE";
	 break;
      case CONSTRAINED_JOINT_TRANSLATIONAL_ID_FAILURE_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_TRANSLATIONAL_ID_FAILURE_LOCAL";
	 break;
      case CONSTRAINED_JOINT_TRANSLATIONAL_ID_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_TRANSLATIONAL_ID_LOCAL";
	 break;
      case CONSTRAINED_JOINT_TRANSLATIONAL_ID_LOCAL_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_TRANSLATIONAL_ID_LOCAL_FAILURE";
	 break;
      case CONSTRAINED_JOINT_TRANSLATIONAL_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_TRANSLATIONAL_FAILURE";
	 break;
      case CONSTRAINED_JOINT_TRANSLATIONAL_FAILURE_ID:
	 key_word = "*CONSTRAINED_JOINT_TRANSLATIONAL_FAILURE_ID";
	 break;
      case CONSTRAINED_JOINT_TRANSLATIONAL_FAILURE_ID_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_TRANSLATIONAL_FAILURE_ID_LOCAL";
	 break;
      case CONSTRAINED_JOINT_TRANSLATIONAL_FAILURE_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_TRANSLATIONAL_FAILURE_LOCAL";
	 break;
      case CONSTRAINED_JOINT_TRANSLATIONAL_FAILURE_LOCAL_ID:
	 key_word = "*CONSTRAINED_JOINT_TRANSLATIONAL_FAILURE_LOCAL_ID";
	 break;
      case CONSTRAINED_JOINT_TRANSLATIONAL_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_TRANSLATIONAL_LOCAL";
	 break;
      case CONSTRAINED_JOINT_TRANSLATIONAL_LOCAL_ID:
	 key_word = "*CONSTRAINED_JOINT_TRANSLATIONAL_LOCAL_ID";
	 break;
      case CONSTRAINED_JOINT_TRANSLATIONAL_LOCAL_ID_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_TRANSLATIONAL_LOCAL_ID_FAILURE";
	 break;
      case CONSTRAINED_JOINT_TRANSLATIONAL_LOCAL_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_TRANSLATIONAL_LOCAL_FAILURE";
	 break;
      case CONSTRAINED_JOINT_TRANSLATIONAL_LOCAL_FAILURE_ID:
	 key_word = "*CONSTRAINED_JOINT_TRANSLATIONAL_LOCAL_FAILURE_ID";
	 break;
      case CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR:
	 key_word = "*CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR";
	 break;
      case CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_ID:
	 key_word = "*CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_ID";
	 break;
      case CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_ID_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_ID_FAILURE";
	 break;
      case CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_ID_FAILURE_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_ID_FAILURE_LOCAL";
	 break;
      case CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_ID_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_ID_LOCAL";
	 break;
      case CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_ID_LOCAL_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_ID_LOCAL_FAILURE";
	 break;
      case CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_FAILURE";
	 break;
      case CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_FAILURE_ID:
	 key_word = "*CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_FAILURE_ID";
	 break;
      case CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_FAILURE_ID_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_FAILURE_ID_LOCAL";
	 break;
      case CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_FAILURE_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_FAILURE_LOCAL";
	 break;
      case CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_FAILURE_LOCAL_ID:
	 key_word = "*CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_FAILURE_LOCAL_ID";
	 break;
      case CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_LOCAL";
	 break;
      case CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_LOCAL_ID:
	 key_word = "*CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_LOCAL_ID";
	 break;
      case CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_LOCAL_ID_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_LOCAL_ID_FAILURE";
	 break;
      case CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_LOCAL_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_LOCAL_FAILURE";
	 break;
      case CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_LOCAL_FAILURE_ID:
	 key_word = "*CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_LOCAL_FAILURE_ID";
	 break;
      case CONSTRAINED_JOINT_UNIVERSAL_ID_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_UNIVERSAL_ID_FAILURE";
	 break;
      case CONSTRAINED_JOINT_UNIVERSAL_ID_FAILURE_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_UNIVERSAL_ID_FAILURE_LOCAL";
	 break;
      case CONSTRAINED_JOINT_UNIVERSAL_ID_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_UNIVERSAL_ID_LOCAL";
	 break;
      case CONSTRAINED_JOINT_UNIVERSAL_ID_LOCAL_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_UNIVERSAL_ID_LOCAL_FAILURE";
	 break;
      case CONSTRAINED_JOINT_UNIVERSAL_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_UNIVERSAL_FAILURE";
	 break;
      case CONSTRAINED_JOINT_UNIVERSAL_FAILURE_ID:
	 key_word = "*CONSTRAINED_JOINT_UNIVERSAL_FAILURE_ID";
	 break;
      case CONSTRAINED_JOINT_UNIVERSAL_FAILURE_ID_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_UNIVERSAL_FAILURE_ID_LOCAL";
	 break;
      case CONSTRAINED_JOINT_UNIVERSAL_FAILURE_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_UNIVERSAL_FAILURE_LOCAL";
	 break;
      case CONSTRAINED_JOINT_UNIVERSAL_FAILURE_LOCAL_ID:
	 key_word = "*CONSTRAINED_JOINT_UNIVERSAL_FAILURE_LOCAL_ID";
	 break;
      case CONSTRAINED_JOINT_UNIVERSAL_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_UNIVERSAL_LOCAL";
	 break;
      case CONSTRAINED_JOINT_UNIVERSAL_LOCAL_ID:
	 key_word = "*CONSTRAINED_JOINT_UNIVERSAL_LOCAL_ID";
	 break;
      case CONSTRAINED_JOINT_UNIVERSAL_LOCAL_ID_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_UNIVERSAL_LOCAL_ID_FAILURE";
	 break;
      case CONSTRAINED_JOINT_UNIVERSAL_LOCAL_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_UNIVERSAL_LOCAL_FAILURE";
	 break;
      case CONSTRAINED_JOINT_UNIVERSAL_LOCAL_FAILURE_ID:
	 key_word = "*CONSTRAINED_JOINT_UNIVERSAL_LOCAL_FAILURE_ID";
	 break;
      case CONSTRAINED_JOINT_UNIVERSAL:
	 key_word = "*CONSTRAINED_JOINT_UNIVERSAL";
	 break;
      case CONSTRAINED_JOINT_UNIVERSAL_ID:
	 key_word = "*CONSTRAINED_JOINT_UNIVERSAL_ID";
	 break;
      case CONSTRAINED_JOINT_CONSTANT_VELOCITY:
	 key_word = "*CONSTRAINED_JOINT_CONSTANT_VELOCITY";
	 break;
      case CONSTRAINED_JOINT_CONSTANT_VELOCITY_ID:
	 key_word = "*CONSTRAINED_JOINT_CONSTANT_VELOCITY_ID";
	 break;
      case CONSTRAINED_JOINT_CONSTANT_VELOCITY_ID_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_CONSTANT_VELOCITY_ID_FAILURE";
	 break;
      case CONSTRAINED_JOINT_CONSTANT_VELOCITY_ID_FAILURE_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_CONSTANT_VELOCITY_ID_FAILURE_LOCAL";
	 break;
      case CONSTRAINED_JOINT_CONSTANT_VELOCITY_ID_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_CONSTANT_VELOCITY_ID_LOCAL";
	 break;
      case CONSTRAINED_JOINT_CONSTANT_VELOCITY_ID_LOCAL_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_CONSTANT_VELOCITY_ID_LOCAL_FAILURE";
	 break;
      case CONSTRAINED_JOINT_CONSTANT_VELOCITY_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_CONSTANT_VELOCITY_FAILURE";
	 break;
      case CONSTRAINED_JOINT_CONSTANT_VELOCITY_FAILURE_ID:
	 key_word = "*CONSTRAINED_JOINT_CONSTANT_VELOCITY_FAILURE_ID";
	 break;
      case CONSTRAINED_JOINT_CONSTANT_VELOCITY_FAILURE_ID_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_CONSTANT_VELOCITY_FAILURE_ID_LOCAL";
	 break;
      case CONSTRAINED_JOINT_CONSTANT_VELOCITY_FAILURE_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_CONSTANT_VELOCITY_FAILURE_LOCAL";
	 break;
      case CONSTRAINED_JOINT_CONSTANT_VELOCITY_FAILURE_LOCAL_ID:
	 key_word = "*CONSTRAINED_JOINT_CONSTANT_VELOCITY_FAILURE_LOCAL_ID";
	 break;
      case CONSTRAINED_JOINT_CONSTANT_VELOCITY_LOCAL:
	 key_word = "*CONSTRAINED_JOINT_CONSTANT_VELOCITY_LOCAL";
	 break;
      case CONSTRAINED_JOINT_CONSTANT_VELOCITY_LOCAL_ID:
	 key_word = "*CONSTRAINED_JOINT_CONSTANT_VELOCITY_LOCAL_ID";
	 break;
      case CONSTRAINED_JOINT_CONSTANT_VELOCITY_LOCAL_ID_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_CONSTANT_VELOCITY_LOCAL_ID_FAILURE";
	 break;
      case CONSTRAINED_JOINT_CONSTANT_VELOCITY_LOCAL_FAILURE:
	 key_word = "*CONSTRAINED_JOINT_CONSTANT_VELOCITY_LOCAL_FAILURE";
	 break;
      case CONSTRAINED_JOINT_CONSTANT_VELOCITY_LOCAL_FAILURE_ID:
	 key_word = "*CONSTRAINED_JOINT_CONSTANT_VELOCITY_LOCAL_FAILURE_ID";
	 break;
      case CONSTRAINED_NODAL_RIGID_BODY_TITLE:
	 key_word = "*CONSTRAINED_NODAL_RIGID_BODY_TITLE";
	 break;
      case CONSTRAINED_NODAL_RIGID_BODY:
	 key_word = "*CONSTRAINED_NODAL_RIGID_BODY";
	 break;
      case CONSTRAINED_NODAL_RIGID_BODY_INERTIA:
	 key_word = "*CONSTRAINED_NODAL_RIGID_BODY_INERTIA";
	 break;
      case CONSTRAINED_NODAL_RIGID_BODY_INERTIA_TITLE:
	 key_word = "*CONSTRAINED_NODAL_RIGID_BODY_INERTIA_TITLE";
	 break;
      case CONSTRAINED_NODAL_RIGID_BODY_SPC:
	 key_word = "*CONSTRAINED_NODAL_RIGID_BODY_SPC";
	 break;
      case CONSTRAINED_NODAL_RIGID_BODY_SPC_TITLE:
	 key_word = "*CONSTRAINED_NODAL_RIGID_BODY_SPC_TITLE";
	 break;
      case CONSTRAINED_NODAL_RIGID_BODY_SPC_INERTIA:
	 key_word = "*CONSTRAINED_NODAL_RIGID_BODY_SPC_INERTIA";
	 break;
      case CONSTRAINED_NODAL_RIGID_BODY_SPC_INERTIA_TITLE:
	 key_word = "*CONSTRAINED_NODAL_RIGID_BODY_SPC_INERTIA_TITLE";
	 break;
      case CONSTRAINED_NODE_SET:
	 key_word = "*CONSTRAINED_NODE_SET";
	 break;
      case CONSTRAINED_NODE_SET_ID:
	 key_word = "*CONSTRAINED_NODE_SET_ID";
	 break;
      case CONSTRAINED_POINTS:
	 key_word = "*CONSTRAINED_POINTS";
	 break;
      case CONSTRAINED_ADAPTIVITY:
	 key_word = "*CONSTRAINED_ADAPTIVITY";
	 break;
      case CONSTRAINED_EULER_IN_EULER:
	 key_word = "*CONSTRAINED_EULER_IN_EULER";
	 break;
      case CONSTRAINED_EXTRA_NODES_NODE:
	 key_word = "*CONSTRAINED_EXTRA_NODES_NODE";
	 break;
      case CONSTRAINED_EXTRA_NODES_SET:
	 key_word = "*CONSTRAINED_EXTRA_NODES_SET";
	 break;
      case CONSTRAINED_GLOBAL:
	 key_word = "*CONSTRAINED_GLOBAL";
	 break;
      case CONSTRAINED_INTERPOLATION:
	 key_word = "*CONSTRAINED_INTERPOLATION";
	 break;
      case CONSTRAINED_INTERPOLATION_LOCAL:
	 key_word = "*CONSTRAINED_INTERPOLATION_LOCAL";
	 break;
      case CONSTRAINED_JOINT_STIFFNESS_FLEXION_TORSION:
	 key_word = "*CONSTRAINED_JOINT_STIFFNESS_FLEXION_TORSION";
	 break;
      case CONSTRAINED_JOINT_STIFFNESS_GENERALIZED:
	 key_word = "*CONSTRAINED_JOINT_STIFFNESS_GENERALIZED";
	 break;
      case CONSTRAINED_JOINT_STIFFNESS_TRANSLATIONAL:
	 key_word = "*CONSTRAINED_JOINT_STIFFNESS_TRANSLATIONAL";
	 break;
      case CONSTRAINED_SHELL_TO_SOLID:
	 key_word = "*CONSTRAINED_SHELL_TO_SOLID";
	 break;
      case CONSTRAINED_SPLINE:
	 key_word = "*CONSTRAINED_SPLINE";
	 break;
      case CONSTRAINED_TIE_BREAK:
	 key_word = "*CONSTRAINED_TIE_BREAK";
	 break;
      case CONSTRAINED_TIED_NODES_FAILURE:
	 key_word = "*CONSTRAINED_TIED_NODES_FAILURE";
	 break;
      case CONSTRAINED_BUTT_WELD:
	 key_word = "*CONSTRAINED_BUTT_WELD";
	 break;
      case CONSTRAINED_GENERALIZED_WELD_BUTT:
	 key_word = "*CONSTRAINED_GENERALIZED_WELD_BUTT";
	 break;
      case CONSTRAINED_GENERALIZED_WELD_BUTT_ID:
	 key_word = "*CONSTRAINED_GENERALIZED_WELD_BUTT_ID";
	 break;
      case CONSTRAINED_GENERALIZED_WELD_COMBINED:
	 key_word = "*CONSTRAINED_GENERALIZED_WELD_COMBINED";
	 break;
      case CONSTRAINED_GENERALIZED_WELD_COMBINED_ID:
	 key_word = "*CONSTRAINED_GENERALIZED_WELD_COMBINED_ID";
	 break;
      case CONSTRAINED_GENERALIZED_WELD_CROSS_FILLET:
	 key_word = "*CONSTRAINED_GENERALIZED_WELD_CROSS_FILLET";
	 break;
      case CONSTRAINED_GENERALIZED_WELD_CROSS_FILLET_ID:
	 key_word = "*CONSTRAINED_GENERALIZED_WELD_CROSS_FILLET_ID";
	 break;
      case CONSTRAINED_GENERALIZED_WELD_FILLET:
	 key_word = "*CONSTRAINED_GENERALIZED_WELD_FILLET";
	 break;
      case CONSTRAINED_GENERALIZED_WELD_FILLET_ID:
	 key_word = "*CONSTRAINED_GENERALIZED_WELD_FILLET_ID";
	 break;
      case CONSTRAINED_GENERALIZED_WELD_SPOT:
	 key_word = "*CONSTRAINED_GENERALIZED_WELD_SPOT";
	 break;
      case CONSTRAINED_GENERALIZED_WELD_SPOT_ID:
	 key_word = "*CONSTRAINED_GENERALIZED_WELD_SPOT_ID";
	 break;
      case CONSTRAINED_RIVET:
	 key_word = "*CONSTRAINED_RIVET";
	 break;
      case CONSTRAINED_RIVET_ID:
	 key_word = "*CONSTRAINED_RIVET_ID";
	 break;
      case CONSTRAINED_SPOTWELD:
	 key_word = "*CONSTRAINED_SPOTWELD";
	 break;
      case CONSTRAINED_SPOTWELD_ID:
	 key_word = "*CONSTRAINED_SPOTWELD_ID";
	 break;
      case CONSTRAINED_SPOTWELD_ID_FILTERED_FORCE:
	 key_word = "*CONSTRAINED_SPOTWELD_ID_FILTERED_FORCE";
	 break;
      case CONSTRAINED_SPOTWELD_FILTERED_FORCE:
	 key_word = "*CONSTRAINED_SPOTWELD_FILTERED_FORCE";
	 break;
      case CONSTRAINED_SPOTWELD_FILTERED_FORCE_ID:
	 key_word = "*CONSTRAINED_SPOTWELD_FILTERED_FORCE_ID";
	 break;
   }
   return 0;
}

unsigned int ConstExport::dbReadConsts()
{
   char         **row_data, buf[16];
   unsigned int	i, num_consts = 0, total_consts = 0, num_kw_types = 0;
   expTypeFuncIterator eexp_iter = expTypeFuncMap.end(), exp_iter;

   string       qry = "select kw_type from ", kw_str;
   string table_name = "`" + modelName + "_CONSTRAINEDS`";
   qry += table_name;
   qry += " group by kw_type;";

cout << "KW QRY = " << qry << endl;

   if( goldenConn->executeQuery( qry.data() ) )
      return 0;

   num_kw_types = goldenConn->numRows();

   if( !num_kw_types )
      return 0;

   unsigned int *kw_types = new unsigned int[num_kw_types];

   for(i = 0; i < num_kw_types; i++)
   {
      row_data = goldenConn->nextRow();
      kw_types[i] = atoi( row_data[0] );
cout << "KW CONSTRAINT TYPE = " << kw_types[i] << endl;
   }

   for(i = 0; i < num_kw_types; i++)
   {
      qry = "select * from ";
      qry += table_name;
      qry += " where kw_type=";
      sprintf(buf, "%u", kw_types[i]);
      qry += buf;
      qry += " order by card_index;";

cout << "CONSTRAINT QRY = " << qry << endl;

      if( getKeywordFromType(kw_types[i], kw_str) )
         continue;

cout << "CONSTRAINT KW = " << kw_str << endl;

      if( goldenConn->executeQuery( qry.data() ) )
	 break;

      exp_iter = expTypeFuncMap.find(kw_types[i]);

      if( exp_iter == eexp_iter )
      {
	 cout << "CONSTRAINT TYPE NOT FOUND" << endl;
         continue;
      }

      num_consts = 0;
      while( goldenConn->rowsLeft() )
      {
	 impObj = new ExportObject((char *)kw_str.data(), kw_types[i]);
         goldenConn->clearFlag(KW_DATA_END);
	 (exp_iter->second)(goldenConn, impObj);
         if( impObj->cardCount )
         {
	    constManPtr->add(kw_str.data(), impObj);
	    num_consts++;
         }
         else
            delete impObj;
      }

      total_consts += num_consts;
   }

   delete kw_types;

   return total_consts;
}

