#ifndef _DBCONSTLAGRANGESOLID_H_
#define _DBCONSTLAGRANGESOLID_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *CONSTRAINED_LAGRANGE_IN_SOLID
  * keyword */

class DBConstLagrangeSolid : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBConstLagrangeSolid(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBConstLagrangeSolid()
   {
   }

public:
/** Function to get IDCard details for *CONSTRAINED_LAGRANGE_IN_SOLID
  * keyword from database */
   void dbReadIDCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"COUPID","TITLE",};
      unsigned int field_types[] = {DATA_INT, DATA_CHAR_ARRAY, };
      numFields = 2;
      unsigned int field_widths[] = {10, 70, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 2, CONST, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("IDCard");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","IDCard",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get SlaveMaster details for *CONSTRAINED_LAGRANGE_IN_SOLID
  * keyword from database */
   int dbReadSlaveMaster(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"SLAVE","MASTER","SSTYP","MSTYP","NQUAD","CTYPE","DIREC","MCOUP",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return 0;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, CONST, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("SlaveMaster");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","SlaveMaster",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
      if( wordArray[7] )
         return atoi(wordArray[7]);
      else
         return 0;
   }

/** Function to get TimeCard details for *CONSTRAINED_LAGRANGE_IN_SOLID
  * keyword from database */
   void dbReadTimeCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"START","END","PFAC","FRIC","FRCMIN","NORM","NORMTYP","DAMP",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_DOUBLE, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, CONST, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("TimeCard");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","TimeCard",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get HeatTransfer details for *CONSTRAINED_LAGRANGE_IN_SOLID
  * keyword from database */
   int dbReadHeatTransfer(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"CQ","HMIN","HMAX","ILEAK","PLEAK","LCIDPOR","NVENT","IBLOCK",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {5, };
      unsigned int man_types[] = {DEFINE, };
      unsigned int kw_types[] = {CURVE, };
      unsigned int num_indices = 1;
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return 0;
      }
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      nvent = 0;
      if( wordArray[8] )
         nvent = atoi(wordArray[8]);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("HeatTransfer");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","HeatTransfer",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
      if( wordArray[8] )
         return atoi(wordArray[8]);
      else
         return 0;
   }

/** Function to get Card4a details for *CONSTRAINED_LAGRANGE_IN_SOLID
  * keyword from database */
   void dbReadCard4a(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"IBOXID","IPENCHK","INTFORC","IALESOF","LAGMUL","PFACMM","THKF",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {DEFINE, };
      unsigned int kw_types[] = {BOX, };
      unsigned int num_indices = 1;
      numFields = 7;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card4a");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card4a",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card4b details for *CONSTRAINED_LAGRANGE_IN_SOLID
  * keyword from database */
   void dbReadCard4b(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"A1","B1","A2","B2","A3","B3",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card4b");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card4b",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card4c details for *CONSTRAINED_LAGRANGE_IN_SOLID
  * keyword from database */
   void dbReadCard4c(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"VENTSID","VENTYP","VTCOEF","POPPRES","COEFLC",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, };
      numFields = 5;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, };
      unsigned int end_loop;
      end_loop = nvent;
      for(loop_count = 0; loop_count < end_loop; loop_count++)
      {
         numFields = 5;
         wordArray = goldenConn->nextCard();
         if( !wordArray )
         {
            numFields = 0;
         return;
         }
         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card4c",loop_count);
            cardObj = new DBCard(name_buf);
            ((DBCard *)cardObj)->index = atoi(wordArray[0]);
            cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
            impObj->addCard(cardObj);
         }
         impObj->cardCount++;
      }
   }

/** Function to import all the cards of keyword *CONSTRAINED_LAGRANGE_IN_SOLID
  * from database */
   unsigned int importDBConstLagrangeSolid()
   {
      int ctype = 0;
      int nvent = 0;
      if( strstr(impObj->getKeyword().data(), "_TITLE") )
      {
         dbReadIDCard();
      }
      ctype = dbReadSlaveMaster();
      dbReadTimeCard();
      nvent = dbReadHeatTransfer();
      if( ctype == 11 || ctype == 12 )
      {
         dbReadCard4a();
         dbReadCard4b();
      }
      if( nvent )
      {
         dbReadCard4c();
      }
      return 0;
   }
public:
   int nvent;
};

#endif

