#ifndef _DBCONSTLINEARLOCAL_H_
#define _DBCONSTLINEARLOCAL_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *CONSTRAINED_LINEAR_LOCAL
  * keyword */

class DBConstLinearLocal : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBConstLinearLocal(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBConstLinearLocal()
   {
   }

public:
/** Function to get LoadCurve details for *CONSTRAINED_LINEAR_LOCAL
  * keyword from database */
   void dbReadLoadCurve(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"LCID",};
      unsigned int field_types[] = {DATA_INT, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {DEFINE, };
      unsigned int kw_types[] = {CURVE, };
      unsigned int num_indices = 1;
      numFields = 1;
      unsigned int field_widths[] = {10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, CONST, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("LoadCurve");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","LoadCurve",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get NodeCard details for *CONSTRAINED_LINEAR_LOCAL
  * keyword from database */
   void dbReadNodeCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"NID","DOF","CID","COEF",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, 2, };
      unsigned int man_types[] = {NOD, DEFINE, };
      unsigned int kw_types[] = {9999, COORDINATE, };
      unsigned int num_indices = 2;
      numFields = 4;
      unsigned int field_widths[] = {10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, CONST, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("NodeCard");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","NodeCard",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *CONSTRAINED_LINEAR_LOCAL
  * from database */
   unsigned int importDBConstLinearLocal()
   {
      dbReadLoadCurve();
      unsigned int loop_count = 0;
      dbReadNodeCard(loop_count);
      loop_count++;
      while(numFields)
      {
         dbReadNodeCard(loop_count);
         loop_count++;
      }
      ((ExportObject *)impObj)->loopCount = loop_count-1;
      return 0;
   }
};

#endif

