#ifndef _DBCONSTLOCAL_H_
#define _DBCONSTLOCAL_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *CONSTRAINED_LOCAL
  * keyword */

class DBConstLocal : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBConstLocal(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBConstLocal()
   {
   }

public:
/** Function to get Constraint details for *CONSTRAINED_LOCAL
  * keyword from database */
   void dbReadConstraint(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"TC","RC","CIR","X","Y","Z","CID",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, };
      unsigned int field_indices[] = {6, };
      unsigned int man_types[] = {DEFINE, };
      unsigned int kw_types[] = {COORDINATE, };
      unsigned int num_indices = 1;
      numFields = 7;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, CONST, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Constraint");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Constraint",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *CONSTRAINED_LOCAL
  * from database */
   unsigned int importDBConstLocal()
   {
      dbReadConstraint();
      return 0;
   }
};

#endif

