#ifndef _DBCONSTRIGIDBODYSTOPPERS_H_
#define _DBCONSTRIGIDBODYSTOPPERS_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *CONSTRAINED_RIGID_BODY_STOPPERS
  * keyword */

class DBConstRigidBodyStoppers : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBConstRigidBodyStoppers(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBConstRigidBodyStoppers()
   {
   }

public:
/** Function to get MasterRigid details for *CONSTRAINED_RIGID_BODY_STOPPERS
  * keyword from database */
   void dbReadMasterRigid(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"PID","LCMAX","LCMIN","PSIDMX","PSIDMN","LCVMNX","DIR","VID",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, 3, 4, 5, 7, };
      unsigned int man_types[] = {PARTC, DEFINE, DEFINE, SET, SET, DEFINE, DEFINE, };
      unsigned int kw_types[] = {9999, CURVE, CURVE, 9999, 9999, CURVE, VECTOR, };
      unsigned int num_indices = 7;
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, CONST, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("MasterRigid");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","MasterRigid",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Time details for *CONSTRAINED_RIGID_BODY_STOPPERS
  * keyword from database */
   void dbReadTime(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"TB","TD",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 2;
      unsigned int field_widths[] = {10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, CONST, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Time");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Time",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *CONSTRAINED_RIGID_BODY_STOPPERS
  * from database */
   unsigned int importDBConstRigidBodyStoppers()
   {
      dbReadMasterRigid();
      dbReadTime();
      return 0;
   }
};

#endif

