#ifndef _DBCONSTJOINTLOCALFAILURE_H_
#define _DBCONSTJOINTLOCALFAILURE_H_

#include "manager.h"
#include "dispexport.h"
#include "dbconstjoint.h"

/** Class used for getting data from database for *CONSTRAINED_JOINT_SPHERICAL_LOCAL_FAILURE
  * keyword */

class DBConstJointLocalFailure : public DBConstJoint
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBConstJointLocalFailure(GoldenConn *gold_conn, ImportObject *imp_obj) : DBConstJoint (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBConstJointLocalFailure()
   {
   }

public:
/** Function to get Local details for *CONSTRAINED_JOINT_SPHERICAL_LOCAL_FAILURE
  * keyword from database */
   void dbReadLocal(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"RAID","LST",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, };
      numFields = 2;
      unsigned int field_widths[] = {10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, CONST, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         constJointFind(&wordArray[2], numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Local");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Local",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Failure1 details for *CONSTRAINED_JOINT_SPHERICAL_LOCAL_FAILURE
  * keyword from database */
   void dbReadFailure1(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"CID","TFAIL","COUPL",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {DEFINE, };
      unsigned int kw_types[] = {COORDINATE, };
      unsigned int num_indices = 1;
      numFields = 3;
      unsigned int field_widths[] = {10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, CONST, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Failure1");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Failure1",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Failure2 details for *CONSTRAINED_JOINT_SPHERICAL_LOCAL_FAILURE
  * keyword from database */
   void dbReadFailure2(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"NXX","NYY","NZZ","MXX","MYY","MZZ",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Failure2");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Failure2",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *CONSTRAINED_JOINT_SPHERICAL_LOCAL_FAILURE
  * from database */
   unsigned int importDBConstJointLocalFailure()
   {
      importDBConstJoint();
      if( strstr(impObj->getKeyword().data(), "_LOCAL") )
      {
         dbReadLocal();
      }
      if( strstr(impObj->getKeyword().data(), "_FAIL") )
      {
         dbReadFailure1();
         dbReadFailure2();
      }
      return 0;
   }
};

#endif

