#ifndef _DBCONSTJOINTMOTOR_H_
#define _DBCONSTJOINTMOTOR_H_

#include "manager.h"
#include "dispexport.h"
#include "dbconstjoint.h"

/** Class used for getting data from database for *CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR
  * keyword */

class DBConstJointMotor : public DBConstJoint
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBConstJointMotor(GoldenConn *gold_conn, ImportObject *imp_obj) : DBConstJoint (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBConstJointMotor()
   {
   }

public:
/** Function to get Motor details for *CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR
  * keyword from database */
   void dbReadMotor(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"PARM","LCID","TYPE","R1",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_INT, DATA_INT, DATA_DOUBLE, };
      unsigned int field_indices[] = {1, };
      unsigned int man_types[] = {DEFINE, };
      unsigned int kw_types[] = {CURVE, };
      unsigned int num_indices = 1;
      numFields = 4;
      unsigned int field_widths[] = {10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, CONST, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Motor");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Motor",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR
  * from database */
   unsigned int importDBConstJointMotor()
   {
      importDBConstJoint();
      dbReadMotor();
      return 0;
   }
};

#endif

