#ifndef _DBCONSTNODALRIGIDBODYINERTIA_H_
#define _DBCONSTNODALRIGIDBODYINERTIA_H_

#include "manager.h"
#include "dispexport.h"
#include "dbconstnodalrigidbody.h"

/** Class used for getting data from database for *CONSTRAINED_NODAL_RIGID_BODY_INERTIA
  * keyword */

class DBConstNodalRigidBodyInertia : public DBConstNodalRigidBody
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBConstNodalRigidBodyInertia(GoldenConn *gold_conn, ImportObject *imp_obj) : DBConstNodalRigidBody (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBConstNodalRigidBodyInertia()
   {
   }

public:
/** Function to get NodalPoint details for *CONSTRAINED_NODAL_RIGID_BODY_INERTIA
  * keyword from database */
   int dbReadNodalPoint(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"XC","YC","ZC","TM","IRCS","NODEID",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, };
      numFields = 6;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return 0;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, CONST, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("NodalPoint");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","NodalPoint",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
      if( wordArray[6] )
         return atoi(wordArray[6]);
      else
         return 0;
   }

/** Function to get Inertia details for *CONSTRAINED_NODAL_RIGID_BODY_INERTIA
  * keyword from database */
   void dbReadInertia(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"IXX","IXY","IXZ","IYY","IYZ","IZZ",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, CONST, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Inertia");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Inertia",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Velocity details for *CONSTRAINED_NODAL_RIGID_BODY_INERTIA
  * keyword from database */
   void dbReadVelocity(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"VTX","VTY","VTZ","VRX","VRY","VRZ",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Velocity");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Velocity",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get LocalAxis details for *CONSTRAINED_NODAL_RIGID_BODY_INERTIA
  * keyword from database */
   void dbReadLocalAxis(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"XL","YL","ZL","XLIP","YLIP","ZLIP","CID2",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, };
      numFields = 7;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("LocalAxis");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","LocalAxis",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *CONSTRAINED_NODAL_RIGID_BODY_INERTIA
  * from database */
   unsigned int importDBConstNodalRigidBodyInertia()
   {
      int ircs = 0;
      importDBConstNodalRigidBody();
      ircs = dbReadNodalPoint();
      dbReadInertia();
      dbReadVelocity();
      if( ircs == 1 )
      {
         dbReadLocalAxis();
      }
      return 0;
   }
};

#endif

