#ifndef _DBCONSTNODALRIGIDBODYSPC_H_
#define _DBCONSTNODALRIGIDBODYSPC_H_

#include "manager.h"
#include "dispexport.h"
#include "dbconstnodalrigidbody.h"

/** Class used for getting data from database for *CONSTRAINED_NODAL_RIGID_BODY_SPC
  * keyword */

class DBConstNodalRigidBodySpc : public DBConstNodalRigidBody
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBConstNodalRigidBodySpc(GoldenConn *gold_conn, ImportObject *imp_obj) : DBConstNodalRigidBody (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBConstNodalRigidBodySpc()
   {
   }

public:
/** Function to get Spc details for *CONSTRAINED_NODAL_RIGID_BODY_SPC
  * keyword from database */
   void dbReadSpc(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"CMO","CON1","CON2",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 3;
      unsigned int field_widths[] = {10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, CONST, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Spc");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Spc",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *CONSTRAINED_NODAL_RIGID_BODY_SPC
  * from database */
   unsigned int importDBConstNodalRigidBodySpc()
   {
      importDBConstNodalRigidBody();
      dbReadSpc();
      return 0;
   }
};

#endif

