#ifndef _DBCONSTADAPT_H_
#define _DBCONSTADAPT_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *CONSTRAINED_ADAPTIVITY
  * keyword */

class DBConstAdapt : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBConstAdapt(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBConstAdapt()
   {
   }

public:
/** Function to get Slave details for *CONSTRAINED_ADAPTIVITY
  * keyword from database */
   void dbReadSlave(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"SN","MN1","MN2",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, };
      unsigned int man_types[] = {NOD, NOD, NOD, };
      unsigned int kw_types[] = {9999, 9999, 9999, };
      unsigned int num_indices = 3;
      numFields = 3;
      unsigned int field_widths[] = {10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, CONST, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Slave");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Slave",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *CONSTRAINED_ADAPTIVITY
  * from database */
   unsigned int importDBConstAdapt()
   {
      dbReadSlave();
      return 0;
   }
};

#endif

