#ifndef _DBCONSTEXTRANODES_H_
#define _DBCONSTEXTRANODES_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *CONSTRAINED_EXTRA_NODES_NODE
  * keyword */

class DBConstExtraNodes : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBConstExtraNodes(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBConstExtraNodes()
   {
   }

public:
/** Function to get PartSet details for *CONSTRAINED_EXTRA_NODES_NODE
  * keyword from database */
   void dbReadPartSet(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"PID","NID/NSID","IFLAG",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, };
      numFields = 3;
      unsigned int field_widths[] = {10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, CONST, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         constExtraNodes(&wordArray[2], numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("PartSet");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","PartSet",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *CONSTRAINED_EXTRA_NODES_NODE
  * from database */
   unsigned int importDBConstExtraNodes()
   {
      unsigned int loop_count = 0;
      dbReadPartSet(loop_count);
      loop_count++;
      while(numFields)
      {
         dbReadPartSet(loop_count);
         loop_count++;
      }
      ((ExportObject *)impObj)->loopCount = loop_count-1;
      return 0;
   }
};

#endif

