#ifndef _DBCONSTINTERPOLLOCAL_H_
#define _DBCONSTINTERPOLLOCAL_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *CONSTRAINED_INTERPOLATION_LOCAL
  * keyword */

class DBConstInterpolLocal : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBConstInterpolLocal(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBConstInterpolLocal()
   {
   }

public:
/** Function to get Interpol1 details for *CONSTRAINED_INTERPOLATION_LOCAL
  * keyword from database */
   void dbReadInterpol1(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"ICID","DNID","DDOF","CIDD",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 3, };
      unsigned int man_types[] = {DEFINE, NOD, DEFINE, };
      unsigned int kw_types[] = {COORDINATE, 9999, COORDINATE, };
      unsigned int num_indices = 3;
      numFields = 4;
      unsigned int field_widths[] = {10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, CONST, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Interpol1");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Interpol1",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get IndeNode details for *CONSTRAINED_INTERPOLATION_LOCAL
  * keyword from database */
   void dbReadIndeNode(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"INID","IDOF","TWGHTX","TWGHTY","TWGHTZ","RWGHTX","RWGHTY","RWGHTZ",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {NOD, };
      unsigned int kw_types[] = {9999, };
      unsigned int num_indices = 1;
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, CONST, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("IndeNode");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","IndeNode",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get LocalCID details for *CONSTRAINED_INTERPOLATION_LOCAL
  * keyword from database */
   void dbReadLocalCID(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"CIDI",};
      unsigned int field_types[] = {DATA_INT, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {DEFINE, };
      unsigned int kw_types[] = {COORDINATE, };
      unsigned int num_indices = 1;
      numFields = 1;
      unsigned int field_widths[] = {10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("LocalCID");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","LocalCID",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *CONSTRAINED_INTERPOLATION_LOCAL
  * from database */
   unsigned int importDBConstInterpolLocal()
   {
      dbReadInterpol1();
      unsigned int loop_count = 0;
      dbReadIndeNode(loop_count);
      dbReadLocalCID(loop_count);
      loop_count++;
      while(numFields)
      {
         dbReadIndeNode(loop_count);
         dbReadLocalCID(loop_count);
         loop_count++;
      }
      ((ExportObject *)impObj)->loopCount = loop_count-1;
      return 0;
   }
};

#endif

