#ifndef _DBCONSTJOINTSTIFFGENERAL_H_
#define _DBCONSTJOINTSTIFFGENERAL_H_

#include "manager.h"
#include "dispexport.h"
#include "dbconstjointstiffness.h"

/** Class used for getting data from database for *CONSTRAINED_JOINT_STIFFNESS_GENERALIZED
  * keyword */

class DBConstJointStiffGeneral : public DBConstJointStiffness
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBConstJointStiffGeneral(GoldenConn *gold_conn, ImportObject *imp_obj) : DBConstJointStiffness (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBConstJointStiffGeneral()
   {
   }

public:
/** Function to get LoadCurves details for *CONSTRAINED_JOINT_STIFFNESS_GENERALIZED
  * keyword from database */
   void dbReadLoadCurves(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"LCIDPH","LCIDT","LCIDPS","DLCIDPH","DLCIDT","DLCIDPS",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 6;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, CONST, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("LoadCurves");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","LoadCurves",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get StiffMoment details for *CONSTRAINED_JOINT_STIFFNESS_GENERALIZED
  * keyword from database */
   void dbReadStiffMoment(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"ESPH","FMPH","EST","FMT","ESPS","FMPS",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, CONST, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("StiffMoment");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","StiffMoment",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get StopAngles details for *CONSTRAINED_JOINT_STIFFNESS_GENERALIZED
  * keyword from database */
   void dbReadStopAngles(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"NSAPH","PSAPH","NSAT","PSAT","NSAPS","PSAPS",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("StopAngles");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","StopAngles",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *CONSTRAINED_JOINT_STIFFNESS_GENERALIZED
  * from database */
   unsigned int importDBConstJointStiffGeneral()
   {
      importDBConstJointStiffness();
      dbReadLoadCurves();
      dbReadStiffMoment();
      dbReadStopAngles();
      return 0;
   }
};

#endif

