#ifndef _DBCONSTJOINTSTIFFNESS_H_
#define _DBCONSTJOINTSTIFFNESS_H_

#include "manager.h"
#include "dispexport.h"
#include "goldenconn.h"
#include "dbcard.h"

/** Class used for getting data from database for *CONSTRAINED_JOINT_STIFFNESS
  * keyword */

class DBConstJointStiffness
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBConstJointStiffness(GoldenConn *gold_conn, ImportObject *imp_obj)
   {
      goldenConn = gold_conn;
      impObj = imp_obj;
      numFields = 0;
      wordArray = NULL;
      cardObj = NULL;
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBConstJointStiffness()
   {
      goldenConn = NULL;
      impObj = NULL;
      numFields = 0;
      wordArray = NULL;
      cardObj = NULL;
   }

public:
/** Number of fields in each card */
   unsigned int   numFields;
/** List of field values read from database */
   char           **wordArray;
/** Object to save the imported data from database */
   ImportObject   *impObj;
/** Object to connect to database */
   GoldenConn     *goldenConn;
/** Object to store the fields and their values */
   Card           *cardObj;

public:
/** Function to get Stiffness details for *CONSTRAINED_JOINT_STIFFNESS
  * keyword from database */
   void dbReadStiffness(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"JSID","PIDA","PIDB","CIDA","CIDB","JID",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {1, 2, 3, 4, 5, };
      unsigned int man_types[] = {PARTC, PARTC, DEFINE, DEFINE, CONST, };
      unsigned int kw_types[] = {9999, 9999, COORDINATE, COORDINATE, 9999, };
      unsigned int num_indices = 5;
      numFields = 6;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 2, CONST, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Stiffness");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Stiffness",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *CONSTRAINED_JOINT_STIFFNESS
  * from database */
   unsigned int importDBConstJointStiffness()
   {
      dbReadStiffness();
      return 0;
   }
};

#endif

