#ifndef _DBCONSTSPLINE_H_
#define _DBCONSTSPLINE_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *CONSTRAINED_SPLINE
  * keyword */

class DBConstSpline : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBConstSpline(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBConstSpline()
   {
   }

public:
/** Function to get Spline details for *CONSTRAINED_SPLINE
  * keyword from database */
   void dbReadSpline(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"SPLID","DLRATIO",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, };
      numFields = 2;
      unsigned int field_widths[] = {10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 2, CONST, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Spline");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Spline",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Nodes details for *CONSTRAINED_SPLINE
  * keyword from database */
   void dbReadNodes(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"NID","DOF",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, };
      numFields = 2;
      unsigned int field_widths[] = {10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, CONST, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Nodes");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Nodes",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *CONSTRAINED_SPLINE
  * from database */
   unsigned int importDBConstSpline()
   {
      dbReadSpline();
      unsigned int loop_count = 0;
      dbReadNodes(loop_count);
      loop_count++;
      while(numFields)
      {
         dbReadNodes(loop_count);
         loop_count++;
      }
      ((ExportObject *)impObj)->loopCount = loop_count-1;
      return 0;
   }
};

#endif

