#ifndef _DBCONSTGENWELDCOMBINED_H_
#define _DBCONSTGENWELDCOMBINED_H_

#include "manager.h"
#include "dispexport.h"
#include "dbconstgenweld.h"

/** Class used for getting data from database for *CONSTRAINED_GENERALIZED_WELD_COMBINED
  * keyword */

class DBConstGenWeldCombined : public DBConstGenWeld
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBConstGenWeldCombined(GoldenConn *gold_conn, ImportObject *imp_obj) : DBConstGenWeld (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBConstGenWeldCombined()
   {
   }

public:
/** Function to get Combined1 details for *CONSTRAINED_GENERALIZED_WELD_COMBINED
  * keyword from database */
   void dbReadCombined1(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"TFAIL","EPSF","SIGY","BETA","L","W","A","ALPHA",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, CONST, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Combined1");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Combined1",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Combined2 details for *CONSTRAINED_GENERALIZED_WELD_COMBINED
  * keyword from database */
   void dbReadCombined2(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"NODEA","NODEB","NCID","WTYP",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, };
      unsigned int man_types[] = {NOD, NOD, DEFINE, };
      unsigned int kw_types[] = {9999, 9999, COORDINATE, };
      unsigned int num_indices = 3;
      numFields = 4;
      unsigned int field_widths[] = {10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, CONST, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Combined2");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Combined2",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *CONSTRAINED_GENERALIZED_WELD_COMBINED
  * from database */
   unsigned int importDBConstGenWeldCombined()
   {
      importDBConstGenWeld();
      for(int i = 0; i < npr; i++)
      {
         dbReadCombined1();
         dbReadCombined2();
      }
      return 0;
   }
};

#endif

