#ifndef _DBCONSTSPOTWELDFILTER_H_
#define _DBCONSTSPOTWELDFILTER_H_

#include "manager.h"
#include "dispexport.h"
#include "dbconstspotweld.h"

/** Class used for getting data from database for *CONSTRAINED_SPOTWELD_FILTERED_FORCE
  * keyword */

class DBConstSpotWeldFilter : public DBConstSpotWeld
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBConstSpotWeldFilter(GoldenConn *gold_conn, ImportObject *imp_obj) : DBConstSpotWeld (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBConstSpotWeldFilter()
   {
   }

public:
/** Function to get Filter details for *CONSTRAINED_SPOTWELD_FILTERED_FORCE
  * keyword from database */
   void dbReadFilter(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"NF","TW",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, };
      numFields = 2;
      unsigned int field_widths[] = {10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, CONST, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Filter");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Filter",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *CONSTRAINED_SPOTWELD_FILTERED_FORCE
  * from database */
   unsigned int importDBConstSpotWeldFilter()
   {
      importDBConstSpotWeld();
      dbReadFilter();
      return 0;
   }
};

#endif

