#include <iostream>
#include <algorithm>
#include "generic.h"
#include "contacttype.h"
#include "contactimport.h"
#include "card4import.h"
#include "contactid.h"
#include "contactmpp.h"
#include "contactthermal.h"
#include "contactthermalfriction.h"
#include "contactoptiona.h"
#include "contactoptionb.h"
#include "contactoptionc.h"
#include "contactmandatory.h"

#include "contact2dauto.h"
#include "contact2dnoauto.h"
#include "contact2dpenfric.h"
#include "contact2dthermal.h"
#include "contact2dopta.h"

#include <stdlib.h>

using namespace std;

ContactImport::ContactImport
(
   FILE          *fp,
   DataLoc       *data_loc,
   ContactManager    *contact_man
)
{
   filePtr = fp;
   contactManPtr = contact_man;
   dataLocPtr = data_loc;
   dataLine = NULL;

   initSimpleTypesAndFunctions();
}

ContactType ContactImport::getGebodTypeFromKeyword
            (
	       const char  *key_word
            )
{
   if( strstr(key_word, "D_HEA") )
      return CONTACT_GEBOD_HEAD;
   else if( strstr(key_word, "FT_FO") )
      return CONTACT_GEBOD_LEFT_FOOT;
   else if( strstr(key_word, "FT_HA") )
      return CONTACT_GEBOD_LEFT_HAND;
   else if( strstr(key_word, "DLE_T") )
      return CONTACT_GEBOD_MIDDLE_TORSO;
   else if( strstr(key_word, "FT_SH") )
      return CONTACT_GEBOD_LEFT_SHOULDER;
   else if( strstr(key_word, "WER_TO") )
      return CONTACT_GEBOD_LOWER_TORSO;
   else if( strstr(key_word, "OD_NEC") )
      return CONTACT_GEBOD_NECK;
   else if( strstr(key_word, "HT_FOO") )
      return CONTACT_GEBOD_RIGHT_FOOT;
   else if( strstr(key_word, "HT_HAN") )
      return CONTACT_GEBOD_RIGHT_HAND;
   else if( strstr(key_word, "HT_SH") )
      return CONTACT_GEBOD_RIGHT_SHOULDER;
   else if( strstr(key_word, "PER_TO") )
      return CONTACT_GEBOD_UPPER_TORSO;
   else if( strstr(key_word, "_LEFT") )
   {
      if( strstr(key_word, "WER_AR") )
         return CONTACT_GEBOD_LEFT_LOWER_ARM;
      else if( strstr(key_word, "WER_LE") )
	 return CONTACT_GEBOD_LEFT_LOWER_LEG;
      else if( strstr(key_word, "PER_AR") )
	 return CONTACT_GEBOD_LEFT_UPPER_ARM;
      else if( strstr(key_word, "PER_LE") )
	 return CONTACT_GEBOD_LEFT_UPPER_LEG;
   }
   else if( strstr(key_word, "_RIGHT") )
   {
      if( strstr(key_word, "WER_AR") )
         return CONTACT_GEBOD_RIGHT_LOWER_ARM;
      else if( strstr(key_word, "WER_LE") )
	 return CONTACT_GEBOD_RIGHT_LOWER_LEG;
      else if( strstr(key_word, "PER_AR") )
	 return CONTACT_GEBOD_RIGHT_UPPER_ARM;
      else if( strstr(key_word, "PER_LE") )
	 return CONTACT_GEBOD_RIGHT_UPPER_LEG;
   }

   return CONTACT_NEW_TYPE;
}

ContactType ContactImport::get2DContactTypeFromKeyword
            (
	       const char  *key_word
            )
{
   if( strstr(key_word, "_ONL") )
      return CONTACT_2D_SLIDING_ONLY;
   else if( strstr(key_word, "IED_SL") )
      return CONTACT_2D_TIED_SLIDING;
   else if( strstr(key_word, "NG_VOI") )
      return CONTACT_2D_SLIDING_VOIDS;
   else if( strstr(key_word, "TY_FRIC") )
      return CONTACT_2D_PENALTY_FRICTION;
   else if( strstr(key_word, "_PEN") )
      return CONTACT_2D_PENALTY;
   else if( strstr(key_word, "LE_SUR") )
      return CONTACT_2D_AUTOMATIC_SINGLE_SURFACE;
   else if( strstr(key_word, "CE_TO_SU") )
      return CONTACT_2D_AUTOMATIC_SURFACE_TO_SURFACE;
   else if( strstr(key_word, "DE_TO_SU") )
      return CONTACT_2D_AUTOMATIC_NODE_TO_SURFACE;
   else if( strstr(key_word, "IN_CON") )
      return CONTACT_2D_AUTOMATIC_SURFACE_IN_CONTINUUM;
   else if( strstr(key_word, "ED__ON") )
      return CONTACT_2D_AUTOMATIC_TIED_ONE_WAY;
   else if( strstr(key_word, "IC_TI") )
      return CONTACT_2D_AUTOMATIC_TIED;
   else
      return CONTACT_NEW_TYPE; 
}

ContactType ContactImport::getContactTypeFromKeyword
	    (
	       const char  *key_word,
	       unsigned int *contact_id
	    )
{
   *contact_id = 0;

   if( strstr(key_word, "_2D_") )
   {
      return get2DContactTypeFromKeyword(key_word);
   }
   else if( strstr(key_word, "_GEB") )
   {
      return getGebodTypeFromKeyword(key_word);
   }
   else if( strstr(key_word, "_CAB") )
      return CONTACT_GUIDED_CABLE;
   else if( strstr(key_word, "T_INT") )
      return CONTACT_INTERIOR;
   else if( strstr(key_word, "_1D") )
      return CONTACT_1D;
   else if( strstr(key_word, "ID_SU") )
      return CONTACT_RIGID_SURFACE;
   else if( strstr(key_word, "T_ENT") )
      return CONTACT_ENTITY;
   else if( strstr(key_word, "T_COU") )
      return CONTACT_COUPLING;
   else if( strstr(key_word, "O_MOV") )
      return CONTACT_AUTO_MOVE;

   else if( strstr(key_word, "BAG_SI") )
      return CONTACT_AIRBAG_SINGLE_SURFACE;
   else if( strstr(key_word, "C_GEN") )
   {
      if( strstr(key_word, "_INT") )
	 return CONTACT_AUTOMATIC_GENERAL_INTERIOR;
      else
         return CONTACT_AUTOMATIC_GENERAL;
   }
   else if( strstr(key_word, "C_NOD") )
   {
      if( strstr(key_word, "_SMOO") )
	 return CONTACT_AUTOMATIC_NODES_TO_SURFACE_SMOOTH;
      else
         return CONTACT_AUTOMATIC_NODES_TO_SURFACE;
   }
   else if( strstr(key_word, "C_ONE") )
   {
      if( strstr(key_word, "_TIE") )
	 return CONTACT_AUTOMATIC_ONE_WAY_SURFACE_TO_SURFACE_TIEBREAK;
      else if( strstr(key_word, "_SMOO") )
	 return CONTACT_AUTOMATIC_ONE_WAY_SURFACE_TO_SURFACE_SMOOTH;
      else
         return CONTACT_AUTOMATIC_ONE_WAY_SURFACE_TO_SURFACE;
   }
   else if( strstr(key_word, "C_SING") )
   {
      if( strstr(key_word, "_SMOO") )
	 return CONTACT_AUTOMATIC_SINGLE_SURFACE_SMOOTH;
      else
         return CONTACT_AUTOMATIC_SINGLE_SURFACE;
   }
   else if( strstr(key_word, "C_SUR") )
   {
      if( strstr(key_word, "_TIE") )
	 return CONTACT_AUTOMATIC_SURFACE_TO_SURFACE_TIEBREAK;
      else if( strstr(key_word, "_SMOO") )
	 return CONTACT_AUTOMATIC_SURFACE_TO_SURFACE_SMOOTH;
      else
         return CONTACT_AUTOMATIC_SURFACE_TO_SURFACE;
   }
   else if( strstr(key_word, "NT_NO") )
      return CONTACT_CONSTRAINT_NODES_TO_SURFACE;
   else if( strstr(key_word, "NT_SUR") )
      return CONTACT_CONSTRAINT_SURFACE_TO_SURFACE;
   else if( strstr(key_word, "AD_IN") )
      return CONTACT_DRAWBEAD_INITIALIZE;
   else if( strstr(key_word, "_DRA") )
      return CONTACT_DRAWBEAD;
   else if( strstr(key_word, "_ERO") )
   {
      if( strstr(key_word, "_NOD") )
	 return CONTACT_ERODING_NODES_TO_SURFACE;
      else if( strstr(key_word, "_SING") )
	 return CONTACT_ERODING_SINGLE_SURFACE;
      else
         return CONTACT_ERODING_SURFACE_TO_SURFACE;
   }
   else if( strstr(key_word, "_TRA") )
   {
      if( strstr(key_word, "_CONS") )
	 return CONTACT_FORCE_TRANSDUCER_CONSTRAINT;
      else
         return CONTACT_FORCE_TRANSDUCER_PENALTY;
   }
   else if( strstr(key_word, "G_NOD") )
   {
      if( strstr(key_word, "_SMOO") )
	 return CONTACT_FORMING_NODES_TO_SURFACE_SMOOTH;
      else
         return CONTACT_FORMING_NODES_TO_SURFACE;
   }
   else if( strstr(key_word, "G_ONE") )
   {
      if( strstr(key_word, "_SMOO") )
	 return CONTACT_FORMING_ONE_WAY_SURFACE_TO_SURFACE_SMOOTH;
      else
         return CONTACT_FORMING_ONE_WAY_SURFACE_TO_SURFACE;
   }
   else if( strstr(key_word, "_FORM") )
   {
      if( strstr(key_word, "_SMOO") )
	 return CONTACT_FORMING_SURFACE_TO_SURFACE_SMOOTH;
      else
         return CONTACT_FORMING_SURFACE_TO_SURFACE;
   }
   else if( strstr(key_word, "CT_NOD") )
   {
      if( strstr(key_word, "_INTE") )
	 return CONTACT_NODES_TO_SURFACE_INTERFERENCE;
      else if( strstr(key_word, "_SMOO") )
	 return CONTACT_NODES_TO_SURFACE_SMOOTH;
      else
         return CONTACT_NODES_TO_SURFACE;
   }
   else if( strstr(key_word, "CT_ON") )
   {
      if( strstr(key_word, "_INTE") )
	 return CONTACT_ONE_WAY_SURFACE_TO_SURFACE_INTERFERENCE;
      else if( strstr(key_word, "_SMOO") )
	 return CONTACT_ONE_WAY_SURFACE_TO_SURFACE_SMOOTH;
      else
         return CONTACT_ONE_WAY_SURFACE_TO_SURFACE;
   }
   else if( strstr(key_word, "ID_NOD") )
      return CONTACT_RIGID_NODES_TO_RIGID_BODY;
   else if( strstr(key_word, "DY_ON") )
      return CONTACT_RIGID_BODY_ONE_WAY_TO_RIGID_BODY;
   else if( strstr(key_word, "DY_TW") )
      return CONTACT_RIGID_BODY_TWO_WAY_TO_RIGID_BODY;
   else if( strstr(key_word, "CT_SING") )
   {
      if( strstr(key_word, "_EDG") )
	 return CONTACT_SINGLE_EDGE;
      else
	 return CONTACT_SINGLE_SURFACE;
   }
   else if( strstr(key_word, "Y_PEN") )
      return CONTACT_SLIDING_ONLY_PENALTY;
   else if( strstr(key_word, "T_SLI") )
      return CONTACT_SLIDING_ONLY;
   else if( strstr(key_word, "H_TOR") )
      return CONTACT_SPOTWELD_WITH_TORSION;
   else if( strstr(key_word, "T_SPO") )
      return CONTACT_SPOTWELD;
   else if( strstr(key_word, "CT_SU") )
   {
      if( strstr(key_word, "_INTE") )
	 return CONTACT_SURFACE_TO_SURFACE_INTERFERENCE;
      else if( strstr(key_word, "_SMOO") )
	 return CONTACT_SURFACE_TO_SURFACE_SMOOTH;
      else if( strstr(key_word, "_JOI") )
	 return CONTACT_SURFACE_TO_SURFACE_CONTRACTION_JOINT;
      else
         return CONTACT_SURFACE_TO_SURFACE;
   }
   else if( strstr(key_word, "AK_SUR") )
      return CONTACT_TIEBREAK_SURFACE_TO_SURFACE;
   else if( strstr(key_word, "AK_NOD") )
   {
      if( strstr(key_word, "_SUR") )
         return CONTACT_TIEBREAK_NODES_TO_SURFACE;
      else
         return CONTACT_TIEBREAK_NODES_ONLY;
   }
   else if( strstr(key_word, "ED_NOD") )
      return CONTACT_TIED_NODES_TO_SURFACE;
   else if( strstr(key_word, "ED_SH") )
      return CONTACT_TIED_SHELL_EDGE_TO_SURFACE;
   else if( strstr(key_word, "CE_FAIL") )
      return CONTACT_TIED_SURFACE_TO_SURFACE_FAILURE;
   else if( strstr(key_word, "ED_SUR") )
      return CONTACT_TIED_SURFACE_TO_SURFACE;

   return CONTACT_NEW_TYPE;
}

unsigned int ContactImport::readContacts()
{
   char         new_kw[LINE_LEN];
   unsigned int	i = 0, contact_id = 0, contact_type = 0, num_contacts = 0;
   long		loc = 0L;
   VStringIterator   s = dataLocPtr->keywordList.begin(),
		     e = dataLocPtr->keywordList.end(), itr, 
		     pitr = dataLocPtr->keywordList.begin();

   dataLine = new DataLine(filePtr);

   while(true)
   {
      itr = find_if(pitr, e, bind2nd(KeyWordCompare (), "*CONTACT"));

      if( itr == e )
	 break;

      pitr = itr+1;
      i = (unsigned int)(itr - s);
      loc = dataLocPtr->slocList[i];

      rewind(filePtr);

      if( fseek(filePtr, loc, SEEK_SET) )
      {
	 cout << "ERROR in locating the Contact cards" << endl;
	 break;
      }

      dataLine->clearFlag(KW_READ_END);

      char *str = dataLine->readNextCard(); //get the keyword
      Generic::RemoveLeadingAndTrailingBlanks( str );
cout << "KW = " << str << endl;

      contact_type = getContactTypeFromKeyword( str, &contact_id );
cout << "Contact TYPE = " << contact_type << endl;

      if( contact_type == CONTACT_NEW_TYPE )
      {
         cout << "Contact TYPE NOT SUPPORTED" << endl;
         continue;
      }

      num_contacts++;

      strcpy(new_kw, str);

      impObj = new ImportObject(new_kw);

      dataLine->clearFlag(KW_READ_END);

      if( strstr(new_kw, "_ID") || strstr(new_kw, "_TITL") )
      {
	 ContactID con_id(dataLine, impObj);
	 con_id.importContactID();
      }

      if( contact_type < 200 )
      {
	 if( strstr(new_kw, "_MPP") )
	 {
	    ContactMpp con_mpp(dataLine, impObj);
	    con_mpp.importContactMpp();
	 }

	 ContactMandatory con_man(dataLine, impObj);
	 con_man.importContactMandatory();

	 Card4Import card4(dataLine, impObj);
	 card4.importCard4(contact_type);
    
	 if( strstr(new_kw, "_THER") )
	 {
	    if( strstr(new_kw, "_FRIC") )
	    {
	       ContactThermalFriction con_ther(dataLine, impObj);
	       con_ther.importContactThermalFriction();
	    }
	    else
	    {
	       ContactThermal con_ther(dataLine, impObj);
	       con_ther.importContactThermal();
	    }
	 }

	 ContactOptionA  opt_a(dataLine, impObj);
	 opt_a.importContactOptionA();

	 ContactOptionB  opt_b(dataLine, impObj);
	 opt_b.importContactOptionB();

	 ContactOptionC  opt_c(dataLine, impObj);
	 opt_c.importContactOptionC();
      }
      else if( contact_type < 300 )
      {
         if( strstr(new_kw, "_AUTO") )
         {
            Contact2DAuto  auto_2d(dataLine, impObj);
            auto_2d.importContact2DAuto();
         }
         else
         {
            Contact2DNoAuto  no_auto_2d(dataLine, impObj);
            no_auto_2d.importContact2DNoAuto();
         }

         if( contact_type == CONTACT_2D_PENALTY_FRICTION )
         {
            Contact2DPenFric pen_fric(dataLine, impObj);
            pen_fric.importContact2DPenFric();
         }
     
         if( strstr(new_kw, "_THER") )
         {
            Contact2DThermal thermal(dataLine, impObj);
            thermal.importContact2DThermal();
         }

         Contact2DOptA opt(dataLine, impObj);
         opt.importContact2DOptA();
      }
      else
      {
	 typeFuncIterator  btype_iter = typeFuncMap.begin(),
			   etype_iter = typeFuncMap.end(), type_iter;
	 type_iter = typeFuncMap.find(contact_type);

	 if( type_iter != etype_iter )
	 {
	    (type_iter->second)(dataLine, impObj);
	 }
      }

      if( contact_id )
      {
	 contactManPtr->add(new_kw, impObj);
      }
      else
      {
	 sprintf(new_kw, "%s_%d", new_kw, num_contacts);
	 contactManPtr->add(new_kw, impObj);
      }
   }

   return num_contacts;
}

