#ifndef _CARD4_EXPORT_H_
#define _CARD4_EXPORT_H_

#include <map>
#include "exptypemap.h"
#include "dbcard.h"
#include "goldenconn.h"
#include "contacttype.h"

/** Class to get data from database for card4 of *CONTACT keywords */
class Card4Export
{
public:
   /** Constructor for creating this object
     * \param gold_conn Connection object for accessing the database
     * \param imp_obj Object to store the imported data from database
     */
   Card4Export(GoldenConn *gold_conn, ImportObject *imp_obj)
   {
      initExportCard4TypesAndFunctions();
       
      goldenConn = gold_conn;
      impObj = imp_obj; 
   }
   
   ~Card4Export()
   {
      goldenConn = NULL;
      impObj = NULL;
      expTypeFuncMap.clear();
   }

   /** Imports the Card 4 for *CONTACT keywords based on the type
     * \param card4_type Type of *CONTACT
     * \return Number of keywords imported
     */
   unsigned int importCard4(unsigned int card4_type)
   {
      expTypeFuncIterator  btype_iter = expTypeFuncMap.begin(),
                        etype_iter = expTypeFuncMap.end(), type_iter;
      type_iter = expTypeFuncMap.find(card4_type);

      if( type_iter != etype_iter )
      {
         (type_iter->second)(goldenConn, impObj);
      }

      return 0;
   }

   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *CONTACT keyword types and their function pointers
     */
   void initExportCard4TypesAndFunctions();

private:
   /** Connection object for accessing the data */
   GoldenConn                            *goldenConn;
   /** Object to store the data imported from database */
   ImportObject                          *impObj;
   /** A map between type of keyword and pointer to the function to be called */
   map<unsigned int, ExportFunctionPtr>  expTypeFuncMap;
};

#endif

