#ifndef _DBCARD4DRAWBEADINIT_H_
#define _DBCARD4DRAWBEADINIT_H_

#include "manager.h"
#include "dispexport.h"
#include "dbcard4drawbead.h"

/** Class used for getting data from database for *CONTACT_DRAWBEAD_INITIALIZE
  * keyword */

class DBCard4DrawbeadInit : public DBCard4Drawbead
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBCard4DrawbeadInit(GoldenConn *gold_conn, ImportObject *imp_obj) : DBCard4Drawbead (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBCard4DrawbeadInit()
   {
   }

public:
/** Function to get PlasticStrain details for *CONTACT_DRAWBEAD_INITIALIZE
  * keyword from database */
   void dbReadPlasticStrain(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"LCEPS","TSCALE","LCEPS2","OFFSET",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, 2, };
      unsigned int man_types[] = {DEFINE, DEFINE, };
      unsigned int kw_types[] = {CURVE, CURVE, };
      unsigned int num_indices = 2;
      numFields = 4;
      unsigned int field_widths[] = {10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, CONTACT, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("PlasticStrain");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","PlasticStrain",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *CONTACT_DRAWBEAD_INITIALIZE
  * from database */
   unsigned int importDBCard4DrawbeadInit()
   {
      importDBCard4Drawbead();
      dbReadPlasticStrain();
      return 0;
   }
};

#endif

