#ifndef _DBCONTACTTHERMAL_H_
#define _DBCONTACTTHERMAL_H_

#include "manager.h"
#include "dispexport.h"
#include "goldenconn.h"
#include "dbcard.h"

/** Class used for getting data from database for *CONTACT_THERMAL
  * keyword */

class DBContactThermal
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBContactThermal(GoldenConn *gold_conn, ImportObject *imp_obj)
   {
      goldenConn = gold_conn;
      impObj = imp_obj;
      numFields = 0;
      wordArray = NULL;
      cardObj = NULL;
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBContactThermal()
   {
      goldenConn = NULL;
      impObj = NULL;
      numFields = 0;
      wordArray = NULL;
      cardObj = NULL;
   }

public:
/** Number of fields in each card */
   unsigned int   numFields;
/** List of field values read from database */
   char           **wordArray;
/** Object to save the imported data from database */
   ImportObject   *impObj;
/** Object to connect to database */
   GoldenConn     *goldenConn;
/** Object to store the fields and their values */
   Card           *cardObj;

public:
/** Function to get ThermalCard details for *CONTACT_THERMAL
  * keyword from database */
   void dbReadThermalCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"K","FRAD","H0","LMIN","LMAX","CHLM","BC_FLG","ALGO",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, CONTACT, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("ThermalCard");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","ThermalCard",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *CONTACT_THERMAL
  * from database */
   unsigned int importDBContactThermal()
   {
      dbReadThermalCard();
      return 0;
   }
};

#endif

