#include <iostream>
#include <algorithm>
#include "generic.h"
#include "contacttype.h"
#include "contactexport.h"
#include "contactexpobj.h"
#include "card4export.h"
#include "dbcontactid.h"
#include "dbcontactmpp.h"
#include "dbcontactthermal.h"
#include "dbcontactthermalfriction.h"
#include "dbcontactoptiona.h"
#include "dbcontactoptionb.h"
#include "dbcontactoptionc.h"
#include "dbcontactmandatory.h"

#include "dbcontact2dauto.h"
#include "dbcontact2dnoauto.h"
#include "dbcontact2dpenfric.h"
#include "dbcontact2dthermal.h"
#include "dbcontact2dopta.h"

#include <stdlib.h>

using namespace std;

ContactExport::ContactExport
(
   char              *model_name,
   GoldenConn        *gold_conn,
   ContactManager    *contact_man
)
{
   modelName = model_name;
   contactManPtr = contact_man;
   goldenConn = gold_conn;

   initExportSimpleTypesAndFunctions();
}

unsigned int ContactExport::getKeywordFromType
	     (
		unsigned int kw_type,
		unsigned int kw_bin,
		string & key_word
	     )
{
   switch(kw_type)
   {
      case CONTACT_AIRBAG_SINGLE_SURFACE:
	 key_word = "*CONTACT_AIRBAG_SINGLE_SURFACE";
	 break;
      case CONTACT_AUTOMATIC_GENERAL:
	 key_word = "*CONTACT_AUTOMATIC_GENERAL";
	 break;
      case CONTACT_AUTOMATIC_GENERAL_INTERIOR:
	 key_word = "*CONTACT_AUTOMATIC_GENERAL_INTERIOR";
	 break;
      case CONTACT_AUTOMATIC_NODES_TO_SURFACE:
	 key_word = "*CONTACT_AUTOMATIC_NODES_TO_SURFACE";
	 break;
      case CONTACT_AUTOMATIC_NODES_TO_SURFACE_SMOOTH:
	 key_word = "*CONTACT_AUTOMATIC_NODES_TO_SURFACE_SMOOTH";
	 break;
      case CONTACT_AUTOMATIC_ONE_WAY_SURFACE_TO_SURFACE:
	 key_word = "*CONTACT_AUTOMATIC_ONE_WAY_SURFACE_TO_SURFACE";
	 break;
      case CONTACT_AUTOMATIC_ONE_WAY_SURFACE_TO_SURFACE_TIEBREAK:
	 key_word = "*CONTACT_AUTOMATIC_ONE_WAY_SURFACE_TO_SURFACE_TIEBREAK";
	 break;
      case CONTACT_AUTOMATIC_ONE_WAY_SURFACE_TO_SURFACE_SMOOTH:
	 key_word = "*CONTACT_AUTOMATIC_ONE_WAY_SURFACE_TO_SURFACE_SMOOTH";
	 break;
      case CONTACT_AUTOMATIC_SINGLE_SURFACE:
	 key_word = "*CONTACT_AUTOMATIC_SINGLE_SURFACE";
	 break;
      case CONTACT_AUTOMATIC_SINGLE_SURFACE_SMOOTH:
	 key_word = "*CONTACT_AUTOMATIC_SINGLE_SURFACE_SMOOTH";
	 break;
      case CONTACT_AUTOMATIC_SURFACE_TO_SURFACE:
	 key_word = "*CONTACT_AUTOMATIC_SURFACE_TO_SURFACE";
	 break;
      case CONTACT_AUTOMATIC_SURFACE_TO_SURFACE_TIEBREAK:
	 key_word = "*CONTACT_AUTOMATIC_SURFACE_TO_SURFACE_TIEBREAK";
	 break;
      case CONTACT_AUTOMATIC_SURFACE_TO_SURFACE_SMOOTH:
	 key_word = "*CONTACT_AUTOMATIC_SURFACE_TO_SURFACE_SMOOTH";
	 break;
      case CONTACT_CONSTRAINT_NODES_TO_SURFACE:
	 key_word = "*CONTACT_CONSTRAINT_NODES_TO_SURFACE";
	 break;
      case CONTACT_CONSTRAINT_SURFACE_TO_SURFACE:
	 key_word = "*CONTACT_CONSTRAINT_SURFACE_TO_SURFACE";
	 break;
      case CONTACT_DRAWBEAD:
	 key_word = "*CONTACT_DRAWBEAD";
	 break;
      case CONTACT_DRAWBEAD_INITIALIZE:
	 key_word = "*CONTACT_DRAWBEAD_INITIALIZE";
	 break;
      case CONTACT_ERODING_NODES_TO_SURFACE:
	 key_word = "*CONTACT_ERODING_NODES_TO_SURFACE";
	 break;
      case CONTACT_ERODING_SINGLE_SURFACE:
	 key_word = "*CONTACT_ERODING_SINGLE_SURFACE";
	 break;
      case CONTACT_ERODING_SURFACE_TO_SURFACE:
	 key_word = "*CONTACT_ERODING_SURFACE_TO_SURFACE";
	 break;
      case CONTACT_FORCE_TRANSDUCER_CONSTRAINT:
	 key_word = "*CONTACT_FORCE_TRANSDUCER_CONSTRAINT";
	 break;
      case CONTACT_FORCE_TRANSDUCER_PENALTY:
	 key_word = "*CONTACT_FORCE_TRANSDUCER_PENALTY";
	 break;
      case CONTACT_FORMING_NODES_TO_SURFACE:
	 key_word = "*CONTACT_FORMING_NODES_TO_SURFACE";
	 break;
      case CONTACT_FORMING_NODES_TO_SURFACE_SMOOTH:
	 key_word = "*CONTACT_FORMING_NODES_TO_SURFACE_SMOOTH";
	 break;
      case CONTACT_FORMING_ONE_WAY_SURFACE_TO_SURFACE:
	 key_word = "*CONTACT_FORMING_ONE_WAY_SURFACE_TO_SURFACE";
	 break;
      case CONTACT_FORMING_ONE_WAY_SURFACE_TO_SURFACE_SMOOTH:
	 key_word = "*CONTACT_FORMING_ONE_WAY_SURFACE_TO_SURFACE_SMOOTH";
	 break;
      case CONTACT_FORMING_SURFACE_TO_SURFACE:
	 key_word = "*CONTACT_FORMING_SURFACE_TO_SURFACE";
	 break;
      case CONTACT_FORMING_SURFACE_TO_SURFACE_SMOOTH:
	 key_word = "*CONTACT_FORMING_SURFACE_TO_SURFACE_SMOOTH";
	 break;
      case CONTACT_NODES_TO_SURFACE:
	 key_word = "*CONTACT_NODES_TO_SURFACE";
	 break;
      case CONTACT_NODES_TO_SURFACE_INTERFERENCE:
	 key_word = "*CONTACT_NODES_TO_SURFACE_INTERFERENCE";
	 break;
      case CONTACT_NODES_TO_SURFACE_SMOOTH:
	 key_word = "*CONTACT_NODES_TO_SURFACE_SMOOTH";
	 break;
      case CONTACT_ONE_WAY_SURFACE_TO_SURFACE:
	 key_word = "*CONTACT_ONE_WAY_SURFACE_TO_SURFACE";
	 break;
      case CONTACT_ONE_WAY_SURFACE_TO_SURFACE_INTERFERENCE:
	 key_word = "*CONTACT_ONE_WAY_SURFACE_TO_SURFACE_INTERFERENCE";
	 break;
      case CONTACT_ONE_WAY_SURFACE_TO_SURFACE_SMOOTH:
	 key_word = "*CONTACT_ONE_WAY_SURFACE_TO_SURFACE_SMOOTH";
	 break;
      case CONTACT_RIGID_NODES_TO_RIGID_BODY:
	 key_word = "*CONTACT_RIGID_NODES_TO_RIGID_BODY";
	 break;
      case CONTACT_RIGID_BODY_ONE_WAY_TO_RIGID_BODY:
	 key_word = "*CONTACT_RIGID_BODY_ONE_WAY_TO_RIGID_BODY";
	 break;
      case CONTACT_RIGID_BODY_TWO_WAY_TO_RIGID_BODY:
	 key_word = "*CONTACT_RIGID_BODY_TWO_WAY_TO_RIGID_BODY";
	 break;
      case CONTACT_SINGLE_EDGE:
	 key_word = "*CONTACT_SINGLE_EDGE";
	 break;
      case CONTACT_SINGLE_SURFACE:
	 key_word = "*CONTACT_SINGLE_SURFACE";
	 break;
      case CONTACT_SLIDING_ONLY:
	 key_word = "*CONTACT_SLIDING_ONLY";
	 break;
      case CONTACT_SLIDING_ONLY_PENALTY:
	 key_word = "*CONTACT_SLIDING_ONLY_PENALTY";
	 break;
      case CONTACT_SPOTWELD:
	 key_word = "*CONTACT_SPOTWELD";
	 break;
      case CONTACT_SPOTWELD_WITH_TORSION:
	 key_word = "*CONTACT_SPOTWELD_WITH_TORSION";
	 break;
      case CONTACT_SURFACE_TO_SURFACE:
	 key_word = "*CONTACT_SURFACE_TO_SURFACE";
	 break;
      case CONTACT_SURFACE_TO_SURFACE_INTERFERENCE:
	 key_word = "*CONTACT_SURFACE_TO_SURFACE_INTERFERENCE";
	 break;
      case CONTACT_SURFACE_TO_SURFACE_SMOOTH:
	 key_word = "*CONTACT_SURFACE_TO_SURFACE_SMOOTH";
	 break;
      case CONTACT_SURFACE_TO_SURFACE_CONTRACTION_JOINT:
	 key_word = "*CONTACT_SURFACE_TO_SURFACE_CONTRACTION_JOINT";
	 break;
      case CONTACT_TIEBREAK_NODES_TO_SURFACE:
	 key_word = "*CONTACT_TIEBREAK_NODES_TO_SURFACE";
	 break;
      case CONTACT_TIEBREAK_NODES_ONLY:
	 key_word = "*CONTACT_TIEBREAK_NODES_ONLY";
	 break;
      case CONTACT_TIEBREAK_SURFACE_TO_SURFACE:
	 key_word = "*CONTACT_TIEBREAK_SURFACE_TO_SURFACE";
	 break;
      case CONTACT_TIED_NODES_TO_SURFACE:
	 key_word = "*CONTACT_TIED_NODES_TO_SURFACE";
	 break;
      case CONTACT_TIED_SHELL_EDGE_TO_SURFACE:
	 key_word = "*CONTACT_TIED_SHELL_EDGE_TO_SURFACE";
	 break;
      case CONTACT_TIED_SURFACE_TO_SURFACE:
	 key_word = "*CONTACT_TIED_SURFACE_TO_SURFACE";
	 break;
      case CONTACT_TIED_SURFACE_TO_SURFACE_FAILURE:
	 key_word = "*CONTACT_TIED_SURFACE_TO_SURFACE_FAILURE";
	 break;
      case CONTACT_2D_SLIDING_ONLY:
	 key_word = "*CONTACT_2D_SLIDING_ONLY";
	 break;
      case CONTACT_2D_TIED_SLIDING:
	 key_word = "*CONTACT_2D_TIED_SLIDING";
	 break;
      case CONTACT_2D_SLIDING_VOIDS:
	 key_word = "*CONTACT_2D_SLIDING_VOIDS";
	 break;
      case CONTACT_2D_PENALTY_FRICTION:
	 key_word = "*CONTACT_2D_PENALTY_FRICTION";
	 break;
      case CONTACT_2D_PENALTY:
	 key_word = "*CONTACT_2D_PENALTY";
	 break;
      case CONTACT_2D_AUTOMATIC_SINGLE_SURFACE:
	 key_word = "*CONTACT_2D_AUTOMATIC_SINGLE_SURFACE";
	 break;
      case CONTACT_2D_AUTOMATIC_SURFACE_TO_SURFACE:
	 key_word = "*CONTACT_2D_AUTOMATIC_SURFACE_TO_SURFACE";
	 break;
      case CONTACT_2D_AUTOMATIC_NODE_TO_SURFACE:
	 key_word = "*CONTACT_2D_AUTOMATIC_NODE_TO_SURFACE";
	 break;
      case CONTACT_2D_AUTOMATIC_SURFACE_IN_CONTINUUM:
	 key_word = "*CONTACT_2D_AUTOMATIC_SURFACE_IN_CONTINUUM";
	 break;
      case CONTACT_2D_AUTOMATIC_TIED:
	 key_word = "*CONTACT_2D_AUTOMATIC_TIED";
	 break;
      case CONTACT_2D_AUTOMATIC_TIED_ONE_WAY:
	 key_word = "*CONTACT_2D_AUTOMATIC_TIED_ONE_WAY";
	 break;
      case CONTACT_AUTO_MOVE:
	 key_word = "*CONTACT_AUTO_MOVE";
	 break;
      case CONTACT_COUPLING:
	 key_word = "*CONTACT_COUPLING";
	 break;
      case CONTACT_ENTITY:
	 key_word = "*CONTACT_ENTITY";
	 break;
      case CONTACT_GEBOD_HEAD:
	 key_word = "*CONTACT_GEBOD_HEAD";
	 break;
      case CONTACT_GEBOD_LEFT_FOOT:
	 key_word = "*CONTACT_GEBOD_LEFT_FOOT";
	 break;
      case CONTACT_GEBOD_LEFT_HAND:
	 key_word = "*CONTACT_GEBOD_LEFT_HAND";
	 break;
      case CONTACT_GEBOD_LEFT_LOWER_ARM:
	 key_word = "*CONTACT_GEBOD_LEFT_LOWER_ARM";
	 break;
      case CONTACT_GEBOD_LEFT_LOWER_LEG:
	 key_word = "*CONTACT_GEBOD_LEFT_LOWER_LEG";
	 break;
      case CONTACT_GEBOD_LEFT_SHOULDER:
	 key_word = "*CONTACT_GEBOD_LEFT_SHOULDER";
	 break;
      case CONTACT_GEBOD_LEFT_UPPER_ARM:
	 key_word = "*CONTACT_GEBOD_LEFT_UPPER_ARM";
	 break;
      case CONTACT_GEBOD_LEFT_UPPER_LEG:
	 key_word = "*CONTACT_GEBOD_LEFT_UPPER_LEG";
	 break;
      case CONTACT_GEBOD_LOWER_TORSO:
	 key_word = "*CONTACT_GEBOD_LOWER_TORSO";
	 break;
      case CONTACT_GEBOD_MIDDLE_TORSO:
	 key_word = "*CONTACT_GEBOD_MIDDLE_TORSO";
	 break;
      case CONTACT_GEBOD_NECK:
	 key_word = "*CONTACT_GEBOD_NECK";
	 break;
      case CONTACT_GEBOD_RIGHT_FOOT:
	 key_word = "*CONTACT_GEBOD_RIGHT_FOOT";
	 break;
      case CONTACT_GEBOD_RIGHT_HAND:
	 key_word = "*CONTACT_GEBOD_RIGHT_HAND";
	 break;
      case CONTACT_GEBOD_RIGHT_LOWER_ARM:
	 key_word = "*CONTACT_GEBOD_RIGHT_LOWER_ARM";
	 break;
      case CONTACT_GEBOD_RIGHT_LOWER_LEG:
	 key_word = "*CONTACT_GEBOD_RIGHT_LOWER_LEG";
	 break;
      case CONTACT_GEBOD_RIGHT_SHOULDER:
	 key_word = "*CONTACT_GEBOD_RIGHT_SHOULDER";
	 break;
      case CONTACT_GEBOD_RIGHT_UPPER_ARM:
	 key_word = "*CONTACT_GEBOD_RIGHT_UPPER_ARM";
	 break;
      case CONTACT_GEBOD_RIGHT_UPPER_LEG:
	 key_word = "*CONTACT_GEBOD_RIGHT_UPPER_LEG";
	 break;
      case CONTACT_GEBOD_UPPER_TORSO:
	 key_word = "*CONTACT_GEBOD_UPPER_TORSO";
	 break;
      case CONTACT_GUIDED_CABLE:
	 key_word = "*CONTACT_GUIDED_CABLE";
	 break;
      case CONTACT_GUIDED_CABLE_ID:
	 key_word = "*CONTACT_GUIDED_CABLE_ID";
	 break;
      case CONTACT_GUIDED_CABLE_SET:
	 key_word = "*CONTACT_GUIDED_CABLE_SET";
	 break;
      case CONTACT_GUIDED_CABLE_SET_ID:
	 key_word = "*CONTACT_GUIDED_CABLE_SET_ID";
	 break;
      case CONTACT_INTERIOR:
	 key_word = "*CONTACT_INTERIOR";
	 break;
      case CONTACT_RIGID_SURFACE:
	 key_word = "*CONTACT_RIGID_SURFACE";
	 break;
      case CONTACT_1D:
	 key_word = "*CONTACT_1D";
	 break;
      case CONTACT_NEW_TYPE:
	 return 1;
   }

   if( kw_bin & (1 << CONTACT_THERMAL_FRICTION) )
      key_word += "_THERMAL_FRICTION";

   if( kw_bin & (1 << CONTACT_THERMAL) )
      key_word += "_THERMAL";

   if( kw_bin & (1 << CONTACT_SET) )
      key_word += "_SET";

   if( kw_bin & (1 << CONTACT_CONSTRAINED_OFFSET) )
      key_word += "_CONSTRAINED_OFFSET";

   if( kw_bin & (1 << CONTACT_BEAM_OFFSET) )
      key_word += "_BEAM_OFFSET";

   if( kw_bin & (1 << CONTACT_OFFSET) )
      key_word += "_OFFSET";

   if( kw_bin & (1 << CONTACT_ID_TITLE) )
      key_word += "_ID";

   if( kw_bin & (1 << CONTACT_MPP) )
      key_word += "_MPP";

   return 0;
}

unsigned int ContactExport::dbReadContacts()
{
   char         **row_data, buf[16];
   unsigned int	i, num_contacts = 0, total_contacts = 0, num_kw_types = 0;
   expTypeFuncIterator eexp_iter = expTypeFuncMap.end(), exp_iter;

   string       qry = "select kw_type,con_type from ", kw_str;
   string table_name = "`" + modelName + "_CONTACTS`";
   qry += table_name;
   qry += " group by kw_type;";

cout << "KW QRY = " << qry << endl;

   if( goldenConn->executeQuery( qry.data() ) )
      return 0;

   num_kw_types = goldenConn->numRows();

   if( !num_kw_types )
      return 0;

   unsigned int *kw_types = new unsigned int[num_kw_types];
   unsigned int *con_types = new unsigned int[num_kw_types];

   for(i = 0; i < num_kw_types; i++)
   {
      row_data = goldenConn->nextRow();
      kw_types[i] = atoi( row_data[0] );
      con_types[i] = atoi( row_data[1] );
cout << "KW CONTACT TYPE = " << kw_types[i] << endl;
   }

   for(i = 0; i < num_kw_types; i++)
   {
      if( getKeywordFromType(kw_types[i], con_types[i], kw_str) )
         continue;

cout << "CONTACT KW = " << kw_str << endl;

      qry = "select * from ";
      qry += table_name;
      qry += " where kw_type=";
      sprintf(buf, "%u", kw_types[i]);
      qry += buf;
      qry += " order by card_index;";

cout << "CONTACT QRY = " << qry << endl;

      if( goldenConn->executeQuery( qry.data() ) )
	 break;

      num_contacts = 0;
      while( goldenConn->rowsLeft() )
      {
	 impObj = new ContactExportObject((char *)kw_str.data(), 
				     kw_types[i], con_types[i]);
         goldenConn->clearFlag(KW_DATA_END);
	 if( con_types[i] & (1 << CONTACT_ID_TITLE) )
	 {
	    DBContactID con_id(goldenConn, impObj);
	    con_id.importDBContactID();
	 }

	 if( kw_types[i] < CONTACT_OPTION1_MAX )
	 {
	    if( con_types[i] & (1 << CONTACT_MPP) )
	    {
	       DBContactMpp con_mpp(goldenConn, impObj);
	       con_mpp.importDBContactMpp();
	    }

	    DBContactMandatory con_man(goldenConn, impObj);
	    con_man.importDBContactMandatory();

	    Card4Export card4(goldenConn, impObj);
	    card4.importCard4(kw_types[i]);
       
	    if( con_types[i] & (1 << CONTACT_THERMAL) )
	    {
	       DBContactThermal con_ther(goldenConn, impObj);
	       con_ther.importDBContactThermal();
	    }

	    if( con_types[i] & (1 << CONTACT_THERMAL_FRICTION) )
	    {
	       DBContactThermalFriction con_ther(goldenConn, impObj);
	       con_ther.importDBContactThermalFriction();
	    }

	    DBContactOptionA  opt_a(goldenConn, impObj);
	    opt_a.importDBContactOptionA();

	    DBContactOptionB  opt_b(goldenConn, impObj);
	    opt_b.importDBContactOptionB();

	    DBContactOptionC  opt_c(goldenConn, impObj);
	    opt_c.importDBContactOptionC();
	 }
	 else if( kw_types[i] < CONTACT_2D_MAX )
	 {
	    if( con_types[i] & (1 << CONTACT_2D_AUTOMATIC) )
	    {
	       DBContact2DAuto  auto_2d(goldenConn, impObj);
	       auto_2d.importDBContact2DAuto();
	    }
	    else
	    {
	       DBContact2DNoAuto  no_auto_2d(goldenConn, impObj);
	       no_auto_2d.importDBContact2DNoAuto();
	    }

	    if( kw_types[i] == CONTACT_2D_PENALTY_FRICTION )
	    {
	       DBContact2DPenFric pen_fric(goldenConn, impObj);
	       pen_fric.importDBContact2DPenFric();
	    }
	
	    if( con_types[i] & (1 << CONTACT_THERMAL) )
	    {
	       DBContact2DThermal thermal(goldenConn, impObj);
	       thermal.importDBContact2DThermal();
	    }

	    DBContact2DOptA opt(goldenConn, impObj);
	    opt.importDBContact2DOptA();
	 }
	 else
	 {
	    exp_iter = expTypeFuncMap.find(kw_types[i]);

	    if( exp_iter == eexp_iter )
	    {
	       cout << "CONTACT TYPE NOT FOUND" << endl;
	       continue;
	    }

	    (exp_iter->second)(goldenConn, impObj);
	 }

	 if( impObj->cardCount )
         {
	    contactManPtr->add(kw_str.data(), impObj);
	    num_contacts++;
         }
	 else
	    delete impObj;
      }

      total_contacts += num_contacts;
   }

   delete kw_types;
   delete con_types;

   return total_contacts;
}

