#ifndef _Contact_EXPORT_H_
#define _Contact_EXPORT_H_

#include <string>
#include <map>
#include "goldenconn.h"
#include "contactmanager.h"
#include "dbcard.h"
#include "contacttype.h"
#include "exptypemap.h"

/** Class to get data from database for *CONTACT keywords */
class ContactExport
{
public:
   /** Constructor for creating this object
     * \param model_name Name of the model for which the data to be obtained
     * \param gold_conn Connection object for accessing the database
     * \param contact_man Manager pointer to store the data obtained
     */
   ContactExport
   (
      char              *model_name,
      GoldenConn        *gold_conn,
      ContactManager    *contact_man
   );

   ~ContactExport()
   {
      contactManPtr = NULL;
      goldenConn = NULL;
      expTypeFuncMap.clear();
   }

   /** Gets the name of keyword from its type. Type is stored in the database
     * \param kw_type Type of keyword
     * \param kw_bin Flag storing the contact type by setting bits
     * \param key_word Keyword name is stored in this string
     */
   unsigned int getKeywordFromType
		(
		   unsigned int kw_type,
		   unsigned int kw_bin,
		   string & key_word
		);

   /** Fetches the *CONTACT keywords from database and returns 0 if not found 
     * else number of keywords obtained
     */
   unsigned int dbReadContacts();

   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *CONTACT keyword types and their function pointers
     */
   void initExportSimpleTypesAndFunctions();

private:
   string            modelName;
   /** Connection object for accessing the data */
   GoldenConn        *goldenConn;
   ContactManager    *contactManPtr;
   /** Object to store the data imported from database */
   ImportObject      *impObj;
   /** A map between type of keyword and pointer to the function to be called */
   map<unsigned int, ExportFunctionPtr>  expTypeFuncMap;
};

#endif

