#ifndef _DBCONTACTAUTOMOVE_H_
#define _DBCONTACTAUTOMOVE_H_

#include "manager.h"
#include "dispexport.h"
#include "goldenconn.h"
#include "dbcard.h"

/** Class used for getting data from database for *CONTACT_AUTO_MOVE
  * keyword */

class DBContactAutoMove
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBContactAutoMove(GoldenConn *gold_conn, ImportObject *imp_obj)
   {
      goldenConn = gold_conn;
      impObj = imp_obj;
      numFields = 0;
      wordArray = NULL;
      cardObj = NULL;
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBContactAutoMove()
   {
      goldenConn = NULL;
      impObj = NULL;
      numFields = 0;
      wordArray = NULL;
      cardObj = NULL;
   }

public:
/** Number of fields in each card */
   unsigned int   numFields;
/** List of field values read from database */
   char           **wordArray;
/** Object to save the imported data from database */
   ImportObject   *impObj;
/** Object to connect to database */
   GoldenConn     *goldenConn;
/** Object to store the fields and their values */
   Card           *cardObj;

public:
/** Function to get MoveCard details for *CONTACT_AUTO_MOVE
  * keyword from database */
   void dbReadMoveCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"ID","CID","VID","LCID","ATIME",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, };
      unsigned int field_indices[] = {1, 2, 3, };
      unsigned int man_types[] = {CONTACT, DEFINE, DEFINE, };
      unsigned int kw_types[] = {9999, VECTOR, CURVE, };
      unsigned int num_indices = 3;
      numFields = 5;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 2, CONTACT, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("MoveCard");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","MoveCard",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *CONTACT_AUTO_MOVE
  * from database */
   unsigned int importDBContactAutoMove()
   {
      dbReadMoveCard();
      return 0;
   }
};

#endif

