#ifndef _DBCONTACTGUIDEDCABLE_H_
#define _DBCONTACTGUIDEDCABLE_H_

#include "manager.h"
#include "dispexport.h"
#include "goldenconn.h"
#include "dbcard.h"

/** Class used for getting data from database for *CONTACT_GUIDED_CABLE
  * keyword */

class DBContactGuidedCable
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBContactGuidedCable(GoldenConn *gold_conn, ImportObject *imp_obj)
   {
      goldenConn = gold_conn;
      impObj = imp_obj;
      numFields = 0;
      wordArray = NULL;
      cardObj = NULL;
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBContactGuidedCable()
   {
      goldenConn = NULL;
      impObj = NULL;
      numFields = 0;
      wordArray = NULL;
      cardObj = NULL;
   }

public:
/** Number of fields in each card */
   unsigned int   numFields;
/** List of field values read from database */
   char           **wordArray;
/** Object to save the imported data from database */
   ImportObject   *impObj;
/** Object to connect to database */
   GoldenConn     *goldenConn;
/** Object to store the fields and their values */
   Card           *cardObj;

public:
/** Function to get PartNodeSet details for *CONTACT_GUIDED_CABLE
  * keyword from database */
   void dbReadPartNodeSet(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"NSID","PID/PSID","SOFT","SSFAC","FRIC",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 5;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, CONTACT, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         contactGuidedFind(&wordArray[2], numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("PartNodeSet");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","PartNodeSet",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *CONTACT_GUIDED_CABLE
  * from database */
   unsigned int importDBContactGuidedCable()
   {
      dbReadPartNodeSet();
      return 0;
   }
};

#endif

