#include <iostream>
#include <algorithm>
#include "generic.h"
#include "controltype.h"
#include "controlexport.h"
#include <stdlib.h>

using namespace std;

ControlExport::ControlExport
(
   char         *model_name,
   GoldenConn   *gold_conn,
   ControlManager    *control_man
)
{
   modelName = model_name;
   controlManPtr = control_man;
   goldenConn = gold_conn;

   initExportAdaptTypesAndFunctions();
   initExportElementTypesAndFunctions();
   initExportFormingTypesAndFunctions();
   initExportImplicitTypesAndFunctions();
   initExportMppTypesAndFunctions();
   initExportSimpleTypesAndFunctions();
   initExportThermalTypesAndFunctions();
}

int ControlExport::getKeywordFromType
    (
       unsigned int kw_type,
       string & key_word
    )
{
   switch(kw_type)
   {
      case CONTROL_ACCURACY:
	 key_word = "*CONTROL_ACCURACY";
	 break;
      case CONTROL_ADAPSTEP:
	 key_word = "*CONTROL_ADAPSTEP";
	 break;
      case CONTROL_ADAPTIVE:
	 key_word = "*CONTROL_ADAPTIVE";
	 break;
      case CONTROL_ADAPTIVE_CURVE:
	 key_word = "*CONTROL_ADAPTIVE_CURVE";
	 break;
      case CONTROL_ALE:
	 key_word = "*CONTROL_ALE";
	 break;
      case CONTROL_COARSEN:
	 key_word = "*CONTROL_COARSEN";
	 break;
      case CONTROL_DYNAMIC_RELAXATION:
	 key_word = "*CONTROL_DYNAMIC_RELAXATION";
	 break;
      case CONTROL_EXPLOSIVE_SHADOW:
	 key_word = "*CONTROL_EXPLOSIVE_SHADOW";
	 break;
      case CONTROL_REMESHING:
	 key_word = "*CONTROL_REMESHING";
	 break;
      case CONTROL_RIGID:
	 key_word = "*CONTROL_RIGID";
	 break;
      case CONTROL_SHELL:
	 key_word = "*CONTROL_SHELL";
	 break;
      case CONTROL_SOLID:
	 key_word = "*CONTROL_SOLID";
	 break;
      case CONTROL_SOLUTION:
	 key_word = "*CONTROL_SOLUTION";
	 break;
      case CONTROL_SPH:
	 key_word = "*CONTROL_SPH";
	 break;
      case CONTROL_SPOTWELD_BEAM:
	 key_word = "*CONTROL_SPOTWELD_BEAM";
	 break;
      case CONTROL_STAGED_CONSTRUCTION:
	 key_word = "*CONTROL_STAGED_CONSTRUCTION";
	 break;
      case CONTROL_STRUCTURED:
	 key_word = "*CONTROL_STRUCTURED";
	 break;
      case CONTROL_STRUCTURED_TERM:
	 key_word = "*CONTROL_STRUCTURED_TERM";
	 break;
      case CONTROL_CPU:
	 key_word = "*CONTROL_CPU";
	 break;
      case CONTROL_FORMING_POSITION:
	 key_word = "*CONTROL_FORMING_POSITION";
	 break;
      case CONTROL_FORMING_PROJECTION:
	 key_word = "*CONTROL_FORMING_PROJECTION";
	 break;
      case CONTROL_FORMING_TEMPLATE:
	 key_word = "*CONTROL_FORMING_TEMPLATE";
	 break;
      case CONTROL_FORMING_TRAVEL:
	 key_word = "*CONTROL_FORMING_TRAVEL";
	 break;
      case CONTROL_FORMING_USER:
	 key_word = "*CONTROL_FORMING_USER";
	 break;
      case CONTROL_OUTPUT:
	 key_word = "*CONTROL_OUTPUT";
	 break;
      case CONTROL_PARALLEL:
	 key_word = "*CONTROL_PARALLEL";
	 break;
      case CONTROL_SUBCYCLE:
	 key_word = "*CONTROL_SUBCYCLE";
	 break;
      case CONTROL_IMPLICIT_AUTO:
	 key_word = "*CONTROL_IMPLICIT_AUTO";
	 break;
      case CONTROL_IMPLICIT_BUCKLE:
	 key_word = "*CONTROL_IMPLICIT_BUCKLE";
	 break;
      case CONTROL_IMPLICIT_DYNAMICS:
	 key_word = "*CONTROL_IMPLICIT_DYNAMICS";
	 break;
      case CONTROL_IMPLICIT_INERTIA_RELIEF:
	 key_word = "*CONTROL_IMPLICIT_INERTIA_RELIEF";
	 break;
      case CONTROL_IMPLICIT_JOINTS:
	 key_word = "*CONTROL_IMPLICIT_JOINTS";
	 break;
      case CONTROL_IMPLICIT_MODES:
	 key_word = "*CONTROL_IMPLICIT_MODES";
	 break;
      case CONTROL_IMPLICIT_SOLVER:
	 key_word = "*CONTROL_IMPLICIT_SOLVER";
	 break;
      case CONTROL_IMPLICIT_STABILIZATION:
	 key_word = "*CONTROL_IMPLICIT_STABILIZATION";
	 break;
      case CONTROL_IMPLICIT_TERMINATION:
	 key_word = "*CONTROL_IMPLICIT_TERMINATION";
	 break;
      case CONTROL_MPP_DECOMPOSITION_AUTOMATIC:
	 key_word = "*CONTROL_MPP_DECOMPOSITION_AUTOMATIC";
	 break;
      case CONTROL_MPP_DECOMPOSITION_CHECK_SPEED:
	 key_word = "*CONTROL_MPP_DECOMPOSITION_CHECK_SPEED";
	 break;
      case CONTROL_MPP_DECOMPOSITION_CONTACT_DISTRIBUTE:
	 key_word = "*CONTROL_MPP_DECOMPOSITION_CONTACT_DISTRIBUTE";
	 break;
      case CONTROL_MPP_DECOMPOSITION_CONTACT_ISOLATE:
	 key_word = "*CONTROL_MPP_DECOMPOSITION_CONTACT_ISOLATE";
	 break;
      case CONTROL_MPP_DECOMPOSITION_FILE:
	 key_word = "*CONTROL_MPP_DECOMPOSITION_FILE";
	 break;
      case CONTROL_MPP_DECOMPOSITION_METHOD:
	 key_word = "*CONTROL_MPP_DECOMPOSITION_METHOD";
	 break;
      case CONTROL_MPP_DECOMPOSITION_NUMPROC:
	 key_word = "*CONTROL_MPP_DECOMPOSITION_NUMPROC";
	 break;
      case CONTROL_MPP_DECOMPOSITION_SHOW:
	 key_word = "*CONTROL_MPP_DECOMPOSITION_SHOW";
	 break;
      case CONTROL_MPP_DECOMPOSITION_TRANSFORMATION:
	 key_word = "*CONTROL_MPP_DECOMPOSITION_TRANSFORMATION";
	 break;
      case CONTROL_MPP_IO_NOD3DUMP:
	 key_word = "*CONTROL_MPP_IO_NOD3DUMP";
	 break;
      case CONTROL_MPP_IO_NODUMP:
	 key_word = "*CONTROL_MPP_IO_NODUMP";
	 break;
      case CONTROL_MPP_IO_NOFULL:
	 key_word = "*CONTROL_MPP_IO_NOFULL";
	 break;
      case CONTROL_MPP_IO_SWAPBYTES:
	 key_word = "*CONTROL_MPP_IO_SWAPBYTES";
	 break;
      case CONTROL_NONLOCAL:
	 key_word = "*CONTROL_NONLOCAL";
	 break;
      case CONTROL_BULK_VISCOSITY:
	 key_word = "*CONTROL_BULK_VISCOSITY";
	 break;
      case CONTROL_CHECK:
	 key_word = "*CONTROL_CHECK";
	 break;
      case CONTROL_CHECK_SHELL:
	 key_word = "*CONTROL_CHECK_SHELL";
	 break;
      case CONTROL_CONTACT:
	 key_word = "*CONTROL_CONTACT";
	 break;
      case CONTROL_COUPLING:
	 key_word = "*CONTROL_COUPLING";
	 break;
      case CONTROL_EFG:
	 key_word = "*CONTROL_EFG";
	 break;
      case CONTROL_ENERGY:
	 key_word = "*CONTROL_ENERGY";
	 break;
      case CONTROL_HOURGLASS:
	 key_word = "*CONTROL_HOURGLASS";
	 break;
      case CONTROL_HOURGLASS_936:
	 key_word = "*CONTROL_HOURGLASS_936";
	 break;
      case CONTROL_IMPLICIT_EIGENVALUE:
	 key_word = "*CONTROL_IMPLICIT_EIGENVALUE";
	 break;
      case CONTROL_IMPLICIT_GENERAL:
	 key_word = "*CONTROL_IMPLICIT_GENERAL";
	 break;
      case CONTROL_IMPLICIT_SOLUTION:
	 key_word = "*CONTROL_IMPLICIT_SOLUTION";
	 break;
      case CONTROL_TERMINATION:
	 key_word = "*CONTROL_TERMINATION";
	 break;
      case CONTROL_THERMAL_NONLINEAR:
	 key_word = "*CONTROL_THERMAL_NONLINEAR";
	 break;
      case CONTROL_THERMAL_SOLVER:
	 key_word = "*CONTROL_THERMAL_SOLVER";
	 break;
      case CONTROL_THERMAL_TIMESTEP:
	 key_word = "*CONTROL_THERMAL_TIMESTEP";
	 break;
      case CONTROL_TIMESTEP:
	 key_word = "*CONTROL_TIMESTEP";
	 break;
      case CONTROL_NEW_TYPE:
      default:
         return 1;
   }
   return 0;
}

unsigned int ControlExport::dbReadControls()
{
   char         **row_data, buf[16];
   unsigned int	i, num_controls = 0, total_controls = 0, num_kw_types = 0;
   expTypeFuncIterator eexp_iter = expTypeFuncMap.end(), exp_iter;

   string       qry = "select kw_type from ", kw_str;
   string table_name = "`" + modelName + "_CONTROLS`";
   qry += table_name;
   qry += " group by kw_type;";

cout << "KW QRY = " << qry << endl;

   if( goldenConn->executeQuery( qry.data() ) )
      return 0;

   num_kw_types = goldenConn->numRows();

   if( !num_kw_types )
      return 0;

   unsigned int *kw_types = new unsigned int[num_kw_types];

   for(i = 0; i < num_kw_types; i++)
   {
      row_data = goldenConn->nextRow();
      kw_types[i] = atoi( row_data[0] );
cout << "KW CONTROL TYPE = " << kw_types[i] << endl;
   }

   for(i = 0; i < num_kw_types; i++)
   {
      qry = "select * from ";
      qry += table_name;
      qry += " where kw_type=";
      sprintf(buf, "%u", kw_types[i]);
      qry += buf;
      qry += " order by card_index;";

cout << "CONTROL QRY = " << qry << endl;

      if( getKeywordFromType(kw_types[i], kw_str) )
         continue;

cout << "CONTROL KW = " << kw_str << endl;

      if( goldenConn->executeQuery( qry.data() ) )
	 break;

      exp_iter = expTypeFuncMap.find(kw_types[i]);

      if( exp_iter == eexp_iter )
      {
	 cout << "CONTROL TYPE NOT FOUND" << endl;
         continue;
      }

      num_controls = 0;
/* commented on Feb 21 2010 to take care of keywords with no cards. this
   only works when only one kw is there in the database. If more than one
   is there in db then this won't work.
      if( goldenConn->numRows() == 1 )
      {
         impObj = new ExportObject((char *)kw_str.data(), kw_types[i]);
         goldenConn->clearFlag(KW_DATA_END);
         row_data = goldenConn->nextRow();
         if( row_data )
         {
            ((ExportObject *)impObj)->noCardsIndex = atoi(row_data[0]);
cout << "no cards index=" << atoi(row_data[0]) << endl;
         }
	 controlManPtr->add(kw_str.data(), impObj);
         total_controls++;
         continue;
      }
*/

      while( goldenConn->rowsLeft() )
      {
         impObj = new ExportObject((char *)kw_str.data(), kw_types[i]);
         goldenConn->clearFlag(KW_DATA_END);
	 (exp_iter->second)(goldenConn, impObj);
         //to take care of kws with no cards Feb21 2010
cout << ((ExportObject *)impObj)->noCardsIndex << endl;
	 if( impObj->cardCount || ((ExportObject *)impObj)->noCardsIndex )
         {
	    controlManPtr->add(kw_str.data(), impObj);
	    num_controls++;
         }
	 else
	    delete impObj;
      }

      total_controls += num_controls;
   }

   delete kw_types;

   return total_controls;
}

