#ifndef _Control_EXPORT_H_
#define _Control_EXPORT_H_

#include <string>
#include <map>
#include "goldenconn.h"
#include "controlmanager.h"
#include "dataline.h"
#include "dbcard.h"
#include "controltype.h"
#include "exptypemap.h"

/** Class to get data from database for *CONTROL keywords */
class ControlExport
{
public:
   /** Constructor for creating this object
     * \param model_name Name of the model for which the data to be obtained
     * \param gold_conn Connection object for accessing the database
     * \param control_man Manager pointer to store the data obtained
     */
   ControlExport
   (
      char           *model_name,
      GoldenConn   *gold_conn,
      ControlManager    *control_man
   );

   ~ControlExport()
   {
      
      controlManPtr = NULL;
      goldenConn = NULL;
      expTypeFuncMap.clear();
   }

   /** Gets the name of keyword from its type. Type is stored in the database
     * \param kw_type Type of keyword
     * \param key_word Keyword name is stored in this string
     */
int getKeywordFromType
    (
       unsigned int kw_type,
       string & key_word
    );

   /** Fetches the *CONTROL keywords from database and returns 0 if not found 
     * else number of keywords obtained
     */
   unsigned int dbReadControls();

   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *CONTROL keyword types and their function pointers
     */
   void initExportAdaptTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *CONTROL keyword types and their function pointers
     */
   void initExportElementTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *CONTROL keyword types and their function pointers
     */
   void initExportFormingTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *CONTROL keyword types and their function pointers
     */
   void initExportImplicitTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *CONTROL keyword types and their function pointers
     */
   void initExportMppTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *CONTROL keyword types and their function pointers
     */
   void initExportSimpleTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *CONTROL keyword types and their function pointers
     */
   void initExportThermalTypesAndFunctions();

private:
   string            modelName;
   ControlManager    *controlManPtr;
   /** Connection object for accessing the data */
   GoldenConn        *goldenConn;
   /** Object to store the data imported from database */
   ImportObject      *impObj;
   /** A map between type of keyword and pointer to the function to be called */
   map<unsigned int, ExportFunctionPtr>  expTypeFuncMap;
};

#endif

