#include <iostream>
#include <algorithm>
#include "generic.h"
#include "dampingtype.h"
#include "dampingexport.h"
#include <stdlib.h>

using namespace std;

DampingExport::DampingExport
(
   char            *model_name,
   GoldenConn      *gold_conn,
   DampingManager  *damping_man
)
{
   modelName = model_name;
   dampingManPtr = damping_man;
   goldenConn = gold_conn;

   initExportDampingTypesAndFunctions();
}

int DampingExport::getKeywordFromType
    (
       unsigned int kw_type,
       string & key_word
    )
{
   switch(kw_type)
   {
      case DAMPING_FREQUENCY_RANGE:
	 key_word = "*DAMPING_FREQUENCY_RANGE";
	 break;
      case DAMPING_GLOBAL:
	 key_word = "*DAMPING_GLOBAL";
	 break;
      case DAMPING_PART_MASS:
	 key_word = "*DAMPING_PART_MASS";
	 break;
      case DAMPING_PART_STIFFNESS:
	 key_word = "*DAMPING_PART_STIFFNESS";
	 break;
      case DAMPING_RELATIVE:
	 key_word = "*DAMPING_RELATIVE";
	 break;
      case DAMPING_NEW_TYPE:
      default:
         return 1;
   }
   return 0;
}

unsigned int DampingExport::dbReadDampings()
{
   char         **row_data, buf[16];
   unsigned int	i, num_damps = 0, total_damps = 0, num_kw_types = 0;
   expTypeFuncIterator eexp_iter = expTypeFuncMap.end(), exp_iter;

   string       qry = "select kw_type from ", kw_str;
   string table_name = "`" + modelName + "_DAMPINGS`";
   qry += table_name;
   qry += " group by kw_type;";

cout << "KW QRY = " << qry << endl;

   if( goldenConn->executeQuery( qry.data() ) )
      return 0;

   num_kw_types = goldenConn->numRows();

   if( !num_kw_types )
      return 0;

   unsigned int *kw_types = new unsigned int[num_kw_types];

   for(i = 0; i < num_kw_types; i++)
   {
      row_data = goldenConn->nextRow();
      kw_types[i] = atoi( row_data[0] );
cout << "KW DAMPING TYPE = " << kw_types[i] << endl;
   }

   for(i = 0; i < num_kw_types; i++)
   {
      qry = "select * from ";
      qry += table_name;
      qry += " where kw_type=";
      sprintf(buf, "%u", kw_types[i]);
      qry += buf;
      qry += " order by card_index;";

cout << "DAMPING QRY = " << qry << endl;

      if( getKeywordFromType(kw_types[i], kw_str) )
         continue;

cout << "DAMPING KW = " << kw_str << endl;

      if( goldenConn->executeQuery( qry.data() ) )
	 break;

      exp_iter = expTypeFuncMap.find(kw_types[i]);

      if( exp_iter == eexp_iter )
      {
	 cout << "DAMPING TYPE NOT FOUND" << endl;
         continue;
      }

      num_damps = 0;
      while( goldenConn->rowsLeft() )
      {
	 impObj = new ExportObject((char *)kw_str.data(), kw_types[i]);
         goldenConn->clearFlag(KW_DATA_END);
	 (exp_iter->second)(goldenConn, impObj);
         if( impObj->cardCount )
         {
	    dampingManPtr->add(kw_str.data(), impObj);
	    num_damps++;
         }
         else
            delete impObj;
      }

      total_damps += num_damps;
   }

   delete kw_types;

   return total_damps;
}

