#ifndef _Damping_EXPORT_H_
#define _Damping_EXPORT_H_

#include <string>
#include <map>
#include "goldenconn.h"
#include "dampingmanager.h"
#include "dataline.h"
#include "dbcard.h"
#include "dampingtype.h"
#include "exptypemap.h"

/** Class to get data from database for *DAMPING keywords */
class DampingExport
{
public:
   /** Constructor for creating this object
     * \param model_name Name of the model for which the data to be obtained
     * \param gold_conn Connection object for accessing the database
     * \param damping_man DampingManager pointer to store the data obtained
     */
   DampingExport
   (
      char              *model_name,
      GoldenConn        *gold_conn,
      DampingManager    *damping_man
   );

   ~DampingExport()
   {
      dampingManPtr = NULL;
      goldenConn = NULL;
      expTypeFuncMap.clear();
   }

   /** Gets the name of keyword from its type. Type is stored in the database
     * \param kw_type Type of keyword
     * \param key_word Keyword name is stored in this string
     */
   int getKeywordFromType
       (
	  unsigned int kw_type,
	  string & key_word
       );

   /** Fetches the *DAMPING keywords from database and returns 0 if not found else
     * number of keywords obtained
     */
   unsigned int dbReadDampings();

   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *DAMPING keyword types and their function pointers
     */
   void initExportDampingTypesAndFunctions();

private:
   /** Name of the model */
   string            modelName;
   /** Manager pointer for storing the *DAMPING keywords data */
   DampingManager    *dampingManPtr;
   /** Connection object for accessing the data */
   GoldenConn        *goldenConn;
   /** Object to store the data imported from database */
   ImportObject      *impObj;
   /** A map between type of keyword and pointer to the function to be called */
   map<unsigned int, ExportFunctionPtr>  expTypeFuncMap;
};

#endif

