#include <iostream>
#include <algorithm>
#include "generic.h"
#include "databasetype.h"
#include "databaseexport.h"
#include <stdlib.h>

using namespace std;

DatabaseExport::DatabaseExport
(
   char         *model_name,
   GoldenConn   *gold_conn,
   DatabaseManager    *database_man
)
{
   modelName = model_name;
   databaseManPtr = database_man;
   goldenConn = gold_conn;

   initExportBinaryTypesAndFunctions();
   initExportCrossSectionTypesAndFunctions();
   initExportExtentTypesAndFunctions();
   initExportHistryTypesAndFunctions();
   initExportOptionTypesAndFunctions();
   initExportSimpleTypesAndFunctions();
}

int DatabaseExport::getKeywordFromType
    (
       unsigned int kw_type,
       string & key_word
    )
{
   switch(kw_type)
   {
      case DATABASE_BINARY_D3DRLF:
	 key_word = "*DATABASE_BINARY_D3DRLF";
	 break;
      case DATABASE_BINARY_D3CRACK:
	 key_word = "*DATABASE_BINARY_D3CRACK";
	 break;
      case DATABASE_BINARY_D3DUMP:
	 key_word = "*DATABASE_BINARY_D3DUMP";
	 break;
      case DATABASE_BINARY_D3PART:
	 key_word = "*DATABASE_BINARY_D3PART";
	 break;
      case DATABASE_BINARY_D3PLOT:
	 key_word = "*DATABASE_BINARY_D3PLOT";
	 break;
      case DATABASE_BINARY_D3PROP:
	 key_word = "*DATABASE_BINARY_D3PROP";
	 break;
      case DATABASE_BINARY_D3THDT:
	 key_word = "*DATABASE_BINARY_D3THDT";
	 break;
      case DATABASE_BINARY_FSIFOR:
	 key_word = "*DATABASE_BINARY_FSIFOR";
	 break;
      case DATABASE_BINARY_INTFOR:
	 key_word = "*DATABASE_BINARY_INTFOR";
	 break;
      case DATABASE_BINARY_RUNRSF:
	 key_word = "*DATABASE_BINARY_RUNRSF";
	 break;
      case DATABASE_BINARY_XTFILE:
	 key_word = "*DATABASE_BINARY_XTFILE";
	 break;
      case DATABASE_NODAL_FORCE_GROUP:
	 key_word = "*DATABASE_NODAL_FORCE_GROUP";
	 break;
      case DATABASE_EXTENT_AVS:
	 key_word = "*DATABASE_EXTENT_AVS";
	 break;
      case DATABASE_EXTENT_BINARY:
	 key_word = "*DATABASE_EXTENT_BINARY";
	 break;
      case DATABASE_EXTENT_MOVIE:
	 key_word = "*DATABASE_EXTENT_MOVIE";
	 break;
      case DATABASE_EXTENT_MPGS:
	 key_word = "*DATABASE_EXTENT_MPGS";
	 break;
      case DATABASE_EXTENT_SSSTAT:
	 key_word = "*DATABASE_EXTENT_SSSTAT";
	 break;
      case DATABASE_AVSFLT:
	 key_word = "*DATABASE_AVSFLT";
	 break;
      case DATABASE_BNDOUT:
	 key_word = "*DATABASE_BNDOUT";
	 break;
      case DATABASE_DCFAIL:
	 key_word = "*DATABASE_DCFAIL";
	 break;
      case DATABASE_DEFGEO:
	 key_word = "*DATABASE_DEFGEO";
	 break;
      case DATABASE_DEFORC:
	 key_word = "*DATABASE_DEFORC";
	 break;
      case DATABASE_ELOUT:
	 key_word = "*DATABASE_ELOUT";
	 break;
      case DATABASE_FSI:
	 key_word = "*DATABASE_FSI";
	 break;
      case DATABASE_FSI_SENSOR:
	 key_word = "*DATABASE_FSI_SENSOR";
	 break;
      case DATABASE_GCEOUT:
	 key_word = "*DATABASE_GCEOUT";
	 break;
      case DATABASE_GLSTAT:
	 key_word = "*DATABASE_GLSTAT";
	 break;
      case DATABASE_GLSTAT_MASS_PROPERTIES:
	 key_word = "*DATABASE_GLSTAT_MASS_PROPERTIES";
	 break;
      case DATABASE_H3OUT:
	 key_word = "*DATABASE_H3OUT";
	 break;
      case DATABASE_JNTFORC:
	 key_word = "*DATABASE_JNTFORC";
	 break;
      case DATABASE_MATSUM:
	 key_word = "*DATABASE_MATSUM";
	 break;
      case DATABASE_MOVIE:
	 key_word = "*DATABASE_MOVIE";
	 break;
      case DATABASE_MPGS:
	 key_word = "*DATABASE_MPGS";
	 break;
      case DATABASE_NCFORC:
	 key_word = "*DATABASE_NCFORC";
	 break;
      case DATABASE_NODFOR:
	 key_word = "*DATABASE_NODFOR";
	 break;
      case DATABASE_NODOUT:
	 key_word = "*DATABASE_NODOUT";
	 break;
      case DATABASE_ABSTAT:
	 key_word = "*DATABASE_ABSTAT";
	 break;
      case DATABASE_RBDOUT:
	 key_word = "*DATABASE_RBDOUT";
	 break;
      case DATABASE_RCFORC:
	 key_word = "*DATABASE_RCFORC";
	 break;
      case DATABASE_RWFORC:
	 key_word = "*DATABASE_RWFORC";
	 break;
      case DATABASE_SBTOUT:
	 key_word = "*DATABASE_SBTOUT";
	 break;
      case DATABASE_SECFORC:
	 key_word = "*DATABASE_SECFORC";
	 break;
      case DATABASE_SLEOUT:
	 key_word = "*DATABASE_SLEOUT";
	 break;
      case DATABASE_SPCFORC:
	 key_word = "*DATABASE_SPCFORC";
	 break;
      case DATABASE_SPHOUT:
	 key_word = "*DATABASE_SPHOUT";
	 break;
      case DATABASE_SSSTAT:
	 key_word = "*DATABASE_SSSTAT";
	 break;
      case DATABASE_SSSTAT_MASS_PROPERTIES:
	 key_word = "*DATABASE_SSSTAT_MASS_PROPERTIES";
	 break;
      case DATABASE_SWFORC:
	 key_word = "*DATABASE_SWFORC";
	 break;
      case DATABASE_TPRINT:
	 key_word = "*DATABASE_TPRINT";
	 break;
      case DATABASE_TRHIST:
	 key_word = "*DATABASE_TRHIST";
	 break;
      case DATABASE_CROSS_SECTION_PLANE:
	 key_word = "*DATABASE_CROSS_SECTION_PLANE";
	 break;
      case DATABASE_CROSS_SECTION_PLANE_ID:
	 key_word = "*DATABASE_CROSS_SECTION_PLANE_ID";
	 break;
      case DATABASE_CROSS_SECTION_SET:
	 key_word = "*DATABASE_CROSS_SECTION_SET";
	 break;
      case DATABASE_CROSS_SECTION_SET_ID:
	 key_word = "*DATABASE_CROSS_SECTION_SET_ID";
	 break;
      case DATABASE_TRACER:
	 key_word = "*DATABASE_TRACER";
	 break;
      case DATABASE_HISTORY_BEAM:
	 key_word = "*DATABASE_HISTORY_BEAM";
	 break;
      case DATABASE_HISTORY_BEAM_ID:
	 key_word = "*DATABASE_HISTORY_BEAM_ID";
	 break;
      case DATABASE_HISTORY_BEAM_SET:
	 key_word = "*DATABASE_HISTORY_BEAM_SET";
	 break;
      case DATABASE_HISTORY_DISCRETE:
	 key_word = "*DATABASE_HISTORY_DISCRETE";
	 break;
      case DATABASE_HISTORY_DISCRETE_ID:
	 key_word = "*DATABASE_HISTORY_DISCRETE_ID";
	 break;
      case DATABASE_HISTORY_DISCRETE_SET:
	 key_word = "*DATABASE_HISTORY_DISCRETE_SET";
	 break;
      case DATABASE_HISTORY_NODE:
	 key_word = "*DATABASE_HISTORY_NODE";
	 break;
      case DATABASE_HISTORY_NODE_ID:
	 key_word = "*DATABASE_HISTORY_NODE_ID";
	 break;
      case DATABASE_HISTORY_NODE_LOCAL:
	 key_word = "*DATABASE_HISTORY_NODE_LOCAL";
	 break;
      case DATABASE_HISTORY_NODE_LOCAL_ID:
	 key_word = "*DATABASE_HISTORY_NODE_LOCAL_ID";
	 break;
      case DATABASE_HISTORY_NODE_SET:
	 key_word = "*DATABASE_HISTORY_NODE_SET";
	 break;
      case DATABASE_HISTORY_NODE_SET_LOCAL:
	 key_word = "*DATABASE_HISTORY_NODE_SET_LOCAL";
	 break;
      case DATABASE_HISTORY_SEATBELT:
	 key_word = "*DATABASE_HISTORY_SEATBELT";
	 break;
      case DATABASE_HISTORY_SEATBELT_ID:
	 key_word = "*DATABASE_HISTORY_SEATBELT_ID";
	 break;
      case DATABASE_HISTORY_SHELL:
	 key_word = "*DATABASE_HISTORY_SHELL";
	 break;
      case DATABASE_HISTORY_SHELL_ID:
	 key_word = "*DATABASE_HISTORY_SHELL_ID";
	 break;
      case DATABASE_HISTORY_SHELL_SET:
	 key_word = "*DATABASE_HISTORY_SHELL_SET";
	 break;
      case DATABASE_HISTORY_SOLID:
	 key_word = "*DATABASE_HISTORY_SOLID";
	 break;
      case DATABASE_HISTORY_SOLID_ID:
	 key_word = "*DATABASE_HISTORY_SOLID_ID";
	 break;
      case DATABASE_HISTORY_SOLID_SET:
	 key_word = "*DATABASE_HISTORY_SOLID_SET";
	 break;
      case DATABASE_HISTORY_SPH:
	 key_word = "*DATABASE_HISTORY_SPH";
	 break;
      case DATABASE_HISTORY_SPH_SET:
	 key_word = "*DATABASE_HISTORY_SPH_SET";
	 break;
      case DATABASE_HISTORY_TSHELL:
	 key_word = "*DATABASE_HISTORY_TSHELL";
	 break;
      case DATABASE_HISTORY_TSHELL_ID:
	 key_word = "*DATABASE_HISTORY_TSHELL_ID";
	 break;
      case DATABASE_HISTORY_TSHELL_SET:
	 key_word = "*DATABASE_HISTORY_TSHELL_SET";
	 break;
      case DATABASE_ADAMS:
	 key_word = "*DATABASE_ADAMS";
	 break;
      case DATABASE_FORMAT:
	 key_word = "*DATABASE_FORMAT";
	 break;
      case DATABASE_SPRING_FORWARD:
	 key_word = "*DATABASE_SPRING_FORWARD";
	 break;
      case DATABASE_SUPERPLASTIC_FORMING:
	 key_word = "*DATABASE_SUPERPLASTIC_FORMING";
	 break;
      case DATABASE_NEW_TYPE:
      default:
         return 1;
   }
   return 0;
}

unsigned int DatabaseExport::dbReadDatabases()
{
   char         **row_data, buf[16];
   unsigned int	i, num_dbs = 0, total_dbs = 0, num_kw_types = 0;
   expTypeFuncIterator eexp_iter = expTypeFuncMap.end(), exp_iter;

   string       qry = "select kw_type from ", kw_str;
   string table_name = "`" + modelName + "_DATABASES`";
   qry += table_name;
   qry += " group by kw_type;";

cout << "KW QRY = " << qry << endl;

   if( goldenConn->executeQuery( qry.data() ) )
      return 0;

   num_kw_types = goldenConn->numRows();

   if( !num_kw_types )
      return 0;

   unsigned int *kw_types = new unsigned int[num_kw_types];

   for(i = 0; i < num_kw_types; i++)
   {
      row_data = goldenConn->nextRow();
      kw_types[i] = atoi( row_data[0] );
cout << "KW DATABASE TYPE = " << kw_types[i] << endl;
   }

   for(i = 0; i < num_kw_types; i++)
   {
      qry = "select * from ";
      qry += table_name;
      qry += " where kw_type=";
      sprintf(buf, "%u", kw_types[i]);
      qry += buf;
      qry += " order by card_index;";

cout << "DATABASE QRY = " << qry << endl;

      if( getKeywordFromType(kw_types[i], kw_str) )
         continue;

cout << "DATABASE KW = " << kw_str << endl;

      if( goldenConn->executeQuery( qry.data() ) )
	 break;

      exp_iter = expTypeFuncMap.find(kw_types[i]);

      if( exp_iter == eexp_iter )
      {
	 cout << "DATABASE TYPE NOT FOUND" << endl;
         continue;
      }

      num_dbs = 0;
      while( goldenConn->rowsLeft() )
      {
	 impObj = new ExportObject((char *)kw_str.data(), kw_types[i]);
         goldenConn->clearFlag(KW_DATA_END);
	 (exp_iter->second)(goldenConn, impObj);
	 if( impObj->cardCount )
         {
	    databaseManPtr->add(kw_str.data(), impObj);
	    num_dbs++;
         }
	 else
	    delete impObj;
      }

      total_dbs += num_dbs;
   }

   delete kw_types;

   return total_dbs;
}

