#ifndef _Database_EXPORT_H_
#define _Database_EXPORT_H_

#include <string>
#include <map>
#include "goldenconn.h"
#include "databasemanager.h"
#include "dataline.h"
#include "dbcard.h"
#include "databasetype.h"
#include "exptypemap.h"

/** Class to get data from database for *DATABASE keywords */
class DatabaseExport
{
public:
   /** Constructor for creating this object
     * \param model_name Name of the model for which the data to be obtained
     * \param gold_conn Connection object for accessing the database
     * \param database_man Manager pointer to store the data obtained
     */
   DatabaseExport
   (
      char               *model_name,
      GoldenConn         *gold_conn,
      DatabaseManager    *database_man
   );

   ~DatabaseExport()
   {
      databaseManPtr = NULL;
      goldenConn = NULL;
      expTypeFuncMap.clear();
   }

   /** Gets the name of keyword from its type. Type is stored in the database
     * \param kw_type Type of keyword
     * \param key_word Keyword name is stored in this string
     */
   int getKeywordFromType
       (
	  unsigned int kw_type,
	  string & key_word
       );

   /** Fetches the *DATABASE keywords from database and returns 0 if not found 
     * else number of keywords obtained
     */
   unsigned int dbReadDatabases();

   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *DATABASE keyword types and their function pointers
     */
   void initExportBinaryTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *DATABASE keyword types and their function pointers
     */
   void initExportCrossSectionTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *DATABASE keyword types and their function pointers
     */
   void initExportExtentTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *DATABASE keyword types and their function pointers
     */
   void initExportHistryTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *DATABASE keyword types and their function pointers
     */
   void initExportOptionTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *DATABASE keyword types and their function pointers
     */
   void initExportSimpleTypesAndFunctions();

private:
   string           modelName;
   DatabaseManager  *databaseManPtr;
   /** Connection object for accessing the data */
   GoldenConn       *goldenConn;
   /** Object to store the data imported from database */
   ImportObject     *impObj;
   /** A map between type of keyword and pointer to the function to be called */
   map<unsigned int, ExportFunctionPtr>  expTypeFuncMap;
};

#endif

