#ifndef _DBDATABASEEXTENTSSSTAT_H_
#define _DBDATABASEEXTENTSSSTAT_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *DATABASE_EXTENT_SSSTAT
  * keyword */

class DBDatabaseExtentSsstat : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBDatabaseExtentSsstat(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBDatabaseExtentSsstat()
   {
   }

public:
/** Function to get Card details for *DATABASE_EXTENT_SSSTAT
  * keyword from database */
   void dbReadCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"PSID1","PSID2","PSID3","PSID4","PSID5","PSID6","PSID7","PSID8",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, 3, 4, 5, 6, 7, };
      unsigned int man_types[] = {SET, SET, SET, SET, SET, SET, SET, SET, };
      unsigned int kw_types[] = {PARTC, PARTC, PARTC, PARTC, PARTC, PARTC, PARTC, PARTC, };
      unsigned int num_indices = 8;
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, DATABASE, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *DATABASE_EXTENT_SSSTAT
  * from database */
   unsigned int importDBDatabaseExtentSsstat()
   {
      unsigned int loop_count = 0;
      dbReadCard(loop_count);
      loop_count++;
      while(numFields)
      {
         dbReadCard(loop_count);
         loop_count++;
      }
      ((ExportObject *)impObj)->loopCount = loop_count-1;
      return 0;
   }
};

#endif

