#ifndef _DBDEFINEALEBAGINFLATOR_H_
#define _DBDEFINEALEBAGINFLATOR_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *DEFINE_ALEBAG_INFLATOR
  * keyword */

class DBDefineAlebagInflator : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBDefineAlebagInflator(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBDefineAlebagInflator()
   {
   }

public:
/** Function to get Card1 details for *DEFINE_ALEBAG_INFLATOR
  * keyword from database */
   void dbReadCard1(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"INFLAID","UNUSED","UNUSED","UNUSED","NGAS","NORIF","LCIDVEL","LCIDT",};
      unsigned int field_types[] = {DATA_INT, DATA_UNUSED, DATA_UNUSED, DATA_UNUSED, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {6, 7, };
      unsigned int man_types[] = {DEFINE, DEFINE, };
      unsigned int kw_types[] = {CURVE, CURVE, };
      unsigned int num_indices = 2;
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 2, DEFINE, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      ngas = 0;
      if( wordArray[6] )
         ngas = atoi(wordArray[6]);
      norif = 0;
      if( wordArray[7] )
         norif = atoi(wordArray[7]);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card1");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card1",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card2 details for *DEFINE_ALEBAG_INFLATOR
  * keyword from database */
   void dbReadCard2(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"LCIDMD","UNUSED","UNUSED","MWGAS","UNUSED","A","B","C",};
      unsigned int field_types[] = {DATA_INT, DATA_UNUSED, DATA_UNUSED, DATA_DOUBLE, DATA_UNUSED, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {DEFINE, };
      unsigned int kw_types[] = {CURVE, };
      unsigned int num_indices = 1;
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      unsigned int end_loop;
      end_loop = ngas;
      for(loop_count = 0; loop_count < end_loop; loop_count++)
      {
         numFields = 8;
         wordArray = goldenConn->nextCard();
         if( !wordArray )
         {
            numFields = 0;
         return;
         }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, DEFINE, impObj);
         if( Card::isFlagOn(SAVE_REFERENCES) )
            addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card2",loop_count);
            cardObj = new DBCard(name_buf);
            ((DBCard *)cardObj)->index = atoi(wordArray[0]);
            cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
            impObj->addCard(cardObj);
         }
         impObj->cardCount++;
      }
   }

/** Function to get Card3 details for *DEFINE_ALEBAG_INFLATOR
  * keyword from database */
   void dbReadCard3(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"NODEID","VECID","ORIFAREA",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, 1, };
      unsigned int man_types[] = {NOD, DEFINE, };
      unsigned int kw_types[] = {9999, VECTOR, };
      unsigned int num_indices = 2;
      numFields = 3;
      unsigned int field_widths[] = {10, 10, 10, };
      unsigned int end_loop;
      end_loop = norif;
      for(loop_count = 0; loop_count < end_loop; loop_count++)
      {
         numFields = 3;
         wordArray = goldenConn->nextCard();
         if( !wordArray )
         {
            numFields = 0;
         return;
         }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, DEFINE, impObj);
         if( Card::isFlagOn(SAVE_REFERENCES) )
            addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card3",loop_count);
            cardObj = new DBCard(name_buf);
            ((DBCard *)cardObj)->index = atoi(wordArray[0]);
            cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
            impObj->addCard(cardObj);
         }
         impObj->cardCount++;
      }
   }

/** Function to import all the cards of keyword *DEFINE_ALEBAG_INFLATOR
  * from database */
   unsigned int importDBDefineAlebagInflator()
   {
      dbReadCard1();
      dbReadCard2();
      dbReadCard3();
      return 0;
   }
public:
   int ngas;
   int norif;
};

#endif

