#include <iostream>
#include <algorithm>
#include "generic.h"
#include "definetype.h"
#include "defineexport.h"
#include "exptitle.h"
#include <stdlib.h>

using namespace std;

DefineExport::DefineExport
(
   char         *model_name,
   GoldenConn   *gold_conn,
   DefineManager    *define_man
)
{
   modelName = model_name;
   defineManPtr = define_man;
   goldenConn = gold_conn;
   
   initExportAleTypesAndFunctions();
   initExportBoxTypesAndFunctions();
   initExportCoordTypesAndFunctions();
   initExportCurveTypesAndFunctions();
   initExportSimpleTypesAndFunctions();
   initExportWeldTypesAndFunctions();
}

int DefineExport::getKeywordFromType
    (
       unsigned int kw_type,
       string & key_word
    )
{
   int title_flag = 0;

   if( kw_type >= TITLE_CARD )
   {
      kw_type -= TITLE_CARD;
      title_flag = 1;
   }

   switch(kw_type)
   {
      case DEFINE_ALEBAG_BAG:
	 key_word = "*DEFINE_ALEBAG_BAG";
	 break;
      case DEFINE_ALEBAG_HOLE:
	 key_word = "*DEFINE_ALEBAG_HOLE";
	 break;
      case DEFINE_ALEBAG_INFLATOR:
	 key_word = "*DEFINE_ALEBAG_INFLATOR";
	 break;
      case DEFINE_CONTACT_VOLUME:
	 key_word = "*DEFINE_CONTACT_VOLUME";
	 break;
      case DEFINE_DEATH_TIMES_NODES:
	 key_word = "*DEFINE_DEATH_TIMES_NODES";
	 break;
      case DEFINE_DEATH_TIMES_RIGID:
	 key_word = "*DEFINE_DEATH_TIMES_RIGID";
	 break;
      case DEFINE_DEATH_TIMES_SET:
	 key_word = "*DEFINE_DEATH_TIMES_SET";
	 break;
      case DEFINE_BOX:
	 key_word = "*DEFINE_BOX";
	 break;
      case DEFINE_BOX_ADAPTIVE:
	 key_word = "*DEFINE_BOX_ADAPTIVE";
	 break;
      case DEFINE_BOX_COARSEN:
	 key_word = "*DEFINE_BOX_COARSEN";
	 break;
      case DEFINE_BOX_DRAWBEAD:
	 key_word = "*DEFINE_BOX_DRAWBEAD";
	 break;
      case DEFINE_BOX_SPH:
	 key_word = "*DEFINE_BOX_SPH";
	 break;
      case DEFINE_CURVE_SMOOTH:
	 key_word = "*DEFINE_CURVE_SMOOTH";
	 break;
      case DEFINE_COORDINATE_NODES:
	 key_word = "*DEFINE_COORDINATE_NODES";
	 break;
      case DEFINE_COORDINATE_SYSTEM:
	 key_word = "*DEFINE_COORDINATE_SYSTEM";
	 break;
      case DEFINE_COORDINATE_VECTOR:
	 key_word = "*DEFINE_COORDINATE_VECTOR";
	 break;
      case DEFINE_CURVE_FUNCTION:
	 key_word = "*DEFINE_CURVE_FUNCTION";
	 break;
      case DEFINE_SD_ORIENTATION:
	 key_word = "*DEFINE_SD_ORIENTATION";
	 break;
      case DEFINE_TRANSFORMATION:
	 key_word = "*DEFINE_TRANSFORMATION";
	 break;
      case DEFINE_CURVE_3858:
	 key_word = "*DEFINE_CURVE_3858";
	 break;
      case DEFINE_CURVE_5434a:
	 key_word = "*DEFINE_CURVE_5434a";
	 break;
      case DEFINE_CURVE_COMPENSATION:
	 key_word = "*DEFINE_CURVE_COMPENSATION";
	 break;
      case DEFINE_CURVE_DRAWBEAD:
	 key_word = "*DEFINE_CURVE_DRAWBEAD";
	 break;
      case DEFINE_CURVE_ENTITY:
	 key_word = "*DEFINE_CURVE_ENTITY";
	 break;
      case DEFINE_CURVE_FEEDBACK:
	 key_word = "*DEFINE_CURVE_FEEDBACK";
	 break;
      case DEFINE_CURVE:
	 key_word = "*DEFINE_CURVE";
	 break;
      case DEFINE_CURVE_TRIM:
	 key_word = "*DEFINE_CURVE_TRIM";
	 break;
      case DEFINE_CURVE_TRIM_3D:
	 key_word = "*DEFINE_CURVE_TRIM_3D";
	 break;
      case DEFINE_CONSTRUCTION_STAGES:
	 key_word = "*DEFINE_CONSTRUCTION_STAGES";
	 break;
      case DEFINE_FRICTION:
	 key_word = "*DEFINE_FRICTION";
	 break;
      case DEFINE_SET_ADAPTIVE:
	 key_word = "*DEFINE_SET_ADAPTIVE";
	 break;
      case DEFINE_STAGED_CONSTRUCTION_PART:
	 key_word = "*DEFINE_STAGED_CONSTRUCTION_PART";
	 break;
      case DEFINE_TABLE:
	 key_word = "*DEFINE_TABLE";
	 break;
      case DEFINE_VECTOR:
	 key_word = "*DEFINE_VECTOR";
	 break;
      case DEFINE_CONNECTION_PROPERTIES:
	 key_word = "*DEFINE_CONNECTION_PROPERTIES";
	 break;
      case DEFINE_CONNECTION_PROPERTIES_ADD:
	 key_word = "*DEFINE_CONNECTION_PROPERTIES_ADD";
	 break;
      case DEFINE_HEX_SPOTWELD_ASSEMBLY:
	 key_word = "*DEFINE_HEX_SPOTWELD_ASSEMBLY";
	 break;
      case DEFINE_HEX_SPOTWELD_ASSEMBLY_N:
	 key_word = "*DEFINE_HEX_SPOTWELD_ASSEMBLY_N";
	 break;
      case DEFINE_SPOTWELD_FAILURE_RESULTANTS:
	 key_word = "*DEFINE_SPOTWELD_FAILURE_RESULTANTS";
	 break;
      case DEFINE_SPOTWELD_RUPTURE_PARAMETER:
	 key_word = "*DEFINE_SPOTWELD_RUPTURE_PARAMETER";
	 break;
      case DEFINE_SPOTWELD_RUPTURE_STRESS:
	 key_word = "*DEFINE_SPOTWELD_RUPTURE_STRESS";
	 break;
      case DEFINE_NEW_TYPE:
      default:
         return 1;
   }

   if( title_flag )
      key_word += "_TITLE";

   return 0;
}

unsigned int DefineExport::dbReadDefines
             (
                unsigned int def_type
             )
{
   char         **row_data, buf[16];
   unsigned int	i, num_defines = 0, total_defines = 0, num_kw_types = 0;
   expTypeFuncIterator eexp_iter = expTypeFuncMap.end(), exp_iter;

   string       qry = "select kw_type from ", kw_str;
   string table_name = "`" + modelName + "_DEFINES`";
   qry += table_name;
   qry += " group by kw_type;";

cout << "KW QRY = " << qry << endl;

   if( goldenConn->executeQuery( qry.data() ) )
      return 0;

   num_kw_types = goldenConn->numRows();

   if( !num_kw_types )
      return 0;

   unsigned int *kw_types = new unsigned int[num_kw_types];

   for(i = 0; i < num_kw_types; i++)
   {
      row_data = goldenConn->nextRow();
      kw_types[i] = atoi( row_data[0] );
cout << "KW DEFINE TYPE = " << kw_types[i] << endl;
   }

   for(i = 0; i < num_kw_types; i++)
   {
      if( getKeywordFromType(kw_types[i], kw_str) )
         continue;

cout << "DEFINE KW = " << kw_str << endl;

      if( def_type != DEFINE_NEW_TYPE && def_type != kw_types[i] )
         continue;

      qry = "select * from ";
      qry += table_name;
      qry += " where kw_type=";
      sprintf(buf, "%u", kw_types[i]);
      qry += buf;
      qry += " order by card_index;";

cout << "DEFINE QRY = " << qry << endl;

      if( goldenConn->executeQuery( qry.data() ) )
	 break;

      unsigned int kw_type;
      if( kw_types[i] < TITLE_CARD )
         kw_type = kw_types[i];
      else
         kw_type = kw_types[i] - TITLE_CARD;

      exp_iter = expTypeFuncMap.find(kw_type);

      if( exp_iter == eexp_iter )
      {
	 cout << "DEFINE TYPE NOT FOUND" << endl;
         continue;
      }

      num_defines = 0;
      if( kw_types[i] < TITLE_CARD )
      {
	 while( goldenConn->rowsLeft() )
         {
            impObj = new ExportObject((char *)kw_str.data(), kw_types[i]);
            goldenConn->clearFlag(KW_DATA_END);
	    (exp_iter->second)(goldenConn, impObj);
	    if( impObj->cardCount )
	    {
	       defineManPtr->add(kw_str.data(), impObj);
	       num_defines++;
	    }
	    else
	       delete impObj;
         }
      }
      else
      {
         DBTitle title(goldenConn);

	 while( goldenConn->rowsLeft() )
         {
            impObj = new ExportObject((char *)kw_str.data(), kw_types[i]);
            goldenConn->clearFlag(KW_DATA_END);
            title.readCard(impObj);
	    (exp_iter->second)(goldenConn, impObj);
	    if( impObj->cardCount )
	    {
	       defineManPtr->add(kw_str.data(), impObj);
	       num_defines++;
	    }
	    else
	       delete impObj;
         }
      }

      total_defines += num_defines;
   }

   delete kw_types;

   return total_defines;
}

