#ifndef _Define_EXPORT_H_
#define _Define_EXPORT_H_

#include <string>
#include <map>
#include "goldenconn.h"
#include "definemanager.h"
#include "dataline.h"
#include "dbcard.h"
#include "definetype.h"
#include "exptypemap.h"

/** Class to get data from database for *DEFINE keywords */
class DefineExport
{
public:
   /** Constructor for creating this object
     * \param model_name Name of the model for which the data to be obtained
     * \param gold_conn Connection object for accessing the database
     * \param define_man Manager pointer to store the data obtained
     */
   DefineExport
   (
      char           *model_name,
      GoldenConn     *gold_conn,
      DefineManager  *define_man
   );

   ~DefineExport()
   {
      
      defineManPtr = NULL;
      goldenConn = NULL;
      expTypeFuncMap.clear();
   }

   /** Gets the name of keyword from its type. Type is stored in the database
     * \param kw_type Type of keyword
     * \param key_word Keyword name is stored in this string
     */
   int getKeywordFromType
       (
	  unsigned int kw_type,
	  string & key_word
       );

   /** Fetches the *DEFINE keywords from database and returns 0 if not found 
     * else number of keywords obtained
     */
   unsigned int dbReadDefines(unsigned int def_type = DEFINE_NEW_TYPE);

   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *DEFINE keyword types and their function pointers
     */
   void initExportAleTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *DEFINE keyword types and their function pointers
     */
   void initExportBoxTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *DEFINE keyword types and their function pointers
     */
   void initExportCoordTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *DEFINE keyword types and their function pointers
     */
   void initExportCurveTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *DEFINE keyword types and their function pointers
     */
   void initExportSimpleTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *DEFINE keyword types and their function pointers
     */
   void initExportWeldTypesAndFunctions();

private:
   string           modelName;
   DefineManager    *defineManPtr;
   /** Connection object for accessing the data */
   GoldenConn       *goldenConn;
   /** Object to store the data imported from database */
   ImportObject     *impObj;
   /** A map between type of keyword and pointer to the function to be called */
   map<unsigned int, ExportFunctionPtr>  expTypeFuncMap;
};

#endif

