#include <iostream>
#include <algorithm>
#include "generic.h"
#include "deformtype.h"
#include "deformexport.h"
#include <stdlib.h>

using namespace std;

DeformExport::DeformExport
(
   char         *model_name,
   GoldenConn   *gold_conn,
   DeformManager    *deform_man
)
{
   modelName = model_name;
   deformManPtr = deform_man;
   goldenConn = gold_conn;

   initExportDeformTypesAndFunctions();
}

int DeformExport::getKeywordFromType
    (
       unsigned int kw_type,
       string & key_word
    )
{
   switch(kw_type)
   {
      case DEFORMABLE_TO_RIGID:
	 key_word = "*DEFORMABLE_TO_RIGID";
	 break;
      case DEFORMABLE_TO_RIGID_AUTOMATIC:
	 key_word = "*DEFORMABLE_TO_RIGID_AUTOMATIC";
	 break;
      case DEFORMABLE_TO_RIGID_INERTIA:
	 key_word = "*DEFORMABLE_TO_RIGID_INERTIA";
	 break;
      case DEFORM_NEW_TYPE:
      default:
         return 1;
   }
   return 0;
}

unsigned int DeformExport::dbReadDeforms()
{
   char         **row_data, buf[16];
   unsigned int	i, num_deforms = 0, total_deforms = 0, num_kw_types = 0;
   expTypeFuncIterator eexp_iter = expTypeFuncMap.end(), exp_iter;

   string       qry = "select kw_type from ", kw_str;
   string table_name = "`" + modelName + "_DEFORMABLES`";
   qry += table_name;
   qry += " group by kw_type;";

cout << "KW QRY = " << qry << endl;

   if( goldenConn->executeQuery( qry.data() ) )
      return 0;

   num_kw_types = goldenConn->numRows();

   if( !num_kw_types )
      return 0;

   unsigned int *kw_types = new unsigned int[num_kw_types];

   for(i = 0; i < num_kw_types; i++)
   {
      row_data = goldenConn->nextRow();
      kw_types[i] = atoi( row_data[0] );
cout << "KW DEFORM TYPE = " << kw_types[i] << endl;
   }

   for(i = 0; i < num_kw_types; i++)
   {
      qry = "select * from ";
      qry += table_name;
      qry += " where kw_type=";
      sprintf(buf, "%u", kw_types[i]);
      qry += buf;
      qry += " order by card_index;";

cout << "DEFORM QRY = " << qry << endl;

      if( getKeywordFromType(kw_types[i], kw_str) )
         continue;

cout << "DEFORM KW = " << kw_str << endl;

      if( goldenConn->executeQuery( qry.data() ) )
	 break;

      exp_iter = expTypeFuncMap.find(kw_types[i]);

      if( exp_iter == eexp_iter )
      {
	 cout << "DEFORM TYPE NOT FOUND" << endl;
         continue;
      }

      num_deforms = 0;
      while( goldenConn->rowsLeft() )
      {
	 impObj = new ExportObject((char *)kw_str.data(), kw_types[i]);
         goldenConn->clearFlag(KW_DATA_END);
	 (exp_iter->second)(goldenConn, impObj);
	 if( impObj->cardCount )
	 {
	    deformManPtr->add(kw_str.data(), impObj);
	    num_deforms++;
	 }
	 else
	    delete impObj;
      }

      total_deforms += num_deforms;
   }

   delete kw_types;

   return total_deforms;
}

