#ifndef _Deform_EXPORT_H_
#define _Deform_EXPORT_H_

#include <string>
#include <map>
#include "goldenconn.h"
#include "deformmanager.h"
#include "dataline.h"
#include "dbcard.h"
#include "deformtype.h"
#include "exptypemap.h"

/** Class to get data from database for *DEFORMABLE keywords */
class DeformExport
{
public:
   /** Constructor for creating this object
     * \param model_name Name of the model for which the data to be obtained
     * \param gold_conn Connection object for accessing the database
     * \param deform_man Manager pointer to store the data obtained
     */
   DeformExport
   (
      char           *model_name,
      GoldenConn     *gold_conn,
      DeformManager  *deform_man
   );

   ~DeformExport()
   {
      
      deformManPtr = NULL;
      goldenConn = NULL;
      expTypeFuncMap.clear();
   }

   /** Gets the name of keyword from its type. Type is stored in the database
     * \param kw_type Type of keyword
     * \param key_word Keyword name is stored in this string
     */
   int getKeywordFromType
       (
	  unsigned int kw_type,
	  string & key_word
       );

   /** Fetches the *DEFORM keywords from database and returns 0 if not found 
     * else number of keywords obtained
     */
   unsigned int dbReadDeforms();

   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *DEFORMABLE keyword types and their function pointers
     */
   void initExportDeformTypesAndFunctions();

private:
   string           modelName;
   DeformManager    *deformManPtr;
   /** Connection object for accessing the data */
   GoldenConn       *goldenConn;
   /** Object to store the data imported from database */
   ImportObject     *impObj;
   /** A map between type of keyword and pointer to the function to be called */
   map<unsigned int, ExportFunctionPtr>  expTypeFuncMap;
};

#endif

