#ifndef _DBELEMENTBEAMSCALR_H_
#define _DBELEMENTBEAMSCALR_H_

#include "manager.h"
#include "dispexport.h"
#include "dbelementbeam.h"

/** Class used for getting data from database for *ELEMENT_BEAM_SCALR
  * keyword */

class DBElementBeamScalr : public DBElementBeam
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBElementBeamScalr(GoldenConn *gold_conn, ImportObject *imp_obj) : DBElementBeam (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBElementBeamScalr()
   {
   }

public:
/** Function to get Card1 details for *ELEMENT_BEAM_SCALR
  * keyword from database */
   void dbReadCard1(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"VOL","INER","CID1","CID2","DOFNS",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {2, 3, };
      unsigned int man_types[] = {DEFINE, DEFINE, };
      unsigned int kw_types[] = {COORDINATE, COORDINATE, };
      unsigned int num_indices = 2;
      numFields = 5;
      unsigned int field_widths[] = {16, 16, 8, 8, 8, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, ELEMENT, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card1");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card1",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *ELEMENT_BEAM_SCALR
  * from database */
   unsigned int importDBElementBeamScalr()
   {
      importDBElementBeam();
      dbReadCard1();
      return 0;
   }
};

#endif

