#ifndef _DBELEMENTBEAMSECTION_H_
#define _DBELEMENTBEAMSECTION_H_

#include "manager.h"
#include "dispexport.h"
#include "dbelementbeam.h"

/** Class used for getting data from database for *ELEMENT_BEAM_SECTION
  * keyword */

class DBElementBeamSection : public DBElementBeam
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBElementBeamSection(GoldenConn *gold_conn, ImportObject *imp_obj) : DBElementBeam (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBElementBeamSection()
   {
   }

public:
/** Function to get Card details for *ELEMENT_BEAM_SECTION
  * keyword from database */
   void dbReadCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"STYPE","D1","D2","D3","D4","D5","D6",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 7;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, ELEMENT, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *ELEMENT_BEAM_SECTION
  * from database */
   unsigned int importDBElementBeamSection()
   {
      importDBElementBeam();
      dbReadCard();
      return 0;
   }
};

#endif

