#ifndef _DBELEMENTBEAMTHICKNESS_H_
#define _DBELEMENTBEAMTHICKNESS_H_

#include "manager.h"
#include "dispexport.h"
#include "dbelementbeam.h"

/** Class used for getting data from database for *ELEMENT_BEAM_THICKNESS
  * keyword */

class DBElementBeamThickness : public DBElementBeam
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBElementBeamThickness(GoldenConn *gold_conn, ImportObject *imp_obj) : DBElementBeam (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBElementBeamThickness()
   {
   }

public:
/** Function to get Card details for *ELEMENT_BEAM_THICKNESS
  * keyword from database */
   void dbReadCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"PARM1","PARM2","PARM3","PARM4","PARM5",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 5;
      unsigned int field_widths[] = {16, 16, 16, 16, 16, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, ELEMENT, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *ELEMENT_BEAM_THICKNESS
  * from database */
   unsigned int importDBElementBeamThickness()
   {
      importDBElementBeam();
      dbReadCard();
      return 0;
   }
};

#endif

