#ifndef _DBELEMENTBEAMWARPAGE_H_
#define _DBELEMENTBEAMWARPAGE_H_

#include "manager.h"
#include "dispexport.h"
#include "dbelementbeam.h"

/** Class used for getting data from database for *ELEMENT_BEAM_WARPAGE
  * keyword */

class DBElementBeamWarpage : public DBElementBeam
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBElementBeamWarpage(GoldenConn *gold_conn, ImportObject *imp_obj) : DBElementBeam (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBElementBeamWarpage()
   {
   }

public:
/** Function to get Card details for *ELEMENT_BEAM_WARPAGE
  * keyword from database */
   void dbReadCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"SN1","SN2",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, };
      unsigned int man_types[] = {NOD, NOD, };
      unsigned int kw_types[] = {9999, 9999, };
      unsigned int num_indices = 2;
      numFields = 2;
      unsigned int field_widths[] = {10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, ELEMENT, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *ELEMENT_BEAM_WARPAGE
  * from database */
   unsigned int importDBElementBeamWarpage()
   {
      importDBElementBeam();
      dbReadCard();
      return 0;
   }
};

#endif

