#include <iostream>
#include <algorithm>
#include "generic.h"
#include "elementtype.h"
#include "elementexport.h"
#include "filepath.h"
#include <stdlib.h>
#include <math.h>

using namespace std;

ElementExport::ElementExport
(
   char              *model_name,
   GoldenConn        *gold_conn,
   ElementManager    *element_man
)
{
   modelName = model_name;
   elementManPtr = element_man;
   goldenConn = gold_conn;

   initExportBeamTypesAndFunctions();
   initExportSeatbeltTypesAndFunctions();
   initExportShellTypesAndFunctions();
   initExportSimpleTypesAndFunctions();
}

int ElementExport::getKeywordFromType
    (
       unsigned int elm_type,
       string & kw_str
    )
{
   switch(elm_type)
   {
      case ELEMENT_BEAM_OFFSET:
         kw_str = "*ELEMENT_BEAM_OFFSET";
         break;
      case ELEMENT_BEAM_ORIENTATION:
         kw_str = "*ELEMENT_BEAM_ORIENTATION";
         break;
      case ELEMENT_BEAM_PID:
         kw_str = "*ELEMENT_BEAM_PID";
         break;
      case ELEMENT_BEAM_SCALAR:
         kw_str = "*ELEMENT_BEAM_SCALAR";
         break;
      case ELEMENT_BEAM_SCALR:
         kw_str = "*ELEMENT_BEAM_SCALR";
         break;
      case ELEMENT_BEAM_SECTION:
         kw_str = "*ELEMENT_BEAM_SECTION";
         break;
      case ELEMENT_BEAM_THICKNESS:
         kw_str = "*ELEMENT_BEAM_THICKNESS";
         break;
      case ELEMENT_BEAM_WARPAGE:
         kw_str = "*ELEMENT_BEAM_WARPAGE";
         break;
      case ELEMENT_BEAM:
         kw_str = "*ELEMENT_BEAM";
         break;
      case ELEMENT_SEATBELT_ACCELEROMETER:
         kw_str = "*ELEMENT_SEATBELT_ACCELEROMETER";
         break;
      case ELEMENT_SEATBELT_PRETENSIONER:
         kw_str = "*ELEMENT_SEATBELT_PRETENSIONER";
         break;
      case ELEMENT_SEATBELT_RETRACTOR:
         kw_str = "*ELEMENT_SEATBELT_RETRACTOR";
         break;
      case ELEMENT_SEATBELT_SENSOR:
         kw_str = "*ELEMENT_SEATBELT_SENSOR";
         break;
      case ELEMENT_SEATBELT_SLIPRING:
         kw_str = "*ELEMENT_SEATBELT_SLIPRING";
         break;
      case ELEMENT_SEATBELT:
         kw_str = "*ELEMENT_SEATBELT";
         break;
      case ELEMENT_SHELL_BETA:
         kw_str = "*ELEMENT_SHELL_BETA";
         break;
      case ELEMENT_SHELL_DOF:
         kw_str = "*ELEMENT_SHELL_DOF";
         break;
      case ELEMENT_SHELL_MCD:
         kw_str = "*ELEMENT_SHELL_MCD";
         break;
      case ELEMENT_SHELL_OFFSET:
         kw_str = "*ELEMENT_SHELL_OFFSET";
         break;
      case ELEMENT_SHELL_SOURCE_SINK:
         kw_str = "*ELEMENT_SHELL_SOURCE_SINK";
         break;
      case ELEMENT_SHELL_THICKNESS:
         kw_str = "*ELEMENT_SHELL_THICKNESS";
         break;
      case ELEMENT_SHELL:
         kw_str = "*ELEMENT_SHELL";
         break;
      case ELEMENT_SOLID_DOF:
         kw_str = "*ELEMENT_SOLID_DOF";
         break;
      case ELEMENT_SOLID_ORTHO:
         kw_str = "*ELEMENT_SOLID_ORTHO";
         break;
      case ELEMENT_SOLID:
         kw_str = "*ELEMENT_SOLID";
         break;
      case ELEMENT_TSHELL:
         kw_str = "*ELEMENT_TSHELL";
         break;
      case ELEMENT_DIRECT_MATRIX_INPUT:
         kw_str = "*ELEMENT_DIRECT_MATRIX_INPUT";
         break;
      case ELEMENT_DISCRETE:
         kw_str = "*ELEMENT_DISCRETE";
         break;
      case ELEMENT_INERTIA_OFFSET:
         kw_str = "*ELEMENT_INERTIA_OFFSET";
         break;
      case ELEMENT_INERTIA:
         kw_str = "*ELEMENT_INERTIA";
         break;
      case ELEMENT_MASS_NODE_SET:
         kw_str = "*ELEMENT_MASS_NODE_SET";
         break;
      case ELEMENT_MASS_PART_SET:
         kw_str = "*ELEMENT_MASS_PART_SET";
         break;
      case ELEMENT_MASS_PART:
         kw_str = "*ELEMENT_MASS_PART";
         break;
      case ELEMENT_MASS:
         kw_str = "*ELEMENT_MASS";
         break;
      case ELEMENT_PLOTEL:
         kw_str = "*ELEMENT_PLOTEL";
         break;
      case ELEMENT_SPH:
         kw_str = "*ELEMENT_SPH";
         break;
      case ELEMENT_TRIM:
         kw_str = "*ELEMENT_TRIM";
         break;
      case ELEMENT_NEW_TYPE:
      default:
         return 1;
   }

   return 0;
}

unsigned int ElementExport::dbReadElements
             (
                unsigned int count,
                unsigned int offset,
                unsigned int kw_type,
                StrUIMap *kws_types
             )
{
   char         buf[16], count_buf[64];
   unsigned int	num_elms = 0, total_elms = 0;
   expTypeFuncIterator eexp_iter = expTypeFuncMap.end(), exp_iter;
   string qry, kw_str;
   string table_name = "`" + modelName + "_ELEMENTS`";

/*
   string       qry = "select kw_type from ", kw_str;
   qry += table_name;
   qry += " group by kw_type;";

   if( goldenConn->executeQuery( qry.data() ) )
      return 0;

   num_kw_types = goldenConn->numRows();

   if( !num_kw_types )
      return 0;

   unsigned int *kw_types = new unsigned int[num_kw_types];

   for(i = 0; i < num_kw_types; i++)
   {
      row_data = goldenConn->nextRow();
      kw_types[i] = atoi( row_data[0] );
   }
*/

   if( !kws_types )
   {
      kws_types = new StrUIMap;
      getElementTypes(kws_types);
   }

   count_buf[0] = '\0';
   if( count )
      sprintf(count_buf, " limit %u offset %u", count, offset);

   StrUIIter b = kws_types->begin(), e = kws_types->end();

   //for(i = 0; i < num_kw_types; i++)
   for(; b != e; b++)
   {
      if( getKeywordFromType(b->second, kw_str) )
         continue;

      if( kw_type != ELEMENT_NEW_TYPE && kw_type != b->second )
         continue;

      qry = "select * from ";
      qry += table_name;
      qry += " where kw_type=";
      sprintf(buf, "%u", b->second);
      qry += buf;
      qry += count_buf;
      qry += ";";
cout << "ELM QRY=" << qry << endl;

      if( goldenConn->executeQuery( qry.data() ) )
	 break;

      exp_iter = expTypeFuncMap.find(b->second);

      if( exp_iter == eexp_iter )
      {
	 cout << "Element TYPE NOT FOUND" << endl;
         continue;
      }

#ifdef DEBUG
cout << "ELM TYPE FROM DB = " << b->second << endl;
cout << "ELM TYPE FROM DB = " << kw_str << endl;
#endif

      impObj = new ExportObject((char *)kw_str.data(), b->second);

      num_elms = 0;
      Card::setFlag();
      (exp_iter->second)(goldenConn, impObj);
      Card::clearFlag();
      num_elms++;

      while( goldenConn->rowsLeft() )
      {
	 (exp_iter->second)(goldenConn, impObj);
         num_elms++;
      }

      elementManPtr->add(kw_str.data(), impObj);

      total_elms += num_elms;
      FilePath::closeFile();
   }

   FilePath::closeIDFile();

   return total_elms;
}

unsigned int ElementExport::getElementTypes
             (
                StrUIMap *kws_types
             )
{
   char         **row_data;
   unsigned int	i, num_kw_types = 0;

   string       qry = "select kw_type from ", kw_str;
   string table_name = "`" + modelName + "_ELEMENTS`";
   qry += table_name;
   qry += " group by kw_type;";

   if( goldenConn->executeQuery( qry.data() ) )
      return 0;

   num_kw_types = goldenConn->numRows();

   if( !num_kw_types )
      return 0;

   unsigned int *kw_types = new unsigned int[num_kw_types];

   for(i = 0; i < num_kw_types; i++)
   {
      row_data = goldenConn->nextRow();
      kw_types[i] = atoi( row_data[0] );
   }

   for(i = 0; i < num_kw_types; i++)
   {
      if( getKeywordFromType(kw_types[i], kw_str) )
         continue;

      kws_types->insert(StrUIPair(kw_str, kw_types[i]));
   }

   delete kw_types;

   return kws_types->size();
}

unsigned int ElementExport::dbReadElementsBySequence
             (
             )
{
   char         buf[80];
   unsigned int	num_elms = 0, total_elms = 0;
   expTypeFuncIterator eexp_iter = expTypeFuncMap.end(), exp_iter;
   string qry, kw_str, select_query = "select count(card_index) from ";
   string table_name = "`" + modelName + "_ELEMENTS`";

   select_query += table_name;
   select_query += ";";
//cout << "COUNT QRY=" << select_query << endl;
   if( goldenConn->executeQuery( select_query.data() ) )
      return 0;

   char **row = goldenConn->nextRow();
   total_elms = atoi(row[0]);
  
   if( !total_elms )
   {
      cout << "WARNING: No elements available for model<" << modelName << ">\n";
      return 0;
   }

   qry = "select card_index,kw_type from ";
   qry += table_name;
   qry += " group by kw_type;";
//cout << "KW QRY=" << qry << endl;

   if( goldenConn->executeQuery( qry.data() ) )
      return 0;

   unsigned int num_kw_types = goldenConn->numRows();

   UIUIMap ci_kws;
   unsigned int COUNT_LIMIT = 2000000, limit, start, end = 0, i;
   for(i = 0; i < num_kw_types; i++)
   {
      row = goldenConn->nextRow();
      ci_kws.insert(UIUIPair(atoi(row[0]), atoi(row[1])));
   }

   UIUIIter b = ci_kws.begin(), e = ci_kws.end(), iter;

   iter = b;
   qry = "select * from ";
   qry += table_name;
   qry += " limit ";

   for(; b != e; b++)
   {
      start = b->first;
      iter++;

      if( iter != e )
      {
         end = iter->first;
         num_elms = end - start;
      }
      else
         num_elms = total_elms - end + 1;

      limit = (num_elms > COUNT_LIMIT ) ? COUNT_LIMIT : num_elms;
    
//cout << "NUM ELMS=" << num_elms << " LIMIT=" << limit << endl;

      exp_iter = expTypeFuncMap.find(b->second);

      if( exp_iter == eexp_iter )
      {
	 cout << "Element TYPE NOT FOUND" << endl;
	 continue;
      }

      if( getKeywordFromType(b->second, kw_str) )
	 continue;

      while(num_elms > 0)
      {
	 sprintf(buf, "%u offset %u;", limit, start-1);
         select_query = qry + buf;
cout << "ELM QRY=" << select_query << endl;

	 if( goldenConn->executeQuery( select_query.data() ) )
	    break;

	 impObj = new ExportObject((char *)kw_str.data(), b->second);

	 Card::setFlag();
	 (exp_iter->second)(goldenConn, impObj);
	 Card::clearFlag();

	 while( goldenConn->rowsLeft() )
	 {
	    (exp_iter->second)(goldenConn, impObj);
	 }

cout << "IMPOBJ LEN=" << impObj->cardCount;

	 elementManPtr->add(kw_str.data(), impObj);
         num_elms -= limit;
         start += limit;
         limit = (num_elms > COUNT_LIMIT ) ? COUNT_LIMIT : num_elms;
cout << "NUM ELMS=" << num_elms << " limit=" << limit << " START=" << start << endl;
      }

      FilePath::closeFile();
   }

   FilePath::closeIDFile();

   return total_elms;
}

