#ifndef _ELEMENT_EXPORT_H_
#define _ELEMENT_EXPORT_H_

#include <string>
#include <set>
#include <map>
#include "elementmanager.h"
#include "goldenconn.h"
#include "dbcard.h"
#include "elementtype.h"
#include "exptypemap.h"

typedef map<string, unsigned int> StrUIMap;
typedef pair<string, unsigned int> StrUIPair;
typedef map<string, unsigned int>::iterator StrUIIter;
typedef map<unsigned int, unsigned int> UIUIMap;
typedef pair<unsigned int, unsigned int> UIUIPair;
typedef map<unsigned int, unsigned int>::iterator UIUIIter;

/** Class to get data from database for *ELEMENT keywords */
class ElementExport
{
public:
   /** Constructor for creating this object
     * \param model_name Name of the model for which the data to be obtained
     * \param gold_conn Connection object for accessing the database
     * \param element_man Manager pointer to store the data obtained
     */
   ElementExport
   (
      char          *model_name,
      GoldenConn    *gold_conn,
      ElementManager    *element_man
   );

   ~ElementExport()
   {
      elementManPtr = NULL;
      goldenConn = NULL;
      expTypeFuncMap.clear();
   }

   /** Gets the name of keyword from its type. Type is stored in the database
     * \param elm_type Type of keyword
     * \param kw_str Keyword name is stored in this string
     */
   int getKeywordFromType
       (
	  unsigned int elm_type,
	  string & kw_str
       );

   /** Fetches the *ELEMENT keywords from database and returns 0 if not found 
     * else number of keywords obtained
     * \param count Number of nodes requested from database
     * \param offset Offset from which the nodes are requested
     * \param kw_type Type of node keyword
     * \param kws_types List of element type keywords available in database. This
     * is filled in this function
     */
   unsigned int dbReadElements
                (
                   unsigned int count=0, 
                   unsigned int offset=0, 
                   unsigned int kw_type=ELEMENT_NEW_TYPE,
                   StrUIMap *kws_types=NULL
                );

   /** Gets the type of elements available in the database
     * \param kws_types Types of keywords of *ELEMENT
     * \return Returns the number of types of *ELEMENT keywords
     */
   unsigned int getElementTypes(StrUIMap *kws_types);

   /** Gets the elements sequentially from the database. This improves the
     * speed of getting the data from database. Instead of searching for a
     * type of element and getting the data is taking time. So this function
     * is faster
     * \return Number of elements
     */
   unsigned int dbReadElementsBySequence
		(
		);

   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *ELEMENT keyword types and their function pointers
     */
   void initExportBeamTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *ELEMENT keyword types and their function pointers
     */
   void initExportSeatbeltTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *ELEMENT keyword types and their function pointers
     */
   void initExportShellTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *ELEMENT keyword types and their function pointers
     */
   void initExportSimpleTypesAndFunctions();

private:
   ElementManager    *elementManPtr;
   /** Connection object for accessing the data */
   GoldenConn        *goldenConn;
   /** Object to store the data imported from database */
   ImportObject      *impObj;
   string            modelName;
   /** A map between type of keyword and pointer to the function to be called */
   map<unsigned int, ExportFunctionPtr>  expTypeFuncMap;
};

#endif

