#ifndef _DBELEMENTSEATBELTSENSOR_H_
#define _DBELEMENTSEATBELTSENSOR_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *ELEMENT_SEATBELT_SENSOR
  * keyword */

class DBElementSeatbeltSensor : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBElementSeatbeltSensor(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBElementSeatbeltSensor()
   {
   }

public:
/** Function to get Card1 details for *ELEMENT_SEATBELT_SENSOR
  * keyword from database */
   int dbReadCard1(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"SBSID","SBSTYP","SBSFL",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, };
      numFields = 3;
      unsigned int field_widths[] = {10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return 0;
      }
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 2, ELEMENT, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card1");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card1",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
      if( wordArray[3] )
         return atoi(wordArray[3]);
      else
         return 0;
   }

/** Function to get CardSBSTYP1 details for *ELEMENT_SEATBELT_SENSOR
  * keyword from database */
   void dbReadCardSBSTYP1(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"NID","DOF","ACC","ATIME",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {NOD, };
      unsigned int kw_types[] = {9999, };
      unsigned int num_indices = 1;
      numFields = 4;
      unsigned int field_widths[] = {10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, ELEMENT, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("CardSBSTYP1");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","CardSBSTYP1",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get CardSBSTYP2 details for *ELEMENT_SEATBELT_SENSOR
  * keyword from database */
   void dbReadCardSBSTYP2(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"SBRID","PULRAT","PULTIM",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {ELEMENT, };
      unsigned int kw_types[] = {SBRETRACTOR, };
      unsigned int num_indices = 1;
      numFields = 3;
      unsigned int field_widths[] = {10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, ELEMENT, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("CardSBSTYP2");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","CardSBSTYP2",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get CardSBSTYP3 details for *ELEMENT_SEATBELT_SENSOR
  * keyword from database */
   void dbReadCardSBSTYP3(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"TIME",};
      unsigned int field_types[] = {DATA_DOUBLE, };
      numFields = 1;
      unsigned int field_widths[] = {10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("CardSBSTYP3");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","CardSBSTYP3",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get CardSBSTYP4 details for *ELEMENT_SEATBELT_SENSOR
  * keyword from database */
   void dbReadCardSBSTYP4(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"NID1","NID2","DMX","DMN",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, 1, };
      unsigned int man_types[] = {NOD, NOD, };
      unsigned int kw_types[] = {9999, 9999, };
      unsigned int num_indices = 2;
      numFields = 4;
      unsigned int field_widths[] = {10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("CardSBSTYP4");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","CardSBSTYP4",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *ELEMENT_SEATBELT_SENSOR
  * from database */
   unsigned int importDBElementSeatbeltSensor()
   {
      int sbstyp = 0;
      sbstyp = dbReadCard1();
      if( sbstyp == 1 )
      {
         dbReadCardSBSTYP1();
      }
      else if( sbstyp == 2 )
      {
         dbReadCardSBSTYP2();
      }
      else if( sbstyp == 3 )
      {
         dbReadCardSBSTYP3();
      }
      else if( sbstyp == 4 )
      {
         dbReadCardSBSTYP4();
      }
      return 0;
   }
};

#endif

