#ifndef _DBELEMENTSHELLTHICKNESS_H_
#define _DBELEMENTSHELLTHICKNESS_H_

#include "manager.h"
#include "dispexport.h"
#include "dbelementshell.h"

/** Class used for getting data from database for *ELEMENT_SHELL_THICKNESS
  * keyword */

class DBElementShellThickness : public DBElementShell
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBElementShellThickness(GoldenConn *gold_conn, ImportObject *imp_obj) : DBElementShell (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBElementShellThickness()
   {
   }

public:
/** Function to get Card2 details for *ELEMENT_SHELL_THICKNESS
  * keyword from database */
   void dbReadCard2(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"THIC1","THIC2","THIC3","THIC4","BETA/MCID",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {4, };
      unsigned int man_types[] = {DEFINE, };
      unsigned int kw_types[] = {COORDINATE, };
      unsigned int num_indices = 1;
      numFields = 5;
      unsigned int field_widths[] = {16, 16, 16, 16, 16, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, ELEMENT, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card2");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card2",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *ELEMENT_SHELL_THICKNESS
  * from database */
   unsigned int importDBElementShellThickness()
   {
      importDBElementShell();
      dbReadCard2();
      return 0;
   }
};

#endif

