#ifndef _DBELEMENTSOLIDORTHO_H_
#define _DBELEMENTSOLIDORTHO_H_

#include "manager.h"
#include "dispexport.h"
#include "dbelementsolid.h"

/** Class used for getting data from database for *ELEMENT_SOLID_ORTHO
  * keyword */

class DBElementSolidOrtho : public DBElementSolid
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBElementSolidOrtho(GoldenConn *gold_conn, ImportObject *imp_obj) : DBElementSolid (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBElementSolidOrtho()
   {
   }

public:
/** Function to get CardOrtho1 details for *ELEMENT_SOLID_ORTHO
  * keyword from database */
   void dbReadCardOrtho1(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"A1","A2","A3",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 3;
      unsigned int field_widths[] = {16, 16, 16, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, ELEMENT, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("CardOrtho1");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","CardOrtho1",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get CardOrtho2 details for *ELEMENT_SOLID_ORTHO
  * keyword from database */
   void dbReadCardOrtho2(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"D1","D2","D3",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 3;
      unsigned int field_widths[] = {16, 16, 16, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, ELEMENT, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("CardOrtho2");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","CardOrtho2",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *ELEMENT_SOLID_ORTHO
  * from database */
   unsigned int importDBElementSolidOrtho()
   {
      importDBElementSolid();
      dbReadCardOrtho1();
      dbReadCardOrtho2();
      return 0;
   }
};

#endif

