#ifndef _DBELEMENTDISCRETE_H_
#define _DBELEMENTDISCRETE_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *ELEMENT_DISCRETE
  * keyword */

class DBElementDiscrete : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBElementDiscrete(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBElementDiscrete()
   {
   }

public:
/** Function to get Card1 details for *ELEMENT_DISCRETE
  * keyword from database */
   void dbReadCard1(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"EID","PID","N1","N2","VID","S","PF","OFFSET",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, };
      numFields = 8;
      unsigned int field_widths[] = {8, 8, 8, 8, 8, 16, 8, 16, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 2, ELEMENT, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         saveDiscretes(&wordArray[2], numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card1");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card1",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *ELEMENT_DISCRETE
  * from database */
   unsigned int importDBElementDiscrete()
   {
      dbReadCard1();
      return 0;
   }
};

#endif

