#include <iostream>
#include <algorithm>
#include "generic.h"
#include "eostype.h"
#include "eosexport.h"
#include "exptitle.h"
#include <stdlib.h>

using namespace std;

EosExport::EosExport
(
   char         *model_name,
   GoldenConn   *gold_conn,
   EosManager   *eos_man
)
{
   modelName = model_name;
   eosManPtr = eos_man;
   goldenConn = gold_conn;

   initExportJwlTypesAndFunctions();
   initExportPolyTypesAndFunctions();
   initExportTableTypesAndFunctions();
}

int EosExport::getKeywordFromType
    (
       unsigned int kw_type,
       string & key_word
    )
{
   int title_flag = 0;

   if( kw_type >= TITLE_CARD )
   {
      kw_type -= TITLE_CARD;
      title_flag = 1;
   }

   switch(kw_type)
   {
      case EOS_IDEAL_GAS:
	 key_word = "*EOS_IDEAL_GAS";
	 break;
      case EOS_IGNITION_AND_GROWTH_OF_REACTION_IN_HE:
	 key_word = "*EOS_IGNITION_AND_GROWTH_OF_REACTION_IN_HE";
	 break;
      case EOS_JWL:
	 key_word = "*EOS_JWL";
	 break;
      case EOS_JWLB:
	 key_word = "*EOS_JWLB";
	 break;
      case EOS_PROPELLANT_DEFLAGRATION:
	 key_word = "*EOS_PROPELLANT_DEFLAGRATION";
	 break;
      case EOS_TENSOR_PORE_COLLAPSE:
	 key_word = "*EOS_TENSOR_PORE_COLLAPSE";
	 break;
      case EOS_GRUNEISEN:
	 key_word = "*EOS_GRUNEISEN";
	 break;
      case EOS_LINEAR_POLYNOMIAL:
	 key_word = "*EOS_LINEAR_POLYNOMIAL";
	 break;
      case EOS_LINEAR_POLYNOMIAL_WITH_ENERGY_LEAK:
	 key_word = "*EOS_LINEAR_POLYNOMIAL_WITH_ENERGY_LEAK";
	 break;
      case EOS_RATIO_OF_POLYNOMIALS:
	 key_word = "*EOS_RATIO_OF_POLYNOMIALS";
	 break;
      case EOS_SACK_TUESDAY:
	 key_word = "*EOS_SACK_TUESDAY";
	 break;
      case EOS_GASKET:
	 key_word = "*EOS_GASKET";
	 break;
      case EOS_TABULATED:
	 key_word = "*EOS_TABULATED";
	 break;
      case EOS_TABULATED_COMPACTION:
	 key_word = "*EOS_TABULATED_COMPACTION";
	 break;
      case EOS_USER_DEFINED:
	 key_word = "*EOS_USER_DEFINED";
	 break;
      case EOS_NEW_TYPE:
	 return 1;
   }

   if( title_flag )
      key_word += "_TITLE";

   return 0;
}

unsigned int EosExport::dbReadEoss()
{
   char         **row_data, buf[16];
   unsigned int	i, num_eoss = 0, total_eoss = 0, num_kw_types = 0;
   expTypeFuncIterator eexp_iter = expTypeFuncMap.end(), exp_iter;

   string       qry = "select kw_type from ", kw_str;
   string table_name = "`" + modelName + "_EOSS`";
   qry += table_name;
   qry += " group by kw_type;";

cout << "KW QRY = " << qry << endl;

   if( goldenConn->executeQuery( qry.data() ) )
      return 0;

   num_kw_types = goldenConn->numRows();

   if( !num_kw_types )
      return 0;

   unsigned int *kw_types = new unsigned int[num_kw_types];

   for(i = 0; i < num_kw_types; i++)
   {
      row_data = goldenConn->nextRow();
      kw_types[i] = atoi( row_data[0] );
cout << "KW EOS TYPE = " << kw_types[i] << endl;
   }

   for(i = 0; i < num_kw_types; i++)
   {
      if( getKeywordFromType(kw_types[i], kw_str) )
         continue;

cout << "EOS KW = " << kw_str << endl;

      qry = "select * from ";
      qry += table_name;
      qry += " where kw_type=";
      sprintf(buf, "%u", kw_types[i]);
      qry += buf;
      qry += " order by card_index;";

cout << "EOS QRY = " << qry << endl;

      if( goldenConn->executeQuery( qry.data() ) )
	 break;

      unsigned int kw_type;
      if( kw_types[i] < TITLE_CARD )
         kw_type = kw_types[i];
      else
         kw_type = kw_types[i] - TITLE_CARD;

      exp_iter = expTypeFuncMap.find(kw_type);

      if( exp_iter == eexp_iter )
      {
	 cout << "EOS TYPE NOT FOUND" << endl;
         continue;
      }

      num_eoss = 0;
      if( kw_types[i] < TITLE_CARD )
      {
	 while( goldenConn->rowsLeft() )
	 {
	    impObj = new ExportObject((char *)kw_str.data(), kw_types[i]);
            goldenConn->clearFlag(KW_DATA_END);
	    (exp_iter->second)(goldenConn, impObj);
	    if( impObj->cardCount )
	    {
	       eosManPtr->add(kw_str.data(), impObj);
	       num_eoss++;
	    }
	    else
	       delete impObj;
	 }
      }
      else
      {
         DBTitle title(goldenConn);

	 while( goldenConn->rowsLeft() )
	 {
	    impObj = new ExportObject((char *)kw_str.data(), kw_types[i]);
            goldenConn->clearFlag(KW_DATA_END);
            title.readCard(impObj);
	    (exp_iter->second)(goldenConn, impObj);
	    if( impObj->cardCount )
	    {
	       eosManPtr->add(kw_str.data(), impObj);
	       num_eoss++;
	    }
	    else
	       delete impObj;
	 }
      }

      total_eoss += num_eoss;
   }

   delete kw_types;

   return total_eoss;
}

