#ifndef _Eos_EXPORT_H_
#define _Eos_EXPORT_H_

#include <string>
#include <map>
#include "goldenconn.h"
#include "eosmanager.h"
#include "dataline.h"
#include "dbcard.h"
#include "eostype.h"
#include "exptypemap.h"

/** Class to get data from database for *EOS keywords */
class EosExport
{
public:
   /** Constructor for creating this object
     * \param model_name Name of the model for which the data to be obtained
     * \param gold_conn Connection object for accessing the database
     * \param eos_man Manager pointer to store the data obtained
     */
   EosExport
   (
      char         *model_name,
      GoldenConn   *gold_conn,
      EosManager   *eos_man
   );

   ~EosExport()
   {
      
      eosManPtr = NULL;
      goldenConn = NULL;
      expTypeFuncMap.clear();
   }

   /** Gets the name of keyword from its type. Type is stored in the database
     * \param kw_type Type of keyword
     * \param key_word Keyword name is stored in this string
     */
int getKeywordFromType
    (
       unsigned int kw_type,
       string & key_word
    );

   /** Fetches the *EOS keywords from database and returns 0 if not found 
     * else number of keywords obtained
     */
   unsigned int dbReadEoss();

   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *EOS keyword types and their function pointers
     */
   void initExportJwlTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *EOS keyword types and their function pointers
     */
   void initExportPolyTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *EOS keyword types and their function pointers
     */
   void initExportTableTypesAndFunctions();

private:
   string        modelName;
   EosManager    *eosManPtr;
   /** Connection object for accessing the data */
   GoldenConn    *goldenConn;
   /** Object to store the data imported from database */
   ImportObject  *impObj;
   /** A map between type of keyword and pointer to the function to be called */
   map<unsigned int, ExportFunctionPtr>  expTypeFuncMap;
};

#endif

