#ifndef _Hg_EXPORT_H_
#define _Hg_EXPORT_H_

#include <string>
#include <map>
#include "goldenconn.h"
#include "hgmanager.h"
#include "dataline.h"
#include "dbcard.h"
#include "hgtype.h"
#include "exptypemap.h"

/** Class to get data from database for *HOURGLASS keywords */
class HgExport
{
public:
   /** Constructor for creating this object
     * \param model_name Name of the model for which the data to be obtained
     * \param gold_conn Connection object for accessing the database
     * \param hg_man Manager pointer to store the data obtained
     */
   HgExport
   (
      char         *model_name,
      GoldenConn   *gold_conn,
      HgManager    *hg_man
   );

   ~HgExport()
   {
      hgManPtr = NULL;
      goldenConn = NULL;
      expTypeFuncMap.clear();
   }

   /** Fetches the *HOURGLASS keywords from database and returns 0 if not found 
     * else number of keywords obtained
     */
   unsigned int dbReadHgs();

private:
   string        modelName;
   HgManager     *hgManPtr;
   /** Connection object for accessing the data */
   GoldenConn    *goldenConn;
   /** Object to store the data imported from database */
   ImportObject  *impObj;
   /** A map between type of keyword and pointer to the function to be called */
   map<unsigned int, ExportFunctionPtr>  expTypeFuncMap;
};

#endif

