#ifndef _DBINCLUDENASTRAN_H_
#define _DBINCLUDENASTRAN_H_

#include "manager.h"
#include "dispexport.h"
#include "dbinclude.h"

/** Class used for getting data from database for *INCLUDE_NASTRAN
  * keyword */

class DBIncludeNastran : public DBInclude
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBIncludeNastran(GoldenConn *gold_conn, ImportObject *imp_obj) : DBInclude (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBIncludeNastran()
   {
   }

public:
/** Function to get Card2 details for *INCLUDE_NASTRAN
  * keyword from database */
   void dbReadCard2(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"BEAMDF","SHELLDF","SOLIDDF",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, };
      numFields = 3;
      unsigned int field_widths[] = {10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, INC, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card2");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card2",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *INCLUDE_NASTRAN
  * from database */
   unsigned int importDBIncludeNastran()
   {
      importDBInclude();
      dbReadCard2();
      return 0;
   }
};

#endif

