#include <iostream>
#include <algorithm>
#include "generic.h"
#include "includetype.h"
#include "includeexport.h"
#include <stdlib.h>

using namespace std;

IncludeExport::IncludeExport
(
   char         *model_name,
   GoldenConn   *gold_conn,
   IncludeManager    *include_man
)
{
   modelName = model_name;
   includeManPtr = include_man;
   goldenConn = gold_conn;
   
   initExportCompensateTypesAndFunctions();
   initExportIncludeTypesAndFunctions();
}

int IncludeExport::getKeywordFromType
    (
       unsigned int kw_type,
       string & key_word
    )
{
   switch(kw_type)
   {
      case INCLUDE_COMPENSATION_BLANK_AFTER_SPRINGBACK:
	 key_word = "*INCLUDE_COMPENSATION_BLANK_AFTER_SPRINGBACK";
	 break;
      case INCLUDE_COMPENSATION_BLANK_BEFORE_SPRINGBACK:
	 key_word = "*INCLUDE_COMPENSATION_BLANK_BEFORE_SPRINGBACK";
	 break;
      case INCLUDE_COMPENSATION_COMPENSATED_SHAPE:
	 key_word = "*INCLUDE_COMPENSATION_COMPENSATED_SHAPE";
	 break;
      case INCLUDE_COMPENSATION_CURRENT_TOOLS:
	 key_word = "*INCLUDE_COMPENSATION_CURRENT_TOOLS";
	 break;
      case INCLUDE_COMPENSATION_DESIRED_BLANK_SHAPE:
	 key_word = "*INCLUDE_COMPENSATION_DESIRED_BLANK_SHAPE";
	 break;
      case INCLUDE:
	 key_word = "*INCLUDE";
	 break;
      case INCLUDE_BINARY:
	 key_word = "*INCLUDE_BINARY";
	 break;
      case INCLUDE_NASTRAN:
	 key_word = "*INCLUDE_NASTRAN";
	 break;
      case INCLUDE_PATH:
	 key_word = "*INCLUDE_PATH";
	 break;
      case INCLUDE_STAMPED_PART_INVERSE:
	 key_word = "*INCLUDE_STAMPED_PART_INVERSE";
	 break;
      case INCLUDE_STAMPED_PART_MATRIX:
	 key_word = "*INCLUDE_STAMPED_PART_MATRIX";
	 break;
      case INCLUDE_STAMPED_PART_SET:
	 key_word = "*INCLUDE_STAMPED_PART_SET";
	 break;
      case INCLUDE_STAMPED_SET:
	 key_word = "*INCLUDE_STAMPED_SET";
	 break;
      case INCLUDE_TRANSFORM:
	 key_word = "*INCLUDE_TRANSFORM";
	 break;
      case INCLUDE_TRANSFORM_BINARY:
	 key_word = "*INCLUDE_TRANSFORM_BINARY";
	 break;
      case INCLUDE_NEW_TYPE:
         return 1;
   }

   return 0;
}

unsigned int IncludeExport::dbReadIncludes()
{
   char         **row_data, buf[16];
   unsigned int	i, num_includes = 0, total_includes = 0, num_kw_types = 0;
   expTypeFuncIterator eexp_iter = expTypeFuncMap.end(), exp_iter;

   string       qry = "select kw_type from ", kw_str;
   string table_name = "`" + modelName + "_INCLUDES`";
   qry += table_name;
   //qry += " group by kw_type order by card_index;";
   qry += " group by kw_type;";

cout << "KW QRY = " << qry << endl;

   if( goldenConn->executeQuery( qry.data() ) )
      return 0;

   num_kw_types = goldenConn->numRows();

   if( !num_kw_types )
      return 0;

   unsigned int *kw_types = new unsigned int[num_kw_types];

   for(i = 0; i < num_kw_types; i++)
   {
      row_data = goldenConn->nextRow();
      kw_types[i] = atoi( row_data[0] );
cout << "KW INCLUDE TYPE = " << kw_types[i] << endl;
   }

   for(i = 0; i < num_kw_types; i++)
   {
      if( getKeywordFromType(kw_types[i], kw_str) )
         continue;

cout << "INCLUDE KW = " << kw_str << endl;

      qry = "select * from ";
      qry += table_name;
      qry += " where kw_type=";
      sprintf(buf, "%u", kw_types[i]);
      qry += buf;
      qry += " order by card_index;";

cout << "INCLUDE QRY = " << qry << endl;

      if( goldenConn->executeQuery( qry.data() ) )
	 break;

      exp_iter = expTypeFuncMap.find(kw_types[i]);

      if( exp_iter == eexp_iter )
      {
	 cout << "INCLUDE TYPE NOT FOUND" << endl;
         continue;
      }

      num_includes = 0;
      while( goldenConn->rowsLeft() )
      {
	 impObj = new ExportObject((char *)kw_str.data(), kw_types[i]);
         goldenConn->clearFlag(KW_DATA_END);
	 (exp_iter->second)(goldenConn, impObj);
	 if( impObj->cardCount )
	 {
	    includeManPtr->add(kw_str.data(), impObj);
	    num_includes++;
	 }
	 else
	    delete impObj;
      }

      total_includes += num_includes;
   }

   delete kw_types;

   return total_includes;
}

