#ifndef _Include_EXPORT_H_
#define _Include_EXPORT_H_

#include <string>
#include <map>
#include "goldenconn.h"
#include "includemanager.h"
#include "dataline.h"
#include "dbcard.h"
#include "includetype.h"
#include "exptypemap.h"

/** Class to get data from database for *INCLUDE keywords */
class IncludeExport
{
public:
   /** Constructor for creating this object
     * \param model_name Name of the model for which the data to be obtained
     * \param gold_conn Connection object for accessing the database
     * \param include_man Manager pointer to store the data obtained
     */
   IncludeExport
   (
      char            *model_name,
      GoldenConn      *gold_conn,
      IncludeManager  *include_man
   );

   ~IncludeExport()
   {
      includeManPtr = NULL;
      goldenConn = NULL;
      expTypeFuncMap.clear();
   }

   /** Gets the name of keyword from its type. Type is stored in the database
     * \param kw_type Type of keyword
     * \param key_word Keyword name is stored in this string
     */
   int getKeywordFromType
       (
	  unsigned int kw_type,
	  string & key_word
       );

   /** Fetches the *INCLUDE keywords from database and returns 0 if not found 
     * else number of keywords obtained
     */
   unsigned int dbReadIncludes();

   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *DAMPING keyword types and their function pointers
     */
   void initExportCompensateTypesAndFunctions();

   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *INCLUDE keyword types and their function pointers
     */
   void initExportIncludeTypesAndFunctions();

private:
   string            modelName;
   IncludeManager    *includeManPtr;
   /** Connection object for accessing the data */
   GoldenConn        *goldenConn;
   /** Object to store the data imported from database */
   ImportObject      *impObj;
   /** A map between type of keyword and pointer to the function to be called */
   map<unsigned int, ExportFunctionPtr>  expTypeFuncMap;
};

#endif

