#include <iostream>
#include <algorithm>
#include "generic.h"
#include "initialtype.h"
#include "initialexport.h"
#include <stdlib.h>

using namespace std;

InitialExport::InitialExport
(
   char            *model_name,
   GoldenConn      *gold_conn,
   InitialManager  *initial_man
)
{
   modelName = model_name;
   initialManPtr = initial_man;
   goldenConn = gold_conn;

   initExportSimpleTypesAndFunctions();
   initExportStrainTypesAndFunctions();
   initExportStressTypesAndFunctions();
   initExportVelocityTypesAndFunctions();
   initExportVolumeTypesAndFunctions();
}

int InitialExport::getKeywordFromType
    (
       unsigned int kw_type,
       string & key_word
    )
{
   switch(kw_type)
   {
      case INITIAL_DETONATION:
	 key_word = "*INITIAL_DETONATION";
	 break;
      case INITIAL_GAS_MIXTURE:
	 key_word = "*INITIAL_GAS_MIXTURE";
	 break;
      case INITIAL_MOMENTUM:
	 key_word = "*INITIAL_MOMENTUM";
	 break;
      case INITIAL_VEHICLE_KINEMATICS:
	 key_word = "*INITIAL_VEHICLE_KINEMATICS";
	 break;
      case INITIAL_FOAM_REFERENCE_GEOMETRY:
	 key_word = "*INITIAL_FOAM_REFERENCE_GEOMETRY";
	 break;
      case INITIAL_STRAIN_SHELL:
	 key_word = "*INITIAL_STRAIN_SHELL";
	 break;
      case INITIAL_STRAIN_SOLID:
	 key_word = "*INITIAL_STRAIN_SOLID";
	 break;
      case INITIAL_TEMPERATURE_NODE:
	 key_word = "*INITIAL_TEMPERATURE_NODE";
	 break;
      case INITIAL_TEMPERATURE_SET:
	 key_word = "*INITIAL_TEMPERATURE_SET";
	 break;
      case INITIAL_STRESS_BEAM:
	 key_word = "*INITIAL_STRESS_BEAM";
	 break;
      case INITIAL_STRESS_DEPTH:
	 key_word = "*INITIAL_STRESS_DEPTH";
	 break;
      case INITIAL_STRESS_SECTION:
	 key_word = "*INITIAL_STRESS_SECTION";
	 break;
      case INITIAL_STRESS_SHELL:
	 key_word = "*INITIAL_STRESS_SHELL";
	 break;
      case INITIAL_STRESS_SHELL_SET:
	 key_word = "*INITIAL_STRESS_SHELL_SET";
	 break;
      case INITIAL_STRESS_SOLID:
	 key_word = "*INITIAL_STRESS_SOLID";
	 break;
      case INITIAL_STRESS_TSHELL:
	 key_word = "*INITIAL_STRESS_TSHELL";
	 break;
      case INITIAL_VELOCITY:
	 key_word = "*INITIAL_VELOCITY";
	 break;
      case INITIAL_VELOCITY_GENERATION:
	 key_word = "*INITIAL_VELOCITY_GENERATION";
	 break;
      case INITIAL_VELOCITY_NODE:
	 key_word = "*INITIAL_VELOCITY_NODE";
	 break;
      case INITIAL_VELOCITY_RIGID_BODY:
	 key_word = "*INITIAL_VELOCITY_RIGID_BODY";
	 break;
      case INITIAL_VOID_PART:
	 key_word = "*INITIAL_VOID_PART";
	 break;
      case INITIAL_VOID_SET:
	 key_word = "*INITIAL_VOID_SET";
	 break;
      case INITIAL_VOLUME_FRACTION:
	 key_word = "*INITIAL_VOLUME_FRACTION";
	 break;
      case INITIAL_VOLUME_FRACTION_GEOMETRY:
	 key_word = "*INITIAL_VOLUME_FRACTION_GEOMETRY";
	 break;
      case INITIAL_NEW_TYPE:
      default:
         return 1;
   }
   return 0;
}

unsigned int InitialExport::dbReadInitials()
{
   char         **row_data, buf[16];
   unsigned int	i, num_initials = 0, total_initials = 0, num_kw_types = 0;
   expTypeFuncIterator eexp_iter = expTypeFuncMap.end(), exp_iter;

   string       qry = "select kw_type from ", kw_str;
   string table_name = "`" + modelName + "_INITIALS`";
   qry += table_name;
   qry += " group by kw_type;";

cout << "KW QRY = " << qry << endl;

   if( goldenConn->executeQuery( qry.data() ) )
      return 0;

   num_kw_types = goldenConn->numRows();

   if( !num_kw_types )
      return 0;

   unsigned int *kw_types = new unsigned int[num_kw_types];

   for(i = 0; i < num_kw_types; i++)
   {
      row_data = goldenConn->nextRow();
      kw_types[i] = atoi( row_data[0] );
cout << "KW INITIAL TYPE = " << kw_types[i] << endl;
   }

   for(i = 0; i < num_kw_types; i++)
   {
      if( getKeywordFromType(kw_types[i], kw_str) )
         continue;

cout << "INITIAL KW = " << kw_str << endl;

      qry = "select * from ";
      qry += table_name;
      qry += " where kw_type=";
      sprintf(buf, "%u", kw_types[i]);
      qry += buf;
      qry += " order by card_index;";

cout << "INITIAL QRY = " << qry << endl;

      if( goldenConn->executeQuery( qry.data() ) )
	 break;

      exp_iter = expTypeFuncMap.find(kw_types[i]);

      if( exp_iter == eexp_iter )
      {
	 cout << "INITIAL TYPE NOT FOUND" << endl;
         continue;
      }

      num_initials = 0;
      while( goldenConn->rowsLeft() )
      {
         impObj = new ExportObject((char *)kw_str.data(), kw_types[i]);
         goldenConn->clearFlag(KW_DATA_END);
	 (exp_iter->second)(goldenConn, impObj);
	 if( impObj->cardCount )
         {
	    initialManPtr->add(kw_str.data(), impObj);
	    num_initials++;
         }
	 else
	    delete impObj;
      }

      total_initials += num_initials;
   }

   delete kw_types;

   return total_initials;
}

