#ifndef _DBINITIALSTRESSSECTION_H_
#define _DBINITIALSTRESSSECTION_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *INITIAL_STRESS_SECTION
  * keyword */

class DBInitialStressSection : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBInitialStressSection(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBInitialStressSection()
   {
   }

public:
/** Function to get Card1 details for *INITIAL_STRESS_SECTION
  * keyword from database */
   void dbReadCard1(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"ISSID","CSID","LCID","PSID","VID",};
      unsigned int field_types[] = {DATA_INT, DATA_CHAR_ARRAY, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {1, 2, 3, 4, };
      unsigned int man_types[] = {DATABASE, DEFINE, SET, DEFINE, };
      unsigned int kw_types[] = {9999, CURVE, PARTC, VECTOR, };
      unsigned int num_indices = 4;
      numFields = 5;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 2, DEFINE, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card1");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card1",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *INITIAL_STRESS_SECTION
  * from database */
   unsigned int importDBInitialStressSection()
   {
      dbReadCard1();
      return 0;
   }
};

#endif

