#ifndef _DBINITIALSTRESSSOLID_H_
#define _DBINITIALSTRESSSOLID_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *INITIAL_STRESS_SOLID
  * keyword */

class DBInitialStressSolid : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBInitialStressSolid(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBInitialStressSolid()
   {
   }

public:
/** Function to get Card1 details for *INITIAL_STRESS_SOLID
  * keyword from database */
   int dbReadCard1(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"EID","NINT","NHISV","LARGE","IVFLG",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {ELEMENT, };
      unsigned int kw_types[] = {SOLID, };
      unsigned int num_indices = 1;
      numFields = 5;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return 0;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, INITIAL, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      nint = 0;
      if( wordArray[3] )
         nint = atoi(wordArray[3]);
      nhisv = 0;
      if( wordArray[4] )
         nhisv = atoi(wordArray[4]);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card1");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card1",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
      if( wordArray[5] )
         return atoi(wordArray[5]);
      else
         return 0;
   }

/** Function to get Card2 details for *INITIAL_STRESS_SOLID
  * keyword from database */
   void dbReadCard2(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"SIGXX","SIGYY","SIGZZ","SIGXY","SIGYZ","SIGZX","EPS",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 7;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, };
      unsigned int end_loop;
      end_loop = nint;
      for(loop_count = 0; loop_count < end_loop; loop_count++)
      {
         numFields = 7;
         wordArray = goldenConn->nextCard();
         if( !wordArray )
         {
            numFields = 0;
         return;
         }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, INITIAL, impObj);
         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card2",loop_count);
            cardObj = new DBCard(name_buf);
            ((DBCard *)cardObj)->index = atoi(wordArray[0]);
            cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
            impObj->addCard(cardObj);
         }
         impObj->cardCount++;
      }
   }

/** Function to get Card3 details for *INITIAL_STRESS_SOLID
  * keyword from database */
   void dbReadCard3(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"SIGXX","SIGYY","SIGZZ","SIGXY","SIGYZ",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 5;
      unsigned int field_widths[] = {16, 16, 16, 16, 16, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card3");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card3",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card4 details for *INITIAL_STRESS_SOLID
  * keyword from database */
   void dbReadCard4(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"SIGZX","EPS","HISV1","HISV2","HISV3",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 5;
      unsigned int field_widths[] = {16, 16, 16, 16, 16, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card4");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card4",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card5 details for *INITIAL_STRESS_SOLID
  * keyword from database */
   void dbReadCard5(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"HISV4","HISV5","HISV6","HISV7","HISV8",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 5;
      unsigned int field_widths[] = {16, 16, 16, 16, 16, };
      unsigned int end_loop;
      end_loop = (((nhisv - 3)%5) ? ((nhisv-3)/5)+1 : (nhisv-3)/5);
      for(loop_count = 0; loop_count < end_loop; loop_count++)
      {
         numFields = 5;
         wordArray = goldenConn->nextCard();
         if( !wordArray )
         {
            numFields = 0;
         return;
         }
         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card5",loop_count);
            cardObj = new DBCard(name_buf);
            ((DBCard *)cardObj)->index = atoi(wordArray[0]);
            cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
            impObj->addCard(cardObj);
         }
         impObj->cardCount++;
      }
   }

/** Function to import all the cards of keyword *INITIAL_STRESS_SOLID
  * from database */
   unsigned int importDBInitialStressSolid()
   {
      int large = 0;
      large = dbReadCard1();
      if( large == 0 )
      {
         dbReadCard2();
      }
      if( large == 1 )
      {
         for(int i = 0; i < nint; i++)
         {
            dbReadCard3();
            dbReadCard4();
            if( nhisv > 3 )
            {
               dbReadCard5();
            }
         }
      }
      return 0;
   }
public:
   int nint;
   int nhisv;
};

#endif

