#ifndef _DBINITIALVOLUMEFRACTIONGEOMETRY_H_
#define _DBINITIALVOLUMEFRACTIONGEOMETRY_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *INITIAL_VOLUME_FRACTION_GEOMETRY
  * keyword */

class DBInitialVolumeFractionGeometry : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBInitialVolumeFractionGeometry(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBInitialVolumeFractionGeometry()
   {
   }

public:
/** Function to get Card1 details for *INITIAL_VOLUME_FRACTION_GEOMETRY
  * keyword from database */
   void dbReadCard1(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"FMSID","FMIDTYP","BAMMG","NTRACE",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 4;
      unsigned int field_widths[] = {10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, INITIAL, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         initialGasFind(&wordArray[2], numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card1");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card1",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Carda details for *INITIAL_VOLUME_FRACTION_GEOMETRY
  * keyword from database */
   int dbReadCarda(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"CONTTYP","FILLOPT","FAMMG",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {2, };
      unsigned int man_types[] = {ALE, };
      unsigned int kw_types[] = {MMG, };
      unsigned int num_indices = 1;
      numFields = 3;
      unsigned int field_widths[] = {10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return 0;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, INITIAL, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Carda");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Carda",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
      if( wordArray[2] )
         return atoi(wordArray[2]);
      else
         return 0;
   }

/** Function to get Cardb1 details for *INITIAL_VOLUME_FRACTION_GEOMETRY
  * keyword from database */
   void dbReadCardb1(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"SID","STYPE","NORMDIR","XOFFSET",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, };
      numFields = 4;
      unsigned int field_widths[] = {10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_REFERENCES) )
         airbagVentHoleFind(&wordArray[2], numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Cardb1");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Cardb1",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Cardb2 details for *INITIAL_VOLUME_FRACTION_GEOMETRY
  * keyword from database */
   void dbReadCardb2(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"SGSID","NORMDIR","XOFFSET",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {SET, };
      unsigned int kw_types[] = {SEGMENT, };
      unsigned int num_indices = 1;
      numFields = 3;
      unsigned int field_widths[] = {10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Cardb2");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Cardb2",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Cardb3 details for *INITIAL_VOLUME_FRACTION_GEOMETRY
  * keyword from database */
   void dbReadCardb3(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"X0","Y0","Z0","XCOS","YCOS","ZCOS",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Cardb3");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Cardb3",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Cardb4 details for *INITIAL_VOLUME_FRACTION_GEOMETRY
  * keyword from database */
   void dbReadCardb4(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"X0","Y0","Z0","X1","Y1","Z1","R1","R2",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Cardb4");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Cardb4",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Cardb5 details for *INITIAL_VOLUME_FRACTION_GEOMETRY
  * keyword from database */
   void dbReadCardb5(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"X0","Y0","Z0","X1","Y1","Z1",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Cardb5");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Cardb5",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Cardb6 details for *INITIAL_VOLUME_FRACTION_GEOMETRY
  * keyword from database */
   void dbReadCardb6(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"X0","Y0","Z0","R0",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 4;
      unsigned int field_widths[] = {10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Cardb6");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Cardb6",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *INITIAL_VOLUME_FRACTION_GEOMETRY
  * from database */
   unsigned int importDBInitialVolumeFractionGeometry()
   {
      int conttyp = 0;
      dbReadCard1();
      unsigned int loop_count = 0;
      conttyp = dbReadCarda(loop_count);
      if( conttyp == 1 )
      {
         dbReadCardb1(loop_count);
      }
      else if( conttyp == 2 )
      {
         dbReadCardb2(loop_count);
      }
      else if( conttyp == 3 )
      {
         dbReadCardb3(loop_count);
      }
      else if( conttyp == 4 )
      {
         dbReadCardb4(loop_count);
      }
      else if( conttyp == 5 )
      {
         dbReadCardb5(loop_count);
      }
      else if( conttyp == 6 )
      {
         dbReadCardb6(loop_count);
      }
      loop_count++;
      while(numFields)
      {
         conttyp = dbReadCarda(loop_count);
         if( conttyp == 1 )
         {
            dbReadCardb1(loop_count);
         }
         else if( conttyp == 2 )
         {
            dbReadCardb2(loop_count);
         }
         else if( conttyp == 3 )
         {
            dbReadCardb3(loop_count);
         }
         else if( conttyp == 4 )
         {
            dbReadCardb4(loop_count);
         }
         else if( conttyp == 5 )
         {
            dbReadCardb5(loop_count);
         }
         else if( conttyp == 6 )
         {
            dbReadCardb6(loop_count);
         }
         loop_count++;
      }
      ((ExportObject *)impObj)->loopCount = loop_count-1;
      return 0;
   }
};

#endif

