#ifndef _DBINTEGRATIONSHELL_H_
#define _DBINTEGRATIONSHELL_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *INTEGRATION_SHELL
  * keyword */

class DBIntegrationShell : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBIntegrationShell(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBIntegrationShell()
   {
   }

public:
/** Function to get Card1 details for *INTEGRATION_SHELL
  * keyword from database */
   int dbReadCard1(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"IRID","NIP","ESOP","FAILOPT",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 4;
      unsigned int field_widths[] = {10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return 0;
      }
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 2, INTEGRATION, impObj);
      nip = 0;
      if( wordArray[3] )
         nip = atoi(wordArray[3]);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card1");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card1",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
      if( wordArray[4] )
         return atoi(wordArray[4]);
      else
         return 0;
   }

/** Function to get Card2 details for *INTEGRATION_SHELL
  * keyword from database */
   void dbReadCard2(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"S","WF","PID",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_INT, };
      unsigned int field_indices[] = {2, };
      unsigned int man_types[] = {PARTC, };
      unsigned int kw_types[] = {9999, };
      unsigned int num_indices = 1;
      numFields = 3;
      unsigned int field_widths[] = {10, 10, 10, };
      unsigned int end_loop;
      end_loop = nip;
      for(loop_count = 0; loop_count < end_loop; loop_count++)
      {
         numFields = 3;
         wordArray = goldenConn->nextCard();
         if( !wordArray )
         {
            numFields = 0;
         return;
         }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, INTEGRATION, impObj);
         if( Card::isFlagOn(SAVE_REFERENCES) )
            addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card2",loop_count);
            cardObj = new DBCard(name_buf);
            ((DBCard *)cardObj)->index = atoi(wordArray[0]);
            cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
            impObj->addCard(cardObj);
         }
         impObj->cardCount++;
      }
   }

/** Function to import all the cards of keyword *INTEGRATION_SHELL
  * from database */
   unsigned int importDBIntegrationShell()
   {
      int esop = 0;
      esop = dbReadCard1();
      if( esop == 0 )
      {
         dbReadCard2();
      }
      return 0;
   }
public:
   int nip;
};

#endif

