#include <iostream>
#include <algorithm>
#include "generic.h"
#include "integrationtype.h"
#include "integrationexport.h"
#include <stdlib.h>

using namespace std;

IntegrationExport::IntegrationExport
(
   char         *model_name,
   GoldenConn   *gold_conn,
   IntegrationManager    *integration_man
)
{
   modelName = model_name;
   integrationManPtr = integration_man;
   goldenConn = gold_conn;
   
   initExportIntegrationTypesAndFunctions();
}

int IntegrationExport::getKeywordFromType
    (
       unsigned int kw_type,
       string & key_word
    )
{
   switch(kw_type)
   {
      case INTEGRATION_BEAM:
	 key_word = "*INTEGRATION_BEAM";
	 break;
      case INTEGRATION_SHELL:
	 key_word = "*INTEGRATION_SHELL";
	 break;
      case INTEGRATION_NEW_TYPE:
      default:
         return 1;
   }
   return 0;
}

unsigned int IntegrationExport::dbReadIntegrations()
{
   char         **row_data, buf[16];
   unsigned int	i, num_integrations = 0, total_integrations = 0, 
                num_kw_types = 0;
   expTypeFuncIterator eexp_iter = expTypeFuncMap.end(), exp_iter;

   string       qry = "select kw_type from ", kw_str;
   string table_name = "`" + modelName + "_INTEGRATIONS`";
   qry += table_name;
   qry += " group by kw_type;";

cout << "KW QRY = " << qry << endl;

   if( goldenConn->executeQuery( qry.data() ) )
      return 0;

   num_kw_types = goldenConn->numRows();

   if( !num_kw_types )
      return 0;

   unsigned int *kw_types = new unsigned int[num_kw_types];

   for(i = 0; i < num_kw_types; i++)
   {
      row_data = goldenConn->nextRow();
      kw_types[i] = atoi( row_data[0] );
cout << "KW INTEGRATION TYPE = " << kw_types[i] << endl;
   }

   for(i = 0; i < num_kw_types; i++)
   {
      if( getKeywordFromType(kw_types[i], kw_str) )
         continue;

cout << "INTEGRATION KW = " << kw_str << endl;

      qry = "select * from ";
      qry += table_name;
      qry += " where kw_type=";
      sprintf(buf, "%u", kw_types[i]);
      qry += buf;
      qry += " order by card_index;";

cout << "INTEGRATION QRY = " << qry << endl;

      if( goldenConn->executeQuery( qry.data() ) )
	 break;

      exp_iter = expTypeFuncMap.find(kw_types[i]);

      if( exp_iter == eexp_iter )
      {
	 cout << "INTEGRATION TYPE NOT FOUND" << endl;
         continue;
      }

      num_integrations = 0;
      while( goldenConn->rowsLeft() )
      {
         impObj = new ExportObject((char *)kw_str.data(), kw_types[i]);
         goldenConn->clearFlag(KW_DATA_END);
	 (exp_iter->second)(goldenConn, impObj);
	 if( impObj->cardCount )
	 {
	    integrationManPtr->add(kw_str.data(), impObj);
	    num_integrations++;
	 }
	 else
	    delete impObj;
      }

      total_integrations += num_integrations;
   }

   delete kw_types;

   return total_integrations;
}

