#include <iostream>
#include <algorithm>
#include "generic.h"
#include "interfacetype.h"
#include "interfaceexport.h"
#include <stdlib.h>

using namespace std;

InterfaceExport::InterfaceExport
(
   char              *model_name,
   GoldenConn        *gold_conn,
   InterfaceManager  *interface_man
)
{
   modelName = model_name;
   interfaceManPtr = interface_man;
   goldenConn = gold_conn;
   
   initExportInterfaceTypesAndFunctions();
}

int InterfaceExport::getKeywordFromType
    (
       unsigned int kw_type,
       string & key_word
    )
{
   switch(kw_type)
   {
      case INTERFACE_COMPENSATION_NEW:
	 key_word = "*INTERFACE_COMPENSATION_NEW";
	 break;
      case INTERFACE_COMPONENT_NODE:
	 key_word = "*INTERFACE_COMPONENT_NODE";
	 break;
      case INTERFACE_COMPONENT_SEGMENT:
	 key_word = "*INTERFACE_COMPONENT_SEGMENT";
	 break;
      case INTERFACE_JOY:
	 key_word = "*INTERFACE_JOY";
	 break;
      case INTERFACE_LINKING_DISCRETE_NODE_NODE:
	 key_word = "*INTERFACE_LINKING_DISCRETE_NODE_NODE";
	 break;
      case INTERFACE_LINKING_DISCRETE_NODE_SET:
	 key_word = "*INTERFACE_LINKING_DISCRETE_NODE_SET";
	 break;
      case INTERFACE_LINKING_EDGE:
	 key_word = "*INTERFACE_LINKING_EDGE";
	 break;
      case INTERFACE_LINKING_SEGMENT:
	 key_word = "*INTERFACE_LINKING_SEGMENT";
	 break;
      case INTERFACE_SPRINGBACK_LSDYNA_NOTHICKNESS:
	 key_word = "*INTERFACE_SPRINGBACK_LSDYNA_NOTHICKNESS";
	 break;
      case INTERFACE_SPRINGBACK_LSDYNA_THICKNESS:
	 key_word = "*INTERFACE_SPRINGBACK_LSDYNA_THICKNESS";
	 break;
      case INTERFACE_SPRINGBACK_NASTRAN_NOTHICKNESS:
	 key_word = "*INTERFACE_SPRINGBACK_NASTRAN_NOTHICKNESS";
	 break;
      case INTERFACE_SPRINGBACK_NASTRAN_THICKNESS:
	 key_word = "*INTERFACE_SPRINGBACK_NASTRAN_THICKNESS";
	 break;
      case INTERFACE_SPRINGBACK_SEAMLESS_NOTHICKNESS:
	 key_word = "*INTERFACE_SPRINGBACK_SEAMLESS_NOTHICKNESS";
	 break;
      case INTERFACE_SPRINGBACK_SEAMLESS_THICKNESS:
	 key_word = "*INTERFACE_SPRINGBACK_SEAMLESS_THICKNESS";
	 break;
      case INTERFACE_NEW_TYPE:
      default:
         return 1;
   }
   return 0;
}

unsigned int InterfaceExport::dbReadInterfaces()
{
   char         **row_data, buf[16];
   unsigned int	i, num_interfaces = 0, total_interfaces = 0, 
                num_kw_types = 0;
   expTypeFuncIterator eexp_iter = expTypeFuncMap.end(), exp_iter;

   string       qry = "select kw_type from ", kw_str;
   string table_name = "`" + modelName + "_INTERFACES`";
   qry += table_name;
   qry += " group by kw_type;";

cout << "KW QRY = " << qry << endl;

   if( goldenConn->executeQuery( qry.data() ) )
      return 0;

   num_kw_types = goldenConn->numRows();

   if( !num_kw_types )
      return 0;

   unsigned int *kw_types = new unsigned int[num_kw_types];

   for(i = 0; i < num_kw_types; i++)
   {
      row_data = goldenConn->nextRow();
      kw_types[i] = atoi( row_data[0] );
cout << "KW INTERFACE TYPE = " << kw_types[i] << endl;
   }

   for(i = 0; i < num_kw_types; i++)
   {
      if( getKeywordFromType(kw_types[i], kw_str) )
         continue;

cout << "INTERFACE KW = " << kw_str << endl;

      qry = "select * from ";
      qry += table_name;
      qry += " where kw_type=";
      sprintf(buf, "%u", kw_types[i]);
      qry += buf;
      qry += " order by card_index;";

cout << "INTERFACE QRY = " << qry << endl;

      if( goldenConn->executeQuery( qry.data() ) )
	 break;

      exp_iter = expTypeFuncMap.find(kw_types[i]);

      if( exp_iter == eexp_iter )
      {
	 cout << "INTERFACE TYPE NOT FOUND" << endl;
         continue;
      }

      num_interfaces = 0;
      while( goldenConn->rowsLeft() )
      {
	 impObj = new ExportObject((char *)kw_str.data(), kw_types[i]);
         goldenConn->clearFlag(KW_DATA_END);
	 (exp_iter->second)(goldenConn, impObj);
	 if( impObj->cardCount )
	 {
	    interfaceManPtr->add(kw_str.data(), impObj);
	    num_interfaces++;
	 }
	 else
	    delete impObj;
      }

      total_interfaces += num_interfaces;
   }

   delete kw_types;

   return total_interfaces;
}

