#ifndef _KEYWORD_EXPORT_H_
#define _KEYWORD_EXPORT_H_

#include <string>
#include <map>
#include "goldenconn.h"
#include "controlmanager.h"
#include "dataline.h"
#include "dbcard.h"
#include "keywordtype.h"
#include "exptypemap.h"

/** Class for importing data from database for *KEYWORD type of keywords */
class KeywordExport
{
public:
   /** Constructor for creating this object. The *KEYWORD and *TITLE are stored
     * in the _CONTROLS table in database
     * \param model_name Name of the model
     * \param gold_conn Connection object to access database
     * \param control_man Manager pointer to which the data to be appended
     */
   KeywordExport
   (
      char           *model_name,
      GoldenConn   *gold_conn,
      ControlManager    *control_man
   );

   ~KeywordExport()
   {
      controlManPtr = NULL;
      goldenConn = NULL;
      expTypeFuncMap.clear();
   }

   /** Gets the keyword string from the given keyword type
     * \param kw_type Type of keyword related to *KEYWORD
     * \param key_word Name of the keyword as string
     * \return Returns 0 on success else 1
     */
   int getKeywordFromType
       (
	  unsigned int kw_type,
	  string & key_word
       );

   /** Reads the *KEYWORD and *TITLE keywords from database.
     * \return Returns 1 on success else 0
     */
   unsigned int dbReadKWAndTitle();

   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *KEYWORD keyword types and their function pointers
     */
   void initExportKeywordTypesAndFunctions();

private:
   string            modelName;
   ControlManager    *controlManPtr;
   /** Connection object for accessing the data */
   GoldenConn        *goldenConn;
   /** Object to store the data imported from database */
   ImportObject      *impObj;
   /** A map between type of keyword and pointer to the function to be called */
   map<unsigned int, ExportFunctionPtr>  expTypeFuncMap;
};

#endif

