#ifndef _DBLOADMOVINGPRESSURE_H_
#define _DBLOADMOVINGPRESSURE_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *LOAD_MOVING_PRESSURE
  * keyword */

class DBLoadMovingPressure : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBLoadMovingPressure(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBLoadMovingPressure()
   {
   }

public:
/** Function to get Card1 details for *LOAD_MOVING_PRESSURE
  * keyword from database */
   void dbReadCard1(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"LOADID",};
      unsigned int field_types[] = {DATA_INT, };
      numFields = 1;
      unsigned int field_widths[] = {10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 2, LOAD, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card1");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card1",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Cardn details for *LOAD_MOVING_PRESSURE
  * keyword from database */
   void dbReadCardn(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"NODE1","NODE2","LCID","CUTOFF","LCIDT",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, 4, };
      unsigned int man_types[] = {NOD, NOD, DEFINE, DEFINE, };
      unsigned int kw_types[] = {9999, 9999, CURVE, CURVE, };
      unsigned int num_indices = 4;
      numFields = 5;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, LOAD, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Cardn");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Cardn",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get CardnPlus1 details for *LOAD_MOVING_PRESSURE
  * keyword from database */
   void dbReadCardnPlus1(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"ID","IDTYPE","NIP",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, };
      numFields = 3;
      unsigned int field_widths[] = {10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, LOAD, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         loadMovingPressureFind(&wordArray[2], numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("CardnPlus1");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","CardnPlus1",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *LOAD_MOVING_PRESSURE
  * from database */
   unsigned int importDBLoadMovingPressure()
   {
      dbReadCard1();
      dbReadCardn();
      dbReadCardnPlus1();
      return 0;
   }
};

#endif

