#ifndef _DBLOADSHELLELEMENT_H_
#define _DBLOADSHELLELEMENT_H_

#include "manager.h"
#include "dispexport.h"
#include "dbloadid.h"

/** Class used for getting data from database for *LOAD_SHELL_ELEMENT
  * keyword */

class DBLoadShellElement : public DBLoadID
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBLoadShellElement(GoldenConn *gold_conn, ImportObject *imp_obj) : DBLoadID (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBLoadShellElement()
   {
   }

public:
/** Function to get Card1 details for *LOAD_SHELL_ELEMENT
  * keyword from database */
   void dbReadCard1(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"EID/ESID","LCID","SF","AT",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 4;
      unsigned int field_widths[] = {10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, LOAD, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         loadShellFind(&wordArray[2], numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card1");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card1",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *LOAD_SHELL_ELEMENT
  * from database */
   unsigned int importDBLoadShellElement()
   {
      importDBLoadID();
      dbReadCard1();
      return 0;
   }
};

#endif

