#include <iostream>
#include <algorithm>
#include "generic.h"
#include "loadtype.h"
#include "loadexport.h"
#include <stdlib.h>

using namespace std;

LoadExport::LoadExport
(
   char         *model_name,
   GoldenConn   *gold_conn,
   LoadManager    *load_man
)
{
   modelName = model_name;
   loadManPtr = load_man;
   goldenConn = gold_conn;
   
   initExportBodyTypesAndFunctions();
   initExportElementTypesAndFunctions();
   initExportSegmentTypesAndFunctions();
   initExportSimpleTypesAndFunctions();
   initExportThermalTypesAndFunctions();
}

int LoadExport::getKeywordFromType
    (
       unsigned int kw_type,
       string & key_word
    )
{
   switch(kw_type)
   {
      case LOAD_BODY_GENERALIZED:
	 key_word = "*LOAD_BODY_GENERALIZED";
	 break;
      case LOAD_BODY_PARTS:
	 key_word = "*LOAD_BODY_PARTS";
	 break;
      case LOAD_BODY_POROUS:
	 key_word = "*LOAD_BODY_POROUS";
	 break;
      case LOAD_BODY_RX:
	 key_word = "*LOAD_BODY_RX";
	 break;
      case LOAD_BODY_RY:
	 key_word = "*LOAD_BODY_RY";
	 break;
      case LOAD_BODY_RZ:
	 key_word = "*LOAD_BODY_RZ";
	 break;
      case LOAD_BODY_X:
	 key_word = "*LOAD_BODY_X";
	 break;
      case LOAD_BODY_Y:
	 key_word = "*LOAD_BODY_Y";
	 break;
      case LOAD_BODY_Z:
	 key_word = "*LOAD_BODY_Z";
	 break;
      case LOAD_GRAVITY_PART:
	 key_word = "*LOAD_GRAVITY_PART";
	 break;
      case LOAD_REMOVE_PART:
	 key_word = "*LOAD_REMOVE_PART";
	 break;
      case LOAD_STIFFEN_PART:
	 key_word = "*LOAD_STIFFEN_PART";
	 break;
      case LOAD_BEAM_ELEMENT:
	 key_word = "*LOAD_BEAM_ELEMENT";
	 break;
      case LOAD_BEAM_SET:
	 key_word = "*LOAD_BEAM_SET";
	 break;
      case LOAD_HEAT_GENERATION_SET:
	 key_word = "*LOAD_HEAT_GENERATION_SET";
	 break;
      case LOAD_HEAT_GENERATION_SOLID:
	 key_word = "*LOAD_HEAT_GENERATION_SOLID";
	 break;
      case LOAD_MOVING_PRESSURE:
	 key_word = "*LOAD_MOVING_PRESSURE";
	 break;
      case LOAD_RIGID_BODY:
	 key_word = "*LOAD_RIGID_BODY";
	 break;
      case LOAD_SHELL_ELEMENT:
	 key_word = "*LOAD_SHELL_ELEMENT";
	 break;
      case LOAD_SHELL_ELEMENT_ID:
	 key_word = "*LOAD_SHELL_ELEMENT_ID";
	 break;
      case LOAD_SHELL_SET:
	 key_word = "*LOAD_SHELL_SET";
	 break;
      case LOAD_SHELL_SET_ID:
	 key_word = "*LOAD_SHELL_SET_ID";
	 break;
      case LOAD_SUPERPLASTIC_FORMING:
	 key_word = "*LOAD_SUPERPLASTIC_FORMING";
	 break;
      case LOAD_SURFACE_STRESS:
	 key_word = "*LOAD_SURFACE_STRESS";
	 break;
      case LOAD_SURFACE_STRESS_SET:
	 key_word = "*LOAD_SURFACE_STRESS_SET";
	 break;
      case LOAD_HEAT_CONTROLLER:
	 key_word = "*LOAD_HEAT_CONTROLLER";
	 break;
      case LOAD_MOTION_NODE:
	 key_word = "*LOAD_MOTION_NODE";
	 break;
      case LOAD_NODE_POINT:
	 key_word = "*LOAD_NODE_POINT";
	 break;
      case LOAD_NODE_SET:
	 key_word = "*LOAD_NODE_SET";
	 break;
      case LOAD_SEGMENT:
	 key_word = "*LOAD_SEGMENT";
	 break;
      case LOAD_SEGMENT_ID:
	 key_word = "*LOAD_SEGMENT_ID";
	 break;
      case LOAD_SEGMENT_NONUNIFORM:
	 key_word = "*LOAD_SEGMENT_NONUNIFORM";
	 break;
      case LOAD_SEGMENT_NONUNIFORM_ID:
	 key_word = "*LOAD_SEGMENT_NONUNIFORM_ID";
	 break;
      case LOAD_SEGMENT_SET:
	 key_word = "*LOAD_SEGMENT_SET";
	 break;
      case LOAD_SEGMENT_SET_ID:
	 key_word = "*LOAD_SEGMENT_SET_ID";
	 break;
      case LOAD_SEGMENT_SET_NONUNIFORM:
	 key_word = "*LOAD_SEGMENT_SET_NONUNIFORM";
	 break;
      case LOAD_SEGMENT_SET_NONUNIFORM_ID:
	 key_word = "*LOAD_SEGMENT_SET_NONUNIFORM_ID";
	 break;
      case LOAD_ALE_CONVECTION:
	 key_word = "*LOAD_ALE_CONVECTION";
	 break;
      case LOAD_ALE_CONVECTION_ID:
	 key_word = "*LOAD_ALE_CONVECTION_ID";
	 break;
      case LOAD_BLAST:
	 key_word = "*LOAD_BLAST";
	 break;
      case LOAD_BRODE:
	 key_word = "*LOAD_BRODE";
	 break;
      case LOAD_DENSITY_DEPTH:
	 key_word = "*LOAD_DENSITY_DEPTH";
	 break;
      case LOAD_MASK:
	 key_word = "*LOAD_MASK";
	 break;
      case LOAD_SSA:
	 key_word = "*LOAD_SSA";
	 break;
      case LOAD_VOLUME_LOSS:
	 key_word = "*LOAD_VOLUME_LOSS";
	 break;
      case LOAD_THERMAL_CONSTANT:
	 key_word = "*LOAD_THERMAL_CONSTANT";
	 break;
      case LOAD_THERMAL_CONSTANT_NODE:
	 key_word = "*LOAD_THERMAL_CONSTANT_NODE";
	 break;
      case LOAD_THERMAL_LOAD_CURVE:
	 key_word = "*LOAD_THERMAL_LOAD_CURVE";
	 break;
      case LOAD_THERMAL_TOPAZ:
	 key_word = "*LOAD_THERMAL_TOPAZ";
	 break;
      case LOAD_THERMAL_VARIABLE:
	 key_word = "*LOAD_THERMAL_VARIABLE";
	 break;
      case LOAD_THERMAL_VARIABLE_NODE:
	 key_word = "*LOAD_THERMAL_VARIABLE_NODE";
	 break;
      case LOAD_THERMAL_VARIABLE_SHELL:
	 key_word = "*LOAD_THERMAL_VARIABLE_SHELL";
	 break;
      case LOAD_THERMAL_VARIABLE_SHELL_SET:
	 key_word = "*LOAD_THERMAL_VARIABLE_SHELL_SET";
	 break;
      case LOAD_NEW_TYPE:
      default:
         return 1;
   }
   return 0;
}

unsigned int LoadExport::dbReadLoads()
{
   char         **row_data, buf[16];
   unsigned int	i, num_loads = 0, total_loads = 0, num_kw_types = 0;
   expTypeFuncIterator eexp_iter = expTypeFuncMap.end(), exp_iter;

   string       qry = "select kw_type from ", kw_str;
   string table_name = "`" + modelName + "_LOADS`";
   qry += table_name;
   qry += " group by kw_type;";

cout << "KW QRY = " << qry << endl;

   if( goldenConn->executeQuery( qry.data() ) )
      return 0;

   num_kw_types = goldenConn->numRows();

   if( !num_kw_types )
      return 0;

   unsigned int *kw_types = new unsigned int[num_kw_types];

   for(i = 0; i < num_kw_types; i++)
   {
      row_data = goldenConn->nextRow();
      kw_types[i] = atoi( row_data[0] );
cout << "KW LOAD TYPE = " << kw_types[i] << endl;
   }

   for(i = 0; i < num_kw_types; i++)
   {
      if( getKeywordFromType(kw_types[i], kw_str) )
         continue;

cout << "LOAD KW = " << kw_str << endl;

      qry = "select * from ";
      qry += table_name;
      qry += " where kw_type=";
      sprintf(buf, "%u", kw_types[i]);
      qry += buf;
      qry += " order by card_index;";

cout << "LOAD QRY = " << qry << endl;

      if( goldenConn->executeQuery( qry.data() ) )
	 break;

      exp_iter = expTypeFuncMap.find(kw_types[i]);

      if( exp_iter == eexp_iter )
      {
	 cout << "LOAD TYPE NOT FOUND" << endl;
         continue;
      }

      num_loads = 0;
      while( goldenConn->rowsLeft() )
      {
	 impObj = new ExportObject((char *)kw_str.data(), kw_types[i]);
         goldenConn->clearFlag(KW_DATA_END);
	 (exp_iter->second)(goldenConn, impObj);
         //to take care of kws with no cards Feb21 2010
	 if( impObj->cardCount || ((ExportObject *)impObj)->noCardsIndex )
         {
	    loadManPtr->add(kw_str.data(), impObj);
	    num_loads++;
         }
	 else
	    delete impObj;
      }

      total_loads += num_loads;
   }

   delete kw_types;

   return total_loads;
}

