#ifndef _DBLOADMOTIONNODE_H_
#define _DBLOADMOTIONNODE_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *LOAD_MOTION_NODE
  * keyword */

class DBLoadMotionNode : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBLoadMotionNode(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBLoadMotionNode()
   {
   }

public:
/** Function to get Card details for *LOAD_MOTION_NODE
  * keyword from database */
   void dbReadCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"NODE1","DOF1","LCID","SF","CID1","NODE2","DOF2","CID2",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 2, 4, 5, 7, };
      unsigned int man_types[] = {NOD, DEFINE, DEFINE, NOD, DEFINE, };
      unsigned int kw_types[] = {9999, CURVE, COORDINATE, 9999, COORDINATE, };
      unsigned int num_indices = 5;
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, LOAD, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *LOAD_MOTION_NODE
  * from database */
   unsigned int importDBLoadMotionNode()
   {
      dbReadCard();
      return 0;
   }
};

#endif

