#ifndef _DBMATALEGASMIXTURE_H_
#define _DBMATALEGASMIXTURE_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *MAT_ALE_GAS_MIXTURE
  * keyword */

class DBMatAleGasMixture : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBMatAleGasMixture(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBMatAleGasMixture()
   {
   }

public:
/** Function to get Card1 details for *MAT_ALE_GAS_MIXTURE
  * keyword from database */
   double dbReadCard1(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"MID","IADIAB","RUNIV",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_INT, DATA_DOUBLE, };
      numFields = 3;
      unsigned int field_widths[] = {10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return 0.0;
      }
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 2, MAT, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card1");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card1",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
      if( wordArray[4] )
         return atof(wordArray[4]);
      else
         return 0;
   }

/** Function to get Card2RUNIV0 details for *MAT_ALE_GAS_MIXTURE
  * keyword from database */
   void dbReadCard2RUNIV0(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"CVmass1","CVmass2","CVmass3","CVmass4","CVmass5","CVmass6","CVmass7","Cvmass8",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, MAT, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card2RUNIV0");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card2RUNIV0",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card3RUNIV0 details for *MAT_ALE_GAS_MIXTURE
  * keyword from database */
   void dbReadCard3RUNIV0(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"CPmass1","CPmass2","CPmass3","CPmass4","CPmass5","CPmass6","CPmass7","Cpmass8",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, MAT, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card3RUNIV0");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card3RUNIV0",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card2RUNIV1 details for *MAT_ALE_GAS_MIXTURE
  * keyword from database */
   void dbReadCard2RUNIV1(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"MOLWT1","MOLWT2","MOLWT3","MOLWT4","MOLWT5","MOLWT6","MOLWT7","MOLWT8",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card2RUNIV1");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card2RUNIV1",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card3RUNIV1 details for *MAT_ALE_GAS_MIXTURE
  * keyword from database */
   void dbReadCard3RUNIV1(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"CPmole1","CPmole2","CPmole3","CPmole4","CPmole5","CPmole6","Cpmole7","CPmole8",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card3RUNIV1");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card3RUNIV1",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card4RUNIV1 details for *MAT_ALE_GAS_MIXTURE
  * keyword from database */
   void dbReadCard4RUNIV1(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"B1","B2","B3","B4","B5","B6","B7","B8",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card4RUNIV1");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card4RUNIV1",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card5RUNIV1 details for *MAT_ALE_GAS_MIXTURE
  * keyword from database */
   void dbReadCard5RUNIV1(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"C1","C2","C3","C4","C5","C6","C7","C8",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card5RUNIV1");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card5RUNIV1",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *MAT_ALE_GAS_MIXTURE
  * from database */
   unsigned int importDBMatAleGasMixture()
   {
      double runiv = 0.0;
      runiv = dbReadCard1();
      if( runiv == 0.0 )
      {
         dbReadCard2RUNIV0();
         dbReadCard3RUNIV0();
      }
      if( runiv != 0.0 )
      {
         dbReadCard2RUNIV1();
         dbReadCard3RUNIV1();
         dbReadCard4RUNIV1();
         dbReadCard5RUNIV1();
      }
      return 0;
   }
};

#endif

