#ifndef _DBMATTRANSVERSELYANISOTROPICELASTICPLASTICECHANGE_H_
#define _DBMATTRANSVERSELYANISOTROPICELASTICPLASTICECHANGE_H_

#include "manager.h"
#include "dispexport.h"
#include "dbmattransverselyanisotropicelasticplastic.h"

/** Class used for getting data from database for *MAT_TRANSVERSELY_ANISOTROPIC_ELASTIC_PLASTIC_ECHANGE
  * keyword */

class DBMatTransverselyAnisotropicElasticPlasticEchange : public DBMatTransverselyAnisotropicElasticPlastic
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBMatTransverselyAnisotropicElasticPlasticEchange(GoldenConn *gold_conn, ImportObject *imp_obj) : DBMatTransverselyAnisotropicElasticPlastic (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBMatTransverselyAnisotropicElasticPlasticEchange()
   {
   }

public:
/** Function to get CardExchange details for *MAT_TRANSVERSELY_ANISOTROPIC_ELASTIC_PLASTIC_ECHANGE
  * keyword from database */
   void dbReadCardExchange(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"IDSCALE","EA","COE",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 3;
      unsigned int field_widths[] = {10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, MAT, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("CardExchange");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","CardExchange",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *MAT_TRANSVERSELY_ANISOTROPIC_ELASTIC_PLASTIC_ECHANGE
  * from database */
   unsigned int importDBMatTransverselyAnisotropicElasticPlasticEchange()
   {
      importDBMatTransverselyAnisotropicElasticPlastic();
      dbReadCardExchange();
      return 0;
   }
};

#endif

