#ifndef _DBMATBARLATYLD2000_H_
#define _DBMATBARLATYLD2000_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *MAT_BARLAT_YLD2000
  * keyword */

class DBMatBarlatYld2000 : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBMatBarlatYld2000(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBMatBarlatYld2000()
   {
   }

public:
/** Function to get Card1 details for *MAT_BARLAT_YLD2000
  * keyword from database */
   int dbReadCard1(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"MID","RO","E","PR","FIT","BETA","ITER",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_INT, };
      numFields = 7;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return 0;
      }
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 2, MAT, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card1");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card1",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
      if( wordArray[6] )
         return atoi(wordArray[6]);
      else
         return 0;
   }

/** Function to get Card2 details for *MAT_BARLAT_YLD2000
  * keyword from database */
   void dbReadCard2(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"K","E0","N","C","P","HARD","A",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 7;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, MAT, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card2");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card2",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card3FIT0 details for *MAT_BARLAT_YLD2000
  * keyword from database */
   void dbReadCard3FIT0(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"ALPHA1","ALPHA2","ALPHA3","ALPHA4","ALPHA5","ALPHA6","ALPHA7","ALPHA8",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, MAT, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card3FIT0");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card3FIT0",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card3FIT1 details for *MAT_BARLAT_YLD2000
  * keyword from database */
   void dbReadCard3FIT1(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"SIG00","SIG45","SIG90","R00","R45","R90",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card3FIT1");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card3FIT1",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card4FIT1 details for *MAT_BARLAT_YLD2000
  * keyword from database */
   void dbReadCard4FIT1(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"SIGXX","SIGYY","SIGXY","DXX","DYY","DXY",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card4FIT1");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card4FIT1",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card4_5 details for *MAT_BARLAT_YLD2000
  * keyword from database */
   void dbReadCard4_5(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"AOPT","OFFANG",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 2;
      unsigned int field_widths[] = {10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card4_5");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card4_5",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card5_6 details for *MAT_BARLAT_YLD2000
  * keyword from database */
   void dbReadCard5_6(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"UNUSED","UNUSED","UNUSED","A1","A2","A3",};
      unsigned int field_types[] = {DATA_UNUSED, DATA_UNUSED, DATA_UNUSED, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card5_6");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card5_6",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card6_7 details for *MAT_BARLAT_YLD2000
  * keyword from database */
   void dbReadCard6_7(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"V1","V2","V3","D1","D2","D3",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card6_7");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card6_7",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *MAT_BARLAT_YLD2000
  * from database */
   unsigned int importDBMatBarlatYld2000()
   {
      int fit = 0;
      fit = dbReadCard1();
      dbReadCard2();
      if( fit == 0 )
      {
         dbReadCard3FIT0();
      }
      if( fit == 1 )
      {
         dbReadCard3FIT1();
         dbReadCard4FIT1();
      }
      dbReadCard4_5();
      dbReadCard5_6();
      dbReadCard6_7();
      return 0;
   }
};

#endif

