#ifndef _DBMATWINFRITHCONCRETEREINFORCEMENT_H_
#define _DBMATWINFRITHCONCRETEREINFORCEMENT_H_

#include "manager.h"
#include "dispexport.h"
#include "dbmatwinfrithconcrete.h"

/** Class used for getting data from database for *MAT_WINFRITH_CONCRETE_REINFORCEMENT
  * keyword */

class DBMatWinfrithConcreteReinforcement : public DBMatWinfrithConcrete
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBMatWinfrithConcreteReinforcement(GoldenConn *gold_conn, ImportObject *imp_obj) : DBMatWinfrithConcrete (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBMatWinfrithConcreteReinforcement()
   {
   }

public:
/** Function to get Card1 details for *MAT_WINFRITH_CONCRETE_REINFORCEMENT
  * keyword from database */
   void dbReadCard1(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"EID1","EID2","INC","XR","YR","ZR",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, MAT, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card1");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card1",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card2 details for *MAT_WINFRITH_CONCRETE_REINFORCEMENT
  * keyword from database */
   void dbReadCard2(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"UNUSED","PID","AXIS","COOR","RQA","RQB",};
      unsigned int field_types[] = {DATA_UNUSED, DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, MAT, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card2");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card2",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *MAT_WINFRITH_CONCRETE_REINFORCEMENT
  * from database */
   unsigned int importDBMatWinfrithConcreteReinforcement()
   {
      importDBMatWinfrithConcrete();
      dbReadCard1();
      dbReadCard2();
      return 0;
   }
};

#endif

