#ifndef _DBMATARUPADHESIVE_H_
#define _DBMATARUPADHESIVE_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *MAT_ARUP_ADHESIVE
  * keyword */

class DBMatArupAdhesive : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBMatArupAdhesive(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBMatArupAdhesive()
   {
   }

public:
/** Function to get Card1 details for *MAT_ARUP_ADHESIVE
  * keyword from database */
   void dbReadCard1(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"MID","RO","E","PR","TENMAX","GCTEN","SHRMAX","GCSHR",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 2, MAT, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card1");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card1",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card2 details for *MAT_ARUP_ADHESIVE
  * keyword from database */
   void dbReadCard2(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"PWRT","PWRS","SHRP","SHT_SL","EDOT0","EDOT2","UNUSED","XEDGE",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_UNUSED, DATA_INT, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, MAT, impObj);
      edot2 = 0;
      if( wordArray[7] )
         edot2 = atof(wordArray[7]);
      xedge = 0;
      if( wordArray[9] )
         xedge = atoi(wordArray[9]);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card2");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card2",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card3XEDGE1 details for *MAT_ARUP_ADHESIVE
  * keyword from database */
   void dbReadCard3XEDGE1(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"TMAXE","GCTE","SMAXE","GCSE","PWRTE","PWRSE",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, MAT, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card3XEDGE1");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card3XEDGE1",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card4XEDGE1 details for *MAT_ARUP_ADHESIVE
  * keyword from database */
   void dbReadCard4XEDGE1(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"FACET","FACCT","FACES","FACCS","SOFTT","SOFTS",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card4XEDGE1");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card4XEDGE1",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card5EDOT21 details for *MAT_ARUP_ADHESIVE
  * keyword from database */
   void dbReadCard5EDOT21(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"SDFAC","SGFAC","SDEFAC","SGEFAC",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 4;
      unsigned int field_widths[] = {10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card5EDOT21");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card5EDOT21",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *MAT_ARUP_ADHESIVE
  * from database */
   unsigned int importDBMatArupAdhesive()
   {
      dbReadCard1();
      dbReadCard2();
      dbReadCard3XEDGE1();
      dbReadCard4XEDGE1();
      if( edot2 != 0.0 )
      {
         dbReadCard5EDOT21();
      }
      return 0;
   }
public:
   double edot2;
   int xedge;
};

#endif

