#ifndef _Mat_EXPORT_H_
#define _Mat_EXPORT_H_

#include <string>
#include <map>
#include "goldenconn.h"
#include "matmanager.h"
#include "dataline.h"
#include "dbcard.h"
#include "mattype.h"
#include "exptypemap.h"

/** Class to get data from database for *MAT keywords */
class MatExport
{
public:
   /** Constructor for creating this object
     * \param model_name Name of the model for which the data to be obtained
     * \param gold_conn Connection object for accessing the database
     * \param mat_man Manager pointer to store the data obtained
     */
   MatExport
   (
      char         *model_name,
      GoldenConn   *gold_conn,
      MatManager   *mat_man
   );

   ~MatExport()
   {
      matManPtr = NULL;
      goldenConn = NULL;
      expTypeFuncMap.clear();
   }

   /** Gets the name of keyword from its type. Type is stored in the database
     * \param kw_type Type of keyword
     * \param key_word Keyword name is stored in this string
     */
   int getKeywordFromType
       (
	  unsigned int kw_type,
	  string & key_word
       );

   /** Fetches the *MAT keywords from database and returns 0 if not found 
     * else number of keywords obtained
     */
   unsigned int dbReadMats();

   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *MAT keyword types and their function pointers
     */
   void initExportAleTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *MAT keyword types and their function pointers
     */
   void initExportAnisotropicTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *MAT keyword types and their function pointers
     */
   void initExportBammanTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *MAT keyword types and their function pointers
     */
   void initExportBarlatTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *MAT keyword types and their function pointers
     */
   void initExportBlatzTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *MAT keyword types and their function pointers
     */
   void initExportCohesiveTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *MAT keyword types and their function pointers
     */
   void initExportCompoTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *MAT keyword types and their function pointers
     */
   void initExportCompositeTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *MAT keyword types and their function pointers
     */
   void initExportConcreteTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *MAT keyword types and their function pointers
     */
   void initExportDamperTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *MAT keyword types and their function pointers
     */
   void initExportDiscreteTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *MAT keyword types and their function pointers
     */
   void initExportDofTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *MAT keyword types and their function pointers
     */
   void initExportElasticTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *MAT keyword types and their function pointers
     */
   void initExportFoamTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *MAT keyword types and their function pointers
     */
   void initExportGeneralTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *MAT keyword types and their function pointers
     */
   void initExportGensprTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *MAT keyword types and their function pointers
     */
   void initExportGursonTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *MAT keyword types and their function pointers
     */
   void initExportHoneyTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *MAT keyword types and their function pointers
     */
   void initExportLowdenseTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *MAT keyword types and their function pointers
     */
   void initExportModifiedTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *MAT keyword types and their function pointers
     */
   void initExportModifyTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *MAT keyword types and their function pointers
     */
   void initExportMohrTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *MAT keyword types and their function pointers
     */
   void initExportOrthoTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *MAT keyword types and their function pointers
     */
   void initExportOthersTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *MAT keyword types and their function pointers
     */
   void initExportPlasticTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *MAT keyword types and their function pointers
     */
   void initExportPlasticityTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *MAT keyword types and their function pointers
     */
   void initExportSeatbeltTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *MAT keyword types and their function pointers
     */
   void initExportSeismicTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *MAT keyword types and their function pointers
     */
   void initExportSensitiveTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *MAT keyword types and their function pointers
     */
   void initExportSimpleTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *MAT keyword types and their function pointers
     */
   void initExportSoilTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *MAT keyword types and their function pointers
     */
   void initExportSpringTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *MAT keyword types and their function pointers
     */
   void initExportSpringdisTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *MAT keyword types and their function pointers
     */
   void initExportThermalTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *MAT keyword types and their function pointers
     */
   void initExportViscoelasticTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *MAT keyword types and their function pointers
     */
   void initExportViscoplasticTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *MAT keyword types and their function pointers
     */
   void initExportWeldTypesAndFunctions();

private:
   string        modelName;
   MatManager    *matManPtr;
   /** Connection object for accessing the data */
   GoldenConn    *goldenConn;
   /** Object to store the data imported from database */
   ImportObject  *impObj;
   /** A map between type of keyword and pointer to the function to be called */
   map<unsigned int, ExportFunctionPtr>  expTypeFuncMap;
};

#endif

