#ifndef _DBMATMODIFIEDFORCELIMITED_H_
#define _DBMATMODIFIEDFORCELIMITED_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *MAT_MODIFIED_FORCE_LIMITED
  * keyword */

class DBMatModifiedForceLimited : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBMatModifiedForceLimited(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBMatModifiedForceLimited()
   {
   }

public:
/** Function to get Card1 details for *MAT_MODIFIED_FORCE_LIMITED
  * keyword from database */
   void dbReadCard1(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"MID","RO","E","PR","DF","AOPT","YTFLAG","ASOFT",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 2, MAT, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card1");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card1",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card2 details for *MAT_MODIFIED_FORCE_LIMITED
  * keyword from database */
   void dbReadCard2(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"M1","M2","M3","M4","M5","M6","M7","M8",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, MAT, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card2");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card2",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card3 details for *MAT_MODIFIED_FORCE_LIMITED
  * keyword from database */
   void dbReadCard3(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"LC1","LC2","LC3","LC4","LC5","LC6","LC7","LC8",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, 3, 4, 5, 6, 7, };
      unsigned int man_types[] = {DEFINE, DEFINE, DEFINE, DEFINE, DEFINE, DEFINE, DEFINE, DEFINE, };
      unsigned int kw_types[] = {CURVE, CURVE, CURVE, CURVE, CURVE, CURVE, CURVE, CURVE, };
      unsigned int num_indices = 8;
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, MAT, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card3");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card3",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card4 details for *MAT_MODIFIED_FORCE_LIMITED
  * keyword from database */
   void dbReadCard4(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"LPS1","SFS1","LPS2","SFS2","YMS1","YMS2",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card4");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card4",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card5 details for *MAT_MODIFIED_FORCE_LIMITED
  * keyword from database */
   void dbReadCard5(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"LPT1","SFT1","LPT2","SFT2","YMT1","YMT2",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card5");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card5",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card6 details for *MAT_MODIFIED_FORCE_LIMITED
  * keyword from database */
   void dbReadCard6(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"LPR","SFR","YMR",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 3;
      unsigned int field_widths[] = {10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card6");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card6",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card7 details for *MAT_MODIFIED_FORCE_LIMITED
  * keyword from database */
   void dbReadCard7(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"LYS1","SYS1","LYS2","SYS2","LYT1","SYT1","LYT2","SYT2",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card7");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card7",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card8 details for *MAT_MODIFIED_FORCE_LIMITED
  * keyword from database */
   void dbReadCard8(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"LYR","SYR",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 2;
      unsigned int field_widths[] = {10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card8");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card8",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card9 details for *MAT_MODIFIED_FORCE_LIMITED
  * keyword from database */
   void dbReadCard9(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"HMS1_1","HMS1_2","HMS1_3","HMS1_4","HMS1_5","HMS1_6","HMS1_7","HMS1_8",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card9");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card9",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card10 details for *MAT_MODIFIED_FORCE_LIMITED
  * keyword from database */
   void dbReadCard10(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"LPMS1_1","LPMS1_2","LPMS1_3","LPMS1_4","LPMS1_5","LPMS1_6","LPMS1_7","LPMS1_8",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card10");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card10",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card11 details for *MAT_MODIFIED_FORCE_LIMITED
  * keyword from database */
   void dbReadCard11(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"HMS2_1","HMS2_2","HMS2_3","HMS2_4","HMS2_5","HMS2_6","HMS2_7","HMS2_8",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card11");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card11",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card12 details for *MAT_MODIFIED_FORCE_LIMITED
  * keyword from database */
   void dbReadCard12(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"LPMS2_1","LPMS2_2","LPMS2_3","LPMS2_4","LPMS2_5","LPMS2_6","LPMS2_7","LPMS2_8",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card12");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card12",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card13 details for *MAT_MODIFIED_FORCE_LIMITED
  * keyword from database */
   void dbReadCard13(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"HMT1_1","HMT1_2","HMT1_3","HMT1_4","HMT1_5","HMT1_6","HMT1_7","HMT1_8",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card13");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card13",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card14 details for *MAT_MODIFIED_FORCE_LIMITED
  * keyword from database */
   void dbReadCard14(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"LPMT1_1","LPMT1_2","LPMT1_3","LPMT1_4","LPMT1_5","LPMT1_6","LPMT1_7","LPMT1_8",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card14");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card14",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card15 details for *MAT_MODIFIED_FORCE_LIMITED
  * keyword from database */
   void dbReadCard15(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"HMT2_1","HMT2_2","HMT2_3","HMT2_4","HMT2_5","HMT2_6","HMT2_7","HMT2_8",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card15");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card15",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card16 details for *MAT_MODIFIED_FORCE_LIMITED
  * keyword from database */
   void dbReadCard16(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"LPMT2_1","LPMT2_2","LPMT2_3","LPMT2_4","LPMT2_5","LPMT2_6","LPMT2_7","LPMT2_8",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card16");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card16",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card17 details for *MAT_MODIFIED_FORCE_LIMITED
  * keyword from database */
   void dbReadCard17(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"HMR_1","HMR_2","HMR_3","HMR_4","HMR_5","HMR_6","HMR_7","HMR_8",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card17");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card17",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card18 details for *MAT_MODIFIED_FORCE_LIMITED
  * keyword from database */
   void dbReadCard18(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"LPMR_1","LPMR_2","LPMR_3","LPMR_4","LPMR_5","LPMR_6","LPMR_7","LPMR_8",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card18");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card18",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *MAT_MODIFIED_FORCE_LIMITED
  * from database */
   unsigned int importDBMatModifiedForceLimited()
   {
      dbReadCard1();
      dbReadCard2();
      dbReadCard3();
      dbReadCard4();
      dbReadCard5();
      dbReadCard6();
      dbReadCard7();
      dbReadCard8();
      dbReadCard9();
      dbReadCard10();
      dbReadCard11();
      dbReadCard12();
      dbReadCard13();
      dbReadCard14();
      dbReadCard15();
      dbReadCard16();
      dbReadCard17();
      dbReadCard18();
      return 0;
   }
};

#endif

