#ifndef _DBMATMODIFIEDJOHNSONCOOK_H_
#define _DBMATMODIFIEDJOHNSONCOOK_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *MAT_MODIFIED_JOHNSON_COOK
  * keyword */

class DBMatModifiedJohnsonCook : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBMatModifiedJohnsonCook(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBMatModifiedJohnsonCook()
   {
   }

public:
/** Function to get Card1 details for *MAT_MODIFIED_JOHNSON_COOK
  * keyword from database */
   void dbReadCard1(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"MID","RO","E","PR","BETA","XS1","CP","ALPHA",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 2, MAT, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card1");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card1",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card2 details for *MAT_MODIFIED_JOHNSON_COOK
  * keyword from database */
   void dbReadCard2(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"E0DOT","Tr","Tm","T0","FLAG1","FLAG2",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, };
      numFields = 6;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, MAT, impObj);
      flag1 = 0;
      if( wordArray[6] )
         flag1 = atoi(wordArray[6]);
      flag2 = 0;
      if( wordArray[7] )
         flag2 = atoi(wordArray[7]);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card2");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card2",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card3FLAG10 details for *MAT_MODIFIED_JOHNSON_COOK
  * keyword from database */
   void dbReadCard3FLAG10(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"A","B","N","C","m",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 5;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, MAT, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card3FLAG10");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card3FLAG10",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card4FLAG10 details for *MAT_MODIFIED_JOHNSON_COOK
  * keyword from database */
   void dbReadCard4FLAG10(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"Q1","C1","Q2","C2",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 4;
      unsigned int field_widths[] = {10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card4FLAG10");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card4FLAG10",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card3FLAG11 details for *MAT_MODIFIED_JOHNSON_COOK
  * keyword from database */
   void dbReadCard3FLAG11(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"SIGA","B","BETA0","BETA1",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 4;
      unsigned int field_widths[] = {10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card3FLAG11");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card3FLAG11",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card4FLAG11 details for *MAT_MODIFIED_JOHNSON_COOK
  * keyword from database */
   void dbReadCard4FLAG11(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"A","N","ALPHA0","ALPHA1",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 4;
      unsigned int field_widths[] = {10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card4FLAG11");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card4FLAG11",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card5FLAG20 details for *MAT_MODIFIED_JOHNSON_COOK
  * keyword from database */
   void dbReadCard5FLAG20(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"DC","PD","D1","D2","D3","D4","D5",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 7;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card5FLAG20");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card5FLAG20",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card5FLAG21 details for *MAT_MODIFIED_JOHNSON_COOK
  * keyword from database */
   void dbReadCard5FLAG21(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"DC","WC",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 2;
      unsigned int field_widths[] = {10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card5FLAG21");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card5FLAG21",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card6 details for *MAT_MODIFIED_JOHNSON_COOK
  * keyword from database */
   void dbReadCard6(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"TC","TAUC",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 2;
      unsigned int field_widths[] = {10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card6");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card6",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *MAT_MODIFIED_JOHNSON_COOK
  * from database */
   unsigned int importDBMatModifiedJohnsonCook()
   {
      dbReadCard1();
      dbReadCard2();
      if( flag1 == 0 )
      {
         dbReadCard3FLAG10();
         dbReadCard4FLAG10();
      }
      else if( flag1 == 1 )
      {
         dbReadCard3FLAG11();
         dbReadCard4FLAG11();
      }
      if( flag2 == 0 )
      {
         dbReadCard5FLAG20();
      }
      else if( flag2 == 1 )
      {
         dbReadCard5FLAG21();
      }
      dbReadCard6();
      return 0;
   }
public:
   int flag1;
   int flag2;
};

#endif

