#ifndef _DBMATPLASTICITYWITHDAMAGEORTHORCDC_H_
#define _DBMATPLASTICITYWITHDAMAGEORTHORCDC_H_

#include "manager.h"
#include "dispexport.h"
#include "dbmatplasticitywithdamage.h"

/** Class used for getting data from database for *MAT_PLASTICITY_WITH_DAMAGE_ORTHO_RCDC
  * keyword */

class DBMatPlasticityWithDamageOrthoRcdc : public DBMatPlasticityWithDamage
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBMatPlasticityWithDamageOrthoRcdc(GoldenConn *gold_conn, ImportObject *imp_obj) : DBMatPlasticityWithDamage (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBMatPlasticityWithDamageOrthoRcdc()
   {
   }

public:
/** Function to get Card5 details for *MAT_PLASTICITY_WITH_DAMAGE_ORTHO_RCDC
  * keyword from database */
   void dbReadCard5(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"ALPHA","BETA","GAMMA","D0","B","LAMBDA","DS","L",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, MAT, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card5");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card5",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *MAT_PLASTICITY_WITH_DAMAGE_ORTHO_RCDC
  * from database */
   unsigned int importDBMatPlasticityWithDamageOrthoRcdc()
   {
      importDBMatPlasticityWithDamage();
      dbReadCard5();
      return 0;
   }
};

#endif

