#ifndef _DBMATSPOTWELDDAMAGEFAILURE_H_
#define _DBMATSPOTWELDDAMAGEFAILURE_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *MAT_SPOTWELD_DAMAGE_FAILURE
  * keyword */

class DBMatSpotweldDamageFailure : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBMatSpotweldDamageFailure(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBMatSpotweldDamageFailure()
   {
   }

public:
/** Function to get Card1 details for *MAT_SPOTWELD_DAMAGE_FAILURE
  * keyword from database */
   void dbReadCard1(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"MID","RO","E","PR","SIGY","ET","DT","TFAIL",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 2, MAT, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card1");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card1",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card2 details for *MAT_SPOTWELD_DAMAGE_FAILURE
  * keyword from database */
   int dbReadCard2(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"RS","OPT","FVAL","TRUE_T","UNUSED","BETA",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_UNUSED, DATA_DOUBLE, };
      numFields = 6;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return 0;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, MAT, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card2");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card2",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
      if( wordArray[3] )
         return atoi(wordArray[3]);
      else
         return 0;
   }

/** Function to get Card3OPTM10 details for *MAT_SPOTWELD_DAMAGE_FAILURE
  * keyword from database */
   void dbReadCard3OPTM10(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"EFAIL","NRR","NRS","NRT","MRR","MSS","MTT","NF",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, MAT, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card3OPTM10");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card3OPTM10",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card3OPT1 details for *MAT_SPOTWELD_DAMAGE_FAILURE
  * keyword from database */
   void dbReadCard3OPT1(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"EFAIL","SIGAX","SIGTAU","UNUSED","UNUSED","UNUSED","UNUSED","NF",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_UNUSED, DATA_UNUSED, DATA_UNUSED, DATA_UNUSED, DATA_INT, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card3OPT1");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card3OPT1",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card3OPT2 details for *MAT_SPOTWELD_DAMAGE_FAILURE
  * keyword from database */
   void dbReadCard3OPT2(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"EFAIL","USERV1","USERV2","USERV3","USERV4","USERV5","USERV6","NF",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card3OPT2");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card3OPT2",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card3OPT34 details for *MAT_SPOTWELD_DAMAGE_FAILURE
  * keyword from database */
   void dbReadCard3OPT34(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"EFAIL","ZD","ZT","ZALP1","ZALP2","ZALP3","ZRRAD","NF",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card3OPT34");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card3OPT34",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card3OPT5 details for *MAT_SPOTWELD_DAMAGE_FAILURE
  * keyword from database */
   void dbReadCard3OPT5(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"EFAIL","ZD","ZT","ZT2",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 4;
      unsigned int field_widths[] = {10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card3OPT5");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card3OPT5",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card3OPT679 details for *MAT_SPOTWELD_DAMAGE_FAILURE
  * keyword from database */
   void dbReadCard3OPT679(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"EFAIL","UNUSED","UNUSED","UNUSED","UNUSED","UNUSED","UNUSED","NF",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_UNUSED, DATA_UNUSED, DATA_UNUSED, DATA_UNUSED, DATA_UNUSED, DATA_UNUSED, DATA_INT, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card3OPT679");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card3OPT679",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *MAT_SPOTWELD_DAMAGE_FAILURE
  * from database */
   unsigned int importDBMatSpotweldDamageFailure()
   {
      int opt = 0;
      dbReadCard1();
      opt = dbReadCard2();
      if( opt == -2 || opt == -1 || opt == 0 )
      {
         dbReadCard3OPTM10();
      }
      else if( opt == 1 )
      {
         dbReadCard3OPT1();
      }
      else if( opt == 2 )
      {
         dbReadCard3OPT2();
      }
      else if( opt == 3 || opt == 4 )
      {
         dbReadCard3OPT34();
      }
      else if( opt == 5 )
      {
         dbReadCard3OPT5();
      }
      else if( opt == 6 || opt == 7 || opt == 9 )
      {
         dbReadCard3OPT679();
      }
      return 0;
   }
};

#endif

