#include <iostream>
#include <algorithm>
#include "nodtype.h"
#include "nodexport.h"
#include <stdlib.h>

using namespace std;

NodExport::NodExport
(
   char *        model_name,
   GoldenConn    *gold_conn,
   NodManager    *nod_man
)
{
   nodManPtr = nod_man;
   goldenConn = gold_conn;
   modelName = model_name;

   initExportNodTypesAndFunctions();
}

int NodExport::getKeywordFromType
	(
	   unsigned int kw_type,
	   string & kw_word
	)
{
   switch(kw_type)
   {
      case NODE_RIGID_SURFACE:
         kw_word = "*NODE_RIGID_SURFACE";
         break;
      case NODE_SCALAR_VALUE:
         kw_word = "*NODE_SCALAR_VALUE";
         break;
      case NODE_SCALAR:
         kw_word = "*NODE_SCALAR";
         break;
      case NODE_TRANSFORM:
         kw_word = "*NODE_TRANSFORM";
         break;
      case NODE:
         kw_word = "*NODE";
         break;
      case NOD_NEW_TYPE:
      default:
         return 1;
   }

   return 0;
}

unsigned int NodExport::dbReadNods
             (
                unsigned int count, 
                unsigned int offset, 
                unsigned int kw_type,
                set<string> *keywords
             )
{
   char         **row_data, buf[16], count_buf[64];
   unsigned int	i, num_nods = 0, num_kw_types = 0, total_nodes = 0;
   expTypeFuncIterator eexp_iter = expTypeFuncMap.end(), exp_iter;

   string       qry = "select kw_type from ", kw_str;
   string table_name = "`" + modelName + "_NODES`";
   qry += table_name;
   qry += " group by kw_type;";

cout << "KW QRY = " << qry << endl;

   if( goldenConn->executeQuery( qry.data() ) )
      return 0;

   num_kw_types = goldenConn->numRows();

   if( !num_kw_types )
      return 0;

   count_buf[0] = '\0';
   if( count )
      sprintf(count_buf, " limit %u offset %u", count, offset);

   unsigned int *kw_types = new unsigned int[num_kw_types];

   for(i = 0; i < num_kw_types; i++)
   {
      row_data = goldenConn->nextRow();
      kw_types[i] = atoi( row_data[0] );
cout << "KW NODE TYPE = " << kw_types[i] << endl;
   }

   for(i = 0; i < num_kw_types; i++)
   {
      if( getKeywordFromType(kw_types[i], kw_str) )
         continue;

      if( keywords )
         keywords->insert(kw_str);

cout << "NODE KW = " << kw_str << endl;

      if( kw_type != NOD_NEW_TYPE && kw_type != kw_types[i] )
         continue;

      qry = "select * from ";
      qry += table_name;
      qry += " where kw_type=";
      sprintf(buf, "%u", kw_types[i]);
      qry += buf;
      qry += count_buf;
      qry += ";";

cout << "NODE QRY = " << qry << endl;

      if( goldenConn->executeQuery( qry.data() ) )
	 break;

      exp_iter = expTypeFuncMap.find(kw_types[i]);

      if( exp_iter == eexp_iter )
      {
	 cout << "Node TYPE NOT FOUND" << endl;
         continue;
      }

      impObj = new ExportObject((char *)kw_str.data(), kw_types[i]);

      num_nods = 0;
      Card::setFlag();
      (exp_iter->second)(goldenConn, impObj);
      Card::clearFlag();
      num_nods++;

      while( goldenConn->rowsLeft() )
      {
	 (exp_iter->second)(goldenConn, impObj);
         num_nods++;
      }
      nodManPtr->add(kw_str.data(), impObj);
      
      total_nodes += num_nods;
   }

   delete kw_types;

   return total_nodes;
}

unsigned int NodExport::getNodeTypes
             (
                set<string> & keywords
             )
{
   char         **row_data;
   unsigned int	i, num_kw_types = 0;

   string       qry = "select kw_type from ", kw_str;
   string table_name = "`" + modelName + "_NODES`";
   qry += table_name;
   qry += " group by kw_type;";

cout << "KW QRY = " << qry << endl;

   if( goldenConn->executeQuery( qry.data() ) )
      return 0;

   num_kw_types = goldenConn->numRows();

   if( !num_kw_types )
      return 0;

   unsigned int *kw_types = new unsigned int[num_kw_types];

   for(i = 0; i < num_kw_types; i++)
   {
      row_data = goldenConn->nextRow();
      kw_types[i] = atoi( row_data[0] );
cout << "KW NODE TYPE = " << kw_types[i] << endl;
   }

   for(i = 0; i < num_kw_types; i++)
   {
      if( getKeywordFromType(kw_types[i], kw_str) )
         continue;

      keywords.insert(kw_str);
   }

   return keywords.size();
}

