#ifndef _NOD_EXPORT_H_
#define _NOD_EXPORT_H_

#include <string>
#include <map>
#include <set>
#include "nodmanager.h"
#include "goldenconn.h"
#include "dbcard.h"
#include "nodtype.h"
#include "exptypemap.h"

/** Class to get data from database for *NODE keywords */
class NodExport
{
public:
   /** Constructor for creating this object
     * \param model_name Name of the model for which the data to be obtained
     * \param gold_conn Connection object for accessing the database
     * \param nod_man Manager pointer to store the data obtained
     */
   NodExport
   (
      char          *model_name,
      GoldenConn    *gold_conn,
      NodManager    *nod_man
   );

   ~NodExport()
   {
      nodManPtr = NULL;
      goldenConn = NULL;
      expTypeFuncMap.clear();
   }

   /** Fetches the *NODE keywords from database and returns 0 if not found 
     * else number of keywords obtained
     * \param count Number of nodes requested from database
     * \param offset Offset from which the nodes are requested
     * \param kw_type Type of node keyword
     * \param keywords List of node type keywords available in database. This
     * is filled in this function
     */
   unsigned int dbReadNods
                (
                   unsigned int count = 0, 
                   unsigned int offset = 0, 
                   unsigned int kw_type = NOD_NEW_TYPE,
                   set<string> *keywords = NULL 
                );

   /** Gets the type of *NODE keywords in the database
     * \param keywords List of keywords of type *NODE in the database
     * \return Number of types
     */
   unsigned int getNodeTypes
		(
		   set<string> & keywords
		);

   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *NODE keyword types and their function pointers
     */
   void initExportNodTypesAndFunctions();

   /** Gets the name of keyword from its type. Type is stored in the database
     * \param kw_type Type of keyword
     * \param kw_word Keyword name is stored in this string
     */
   int getKeywordFromType
       (
	  unsigned int kw_type,
	  string & kw_word
       );

private:
   string        modelName;
   NodManager    *nodManPtr;
   /** Object to store the data imported from database */
   ImportObject  *impObj;
   /** Connection object for accessing the data */
   GoldenConn    *goldenConn;
   /** A map between type of keyword and pointer to the function to be called */
   map<unsigned int, ExportFunctionPtr>  expTypeFuncMap;
};

#endif

