#include <iostream>
#include <algorithm>
#include "generic.h"
#include "parametertype.h"
#include "parameterexport.h"
#include <stdlib.h>

using namespace std;

ParameterExport::ParameterExport
(
   char              *model_name,
   GoldenConn        *gold_conn,
   ParameterManager  *parameter_man
)
{
   modelName = model_name;
   parameterManPtr = parameter_man;
   goldenConn = gold_conn;

   initExportParameterTypesAndFunctions();
}

int ParameterExport::getKeywordFromType
    (
       unsigned int kw_type,
       string & key_word
    )
{
   switch(kw_type)
   {
      case PARAMETER:
	 key_word = "*PARAMETER";
	 break;
      case PARAMETER_EXPRESSION:
	 key_word = "*PARAMETER_EXPRESSION";
	 break;
      case PARAMETER_NEW_TYPE:
      default:
         return 1;
   }
   return 0;
}

unsigned int ParameterExport::dbReadParameters()
{
   char         **row_data, buf[16];
   unsigned int	i, num_parameters = 0, total_parameters = 0, 
                num_kw_types = 0;
   expTypeFuncIterator eexp_iter = expTypeFuncMap.end(), exp_iter;

   string       qry = "select kw_type from ", kw_str;
   string table_name = "`" + modelName + "_PARAMETERS`";
   qry += table_name;
   qry += " group by kw_type;";

cout << "KW QRY = " << qry << endl;

   if( goldenConn->executeQuery( qry.data() ) )
      return 0;

   num_kw_types = goldenConn->numRows();

   if( !num_kw_types )
      return 0;

   unsigned int *kw_types = new unsigned int[num_kw_types];

   for(i = 0; i < num_kw_types; i++)
   {
      row_data = goldenConn->nextRow();
      kw_types[i] = atoi( row_data[0] );
cout << "KW PARAMETER TYPE = " << kw_types[i] << endl;
   }

   for(i = 0; i < num_kw_types; i++)
   {
      if( getKeywordFromType(kw_types[i], kw_str) )
         continue;

cout << "PARAMETER KW = " << kw_str << endl;

      qry = "select * from ";
      qry += table_name;
      qry += " where kw_type=";
      sprintf(buf, "%u", kw_types[i]);
      qry += buf;
      qry += " order by card_index;";

cout << "PARAMETER QRY = " << qry << endl;

      if( goldenConn->executeQuery( qry.data() ) )
	 break;

      exp_iter = expTypeFuncMap.find(kw_types[i]);

      if( exp_iter == eexp_iter )
      {
	 cout << "PARAMETER TYPE NOT FOUND" << endl;
         continue;
      }

      num_parameters = 0;
      while( goldenConn->rowsLeft() )
      {
         impObj = new ExportObject((char *)kw_str.data(), kw_types[i]);
         goldenConn->clearFlag(KW_DATA_END);
	 (exp_iter->second)(goldenConn, impObj);
	 if( impObj->cardCount )
	 {
	    parameterManPtr->add(kw_str.data(), impObj);
	    num_parameters++;
	 }
	 else
	    delete impObj;
      }

      total_parameters += num_parameters;
   }

   delete kw_types;

   return total_parameters;
}

