#ifndef _DBPARTCARDS_H_
#define _DBPARTCARDS_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *PART_CARDS
  * keyword */

class DBPartCards : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBPartCards(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBPartCards()
   {
   }

public:
/** Function to get TitleCard details for *PART_CARDS
  * keyword from database */
   void dbReadTitleCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"HEADING",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, };
      numFields = 1;
      unsigned int field_widths[] = {80, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, PARTC, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("TitleCard");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","TitleCard",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get PartCard details for *PART_CARDS
  * keyword from database */
   void dbReadPartCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"PID","SECID","MID","EOSID","HGID","GRAV","ADPOPT","TMID",};
      unsigned int field_types[] = {DATA_INT, DATA_CHAR_ARRAY, DATA_CHAR_ARRAY, DATA_CHAR_ARRAY, DATA_CHAR_ARRAY, DATA_INT, DATA_INT, DATA_CHAR_ARRAY, };
      unsigned int field_indices[] = {1, 2, 3, 4, 7, };
      unsigned int man_types[] = {SECTION, MAT, EOS, HG, MAT, };
      unsigned int kw_types[] = {9999, 9999, 9999, 9999, THERMAL, };
      unsigned int num_indices = 5;
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 2, PARTC, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("PartCard");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","PartCard",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *PART_CARDS
  * from database */
   unsigned int importDBPartCards()
   {
      dbReadTitleCard();
      dbReadPartCard();
      return 0;
   }
};

#endif

