#ifndef _DBPARTREPOSITION_H_
#define _DBPARTREPOSITION_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *PART_REPOSITION
  * keyword */

class DBPartReposition : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBPartReposition(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBPartReposition()
   {
   }

public:
/** Function to get ReposCard details for *PART_REPOSITION
  * keyword from database */
   void dbReadReposCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"CMSN","MDEP","MOVOPT",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, };
      numFields = 3;
      unsigned int field_widths[] = {10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, PARTC, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("ReposCard");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","ReposCard",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *PART_REPOSITION
  * from database */
   unsigned int importDBPartReposition()
   {
      dbReadReposCard();
      return 0;
   }
};

#endif

