#ifndef _DBPARTSENSOR_H_
#define _DBPARTSENSOR_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *PART_SENSOR
  * keyword */

class DBPartSensor : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBPartSensor(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBPartSensor()
   {
   }

public:
/** Function to get PartCard details for *PART_SENSOR
  * keyword from database */
   void dbReadPartCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"PID","SIDA","ACTIVE",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, };
      unsigned int man_types[] = {PARTC, SENSOR, };
      unsigned int kw_types[] = {9999, 9999, };
      unsigned int num_indices = 2;
      numFields = 3;
      unsigned int field_widths[] = {10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, PARTC, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("PartCard");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","PartCard",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *PART_SENSOR
  * from database */
   unsigned int importDBPartSensor()
   {
      dbReadPartCard();
      return 0;
   }
};

#endif

