#include <iostream>
#include <algorithm>
#include "generic.h"
#include "partctype.h"
#include "partcexport.h"

#include "dbpartcards.h"
#include "dbpartinertia.h"
#include "dbpartreposition.h"
#include "dbpartcontact.h"
#include "dbpartprint.h"
#include "dbpartattachmentnodes.h"

#include <stdlib.h>

using namespace std;

PartCExport::PartCExport
(
   char         *model_name,
   GoldenConn   *gold_conn,
   PartCManager *partc_man
)
{
   modelName = model_name;
   partcManPtr = partc_man;
   goldenConn = gold_conn;

   initExportPartCTypesAndFunctions();
}

PartCType PartCExport::getKeywordFromType
	  (
	     unsigned int kw_type,
	     string & key_word
	  )
{
   if( kw_type & (1 << PART_ADAPTIVE_FAILURE) )
   {
      key_word = "*PART_ADAPTIVE_FAILURE";
      return PART_ADAPTIVE_FAILURE;
   }
   else if( kw_type & (1 << PART_COMPOSITE) )
   {
      key_word = "*PART_COMPOSITE";
      return PART_COMPOSITE;
   }
   else if( kw_type & (1 << PART_COMPOSITE_CONTACT) )
   {
      key_word = "*PART_COMPOSITE_CONTACT";
      return PART_COMPOSITE_CONTACT;
   }
   else if( kw_type & (1 << PART_MODES) )
   {
      key_word = "*PART_MODES";
      return PART_MODES;
   }
   else if( kw_type & (1 << PART_MOVE) )
   {
      key_word = "*PART_MOVE";
      return PART_MOVE;
   }
   else if( kw_type & (1 << PART_SENSOR) )
   {
      key_word = "*PART_SENSOR";
      return PART_SENSOR;
   }
   else if( kw_type & (1 << PART) )
   {
      key_word = "*PART";
      if( kw_type & (1 << PART_INERTIA) )
	 key_word += "_INERTIA";
      else if( kw_type & (1 << PART_REPOSITION) )
	 key_word += "_REPOSITION";

      if( kw_type & (1 << PART_CONTACT) )
	 key_word += "_CONTACT";
      if( kw_type & (1 << PART_PRINT) )
	 key_word += "_PRINT";
      if( kw_type & (1 << PART_ATTACH) )
	 key_word += "_ATTACHMENT_NODES";

      return PART;
   }
   else
   {
      key_word = "*PART";
      return PART;
   }
}

unsigned int PartCExport::dbReadPartCs()
{
   char         **row_data, buf[16];
   unsigned int	i, num_partcs = 0, total_partcs = 0, num_kw_types = 0,
                partc_type;
   expTypeFuncIterator eexp_iter = expTypeFuncMap.end(), exp_iter;

   string       qry = "select kw_type from ", kw_str;
   string table_name = "`" + modelName + "_PARTS`";
   qry += table_name;
   qry += " group by kw_type;";

cout << "KW QRY = " << qry << endl;

   if( goldenConn->executeQuery( qry.data() ) )
      return 0;

   num_kw_types = goldenConn->numRows();

   if( !num_kw_types )
      return 0;

   unsigned int *kw_types = new unsigned int[num_kw_types];

   for(i = 0; i < num_kw_types; i++)
   {
      row_data = goldenConn->nextRow();
      kw_types[i] = atoi( row_data[0] );
cout << "KW PARTC TYPE = " << kw_types[i] << endl;
   }

   for(i = 0; i < num_kw_types; i++)
   {
      partc_type = getKeywordFromType(kw_types[i], kw_str);

cout << "PARTC KW = " << kw_str << endl;

      qry = "select * from ";
      qry += table_name;
      qry += " where kw_type=";
      sprintf(buf, "%u", kw_types[i]);
      qry += buf;
      qry += " order by card_index;";

cout << "PARTC QRY = " << qry << endl;

      if( goldenConn->executeQuery( qry.data() ) )
	 break;

      num_partcs = 0;

      if( kw_types[i] & (1 << PART) )
      {
         while( goldenConn->rowsLeft() )
         {
	    impObj = new ExportObject((char *)kw_str.data(), kw_types[i]);
            goldenConn->clearFlag(KW_DATA_END);

	    DBPartCards partc(goldenConn, impObj);
	    partc.importDBPartCards();

	    if( kw_types[i] & (1 << PART_INERTIA) )
	    {
	       DBPartInertia part_inertia(goldenConn, impObj);
	       part_inertia.importDBPartInertia();
	    }
	    else if( kw_types[i] & (1 << PART_REPOSITION) )
	    {
	       DBPartReposition part_repos(goldenConn, impObj);
	       part_repos.importDBPartReposition();
	    }

	    if( kw_types[i] & (1 << PART_CONTACT) )
	    {
	       DBPartContact part_contact(goldenConn, impObj);
	       part_contact.importDBPartContact();
	    }

	    if( kw_types[i] & (1 << PART_PRINT) )
	    {
	       DBPartPrint part_print(goldenConn, impObj);
	       part_print.importDBPartPrint();
	    }

	    if( kw_types[i] & (1 << PART_ATTACH) )
	    {
	       DBPartAttachmentNodes part_attach(goldenConn, impObj);
	       part_attach.importDBPartAttachmentNodes();
	    }

	    if( impObj->cardCount )
	    {
	       partcManPtr->add(kw_str.data(), impObj);
	       num_partcs++;
            }
         }
      }
      else
      {
	 exp_iter = expTypeFuncMap.find(partc_type);
	 if( exp_iter == eexp_iter )
	 {
	    cout << "PARTC TYPE NOT FOUND" << endl;
	    continue;
	 }

	 while( goldenConn->rowsLeft() )
         {
	    impObj = new ExportObject((char *)kw_str.data(), kw_types[i]);
            goldenConn->clearFlag(KW_DATA_END);
	    (exp_iter->second)(goldenConn, impObj);
	    if( impObj->cardCount )
	    {
	       partcManPtr->add(kw_str.data(), impObj);
	       num_partcs++;
	    }
	    else
	       delete impObj;
         }
      }

      total_partcs += num_partcs;
   }

   delete kw_types;

   return total_partcs;
}

