#ifndef _DBPERTURBATIONNODE_H_
#define _DBPERTURBATIONNODE_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *PERTURBATION_NODE
  * keyword */

class DBPerturbationNode : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBPerturbationNode(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBPerturbationNode()
   {
   }

public:
/** Function to get Card1 details for *PERTURBATION_NODE
  * keyword from database */
   int dbReadCard1(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"TYPE","NID","SCL","CMP",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, DATA_INT, };
      unsigned int field_indices[] = {1, };
      unsigned int man_types[] = {SET, };
      unsigned int kw_types[] = {NOD, };
      unsigned int num_indices = 1;
      numFields = 4;
      unsigned int field_widths[] = {10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return 0;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, PERTURB, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card1");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card1",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
      if( wordArray[2] )
         return atoi(wordArray[2]);
      else
         return 0;
   }

/** Function to get Type1Card details for *PERTURBATION_NODE
  * keyword from database */
   void dbReadType1Card(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"AMPL","XWL","XOFF","YWL","YOFF","ZWL","ZOFF",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 7;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, };
      unsigned int end_loop;
      end_loop = 10000;
      for(loop_count = 0; loop_count < end_loop; loop_count++)
      {
         numFields = 7;
         wordArray = goldenConn->nextCard();
         if( !wordArray )
         {
            numFields = 0;
         return;
         }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, PERTURB, impObj);
         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Type1Card",loop_count);
            cardObj = new DBCard(name_buf);
            ((DBCard *)cardObj)->index = atoi(wordArray[0]);
            cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
            impObj->addCard(cardObj);
         }
         impObj->cardCount++;
      }
   }

/** Function to get Type2Card details for *PERTURBATION_NODE
  * keyword from database */
   void dbReadType2Card(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"FADE",};
      unsigned int field_types[] = {DATA_DOUBLE, };
      numFields = 1;
      unsigned int field_widths[] = {10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Type2Card");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Type2Card",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Type3Card details for *PERTURBATION_NODE
  * keyword from database */
   void dbReadType3Card(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"FNAME",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, };
      numFields = 1;
      unsigned int field_widths[] = {80, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Type3Card");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Type3Card",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *PERTURBATION_NODE
  * from database */
   unsigned int importDBPerturbationNode()
   {
      int type = 0;
      type = dbReadCard1();
      if( type == 1 )
      {
         dbReadType1Card();
      }
      else if( type == 2 )
      {
         dbReadType2Card();
      }
      else if( type == 3 )
      {
         dbReadType3Card();
      }
      return 0;
   }
};

#endif

