#include <iostream>
#include <algorithm>
#include "generic.h"
#include "perturbtype.h"
#include "perturbexport.h"
#include <stdlib.h>

using namespace std;

PerturbExport::PerturbExport
(
   char            *model_name,
   GoldenConn      *gold_conn,
   PerturbManager  *perturb_man
)
{
   modelName = model_name;
   perturbManPtr = perturb_man;
   goldenConn = gold_conn;

   initExportPerturbTypesAndFunctions();
}

int PerturbExport::getKeywordFromType
    (
       unsigned int kw_type,
       string & key_word
    )
{
   switch(kw_type)
   {
      case PERTURBATION_NODE:
	 key_word = "*PERTURBATION_NODE";
	 break;
      case PERTURBATION_SHELL_THICKNESS:
	 key_word = "*PERTURBATION_SHELL_THICKNESS";
	 break;
      case PERTURB_NEW_TYPE:
      default:
         return 1;
   }

   return 0;
}

unsigned int PerturbExport::dbReadPerturbs()
{
   char         **row_data, buf[16];
   unsigned int	i, num_perturbs = 0, total_perturbs = 0, num_kw_types = 0;
   expTypeFuncIterator eexp_iter = expTypeFuncMap.end(), exp_iter;

   string       qry = "select kw_type from ", kw_str;
   string table_name = "`" + modelName + "_PERTURBATIONS`";
   qry += table_name;
   qry += " group by kw_type;";

cout << "KW QRY = " << qry << endl;

   if( goldenConn->executeQuery( qry.data() ) )
      return 0;

   num_kw_types = goldenConn->numRows();

   if( !num_kw_types )
      return 0;

   unsigned int *kw_types = new unsigned int[num_kw_types];

   for(i = 0; i < num_kw_types; i++)
   {
      row_data = goldenConn->nextRow();
      kw_types[i] = atoi( row_data[0] );
cout << "KW PERTURB TYPE = " << kw_types[i] << endl;
   }

   for(i = 0; i < num_kw_types; i++)
   {
      if( getKeywordFromType(kw_types[i], kw_str) )
         continue;

cout << "PERTURB KW = " << kw_str << endl;

      qry = "select * from ";
      qry += table_name;
      qry += " where kw_type=";
      sprintf(buf, "%u", kw_types[i]);
      qry += buf;
      qry += " order by card_index;";

cout << "PERTURB QRY = " << qry << endl;

      if( goldenConn->executeQuery( qry.data() ) )
	 break;

      exp_iter = expTypeFuncMap.find(kw_types[i]);

      if( exp_iter == eexp_iter )
      {
	 cout << "PERTURB TYPE NOT FOUND" << endl;
         continue;
      }

      num_perturbs = 0;
      while( goldenConn->rowsLeft() )
      {
	 impObj = new ExportObject((char *)kw_str.data(), kw_types[i]);
         goldenConn->clearFlag(KW_DATA_END);
	 (exp_iter->second)(goldenConn, impObj);
         if( impObj->cardCount )
         {
	    perturbManPtr->add(kw_str.data(), impObj);
	    num_perturbs++;
         }
         else
            delete impObj;
      }

      total_perturbs += num_perturbs;
   }

   delete kw_types;

   return total_perturbs;
}

