#ifndef _DBRIGIDWALLGEOMETRICSPHERE_H_
#define _DBRIGIDWALLGEOMETRICSPHERE_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *RIGIDWALL_GEOMETRIC_SPHERE
  * keyword */

class DBRigidwallGeometricSphere : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBRigidwallGeometricSphere(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBRigidwallGeometricSphere()
   {
   }

public:
/** Function to get Card3 details for *RIGIDWALL_GEOMETRIC_SPHERE
  * keyword from database */
   void dbReadCard3(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"RADSPH",};
      unsigned int field_types[] = {DATA_DOUBLE, };
      numFields = 1;
      unsigned int field_widths[] = {10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, RIGIDWALL, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card3");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card3",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *RIGIDWALL_GEOMETRIC_SPHERE
  * from database */
   unsigned int importDBRigidwallGeometricSphere()
   {
      dbReadCard3();
      return 0;
   }
};

#endif

