#ifndef _DBRIGIDWALLID_H_
#define _DBRIGIDWALLID_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *RIGIDWALL_ID
  * keyword */

class DBRigidwallId : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBRigidwallId(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBRigidwallId()
   {
   }

public:
/** Function to get CardID details for *RIGIDWALL_ID
  * keyword from database */
   void dbReadCardID(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"RWID","HEADING",};
      unsigned int field_types[] = {DATA_INT, DATA_CHAR_ARRAY, };
      numFields = 2;
      unsigned int field_widths[] = {10, 70, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 2, RIGIDWALL, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("CardID");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","CardID",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *RIGIDWALL_ID
  * from database */
   unsigned int importDBRigidwallId()
   {
      dbReadCardID();
      return 0;
   }
};

#endif

