#ifndef _DBRIGIDWALLPLANARFORCES_H_
#define _DBRIGIDWALLPLANARFORCES_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *RIGIDWALL_PLANAR_FORCES
  * keyword */

class DBRigidwallPlanarForces : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBRigidwallPlanarForces(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBRigidwallPlanarForces()
   {
   }

public:
/** Function to get CardE details for *RIGIDWALL_PLANAR_FORCES
  * keyword from database */
   void dbReadCardE(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"SOFT","SSID","N1","N2","N3","N4",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {1, 2, 3, 4, 5, };
      unsigned int man_types[] = {SET, NOD, NOD, NOD, NOD, };
      unsigned int kw_types[] = {SEGMENT, 9999, 9999, 9999, 9999, };
      unsigned int num_indices = 5;
      numFields = 6;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, RIGIDWALL, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("CardE");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","CardE",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *RIGIDWALL_PLANAR_FORCES
  * from database */
   unsigned int importDBRigidwallPlanarForces()
   {
      dbReadCardE();
      return 0;
   }
};

#endif

