#ifndef _DBRIGIDWALLPLANARORTHO_H_
#define _DBRIGIDWALLPLANARORTHO_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *RIGIDWALL_PLANAR_ORTHO
  * keyword */

class DBRigidwallPlanarOrtho : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBRigidwallPlanarOrtho(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBRigidwallPlanarOrtho()
   {
   }

public:
/** Function to get CardA details for *RIGIDWALL_PLANAR_ORTHO
  * keyword from database */
   void dbReadCardA(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"SFRICA","SFRICB","DFRICA","DFRICB","DECAYA","DECAYB",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, RIGIDWALL, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("CardA");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","CardA",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get CardB details for *RIGIDWALL_PLANAR_ORTHO
  * keyword from database */
   void dbReadCardB(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"NODE1","NODE2","D1","D2","D3",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, 1, };
      unsigned int man_types[] = {NOD, NOD, };
      unsigned int kw_types[] = {9999, 9999, };
      unsigned int num_indices = 2;
      numFields = 5;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, RIGIDWALL, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("CardB");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","CardB",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *RIGIDWALL_PLANAR_ORTHO
  * from database */
   unsigned int importDBRigidwallPlanarOrtho()
   {
      dbReadCardA();
      dbReadCardB();
      return 0;
   }
};

#endif

