#include <iostream>
#include <algorithm>
#include "generic.h"
#include "rigidwalltype.h"
#include "rigidwallexport.h"

#include "dbrigidwallid.h"
#include "dbrigidwallgeometric.h"
#include "dbrigidwallgeometricflat.h"
#include "dbrigidwallgeometricprism.h"
#include "dbrigidwallgeometriccylinder.h"
#include "dbrigidwallgeometricsphere.h"
#include "dbrigidwallgeometricmotion.h"

#include "dbrigidwallplanar.h"
#include "dbrigidwallplanarortho.h"
#include "dbrigidwallplanarfinite.h"
#include "dbrigidwallplanarmoving.h"
#include "dbrigidwallplanarforces.h"

#include <stdlib.h>

using namespace std;

RigidwallExport::RigidwallExport
(
   char         *model_name,
   GoldenConn   *gold_conn,
   RigidwallManager    *rigidwall_man
)
{
   modelName = model_name;
   rigidwallManPtr = rigidwall_man;
   goldenConn = gold_conn;
}

RigidwallType RigidwallExport::getKeywordFromType
	      (
		 unsigned int kw_type,
		 string & key_word
	      )
{
   if( kw_type & (1 << RIGIDWALL_GEOMETRIC) )
   {
      key_word = "*RIGIDWALL_GEOMETRIC";

      if( kw_type & (1 << RIGIDWALL_FLAT) )
         key_word += "_FLAT";
      else if( kw_type & (1 << RIGIDWALL_PRISM) )
         key_word += "_PRISM";
      else if( kw_type & (1 << RIGIDWALL_CYLINDER) )
         key_word += "_CYLINDER";
      else if( kw_type & (1 << RIGIDWALL_SPHERE) )
         key_word += "_SPHERE";
           
      if( kw_type & (1 << RIGIDWALL_MOTION) )
         key_word += "_MOTION";

      if( kw_type & (1 << RIGIDWALL_ID) )
         key_word += "_ID";

      return RIGIDWALL_GEOMETRIC;
   }
   else if( kw_type & (1 << RIGIDWALL_PLANAR) )
   {
      key_word = "*RIGIDWALL_PLANAR";

      if( kw_type & (1 << RIGIDWALL_ORTHO) )
         key_word += "_ORTHO";

      if( kw_type & (1 << RIGIDWALL_FINITE) )
         key_word += "_FINITE";

      if( kw_type & (1 << RIGIDWALL_MOVING) )
         key_word += "_MOVING";

      if( kw_type & (1 << RIGIDWALL_FORCES) )
         key_word += "_FORCES";

      if( kw_type & (1 << RIGIDWALL_ID) )
         key_word += "_ID";

      return RIGIDWALL_PLANAR;
   }
   else
      return RIGIDWALL_NEW_TYPE;
}

unsigned int RigidwallExport::dbReadRigidwalls()
{
   char         **row_data, buf[16];
   unsigned int	i, num_rigidwalls = 0, total_rigidwalls = 0, 
                num_kw_types = 0, rw_type = 0;
   expTypeFuncIterator eexp_iter = expTypeFuncMap.end(), exp_iter;

   string       qry = "select kw_type from ", kw_str;
   string table_name = "`" + modelName + "_RIGIDWALLS`";
   qry += table_name;
   qry += " group by kw_type;";

cout << "KW QRY = " << qry << endl;

   if( goldenConn->executeQuery( qry.data() ) )
      return 0;

   num_kw_types = goldenConn->numRows();

   if( !num_kw_types )
      return 0;

   unsigned int *kw_types = new unsigned int[num_kw_types];

   for(i = 0; i < num_kw_types; i++)
   {
      row_data = goldenConn->nextRow();
      kw_types[i] = atoi( row_data[0] );
cout << "KW RIGIDWALL TYPE = " << kw_types[i] << endl;
   }

   for(i = 0; i < num_kw_types; i++)
   {
      rw_type = getKeywordFromType(kw_types[i], kw_str);

      if( rw_type == RIGIDWALL_NEW_TYPE )
         continue;

cout << "RIGIDWALL KW = " << kw_str << endl;

      qry = "select * from ";
      qry += table_name;
      qry += " where kw_type=";
      sprintf(buf, "%u", kw_types[i]);
      qry += buf;
      qry += " order by card_index;";

cout << "RIGIDWALL QRY = " << qry << endl;

      if( goldenConn->executeQuery( qry.data() ) )
	 break;

      num_rigidwalls = 0;
      while( goldenConn->rowsLeft() )
      {
	 impObj = new ExportObject((char *)kw_str.data(), kw_types[i]);
         goldenConn->clearFlag(KW_DATA_END);

	 switch(rw_type)
	 {
	    case RIGIDWALL_GEOMETRIC:
	       importGeometricType(kw_types[i]);
	       break;
	    case RIGIDWALL_PLANAR:
	       importPlanarType(kw_types[i]);
	       break;
	 }

         if( impObj->cardCount )
         {
	    rigidwallManPtr->add(kw_str.data(), impObj);
	    num_rigidwalls++;
         }
         else
            delete impObj;
      }

      total_rigidwalls += num_rigidwalls;
   }

   delete kw_types;

   return total_rigidwalls;
}

unsigned int RigidwallExport::importGeometricType
             (
                unsigned int & rw_type
             )
{
   if( rw_type & (1 << RIGIDWALL_ID) )
   {
      DBRigidwallId  rw_id(goldenConn, impObj);
      rw_id.importDBRigidwallId();
   }

   DBRigidwallGeometric    rw_geo(goldenConn, impObj);
   rw_geo.importDBRigidwallGeometric();

   if( rw_type & (1 << RIGIDWALL_FLAT) )
   {
      DBRigidwallGeometricFlat  rwgeo_flat(goldenConn, impObj);
      rwgeo_flat.importDBRigidwallGeometricFlat();
   }
   else if( rw_type & (1 << RIGIDWALL_PRISM) )
   {
      DBRigidwallGeometricPrism  rwgeo_prism(goldenConn, impObj);
      rwgeo_prism.importDBRigidwallGeometricPrism();
   }
   else if( rw_type & (1 << RIGIDWALL_CYLINDER) )
   {
      DBRigidwallGeometricCylinder  rwgeo_cyl(goldenConn, impObj);
      rwgeo_cyl.importDBRigidwallGeometricCylinder();
   }
   else if( rw_type & (1 << RIGIDWALL_SPHERE) )
   {
      DBRigidwallGeometricSphere  rwgeo_sph(goldenConn, impObj);
      rwgeo_sph.importDBRigidwallGeometricSphere();
   }

   if( rw_type & (1 << RIGIDWALL_MOTION) )
   {
      DBRigidwallGeometricMotion  rwgeo_mot(goldenConn, impObj);
      rwgeo_mot.importDBRigidwallGeometricMotion();
   }
    
   return 0;
}

unsigned int RigidwallExport::importPlanarType
             (
                unsigned int & rw_type
             )
{
   if( rw_type & (1 << RIGIDWALL_ID) )
   {
      DBRigidwallId  rw_id(goldenConn, impObj);
      rw_id.importDBRigidwallId();
   }

   DBRigidwallPlanar    rw_plan(goldenConn, impObj);
   rw_plan.importDBRigidwallPlanar();

   if( rw_type & (1 << RIGIDWALL_ORTHO) )
   {
      DBRigidwallPlanarOrtho  rwplan_ortho(goldenConn, impObj);
      rwplan_ortho.importDBRigidwallPlanarOrtho();
   }

   if( rw_type & (1 << RIGIDWALL_FINITE) )
   {
      DBRigidwallPlanarFinite  rwplan_fin(goldenConn, impObj);
      rwplan_fin.importDBRigidwallPlanarFinite();
   }

   if( rw_type & (1 << RIGIDWALL_MOVING) )
   {
      DBRigidwallPlanarMoving  rwplan_mov(goldenConn, impObj);
      rwplan_mov.importDBRigidwallPlanarMoving();

      if( rw_type & (1 << RIGIDWALL_ORTHO) )
         cout << "Error: ORTHO and MOVING options are not allowed together" 
	      << endl;
   }

   if( rw_type & (1 << RIGIDWALL_FORCES) )
   {
      DBRigidwallPlanarForces  rwplan_for(goldenConn, impObj);
      rwplan_for.importDBRigidwallPlanarForces();
   }

   return 0;
}

