#ifndef _Rigidwall_EXPORT_H_
#define _Rigidwall_EXPORT_H_

#include <string>
#include <map>
#include "goldenconn.h"
#include "rigidwallmanager.h"
#include "dataline.h"
#include "dbcard.h"
#include "rigidwalltype.h"
#include "exptypemap.h"

/** Class to get data from database for *RIGIDWALL keywords */
class RigidwallExport
{
public:
   /** Constructor for creating this object
     * \param model_name Name of the model for which the data to be obtained
     * \param gold_conn Connection object for accessing the database
     * \param rigidwall_man Manager pointer to store the data obtained
     */
   RigidwallExport
   (
      char                *model_name,
      GoldenConn          *gold_conn,
      RigidwallManager    *rigidwall_man
   );

   ~RigidwallExport()
   {
      rigidwallManPtr = NULL;
      goldenConn = NULL;
   }

   /** Gets the name of keyword from its type. Type is stored in the database
     * \param kw_type Type of keyword
     * \param key_word Keyword name is stored in this string
     */
   RigidwallType getKeywordFromType
		 (
		    unsigned int kw_type,
		    string & key_word
		 );

   /** Imports the *RIGIDWALL_PLANAR keywords from database.
     * \param rw_type Rigidwall planar type to get from database
     * \return Returns the number of planar type of rigidwalls
     */
   unsigned int importPlanarType
		(
                   unsigned int & rw_type
		);

   /** Imports the *RIGIDWALL_GEOMETRIC keywords from database.
     * \param rw_type Rigidwall geometric type to get from database
     * \return Returns the number of geometric type of rigidwalls
     */
   unsigned int importGeometricType
		(
                   unsigned int & rw_type
		);

   /** Fetches the *RIGIDWALL keywords from database and returns 0 if not found 
     * else number of keywords obtained
     */
   unsigned int dbReadRigidwalls();

private:
   string              modelName;
   RigidwallManager    *rigidwallManPtr;
   /** Connection object for accessing the data */
   GoldenConn          *goldenConn;
   /** Object to store the data imported from database */
   ImportObject        *impObj;
   /** A map between type of keyword and pointer to the function to be called */
   map<unsigned int, ExportFunctionPtr>  expTypeFuncMap;
};

#endif

