#include <iostream>
#include <algorithm>
#include "generic.h"
#include "sectiontype.h"
#include "sectionbeamtype.h"
#include "sectionexport.h"
#include "exptitle.h"
#include <stdlib.h>

using namespace std;

SectionExport::SectionExport
(
   char         *model_name,
   GoldenConn   *gold_conn,
   SectionManager    *section_man
)
{
   modelName = model_name;
   sectionManPtr = section_man;
   goldenConn = gold_conn;
   
   initExportShellTypesAndFunctions();
   initExportSolidTypesAndFunctions();
}

int SectionExport::getKeywordFromType
    (
       unsigned int kw_type,
       string & key_word
    )
{
   int title_flag = 0;

   if( kw_type >= TITLE_CARD )
   {
      kw_type -= TITLE_CARD;
      title_flag = 1;
   }

   switch(kw_type)
   {
      case SECTION_DISCRETE:
	 key_word = "*SECTION_DISCRETE";
	 break;
      case SECTION_POINT_SOURCE:
	 key_word = "*SECTION_POINT_SOURCE";
	 break;
      case SECTION_POINT_SOURCE_MIXTURE:
	 key_word = "*SECTION_POINT_SOURCE_MIXTURE";
	 break;
      case SECTION_SHELL:
	 key_word = "*SECTION_SHELL";
	 break;
      case SECTION_SHELL_ALE:
	 key_word = "*SECTION_SHELL_ALE";
	 break;
      case SECTION_SHELL_EFG:
	 key_word = "*SECTION_SHELL_EFG";
	 break;
      case SECTION_TSHELL:
	 key_word = "*SECTION_TSHELL";
	 break;
      case SECTION_BEAM:
      case SECTION_BEAM_HUGHES_LIU:
      case SECTION_BEAM_BELYTSCHKO_SCHWER_RESULTANT:
      case SECTION_BEAM_TRUSS_RESULTANT:
      case SECTION_BEAM_BELYTSCHKO_SCHWER_SOLID:
      case SECTION_BEAM_BELYTSCHKO_SCHWER_TUBULAR:
      case SECTION_BEAM_DISCRETE_OR_CABLE:
      case SECTION_BEAM_2D_PLANE_STRAIN_SHELL:
      case SECTION_BEAM_2D_AXISYMMETRIC_SHELL:
      case SECTION_BEAM_SPOTWELD:
      case SECTION_BEAM_INTEGRATED_WARPED:
      case SECTION_BEAM_RESULTANT_WARPED:
         {
	    key_word = "*SECTION_BEAM";
         }
	 break;
      case SECTION_SEATBELT:
	 key_word = "*SECTION_SEATBELT";
	 break;
      case SECTION_SOLID:
	 key_word = "*SECTION_SOLID";
	 break;
      case SECTION_SOLID_ALE:
	 key_word = "*SECTION_SOLID_ALE";
	 break;
      case SECTION_SOLID_EFG:
	 key_word = "*SECTION_SOLID_EFG";
	 break;
      case SECTION_SPH:
	 key_word = "*SECTION_SPH";
	 break;
      case SECTION_SPH_TENSOR:
	 key_word = "*SECTION_SPH_TENSOR";
	 break;
      case SECTION_SPH_USER:
	 key_word = "*SECTION_SPH_USER";
	 break;
      case SECTION_NEW_TYPE:
      default:
	 return 1;
   }

   if( title_flag )
      key_word += "_TITLE";

   return 0;
}

unsigned int SectionExport::dbReadSections()
{
   char         **row_data, buf[16];
   unsigned int	i, num_sections = 0, total_sections = 0, 
                num_kw_types = 0, kw_type = 0;
   expTypeFuncIterator eexp_iter = expTypeFuncMap.end(), exp_iter;

   string       qry = "select kw_type from ", kw_str;
   string table_name = "`" + modelName + "_SECTIONS`";
   qry += table_name;
   qry += " group by kw_type;";

cout << "KW QRY = " << qry << endl;

   if( goldenConn->executeQuery( qry.data() ) )
      return 0;

   num_kw_types = goldenConn->numRows();

   if( !num_kw_types )
      return 0;

   unsigned int *kw_types = new unsigned int[num_kw_types];

   for(i = 0; i < num_kw_types; i++)
   {
      row_data = goldenConn->nextRow();
      kw_types[i] = atoi( row_data[0] );
cout << "KW SECTION TYPE = " << kw_types[i] << endl;
   }

   for(i = 0; i < num_kw_types; i++)
   {
      if( getKeywordFromType(kw_types[i], kw_str) )
         continue;

cout << "SECTION KW = " << kw_str << endl;

      qry = "select * from ";
      qry += table_name;
      qry += " where kw_type=";
      sprintf(buf, "%u", kw_types[i]);
      qry += buf;
      qry += " order by card_index;";

cout << "SECTION QRY = " << qry << endl;

      if( goldenConn->executeQuery( qry.data() ) )
	 break;

      if( kw_types[i] < TITLE_CARD )
         kw_type = kw_types[i];
      else
         kw_type = kw_types[i] - TITLE_CARD;

      if( !strstr(kw_str.data(), "_BEAM") )
         kw_type = kw_types[i];
      else
         kw_type = SECTION_BEAM;

      exp_iter = expTypeFuncMap.find(kw_type);

      if( exp_iter == eexp_iter )
      {
	 cout << "SECTION TYPE NOT FOUND" << endl;
         continue;
      }

      num_sections = 0;
      if( kw_types[i] < TITLE_CARD )
      {
	 while( goldenConn->rowsLeft() )
         {
            impObj = new ExportObject((char *)kw_str.data(), kw_types[i]);
            goldenConn->clearFlag(KW_DATA_END);
	    (exp_iter->second)(goldenConn, impObj);
	    if( impObj->cardCount )
	    {
	       sectionManPtr->add(kw_str.data(), impObj);
	       num_sections++;
	    }
	    else
	       delete impObj;
         }
      }
      else
      {
         DBTitle title(goldenConn);

	 while( goldenConn->rowsLeft() )
         {
            impObj = new ExportObject((char *)kw_str.data(), kw_types[i]);
            goldenConn->clearFlag(KW_DATA_END);
            title.readCard(impObj);
	    (exp_iter->second)(goldenConn, impObj);
	    if( impObj->cardCount )
	    {
	       sectionManPtr->add(kw_str.data(), impObj);
	       num_sections++;
	    }
	    else
	       delete impObj;
         }
      }

      total_sections += num_sections;
   }

   delete kw_types;

   return total_sections;
}

