#ifndef _Section_EXPORT_H_
#define _Section_EXPORT_H_

#include <string>
#include <map>
#include "goldenconn.h"
#include "sectionmanager.h"
#include "dataline.h"
#include "dbcard.h"
#include "sectiontype.h"
#include "exptypemap.h"

/** Class to get data from database for *SECTION keywords */
class SectionExport
{
public:
   /** Constructor for creating this object
     * \param model_name Name of the model for which the data to be obtained
     * \param gold_conn Connection object for accessing the database
     * \param section_man Manager pointer to store the data obtained
     */
   SectionExport
   (
      char            *model_name,
      GoldenConn      *gold_conn,
      SectionManager  *section_man
   );

   ~SectionExport()
   {
      sectionManPtr = NULL;
      goldenConn = NULL;
      expTypeFuncMap.clear();
   }

   /** Gets the name of keyword from its type. Type is stored in the database
     * \param kw_type Type of keyword
     * \param key_word Keyword name is stored in this string
     */
   int getKeywordFromType
       (
	  unsigned int kw_type,
	  string & key_word
       );

   /** Fetches the *SECTION keywords from database and returns 0 if not found 
     * else number of keywords obtained
     */
   unsigned int dbReadSections();

   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *DAMPING keyword types and their function pointers
     */
   void initExportShellTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *SECTION keyword types and their function pointers
     */
   void initExportSolidTypesAndFunctions();

private:
   string            modelName;
   SectionManager    *sectionManPtr;
   /** Connection object for accessing the data */
   GoldenConn        *goldenConn;
   /** Object to store the data imported from database */
   ImportObject      *impObj;
   /** A map between type of keyword and pointer to the function to be called */
   map<unsigned int, ExportFunctionPtr>  expTypeFuncMap;
};

#endif

