#ifndef _DBSECTIONPOINTSOURCEMIXTURE_H_
#define _DBSECTIONPOINTSOURCEMIXTURE_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *SECTION_POINT_SOURCE_MIXTURE
  * keyword */

class DBSectionPointSourceMixture : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBSectionPointSourceMixture(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBSectionPointSourceMixture()
   {
   }

public:
/** Function to get Card1 details for *SECTION_POINT_SOURCE_MIXTURE
  * keyword from database */
   void dbReadCard1(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"SECID","LCIDT","UNUSED","LCIDVEL","NIDLC001","NIDLC002","NIDLC003","IDIR",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_INT, DATA_UNUSED, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {1, 3, 4, 5, 6, };
      unsigned int man_types[] = {DEFINE, DEFINE, NOD, NOD, NOD, };
      unsigned int kw_types[] = {CURVE, CURVE, 9999, 9999, 9999, };
      unsigned int num_indices = 5;
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 2, SECTION, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card1");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card1",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card2 details for *SECTION_POINT_SOURCE_MIXTURE
  * keyword from database */
   void dbReadCard2(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"LCMDOT1","LCMDOT2","LCMDOT3","LCMDOT4","LCMDOT5","LCMDOT6","LCMDOT7","LCMDOT8",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, 3, 4, 5, 6, 7, };
      unsigned int man_types[] = {DEFINE, DEFINE, DEFINE, DEFINE, DEFINE, DEFINE, DEFINE, DEFINE, };
      unsigned int kw_types[] = {CURVE, CURVE, CURVE, CURVE, CURVE, CURVE, CURVE, CURVE, };
      unsigned int num_indices = 8;
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, SECTION, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card2");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card2",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get Card3 details for *SECTION_POINT_SOURCE_MIXTURE
  * keyword from database */
   void dbReadCard3(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"NODEID","VECID","ORIFAREA",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, 1, };
      unsigned int man_types[] = {NOD, DEFINE, };
      unsigned int kw_types[] = {9999, VECTOR, };
      unsigned int num_indices = 2;
      numFields = 3;
      unsigned int field_widths[] = {10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, SECTION, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card3");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card3",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *SECTION_POINT_SOURCE_MIXTURE
  * from database */
   unsigned int importDBSectionPointSourceMixture()
   {
      dbReadCard1();
      dbReadCard2();
      dbReadCard3();
      return 0;
   }
};

#endif

