#ifndef _DBSECTIONSOLID_H_
#define _DBSECTIONSOLID_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *SECTION_SOLID
  * keyword */

class DBSectionSolid : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBSectionSolid(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBSectionSolid()
   {
   }

public:
/** Function to get Card1 details for *SECTION_SOLID
  * keyword from database */
   int dbReadCard1(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"SECID","ELFORM","AET",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_INT, DATA_INT, };
      numFields = 3;
      unsigned int field_widths[] = {10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return 0;
      }
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 2, SECTION, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card1");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card1",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
      if( wordArray[3] )
         return atoi(wordArray[3]);
      else
         return 0;
   }

/** Function to get CardALE details for *SECTION_SOLID
  * keyword from database */
   void dbReadCardALE(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"AFAC","BFAC","CFAC","DFAC","START","END","AAFAC",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 7;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, SECTION, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("CardALE");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","CardALE",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get CardEFG details for *SECTION_SOLID
  * keyword from database */
   void dbReadCardEFG(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"DX","DY","DZ","ISPLINE","IDILA","IEBT","IDIM","TOLDEF",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, SECTION, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("CardEFG");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","CardEFG",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get CardELFORM details for *SECTION_SOLID
  * keyword from database */
   void dbReadCardELFORM(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"NIP","NXDOF","IHGF","ITAJ","LMC","NHSV",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 6;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      nip = 0;
      if( wordArray[2] )
         nip = atoi(wordArray[2]);
      lmc = 0;
      if( wordArray[6] )
         lmc = atoi(wordArray[6]);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("CardELFORM");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","CardELFORM",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to get CardNIP details for *SECTION_SOLID
  * keyword from database */
   void dbReadCardNIP(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"XI","ETA","ZETA","WGT",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 4;
      unsigned int field_widths[] = {10, 10, 10, 10, };
      unsigned int end_loop;
      end_loop = nip;
      for(loop_count = 0; loop_count < end_loop; loop_count++)
      {
         numFields = 4;
         wordArray = goldenConn->nextCard();
         if( !wordArray )
         {
            numFields = 0;
         return;
         }
         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","CardNIP",loop_count);
            cardObj = new DBCard(name_buf);
            ((DBCard *)cardObj)->index = atoi(wordArray[0]);
            cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
            impObj->addCard(cardObj);
         }
         impObj->cardCount++;
      }
   }

/** Function to get CardLMC details for *SECTION_SOLID
  * keyword from database */
   void dbReadCardLMC(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"P1","P2","P3","P4","P5","P6","P7","P8",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      unsigned int end_loop;
      end_loop = ((lmc%8) ? (lmc/8)+1 : lmc/8);
      for(loop_count = 0; loop_count < end_loop; loop_count++)
      {
         numFields = 8;
         wordArray = goldenConn->nextCard();
         if( !wordArray )
         {
            numFields = 0;
         return;
         }
         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","CardLMC",loop_count);
            cardObj = new DBCard(name_buf);
            ((DBCard *)cardObj)->index = atoi(wordArray[0]);
            cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
            impObj->addCard(cardObj);
         }
         impObj->cardCount++;
      }
   }

/** Function to import all the cards of keyword *SECTION_SOLID
  * from database */
   unsigned int importDBSectionSolid()
   {
      int elform = 0;
      elform = dbReadCard1();
      const char *kw = impObj->getKeyword().data();
      if( strstr(kw, "ALE") )
      {
         dbReadCardALE();
      }
      if( strstr(kw, "EFG") )
      {
         dbReadCardEFG();
      }
      if( elform == 101 || elform == 102 || elform == 103 || elform == 104 || elform == 105 )
      {
         dbReadCardELFORM();
         dbReadCardNIP();
         dbReadCardLMC();
      }
      return 0;
   }
public:
   int nip;
   int lmc;
};

#endif

