#ifndef _DBSENSORDEFINECALCMATH_H_
#define _DBSENSORDEFINECALCMATH_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *SENSOR_DEFINE_CALC_MATH
  * keyword */

class DBSensorDefineCalcMath : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBSensorDefineCalcMath(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBSensorDefineCalcMath()
   {
   }

public:
/** Function to get Card details for *SENSOR_DEFINE_CALC_MATH
  * keyword from database */
   void dbReadCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"SENSID","CALC","SENS1","SENS2","SENS3","SENS4","SENS5","SENS6",};
      unsigned int field_types[] = {DATA_INT, DATA_CHAR_ARRAY, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {2, 3, 4, 5, 6, 7, };
      unsigned int man_types[] = {SENSOR, SENSOR, SENSOR, SENSOR, SENSOR, SENSOR, };
      unsigned int kw_types[] = {9999, 9999, 9999, 9999, 9999, 9999, };
      unsigned int num_indices = 6;
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 2, SENSOR, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *SENSOR_DEFINE_CALC_MATH
  * from database */
   unsigned int importDBSensorDefineCalcMath()
   {
      dbReadCard();
      return 0;
   }
};

#endif

