#ifndef _DBSENSORDEFINEELEMENT_H_
#define _DBSENSORDEFINEELEMENT_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *SENSOR_DEFINE_ELEMENT
  * keyword */

class DBSensorDefineElement : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBSensorDefineElement(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBSensorDefineElement()
   {
   }

public:
/** Function to get Card details for *SENSOR_DEFINE_ELEMENT
  * keyword from database */
   void dbReadCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"SENSID","ETYPE","ELEMID","COMP","CTYPE","LAYER",};
      unsigned int field_types[] = {DATA_INT, DATA_CHAR_ARRAY, DATA_INT, DATA_CHAR_ARRAY, DATA_CHAR_ARRAY, DATA_CHAR_ARRAY, };
      numFields = 6;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 2, SENSOR, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         sensorElementFind(&wordArray[2], numFields, 1, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *SENSOR_DEFINE_ELEMENT
  * from database */
   unsigned int importDBSensorDefineElement()
   {
      dbReadCard();
      return 0;
   }
};

#endif

