#ifndef _DBSENSORDEFINENODE_H_
#define _DBSENSORDEFINENODE_H_

#include "manager.h"
#include "dispexport.h"
#include "getdbbase.h"

/** Class used for getting data from database for *SENSOR_DEFINE_NODE
  * keyword */

class DBSensorDefineNode : public GetDBBase
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBSensorDefineNode(GoldenConn *gold_conn, ImportObject *imp_obj) : GetDBBase (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBSensorDefineNode()
   {
   }

public:
/** Function to get Card details for *SENSOR_DEFINE_NODE
  * keyword from database */
   void dbReadCard(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"SENSID","NODE1","NODE2","VID","CRD","CTYPE",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_CHAR_ARRAY, DATA_INT, DATA_CHAR_ARRAY, };
      unsigned int field_indices[] = {1, 2, 3, 4, };
      unsigned int man_types[] = {NOD, NOD, DEFINE, DEFINE, };
      unsigned int kw_types[] = {9999, 9999, VECTOR, COORDINATE, };
      unsigned int num_indices = 4;
      numFields = 6;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 2, SENSOR, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("Card");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","Card",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *SENSOR_DEFINE_NODE
  * from database */
   unsigned int importDBSensorDefineNode()
   {
      dbReadCard();
      return 0;
   }
};

#endif

