#include <iostream>
#include <algorithm>
#include "generic.h"
#include "sensortype.h"
#include "sensorexport.h"
#include <stdlib.h>

using namespace std;

SensorExport::SensorExport
(
   char             *model_name,
   GoldenConn       *gold_conn,
   SensorManager    *sensor_man
)
{
   modelName = model_name;
   sensorManPtr = sensor_man;
   goldenConn = gold_conn;

   initExportSensorTypesAndFunctions();
}

int SensorExport::getKeywordFromType
    (
       unsigned int kw_type,
       string & key_word
    )
{
   switch(kw_type)
   {
      case SENSOR_CONTROL:
	 key_word = "*SENSOR_CONTROL";
	 break;
      case SENSOR_DEFINE_CALC_MATH:
	 key_word = "*SENSOR_DEFINE_CALC_MATH";
	 break;
      case SENSOR_DEFINE_ELEMENT:
	 key_word = "*SENSOR_DEFINE_ELEMENT";
	 break;
      case SENSOR_DEFINE_FORCE:
	 key_word = "*SENSOR_DEFINE_FORCE";
	 break;
      case SENSOR_DEFINE_NODE:
	 key_word = "*SENSOR_DEFINE_NODE";
	 break;
      case SENSOR_SWITCH:
	 key_word = "*SENSOR_SWITCH";
	 break;
      case SENSOR_SWITCH_CALC_LOGIC:
	 key_word = "*SENSOR_SWITCH_CALC_LOGIC";
	 break;
      case SENSOR_NEW_TYPE:
      default:
	 return 1;
   }
   return 0;
}

unsigned int SensorExport::dbReadSensors()
{
   char         **row_data, buf[16];
   unsigned int	i, num_sensors = 0, total_sensors = 0, num_kw_types = 0;
   expTypeFuncIterator eexp_iter = expTypeFuncMap.end(), exp_iter;

   string       qry = "select kw_type from ", kw_str;
   string table_name = "`" + modelName + "_SENSORS`";
   qry += table_name;
   qry += " group by kw_type;";

cout << "KW QRY = " << qry << endl;

   if( goldenConn->executeQuery( qry.data() ) )
      return 0;

   num_kw_types = goldenConn->numRows();

   if( !num_kw_types )
      return 0;

   unsigned int *kw_types = new unsigned int[num_kw_types];

   for(i = 0; i < num_kw_types; i++)
   {
      row_data = goldenConn->nextRow();
      kw_types[i] = atoi( row_data[0] );
cout << "KW SENSOR TYPE = " << kw_types[i] << endl;
   }

   for(i = 0; i < num_kw_types; i++)
   {
      if( getKeywordFromType(kw_types[i], kw_str) )
         continue;

cout << "SENSOR KW = " << kw_str << endl;

      qry = "select * from ";
      qry += table_name;
      qry += " where kw_type=";
      sprintf(buf, "%u", kw_types[i]);
      qry += buf;
      qry += " order by card_index;";

cout << "SENSOR QRY = " << qry << endl;

      if( goldenConn->executeQuery( qry.data() ) )
	 break;

      exp_iter = expTypeFuncMap.find(kw_types[i]);

      if( exp_iter == eexp_iter )
      {
	 cout << "SENSOR TYPE NOT FOUND" << endl;
         continue;
      }

      num_sensors = 0;
      while( goldenConn->rowsLeft() )
      {
	 impObj = new ExportObject((char *)kw_str.data(), kw_types[i]);
         goldenConn->clearFlag(KW_DATA_END);
	 (exp_iter->second)(goldenConn, impObj);
	 if( impObj->cardCount )
	 {
	    sensorManPtr->add(kw_str.data(), impObj);
	    num_sensors++;
	 }
	 else
	    delete impObj;
      }

      total_sensors += num_sensors;
   }

   delete kw_types;

   return total_sensors;
}

