#ifndef _Sensor_EXPORT_H_
#define _Sensor_EXPORT_H_

#include <string>
#include <map>
#include "goldenconn.h"
#include "sensormanager.h"
#include "dataline.h"
#include "dbcard.h"
#include "sensortype.h"
#include "exptypemap.h"

/** Class to get data from database for *SENSOR keywords */
class SensorExport
{
public:
   /** Constructor for creating this object
     * \param model_name Name of the model for which the data to be obtained
     * \param gold_conn Connection object for accessing the database
     * \param sensor_man Manager pointer to store the data obtained
     */
   SensorExport
   (
      char           *model_name,
      GoldenConn     *gold_conn,
      SensorManager  *sensor_man
   );

   ~SensorExport()
   {
      sensorManPtr = NULL;
      goldenConn = NULL;
      expTypeFuncMap.clear();
   }

   /** Gets the name of keyword from its type. Type is stored in the database
     * \param kw_type Type of keyword
     * \param key_word Keyword name is stored in this string
     */
   int getKeywordFromType
       (
	  unsigned int kw_type,
	  string & key_word
       );

   /** Fetches the *SENSOR keywords from database and returns 0 if not found 
     * else number of keywords obtained
     */
   unsigned int dbReadSensors();

   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *SENSOR keyword types and their function pointers
     */
   void initExportSensorTypesAndFunctions();

private:
   string           modelName;
   SensorManager    *sensorManPtr;
   /** Connection object for accessing the data */
   GoldenConn       *goldenConn;
   /** Object to store the data imported from database */
   ImportObject     *impObj;
   /** A map between type of keyword and pointer to the function to be called */
   map<unsigned int, ExportFunctionPtr>  expTypeFuncMap;
};

#endif

