#ifndef _DBSETNODECOLUMN_H_
#define _DBSETNODECOLUMN_H_

#include "manager.h"
#include "dispexport.h"
#include "dbsetidattribute.h"

/** Class used for getting data from database for *SET_NODE_COLUMN
  * keyword */

class DBSetNodeColumn : public DBSetIdAttribute
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBSetNodeColumn(GoldenConn *gold_conn, ImportObject *imp_obj) : DBSetIdAttribute (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBSetNodeColumn()
   {
   }

public:
/** Function to get CardLoop details for *SET_NODE_COLUMN
  * keyword from database */
   void dbReadCardLoop(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"NID","A1","A2","A3","A4",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {NOD, };
      unsigned int kw_types[] = {9999, };
      unsigned int num_indices = 1;
      numFields = 5;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, SET, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("CardLoop");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","CardLoop",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *SET_NODE_COLUMN
  * from database */
   unsigned int importDBSetNodeColumn()
   {
      importDBSetIdAttribute();
      unsigned int loop_count = 0;
      dbReadCardLoop(loop_count);
      loop_count++;
      while(numFields)
      {
         dbReadCardLoop(loop_count);
         loop_count++;
      }
      ((ExportObject *)impObj)->loopCount = loop_count-1;
      return 0;
   }
};

#endif

