#ifndef _Set_EXPORT_H_
#define _Set_EXPORT_H_

#include <string>
#include <map>
#include "goldenconn.h"
#include "setmanager.h"
#include "dataline.h"
#include "dbcard.h"
#include "settype.h"
#include "exptypemap.h"

/** Class to get data from database for *SET keywords */
class SetExport
{
public:
   /** Constructor for creating this object
     * \param model_name Name of the model for which the data to be obtained
     * \param gold_conn Connection object for accessing the database
     * \param set_man Manager pointer to store the data obtained
     */
   SetExport
   (
      char           *model_name,
      GoldenConn   *gold_conn,
      SetManager    *set_man
   );

   ~SetExport()
   {
      
      setManPtr = NULL;
      goldenConn = NULL;
      expTypeFuncMap.clear();
   }

/*
   int getKeywordFromType
       (
	  unsigned int kw_type,
	  string & key_word
       );
*/

   /** Fetches the *SET keywords from database and returns 0 if not found 
     * else number of keywords obtained
     */
   unsigned int dbReadSets();

   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *SET keyword types and their function pointers
     */
   void initExportNodeTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *SET keyword types and their function pointers
     */
   void initExportSimpleTypesAndFunctions();
   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *SET keyword types and their function pointers
     */
   void initExportPartTypesAndFunctions();

private:
   string        modelName;
   SetManager    *setManPtr;
   /** Connection object for accessing the data */
   GoldenConn    *goldenConn;
   /** Object to store the data imported from database */
   ImportObject  *impObj;
   /** A map between type of keyword and pointer to the function to be called */
   map<unsigned int, ExportFunctionPtr>  expTypeFuncMap;
};

#endif

