#ifndef _DBSETGENERAL_H_
#define _DBSETGENERAL_H_

#include "manager.h"
#include "dispexport.h"
#include "dbsetidcard.h"

/** Class used for getting data from database for *SET_BEAM_GENERAL
  * keyword */

class DBSetGeneral : public DBSetIdCard
{
public:
/** Class constructor for creating the objects.
  * \param gold_conn GoldenConn object to access database
  * \param imp_obj ImportObject pointer to hold data
  */
   DBSetGeneral(GoldenConn *gold_conn, ImportObject *imp_obj) : DBSetIdCard (gold_conn, imp_obj)
   {
   }

/** Class destructor for releasing the memory in the object.
  */
   virtual ~DBSetGeneral()
   {
   }

public:
/** Function to get CardLoop details for *SET_BEAM_GENERAL
  * keyword from database */
   void dbReadCardLoop(unsigned int loop_count = (1 << 31))
   {
      const char *fields[] = {"OPTION","E1","E2","E3","E4","E5","E6","E7",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 8;
      unsigned int field_widths[] = {10, 10, 10, 10, 10, 10, 10, 10, };
      wordArray = goldenConn->nextCard();
      if( !wordArray )
      {
         numFields = 0;
         return;
      }
      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )
         addIDToFile(wordArray, 0, SET, impObj);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         setGenFind(&wordArray[2], numFields, 1, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         if( loop_count & (1<<31) )
            cardObj = new DBCard("CardLoop");
         else
         {
            char name_buf[64];
            sprintf(name_buf,"%s_%d","CardLoop",loop_count);
            cardObj = new DBCard(name_buf);
         }
         ((DBCard *)cardObj)->index = atoi(wordArray[0]);
         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);
         impObj->addCard(cardObj);
      }
      impObj->cardCount++;
   }

/** Function to import all the cards of keyword *SET_BEAM_GENERAL
  * from database */
   unsigned int importDBSetGeneral()
   {
      importDBSetIdCard();
      unsigned int loop_count = 0;
      dbReadCardLoop(loop_count);
      loop_count++;
      while(numFields)
      {
         dbReadCardLoop(loop_count);
         loop_count++;
      }
      ((ExportObject *)impObj)->loopCount = loop_count-1;
      return 0;
   }
};

#endif

