#include <iostream>
#include <algorithm>
#include "generic.h"
#include "termtype.h"
#include "termexport.h"
#include <stdlib.h>

using namespace std;

TermExport::TermExport
(
   char         *model_name,
   GoldenConn   *gold_conn,
   TermManager    *term_man
)
{
   modelName = model_name;
   termManPtr = term_man;
   goldenConn = gold_conn;
   

   initExportTermTypesAndFunctions();
}

int TermExport::getKeywordFromType
    (
       unsigned int kw_type,
       string & key_word
    )
{
   switch(kw_type)
   {
      case TERMINATION_BODY:
	 key_word = "*TERMINATION_BODY";
	 break;
      case TERMINATION_CONTACT:
	 key_word = "*TERMINATION_CONTACT";
	 break;
      case TERMINATION_CURVE:
	 key_word = "*TERMINATION_CURVE";
	 break;
      case TERMINATION_DELETED_SHELLS:
	 key_word = "*TERMINATION_DELETED_SHELLS";
	 break;
      case TERMINATION_DELETED_SHELLS_SET:
	 key_word = "*TERMINATION_DELETED_SHELLS_SET";
	 break;
      case TERMINATION_NODE:
	 key_word = "*TERMINATION_NODE";
	 break;
      case TERM_NEW_TYPE:
      default:
	 return 1;
   }
   return 0;
}

unsigned int TermExport::dbReadTerms()
{
   char         **row_data, buf[16];
   unsigned int	i, num_terms = 0, total_terms = 0, num_kw_types = 0;
   expTypeFuncIterator eexp_iter = expTypeFuncMap.end(), exp_iter;

   string       qry = "select kw_type from ", kw_str;
   string table_name = "`" + modelName + "_TERMINATIONS`";
   qry += table_name;
   qry += " group by kw_type;";

cout << "KW QRY = " << qry << endl;

   if( goldenConn->executeQuery( qry.data() ) )
      return 0;

   num_kw_types = goldenConn->numRows();

   if( !num_kw_types )
      return 0;

   unsigned int *kw_types = new unsigned int[num_kw_types];

   for(i = 0; i < num_kw_types; i++)
   {
      row_data = goldenConn->nextRow();
      kw_types[i] = atoi( row_data[0] );
cout << "KW TERM TYPE = " << kw_types[i] << endl;
   }

   for(i = 0; i < num_kw_types; i++)
   {
      if( getKeywordFromType(kw_types[i], kw_str) )
         continue;

cout << "TERM KW = " << kw_str << endl;

      qry = "select * from ";
      qry += table_name;
      qry += " where kw_type=";
      sprintf(buf, "%u", kw_types[i]);
      qry += buf;
      qry += " order by card_index;";

cout << "TERM QRY = " << qry << endl;

      if( goldenConn->executeQuery( qry.data() ) )
	 break;

      exp_iter = expTypeFuncMap.find(kw_types[i]);

      if( exp_iter == eexp_iter )
      {
	 cout << "TERM TYPE NOT FOUND" << endl;
         continue;
      }

      num_terms = 0;
      while( goldenConn->rowsLeft() )
      {
	 impObj = new ExportObject((char *)kw_str.data(), kw_types[i]);
         goldenConn->clearFlag(KW_DATA_END);
	 (exp_iter->second)(goldenConn, impObj);
	 if( impObj->cardCount )
	 {
	    termManPtr->add(kw_str.data(), impObj);
	    num_terms++;
	 }
	 else
	    delete impObj;
      }

      total_terms += num_terms;
   }

   delete kw_types;

   return total_terms;
}

