#ifndef _Term_EXPORT_H_
#define _Term_EXPORT_H_

#include <string>
#include <map>
#include "goldenconn.h"
#include "termmanager.h"
#include "dataline.h"
#include "dbcard.h"
#include "termtype.h"
#include "exptypemap.h"

/** Class to get data from database for *TERMINATION keywords */
class TermExport
{
public:
   /** Constructor for creating this object
     * \param model_name Name of the model for which the data to be obtained
     * \param gold_conn Connection object for accessing the database
     * \param term_man Manager pointer to store the data obtained
     */
   TermExport
   (
      char         *model_name,
      GoldenConn   *gold_conn,
      TermManager  *term_man
   );

   ~TermExport()
   {
      termManPtr = NULL;
      goldenConn = NULL;
      expTypeFuncMap.clear();
   }

   /** Gets the name of keyword from its type. Type is stored in the database
     * \param kw_type Type of keyword
     * \param key_word Keyword name is stored in this string
     */
   int getKeywordFromType
       (
	  unsigned int kw_type,
	  string & key_word
       );

   /** Fetches the *TERMINATION keywords from database and returns 0 if not found 
     * else number of keywords obtained
     */
   unsigned int dbReadTerms();

   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *TERMINATION keyword types and their function pointers
     */
   void initExportTermTypesAndFunctions();

private:
   string        modelName;
   TermManager   *termManPtr;
   /** Connection object for accessing the data */
   GoldenConn    *goldenConn;
   /** Object to store the data imported from database */
   ImportObject  *impObj;
   /** A map between type of keyword and pointer to the function to be called */
   map<unsigned int, ExportFunctionPtr>  expTypeFuncMap;
};

#endif

