#include <iostream>
#include <algorithm>
#include "generic.h"
#include "usertype.h"
#include "userexport.h"
#include <stdlib.h>

using namespace std;

UserExport::UserExport
(
   char         *model_name,
   GoldenConn   *gold_conn,
   UserManager    *user_man
)
{
   modelName = model_name;
   userManPtr = user_man;
   goldenConn = gold_conn;

   initExportUserTypesAndFunctions();
}

int UserExport::getKeywordFromType
    (
       unsigned int kw_type,
       string & key_word
    )
{
   switch(kw_type)
   {
      case USER_INTERFACE_CONTROL:
	 key_word = "*USER_INTERFACE_CONTROL";
	 break;
      case USER_INTERFACE_FRICTION:
	 key_word = "*USER_INTERFACE_FRICTION";
	 break;
      case USER_LOADING:
	 key_word = "*USER_LOADING";
	 break;
      case USER_NEW_TYPE:
      default:
	 return 1;
   }
   return 0;
}

unsigned int UserExport::dbReadUsers()
{
   char         **row_data, buf[16];
   unsigned int	i, num_users = 0, total_users = 0, num_kw_types = 0;
   expTypeFuncIterator eexp_iter = expTypeFuncMap.end(), exp_iter;

   string       qry = "select kw_type from ", kw_str;
   string table_name = "`" + modelName + "_USERS`";
   qry += table_name;
   qry += " group by kw_type;";

cout << "KW QRY = " << qry << endl;

   if( goldenConn->executeQuery( qry.data() ) )
      return 0;

   num_kw_types = goldenConn->numRows();

   if( !num_kw_types )
      return 0;

   unsigned int *kw_types = new unsigned int[num_kw_types];

   for(i = 0; i < num_kw_types; i++)
   {
      row_data = goldenConn->nextRow();
      kw_types[i] = atoi( row_data[0] );
cout << "KW USER TYPE = " << kw_types[i] << endl;
   }

   for(i = 0; i < num_kw_types; i++)
   {
      if( getKeywordFromType(kw_types[i], kw_str) )
         continue;

cout << "USER KW = " << kw_str << endl;

      qry = "select * from ";
      qry += table_name;
      qry += " where kw_type=";
      sprintf(buf, "%u", kw_types[i]);
      qry += buf;
      qry += " order by card_index;";

cout << "USER QRY = " << qry << endl;

      if( goldenConn->executeQuery( qry.data() ) )
	 break;

      exp_iter = expTypeFuncMap.find(kw_types[i]);

      if( exp_iter == eexp_iter )
      {
	 cout << "USER TYPE NOT FOUND" << endl;
         continue;
      }

      num_users = 0;
      while( goldenConn->rowsLeft() )
      {
	 impObj = new ExportObject((char *)kw_str.data(), kw_types[i]);
         goldenConn->clearFlag(KW_DATA_END);
	 (exp_iter->second)(goldenConn, impObj);
	 if( impObj->cardCount )
	 {
	    userManPtr->add(kw_str.data(), impObj);
	    num_users++;
	 }
	 else
	    delete impObj;
      }

      total_users += num_users;
   }

   delete kw_types;

   return total_users;
}

