#ifndef _User_EXPORT_H_
#define _User_EXPORT_H_

#include <string>
#include <map>
#include "goldenconn.h"
#include "usermanager.h"
#include "dataline.h"
#include "dbcard.h"
#include "usertype.h"
#include "exptypemap.h"

/** Class to get data from database for *USER keywords */
class UserExport
{
public:
   /** Constructor for creating this object
     * \param model_name Name of the model for which the data to be obtained
     * \param gold_conn Connection object for accessing the database
     * \param user_man Manager pointer to store the data obtained
     */
   UserExport
   (
      char           *model_name,
      GoldenConn   *gold_conn,
      UserManager    *user_man
   );

   ~UserExport()
   {
      userManPtr = NULL;
      goldenConn = NULL;
      expTypeFuncMap.clear();
   }

   /** Gets the name of keyword from its type. Type is stored in the database
     * \param kw_type Type of keyword
     * \param key_word Keyword name is stored in this string
     */
   int getKeywordFromType
       (
	  unsigned int kw_type,
	  string & key_word
       );

   /** Fetches the *USER keywords from database and returns 0 if not found 
     * else number of keywords obtained
     */
   unsigned int dbReadUsers();

   /** A generated function from the XML files of keywords. Creates a map
     * between each type of keyword and a pointer to a function to be called
     * Initializes the *USER keyword types and their function pointers
     */
   void initExportUserTypesAndFunctions();

private:
   string        modelName;
   UserManager   *userManPtr;
   /** Connection object for accessing the data */
   GoldenConn    *goldenConn;
   /** Object to store the data imported from database */
   ImportObject  *impObj;
   /** A map between type of keyword and pointer to the function to be called */
   map<unsigned int, ExportFunctionPtr>  expTypeFuncMap;
};

#endif

