#ifndef _FILE_GENERIC_H_
#define _FILE_GENERIC_H_

#include <string>
#include <string.h>
#include <stdio.h>
#include <stdlib.h>

using namespace std;

/** Generic file function for writing data to disk.
  * \param file_name Name of file to which the data to be written
  * \param array A pointer holding the char data
  * \param size Count of chars to be written
  */
int writeFile(const char *file_name, void *array, size_t size);
/** Gets the table name from the given file name by removing '&', '.', '\\'
  * etc to make the file name and table name in database a unique
  * \param path Path of file with name
  * \return Copied name. Name has to be freed after use
  */
char *getTableNameFromFile(char *path, unsigned int *table_id, const char *parent_dir);
/** Gets the table name from the given file by removing '&', '.', '\\'
  * etc to make the file name and table name in database a unique. This name
  * for the first file. This file can have include files also. If file name is
  * more than 40 chars, then it is cutailed to 40 and returned as the table name
  * in database is restricted to 64 chars. The remaining 15 chars are used for
  * ___ENTITY in table name.
  * \param path Path of file with name
  * \return Copied name. Name has to be freed after use
  */
char *getMainTableNameFromFile(char *path, unsigned int *out_table_id = NULL);
/** Changes windows path '\\' to '//'.
  * \param path Path of file. Path is changed to slash and returned
  */
void changeBackSlash(char *path);
/** Gets the combined name from both the main and include files. 20 chars from
  * main file and 20 chars from include file are taken, appended and returned
  * a copy. This is done to take care when there are same include file names 
  * in different directories. When the include file names are same, the table
  * in database is overwritten with the new data every time. 
  * \param path Path of first file.
  * \param path Path of second file.
  */
char *getCombinedTableName(const char *first, const char *second);
/** Gets the file name after removing the _Index of file from the include
  * files only not from the main file
  * \param file_name Name of file
  * \param return_name Returned file name
  * \return The file index
  */
int getFileName(const char *file_name, string & ret_name);

void _mkdir(const char *dir);

#endif

