#ifndef _ABAdvancedALE_h_
#define _ABAdvancedALE_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *AIRBAG_ADVANCED_ALE keyword
  * from LSDYNA native file */

class ABAdvancedALE : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ABAdvancedALE(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ABAdvancedALE()
   {
   }

public:
/** Function to import BagIDs details for *AIRBAG_ADVANCED_ALE
  * keyword from file */
   void readBagIDs()
   {
      const char *fields[] = {"BAGID1","BAGID2","BAGID3","BAGID4","BAGID5","BAGID6","BAGID7","BAGID8",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, 3, 4, 5, 6, 7, };
      unsigned int man_types[] = {DEFINE, DEFINE, DEFINE, DEFINE, DEFINE, DEFINE, DEFINE, DEFINE, };
      unsigned int kw_types[] = {ALEBAG, ALEBAG, ALEBAG, ALEBAG, ALEBAG, ALEBAG, ALEBAG, ALEBAG, };
      unsigned int num_indices = 8;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("BagIDs");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import HoleIDs details for *AIRBAG_ADVANCED_ALE
  * keyword from file */
   void readHoleIDs()
   {
      const char *fields[] = {"HOLEID1","HOLEID2","HOLEID3","HOLEID4","HOLEID5","HOLEID6","HOLEID7","HOLEID8",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, 3, 4, 5, 6, 7, };
      unsigned int man_types[] = {DEFINE, DEFINE, DEFINE, DEFINE, DEFINE, DEFINE, DEFINE, DEFINE, };
      unsigned int kw_types[] = {BAGHOLE, BAGHOLE, BAGHOLE, BAGHOLE, BAGHOLE, BAGHOLE, BAGHOLE, BAGHOLE, };
      unsigned int num_indices = 8;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("HoleIDs");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import InflIDs details for *AIRBAG_ADVANCED_ALE
  * keyword from file */
   void readInflIDs()
   {
      const char *fields[] = {"INFLID1","INFLID2","INFLID3","INFLID4","INFLID5","INFLID6","INFLID7","INFLID8",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, 3, 4, 5, 6, 7, };
      unsigned int man_types[] = {DEFINE, DEFINE, DEFINE, DEFINE, DEFINE, DEFINE, DEFINE, DEFINE, };
      unsigned int kw_types[] = {INFLATOR, INFLATOR, INFLATOR, INFLATOR, INFLATOR, INFLATOR, INFLATOR, INFLATOR, };
      unsigned int num_indices = 8;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("InflIDs");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import ALEMesh details for *AIRBAG_ADVANCED_ALE
  * keyword from file */
   void readALEMesh()
   {
      const char *fields[] = {"NX","NY","NZ","UNUSED","ARSNID","IDCENT","EXSID",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_UNUSED, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      nx = 0;
      if( wordArray[0] )
         nx = atoi(wordArray[0]);
      ny = 0;
      if( wordArray[1] )
         ny = atoi(wordArray[1]);
      nz = 0;
      if( wordArray[2] )
         nz = atoi(wordArray[2]);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         airbagAdvancedAle(wordArray, numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("ALEMesh");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import MeshDetails details for *AIRBAG_ADVANCED_ALE
  * keyword from file */
   void readMeshDetails()
   {
      const char *fields[] = {"LX","LY","LZ","ITRANS","UIDAIR",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {3, 4, };
      unsigned int man_types[] = {DEFINE, PARTC, };
      unsigned int kw_types[] = {TRANS, 9999, };
      unsigned int num_indices = 2;
      numFields = 5;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("MeshDetails");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import CVCard1 details for *AIRBAG_ADVANCED_ALE
  * keyword from file */
   void readCVCard1()
   {
      const char *fields[] = {"ATMOST","ATMOSP","UNUSED","GC","CC","UNUSED","MWD","SPSF",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_UNUSED, DATA_DOUBLE, DATA_DOUBLE, DATA_UNUSED, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("CVCard1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import CVCard2 details for *AIRBAG_ADVANCED_ALE
  * keyword from file */
   int readCVCard2()
   {
      const char *fields[] = {"SWTIME","UNUSED","HG","NAIR",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_UNUSED, DATA_DOUBLE, DATA_INT, };
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return 0;
      nair = 0;
      if( wordArray[3] )
         nair = atoi(wordArray[3]);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("CVCard2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
      if( wordArray[3] )
         return atoi(wordArray[3]);
      else
         return 0;
   }

/** Function to import AirCard details for *AIRBAG_ADVANCED_ALE
  * keyword from file */
   void readAirCard()
   {
      const char *fields[] = {"UNUSED","UNUSED","UNUSED","MWAIR","INITM","AIRA","AIRB","AIRC",};
      unsigned int field_types[] = {DATA_UNUSED, DATA_UNUSED, DATA_UNUSED, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int i, end_loop;
      end_loop = nair;
      for(i = 0; i < end_loop; i++)
      {
         numFields = 8;
         wordArray = dataLine->readNextCardAsWords(numFields);
         if( !numFields && dataLine->isFlagOn(KW_READ_END) ) return;

         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
         {
            cardObj = new Card("AirCard");
            cardObj->addFields(numFields, field_types, fields, wordArray);
            impObj->addCard(cardObj);
         }
      }
   }

/** Function to import all the cards of the keyword *AIRBAG_ADVANCED_ALE
  * from LSDYNA native file */
   unsigned int importABAdvancedALE()
   {
      int nair = 0;
      readBagIDs();
      readHoleIDs();
      readInflIDs();
      readALEMesh();
      if(nx && ny && nz)
      {
         readMeshDetails();
      }
      readCVCard1();
      nair = readCVCard2();
      readAirCard();
      return 0;
   }
public:
   int nx;
   int ny;
   int nz;
   int nair;
};

#endif

