#ifndef _ABALE_h_
#define _ABALE_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *AIRBAG_ALE keyword
  * from LSDYNA native file */

class ABALE : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ABALE(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ABALE()
   {
   }

public:
/** Function to import SetInfo details for *AIRBAG_ALE
  * keyword from file */
   void readSetInfo()
   {
      const char *fields[] = {"SID","SIDTYP","UNUSED","UNUSED","UNUSED","UNUSED","MWD","SPSF",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_UNUSED, DATA_UNUSED, DATA_UNUSED, DATA_UNUSED, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         airbagFind(wordArray, numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("SetInfo");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import AmbientCard details for *AIRBAG_ALE
  * keyword from file */
   void readAmbientCard()
   {
      const char *fields[] = {"ATMOST","ATMOSP","UNUSED","GC","CC","TNKVOL","TNKFINP",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_UNUSED, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("AmbientCard");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Coupling details for *AIRBAG_ALE
  * keyword from file */
   void readCoupling()
   {
      const char *fields[] = {"NQUAD","CTYPE","PFAC","FRIC","FRCMIN","NORMTYP","ILEAK","PLEAK",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Coupling");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import VentHole details for *AIRBAG_ALE
  * keyword from file */
   void readVentHole()
   {
      const char *fields[] = {"IVSETID","IVTYPE","IBLOCK","VNTCOF",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, };
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         airbagVentHoleFind(wordArray, numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("VentHole");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import ALEMesh details for *AIRBAG_ALE
  * keyword from file */
   int readALEMesh()
   {
      const char *fields[] = {"NX","NY","NZ","MOVERN","ZOOM",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 5;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return 0;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("ALEMesh");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
      if( wordArray[2] )
         return atoi(wordArray[2]);
      else
         return 0;
   }

/** Function to import Card5a details for *AIRBAG_ALE
  * keyword from file */
   void readCard5a()
   {
      const char *fields[] = {"X0","Y0","Z0","X1","Y1","Z1","IPAIR","IPGAS",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card5a");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card5b details for *AIRBAG_ALE
  * keyword from file */
   void readCard5b()
   {
      const char *fields[] = {"X2","Y2","Z2","X3","Y3","Z3",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card5b");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import ALEToCV details for *AIRBAG_ALE
  * keyword from file */
   void readALEToCV()
   {
      const char *fields[] = {"SWTIME","UNUSED","HG","NAIR","NGAS","NORIF","LCVEL","LCT",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_UNUSED, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {6, 7, };
      unsigned int man_types[] = {DEFINE, DEFINE, };
      unsigned int kw_types[] = {CURVE, CURVE, };
      unsigned int num_indices = 2;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      nair = 0;
      if( wordArray[3] )
         nair = atoi(wordArray[3]);
      ngas = 0;
      if( wordArray[4] )
         ngas = atoi(wordArray[4]);
      norif = 0;
      if( wordArray[5] )
         norif = atoi(wordArray[5]);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("ALEToCV");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import AirCard details for *AIRBAG_ALE
  * keyword from file */
   void readAirCard()
   {
      const char *fields[] = {"UNUSED","UNUSED","UNUSED","MWAIR","INITM","AIRA","AIRB","AIRC",};
      unsigned int field_types[] = {DATA_UNUSED, DATA_UNUSED, DATA_UNUSED, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int i, end_loop;
      end_loop = nair;
      for(i = 0; i < end_loop; i++)
      {
         numFields = 8;
         wordArray = dataLine->readNextCardAsWords(numFields);
         if( !numFields && dataLine->isFlagOn(KW_READ_END) ) return;

         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
         {
            cardObj = new Card("AirCard");
            cardObj->addFields(numFields, field_types, fields, wordArray);
            impObj->addCard(cardObj);
         }
      }
   }

/** Function to import GasCard details for *AIRBAG_ALE
  * keyword from file */
   void readGasCard()
   {
      const char *fields[] = {"LCMF","UNUSED","UNUSED","MWGAS","UNUSED","GASA","GASB","GASC",};
      unsigned int field_types[] = {DATA_INT, DATA_UNUSED, DATA_UNUSED, DATA_DOUBLE, DATA_UNUSED, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {DEFINE, };
      unsigned int kw_types[] = {CURVE, };
      unsigned int num_indices = 1;
      numFields = 8;
      unsigned int i, end_loop;
      end_loop = ngas;
      for(i = 0; i < end_loop; i++)
      {
         numFields = 8;
         wordArray = dataLine->readNextCardAsWords(numFields);
         if( !numFields && dataLine->isFlagOn(KW_READ_END) ) return;

         if( Card::isFlagOn(SAVE_REFERENCES) )
            addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
         {
            cardObj = new Card("GasCard");
            cardObj->addFields(numFields, field_types, fields, wordArray);
            impObj->addCard(cardObj);
         }
      }
   }

/** Function to import OrifCard details for *AIRBAG_ALE
  * keyword from file */
   void readOrifCard()
   {
      const char *fields[] = {"NODEID","VECID","ORIFARE",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, 1, };
      unsigned int man_types[] = {NOD, DEFINE, };
      unsigned int kw_types[] = {9999, VECTOR, };
      unsigned int num_indices = 2;
      numFields = 3;
      unsigned int i, end_loop;
      end_loop = norif;
      for(i = 0; i < end_loop; i++)
      {
         numFields = 3;
         wordArray = dataLine->readNextCardAsWords(numFields);
         if( !numFields && dataLine->isFlagOn(KW_READ_END) ) return;

         if( Card::isFlagOn(SAVE_REFERENCES) )
            addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
         {
            cardObj = new Card("OrifCard");
            cardObj->addFields(numFields, field_types, fields, wordArray);
            impObj->addCard(cardObj);
         }
      }
   }

/** Function to import all the cards of the keyword *AIRBAG_ALE
  * from LSDYNA native file */
   unsigned int importABALE()
   {
      int nz = 0;
      readSetInfo();
      readAmbientCard();
      readCoupling();
      readVentHole();
      nz = readALEMesh();
      if( nz > 0 )
      {
         readCard5a();
         readCard5b();
      }
      readALEToCV();
      readAirCard();
      readGasCard();
      readOrifCard();
      return 0;
   }
public:
   int nair;
   int ngas;
   int norif;
};

#endif

