#ifndef _ABInteraction_h_
#define _ABInteraction_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *AIRBAG_INTERACTION keyword
  * from LSDYNA native file */

class ABInteraction : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ABInteraction(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ABInteraction()
   {
   }

public:
/** Function to import Interaction details for *AIRBAG_INTERACTION
  * keyword from file */
   void readInteraction()
   {
      const char *fields[] = {"AB1","AB2","AREA","SF","PID","LCID","IFLOW",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 4, 5, };
      unsigned int man_types[] = {AIRBAG, AIRBAG, PARTC, DEFINE, };
      unsigned int kw_types[] = {9999, 9999, 9999, CURVE, };
      unsigned int num_indices = 4;
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Interaction");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *AIRBAG_INTERACTION
  * from LSDYNA native file */
   unsigned int importABInteraction()
   {
      readInteraction();
      return 0;
   }
};

#endif

