#ifndef _ABReferenceGeometry_h_
#define _ABReferenceGeometry_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *AIRBAG_REFERENCE_GEOMETRY keyword
  * from LSDYNA native file */

class ABReferenceGeometry : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ABReferenceGeometry(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ABReferenceGeometry()
   {
   }

public:
/** Function to import NodeInfo details for *AIRBAG_REFERENCE_GEOMETRY
  * keyword from file */
   void readNodeInfo()
   {
      const char *fields[] = {"NID","X","Y","Z",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {NOD, };
      unsigned int kw_types[] = {9999, };
      unsigned int num_indices = 1;
      numFields = 4;
      unsigned int field_widths[] = {8, 16, 16, 16, };
      strBuff = dataLine->readNextCard(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("NodeInfo");
         cardObj->addFields(numFields, field_types, field_widths, fields, strBuff);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *AIRBAG_REFERENCE_GEOMETRY
  * from LSDYNA native file */
   unsigned int importABReferenceGeometry()
   {
      readNodeInfo();
      while(numFields)
      {
         readNodeInfo();
      }
      return 0;
   }
};

#endif

