#ifndef _ABShellRefGeometry_h_
#define _ABShellRefGeometry_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *AIRBAG_SHELL_REFERENCE_GEOMETRY keyword
  * from LSDYNA native file */

class ABShellRefGeometry : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ABShellRefGeometry(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ABShellRefGeometry()
   {
   }

public:
/** Function to import ShellInfo details for *AIRBAG_SHELL_REFERENCE_GEOMETRY
  * keyword from file */
   void readShellInfo()
   {
      const char *fields[] = {"EID","PID","N1","N2","N3","N4",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, 3, 4, 5, };
      unsigned int man_types[] = {ELEMENT, PARTC, NOD, NOD, NOD, NOD, };
      unsigned int kw_types[] = {SHELL, 9999, 9999, 9999, 9999, 9999, };
      unsigned int num_indices = 6;
      numFields = 6;
      unsigned int field_widths[] = {8, 8, 8, 8, 8, 8, };
      strBuff = dataLine->readNextCard(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("ShellInfo");
         cardObj->addFields(numFields, field_types, field_widths, fields, strBuff);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *AIRBAG_SHELL_REFERENCE_GEOMETRY
  * from LSDYNA native file */
   unsigned int importABShellRefGeometry()
   {
      readShellInfo();
      while(numFields)
      {
         readShellInfo();
      }
      return 0;
   }
};

#endif

