#include <iostream>
#include <algorithm>
#include "generic.h"
#include "abtype.h"
#include "abimport.h"
#include <stdlib.h>

using namespace std;

ABImport::ABImport
(
   FILE          *fp,
   DataLoc       *data_loc,
   AirbagManager *ab_man
)
{
   filePtr = fp;
   abManPtr = ab_man;
   dataLocPtr = data_loc;
   dataLine = NULL;

   initSimpleTypesAndFunctions();
   initABALETypesAndFunctions();
   initHybridTypesAndFunctions();
   initWangTypesAndFunctions();
   initChemkinTypesAndFunctions();
}

ABType ABImport::getAirbagTypeFromKeyword
	   (
	      const char  *key_word,
	      int *ab_id
	   )
{
   int str_len = strlen(key_word);

   *ab_id = 0;
   //ID option is available
   if( isdigit(key_word[str_len-1]) || strstr(key_word, "_ID") )
   {
      char *id_str = strrchr((char *)key_word, '_');
      id_str++;

      *ab_id = atoi(id_str);

cout << "AB ID = " << *ab_id << endl;

      if( strstr(key_word, "VOL") )
	 return AIRBAG_SIMPLE_PRESSURE_VOLUME_ID;
      else if( strstr(key_word, "E_A") )
	 return AIRBAG_SIMPLE_AIRBAG_MODEL_ID;
      else if( strstr(key_word, "GAS") )
	 return AIRBAG_ADIABATIC_GAS_MODEL_ID;
      else if( strstr(key_word, "NG_NEF") )
      {
	 if( !strstr(key_word, "CM") )
	 {
	    if( strstr(key_word, "_POP") )
	       return AIRBAG_WANG_NEFSKE_POP_ID;
	    else if( strstr(key_word, "SKE_JET") )
	       return AIRBAG_WANG_NEFSKE_JETTING_ID;
	    else if( strstr(key_word, "KE_MUL") )
	       return AIRBAG_WANG_NEFSKE_MULTIPLE_JETTING_ID;
	    else
	       return AIRBAG_WANG_NEFSKE_ID;
	 }
	 else
	 {
	    if( strstr(key_word, "SKE_JET") )
	       return AIRBAG_WANG_NEFSKE_JETTING_CM_ID;
	    else if( strstr(key_word, "KE_MUL") )
	       return AIRBAG_WANG_NEFSKE_MULTIPLE_JETTING_CM_ID;
	 }
      }
      else if( strstr(key_word, "LOAD") )
	 return AIRBAG_LOAD_CURVE_ID;
      else if( strstr(key_word, "_LIN") )
	 return AIRBAG_LINEAR_FLUID_ID;
      else if( strstr(key_word, "HYBRID") )
      {
	 if( strstr(key_word, "_CM") )
	    return AIRBAG_HYBRID_JETTING_CM_ID;
	 else if( strstr(key_word, "D_JET") )
	    return AIRBAG_HYBRID_JETTING_ID;
	 else if( strstr(key_word, "_CHEM") )
	    return AIRBAG_HYBRID_CHEMKIN_ID;
	 else
	    return AIRBAG_HYBRID_ID;
      }
   }
   else
   {
      if( strstr(key_word, "VOL") )
	 return AIRBAG_SIMPLE_PRESSURE_VOLUME;
      else if( strstr(key_word, "E_A") )
	 return AIRBAG_SIMPLE_AIRBAG_MODEL;
      else if( strstr(key_word, "GAS") )
	 return AIRBAG_ADIABATIC_GAS_MODEL;
      else if( strstr(key_word, "NG_NEF") )
      {
	 if( !strstr(key_word, "CM") )
	 {
	    if( strstr(key_word, "_POP") )
	       return AIRBAG_WANG_NEFSKE_POP;
	    else if( strstr(key_word, "SKE_JET") )
	       return AIRBAG_WANG_NEFSKE_JETTING;
	    else if( strstr(key_word, "KE_MUL") )
	       return AIRBAG_WANG_NEFSKE_MULTIPLE_JETTING;
	    else
	       return AIRBAG_WANG_NEFSKE;
	 }
	 else
	 {
	    if( strstr(key_word, "SKE_JET") )
	       return AIRBAG_WANG_NEFSKE_JETTING_CM;
	    if( strstr(key_word, "KE_MUL") )
	       return AIRBAG_WANG_NEFSKE_MULTIPLE_JETTING_CM;
	 }
      }
      else if( strstr(key_word, "LOAD") )
	 return AIRBAG_LOAD_CURVE;
      else if( strstr(key_word, "_LIN") )
	 return AIRBAG_LINEAR_FLUID;
      else if( strstr(key_word, "HYBRID") )
      {
         if( strstr(key_word, "_CM") )
	    return AIRBAG_HYBRID_JETTING_CM;
	 else if( strstr(key_word, "D_JET") )
	    return AIRBAG_HYBRID_JETTING;
	 else if( strstr(key_word, "_CHEM") )
	    return AIRBAG_HYBRID_CHEMKIN;
	 else
	    return AIRBAG_HYBRID;
      }
      else if( strstr(key_word, "D_ALE") )
         return AIRBAG_ADVANCED_ALE;
      else if( strstr(key_word, "G_ALE") )
         return AIRBAG_ALE;
      else if( strstr(key_word, "G_IN") )
         return AIRBAG_INTERACTION;
      else if( strstr(key_word, "_SHE") )
         return AIRBAG_SHELL_REFERENCE_GEOMETRY;
      else if( strstr(key_word, "_GEO") )
      {
         if( strstr(key_word, "TH_RDT") )
            return AIRBAG_REFERENCE_GEOMETRY_BIRTH_RDT;
         else if( strstr(key_word, "RY_RDT") )
            return AIRBAG_REFERENCE_GEOMETRY_RDT;
         else if( strstr(key_word, "RY_BIR") )
            return AIRBAG_REFERENCE_GEOMETRY_BIRTH;
         else
            return AIRBAG_REFERENCE_GEOMETRY;
      }
   }

   return AB_NEW_TYPE;
}

unsigned int ABImport::readAirbags()
{
   char         new_kw[LINE_LEN];
   unsigned int	i = 0, ab_type = 0, num_airbags = 0;
   int          ab_id = 0;
   long		loc = 0L;
   VStringIterator   s = dataLocPtr->keywordList.begin(),
		     e = dataLocPtr->keywordList.end(), itr, 
		     pitr = dataLocPtr->keywordList.begin();
   typeFuncIterator  btype_iter = typeFuncMap.begin(),
                     etype_iter = typeFuncMap.end(), type_iter;
   Card              *card_obj;
   Data              *data_obj;

   dataLine = new DataLine(filePtr);

   while(true)
   {
      itr = find_if(pitr, e, bind2nd(KeyWordCompare (), "*AIRBAG"));

      if( itr == e )
	 break;

      pitr = itr+1;
      i = (unsigned int)(itr - s);
      loc = dataLocPtr->slocList[i];

      rewind(filePtr);

      if( fseek(filePtr, loc, SEEK_SET) )
      {
	 cout << "ERROR in locating the Airbag" << endl;
	 break;
      }

      dataLine->clearFlag(KW_READ_END);

      char *str = dataLine->readNextCard(); //get the keyword
      Generic::RemoveLeadingAndTrailingBlanks( str );
cout << "KW = " << str << endl;

      ab_type = getAirbagTypeFromKeyword( str, &ab_id );
cout << "AB TYPE = " << ab_type << endl;

      if( ab_type == AB_NEW_TYPE )
      {
         cout << "AIRBAG TYPE NOT SUPPORTED" << endl;
         continue;
      }

      num_airbags++;

      strcpy(new_kw, str);

      dataLine->clearFlag(KW_READ_END);
      type_iter = typeFuncMap.find(ab_type);
      if( type_iter != etype_iter )
      {
          impObj = new ImportObject(str, ab_type);

          if( ab_id )
          {
             card_obj = new Card("AirbagDetails");  
             data_obj = new Integer(ab_id);
             card_obj->addField("ABID", data_obj);
             data_obj = new CharArray("AIRBAG");
             card_obj->addField("HEADING", data_obj);
             impObj->addCard(card_obj);
          }

          (type_iter->second)(dataLine, impObj);

          sprintf(new_kw, "%s_%d", new_kw, num_airbags);
          abManPtr->add(new_kw, impObj);
      }
      else
         cout << "AIRBAG TYPE NOT FOUND" << endl;
   }

   return num_airbags;
}

