#ifndef _AB_IMPORT_H_
#define _AB_IMPORT_H_

#include "dataloc.h"
#include "airbagmanager.h"
#include <string>
#include <map>
#include "dataline.h"
#include "card.h"
#include "abtype.h"
#include "typemap.h"

/** Class to import the data from native LSDYNA file for *AIRBAG keywords. All
  * the data is imported through this class and stored in the manager object.
  */
class ABImport
{
public:
   /** Constructor for creating this object
     * \param fp File pointer to the LSDYNA native file
     * \param data_loc Pointer to the list of keywords and their locations in
     * the file
     * \param ab_man Manager pointer to hold the imported data as a list of
     * ImportObject list
     */
   ABImport
   (
      FILE          *fp,
      DataLoc       *data_loc,
      AirbagManager *ab_man
   );

   ~ABImport()
   {
      filePtr = NULL;
      abManPtr = NULL;
      dataLocPtr = NULL;
      delete dataLine;
   }

   /* 
   bool compareAirbagKeyword
	(
	   string  &  key_word
	);
   */

   /** Function for getting the keyword type from given keyword name from LSDYNA
     * native file. The type is stored in the database
     * \param key_word Name of the keyword from file
     * \param ab_id ID of the keyword if it is there
     * \return Type for *AIRBAG group of keywords
     */
   static ABType getAirbagTypeFromKeyword
	      (
		 const char  *key_word,
		 int *ab_id
	      );

   /** Reads the *AIRBAG keywords from file based on given type
     * \param imp_obj Object to store the import data
     * \param ab_type Type of *AIRBAG keyword to read
     * \return Returns 0 on failure else number of *AIRBAG keywords
     */
   int readLineBasedOnAirbagType
       (
	  ImportObject *imp_obj,
	  unsigned int & ab_type
       );

   /** Reads the *AIRBAG keywords from file
     * \return Returns 0 on failure else number of *AIRBAG keywords
     */
   unsigned int readAirbags();

   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *PART keyword there is a function to call
     */
   void initSimpleTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *PART keyword there is a function to call
     */
   void initHybridTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *PART keyword there is a function to call
     */
   void initABALETypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *PART keyword there is a function to call
     */
   void initWangTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *AIRBAG keyword there is a function to call
     */
   void initChemkinTypesAndFunctions();

private:
   FILE          *filePtr;
   /** Manager pointer for holding the imported data for all the keywords */
   AirbagManager *abManPtr;
   /** Pointer to keywords and their locations in the file */
   DataLoc       *dataLocPtr;
   /** Pointer to access the file data line by line */
   DataLine      *dataLine;
   /** Object to store imported data from LSDYNA data file */
   ImportObject  *impObj;
   /** A map between the keyword type and pointer to function */
   map<unsigned int, ImportFunctionPtr>  typeFuncMap;
};

#endif

