#ifndef _ABHybridChemkin_h_
#define _ABHybridChemkin_h_

#include "manager.h"
#include "dispexport.h"
#include "airbag.h"

/** This class is used for importing *AIRBAG_HYBRID_CHEMKIN keyword
  * from LSDYNA native file */

class ABHybridChemkin : public Airbag
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ABHybridChemkin(DataLine *data_line, ImportObject *imp_obj) : Airbag (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ABHybridChemkin()
   {
   }

public:
/** Function to import GasCard details for *AIRBAG_HYBRID_CHEMKIN
  * keyword from file */
   int readGasCard()
   {
      const char *fields[] = {"LCIDM","LCIDT","NGAS","DATA","ATMT","ATMP","RG",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, 1, };
      unsigned int man_types[] = {DEFINE, DEFINE, };
      unsigned int kw_types[] = {CURVE, CURVE, };
      unsigned int num_indices = 2;
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return 0;
      data = 0;
      if( wordArray[3] )
         data = atoi(wordArray[3]);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("GasCard");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
      if( wordArray[2] )
         return atoi(wordArray[2]);
      else
         return 0;
   }

/** Function to import HeatCard details for *AIRBAG_HYBRID_CHEMKIN
  * keyword from file */
   void readHeatCard()
   {
      const char *fields[] = {"HCONV",};
      unsigned int field_types[] = {DATA_DOUBLE, };
      numFields = 1;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("HeatCard");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import VentOrifice details for *AIRBAG_HYBRID_CHEMKIN
  * keyword from file */
   void readVentOrifice()
   {
      const char *fields[] = {"C23","A23",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 2;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("VentOrifice");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import ControlCard details for *AIRBAG_HYBRID_CHEMKIN
  * keyword from file */
   void readControlCard()
   {
      const char *fields[] = {"CHNAME","MW","LCIDN","FMOLE","FMOLET",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {2, };
      unsigned int man_types[] = {DEFINE, };
      unsigned int kw_types[] = {CURVE, };
      unsigned int num_indices = 1;
      numFields = 5;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("ControlCard");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import DATA_EQ_1_Card1 details for *AIRBAG_HYBRID_CHEMKIN
  * keyword from file */
   void readDATA_EQ_1_Card1()
   {
      const char *fields[] = {"TLOW","TMID","THIGH",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 3;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("DATA_EQ_1_Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import DATA_EQ_1_Card2 details for *AIRBAG_HYBRID_CHEMKIN
  * keyword from file */
   void readDATA_EQ_1_Card2()
   {
      const char *fields[] = {"a_low","b_low","c_low","d_low","e_low","f_low","h_low",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("DATA_EQ_1_Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import DATA_EQ_1_Card3 details for *AIRBAG_HYBRID_CHEMKIN
  * keyword from file */
   void readDATA_EQ_1_Card3()
   {
      const char *fields[] = {"a_high","b_high","c_high","d_high","e_high","f_high","h_high",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("DATA_EQ_1_Card3");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import DATA_EQ_3_Card details for *AIRBAG_HYBRID_CHEMKIN
  * keyword from file */
   void readDATA_EQ_3_Card()
   {
      const char *fields[] = {"a","b","c","d","e",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 5;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("DATA_EQ_3_Card");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *AIRBAG_HYBRID_CHEMKIN
  * from LSDYNA native file */
   unsigned int importABHybridChemkin()
   {
      int ngas = 0;
      importAirbag();
      ngas = readGasCard();
      readHeatCard();
      readVentOrifice();
      if(data == 1)
      {
         for(int i = 0; i < ngas; i++)
         {
            readControlCard();
            readDATA_EQ_1_Card1();
            readDATA_EQ_1_Card2();
            readDATA_EQ_1_Card3();
         }
      }
      else if(data == 3)
      {
         for(int i = 0; i < ngas; i++)
         {
            readControlCard();
            readDATA_EQ_3_Card();
         }
      }
      else if(data == 2)
      {
         for(int i = 0; i < ngas; i++)
         {
            readControlCard();
         }
      }
      return 0;
   }
public:
   int data;
};

#endif

