#ifndef _ABHybrid_h_
#define _ABHybrid_h_

#include "manager.h"
#include "dispexport.h"
#include "airbag.h"

/** This class is used for importing *AIRBAG_HYBRID keyword
  * from LSDYNA native file */

class ABHybrid : public Airbag
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ABHybrid(DataLine *data_line, ImportObject *imp_obj) : Airbag (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ABHybrid()
   {
   }

public:
/** Function to import AtmosCard details for *AIRBAG_HYBRID
  * keyword from file */
   void readAtmosCard()
   {
      const char *fields[] = {"ATMOST","ATMOSP","ATMOSD","GC","CC",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 5;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("AtmosCard");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import ExitHole details for *AIRBAG_HYBRID
  * keyword from file */
   void readExitHole()
   {
      const char *fields[] = {"C23","LCC23","A23","LCA23","CP23","LCCP23","AP23","LCAP23",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_INT, };
      unsigned int field_indices[] = {1, 3, 5, 7, };
      unsigned int man_types[] = {DEFINE, DEFINE, DEFINE, DEFINE, };
      unsigned int kw_types[] = {CURVE, CURVE, CURVE, CURVE, };
      unsigned int num_indices = 4;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("ExitHole");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import VentOption details for *AIRBAG_HYBRID
  * keyword from file */
   int readVentOption()
   {
      const char *fields[] = {"OPT","PVENT","NGAS",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, DATA_INT, };
      numFields = 3;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return 0;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("VentOption");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
      if( wordArray[2] )
         return atoi(wordArray[2]);
      else
         return 0;
   }

/** Function to import GasCard details for *AIRBAG_HYBRID
  * keyword from file */
   void readGasCard()
   {
      const char *fields[] = {"LCIDM","LCIDT","UNUSED","MW","INITM","A","B","C",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_UNUSED, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, 1, };
      unsigned int man_types[] = {DEFINE, DEFINE, };
      unsigned int kw_types[] = {CURVE, CURVE, };
      unsigned int num_indices = 2;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("GasCard");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import MassCard details for *AIRBAG_HYBRID
  * keyword from file */
   void readMassCard()
   {
      const char *fields[] = {"FMASS",};
      unsigned int field_types[] = {DATA_DOUBLE, };
      numFields = 1;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("MassCard");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *AIRBAG_HYBRID
  * from LSDYNA native file */
   unsigned int importABHybrid()
   {
      int ngas = 0;
      importAirbag();
      readAtmosCard();
      readExitHole();
      ngas = readVentOption();
      if( ngas != 0 )
      {
         for(int i = 0; i < ngas; i++)
         {
            readGasCard();
            readMassCard();
         }
      }
      return 0;
   }
};

#endif

