#ifndef _ABHybridJetting_h_
#define _ABHybridJetting_h_

#include "manager.h"
#include "dispexport.h"
#include "abhybrid.h"

/** This class is used for importing *AIRBAG_HYBRID_JETTING keyword
  * from LSDYNA native file */

class ABHybridJetting : public ABHybrid
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ABHybridJetting(DataLine *data_line, ImportObject *imp_obj) : ABHybrid (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ABHybridJetting()
   {
   }

public:
/** Function to import FocalPoint1 details for *AIRBAG_HYBRID_JETTING
  * keyword from file */
   void readFocalPoint1()
   {
      const char *fields[] = {"XJFP","YJFP","ZJFP","XJVH","YJVH","ZJVH","CA","BETA",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("FocalPoint1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import FocalPoint2 details for *AIRBAG_HYBRID_JETTING
  * keyword from file */
   void readFocalPoint2()
   {
      const char *fields[] = {"XSJFP","YSJFP","ZSJFP","PSID","UNUSED","NODE1","NODE2","NODE3",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_UNUSED, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {3, 5, 6, 7, };
      unsigned int man_types[] = {SET, NOD, NOD, NOD, };
      unsigned int kw_types[] = {9999, 9999, 9999, 9999, };
      unsigned int num_indices = 4;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("FocalPoint2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *AIRBAG_HYBRID_JETTING
  * from LSDYNA native file */
   unsigned int importABHybridJetting()
   {
      importABHybrid();
      readFocalPoint1();
      readFocalPoint2();
      return 0;
   }
};

#endif

