#ifndef _ABAdiabaticGasModel_h_
#define _ABAdiabaticGasModel_h_

#include "manager.h"
#include "dispexport.h"
#include "airbag.h"

/** This class is used for importing *AIRBAG_ADIABATIC_GAS_MODEL keyword
  * from LSDYNA native file */

class ABAdiabaticGasModel : public Airbag
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ABAdiabaticGasModel(DataLine *data_line, ImportObject *imp_obj) : Airbag (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ABAdiabaticGasModel()
   {
   }

public:
/** Function to import GasCard details for *AIRBAG_ADIABATIC_GAS_MODEL
  * keyword from file */
   void readGasCard()
   {
      const char *fields[] = {"PSF","LCID","GAMMA","P0","PE","RO",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {1, };
      unsigned int man_types[] = {DEFINE, };
      unsigned int kw_types[] = {CURVE, };
      unsigned int num_indices = 1;
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("GasCard");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *AIRBAG_ADIABATIC_GAS_MODEL
  * from LSDYNA native file */
   unsigned int importABAdiabaticGasModel()
   {
      importAirbag();
      readGasCard();
      return 0;
   }
};

#endif

