#ifndef _ABLinearFluid_h_
#define _ABLinearFluid_h_

#include "manager.h"
#include "dispexport.h"
#include "airbag.h"

/** This class is used for importing *AIRBAG_LINEAR_FLUID keyword
  * from LSDYNA native file */

class ABLinearFluid : public Airbag
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ABLinearFluid(DataLine *data_line, ImportObject *imp_obj) : Airbag (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ABLinearFluid()
   {
   }

public:
/** Function to import Fluid details for *AIRBAG_LINEAR_FLUID
  * keyword from file */
   void readFluid()
   {
      const char *fields[] = {"BULK","RO","LCINT","LCOUTT","LCOUTP","LCFIT","LCBULK","LCID",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {2, 3, 4, 5, 6, 7, };
      unsigned int man_types[] = {DEFINE, DEFINE, DEFINE, DEFINE, DEFINE, DEFINE, };
      unsigned int kw_types[] = {CURVE, CURVE, CURVE, CURVE, CURVE, CURVE, };
      unsigned int num_indices = 6;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Fluid");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *AIRBAG_LINEAR_FLUID
  * from LSDYNA native file */
   unsigned int importABLinearFluid()
   {
      importAirbag();
      readFluid();
      return 0;
   }
};

#endif

