#ifndef _ABLoadCurve_h_
#define _ABLoadCurve_h_

#include "manager.h"
#include "dispexport.h"
#include "airbag.h"

/** This class is used for importing *AIRBAG_LOAD_CURVE keyword
  * from LSDYNA native file */

class ABLoadCurve : public Airbag
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ABLoadCurve(DataLine *data_line, ImportObject *imp_obj) : Airbag (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ABLoadCurve()
   {
   }

public:
/** Function to import LoadCurve details for *AIRBAG_LOAD_CURVE
  * keyword from file */
   void readLoadCurve()
   {
      const char *fields[] = {"STIME","LCID","RO","PE","P0","T","T0",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {1, };
      unsigned int man_types[] = {DEFINE, };
      unsigned int kw_types[] = {CURVE, };
      unsigned int num_indices = 1;
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("LoadCurve");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *AIRBAG_LOAD_CURVE
  * from LSDYNA native file */
   unsigned int importABLoadCurve()
   {
      importAirbag();
      readLoadCurve();
      return 0;
   }
};

#endif

