#ifndef _ABSimpleModel_h_
#define _ABSimpleModel_h_

#include "manager.h"
#include "dispexport.h"
#include "airbag.h"

/** This class is used for importing *AIRBAG_SIMPLE_AIRBAG_MODEL keyword
  * from LSDYNA native file */

class ABSimpleModel : public Airbag
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ABSimpleModel(DataLine *data_line, ImportObject *imp_obj) : Airbag (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ABSimpleModel()
   {
   }

public:
/** Function to import GasCard1 details for *AIRBAG_SIMPLE_AIRBAG_MODEL
  * keyword from file */
   void readGasCard1()
   {
      const char *fields[] = {"CV","CP","T","LCID","MU","AREA","PE","RO",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {3, };
      unsigned int man_types[] = {DEFINE, };
      unsigned int kw_types[] = {CURVE, };
      unsigned int num_indices = 1;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("GasCard1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import GasCard2 details for *AIRBAG_SIMPLE_AIRBAG_MODEL
  * keyword from file */
   void readGasCard2()
   {
      const char *fields[] = {"LOU","TEXT","A","B","MW","GASC",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("GasCard2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *AIRBAG_SIMPLE_AIRBAG_MODEL
  * from LSDYNA native file */
   unsigned int importABSimpleModel()
   {
      importAirbag();
      readGasCard1();
      readGasCard2();
      return 0;
   }
};

#endif

