#ifndef _ABSimplePressureVolume_h_
#define _ABSimplePressureVolume_h_

#include "manager.h"
#include "dispexport.h"
#include "airbag.h"

/** This class is used for importing *AIRBAG_SIMPLE_PRESSURE_VOLUME keyword
  * from LSDYNA native file */

class ABSimplePressureVolume : public Airbag
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ABSimplePressureVolume(DataLine *data_line, ImportObject *imp_obj) : Airbag (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ABSimplePressureVolume()
   {
   }

public:
/** Function to import SPVolume details for *AIRBAG_SIMPLE_PRESSURE_VOLUME
  * keyword from file */
   void readSPVolume()
   {
      const char *fields[] = {"CN","BETA","LCID","LCIDDR",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {2, 3, };
      unsigned int man_types[] = {DEFINE, DEFINE, };
      unsigned int kw_types[] = {CURVE, CURVE, };
      unsigned int num_indices = 2;
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("SPVolume");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *AIRBAG_SIMPLE_PRESSURE_VOLUME
  * from LSDYNA native file */
   unsigned int importABSimplePressureVolume()
   {
      importAirbag();
      readSPVolume();
      return 0;
   }
};

#endif

