#ifndef _AleFsiProjection_h_
#define _AleFsiProjection_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *ALE_FSI_PROJECTION keyword
  * from LSDYNA native file */

class AleFsiProjection : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   AleFsiProjection(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~AleFsiProjection()
   {
   }

public:
/** Function to import SetInfo details for *ALE_FSI_PROJECTION
  * keyword from file */
   void readSetInfo()
   {
      const char *fields[] = {"LAGSID","ALESID","LSIDTYP","ASIDTYP","SMMGID","ICORREC","INORM",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         aleFsiFind(wordArray, numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("SetInfo");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Couple details for *ALE_FSI_PROJECTION
  * keyword from file */
   void readCouple()
   {
      const char *fields[] = {"BIRTH","DEATH",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 2;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Couple");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *ALE_FSI_PROJECTION
  * from LSDYNA native file */
   unsigned int importAleFsiProjection()
   {
      readSetInfo();
      readCouple();
      return 0;
   }
};

#endif

