#ifndef _AleFsiSwitchMmg_h_
#define _AleFsiSwitchMmg_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *ALE_FSI_SWITCH_MMG keyword
  * from LSDYNA native file */

class AleFsiSwitchMmg : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   AleFsiSwitchMmg(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~AleFsiSwitchMmg()
   {
   }

public:
/** Function to import IDCard details for *ALE_FSI_SWITCH_MMG
  * keyword from file */
   void readIDCard()
   {
      const char *fields[] = {"ID",};
      unsigned int field_types[] = {DATA_INT, };
      numFields = 1;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, ALE, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("IDCard");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Title details for *ALE_FSI_SWITCH_MMG
  * keyword from file */
   void readTitle()
   {
      const char *fields[] = {"UNUSED","TITLE",};
      unsigned int field_types[] = {DATA_UNUSED, DATA_CHAR_ARRAY, };
      numFields = 2;
      unsigned int field_widths[] = {10, 70, };
      strBuff = dataLine->readNextCard(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Title");
         cardObj->addFields(numFields, field_types, field_widths, fields, strBuff);
         impObj->addCard(cardObj);
      }
   }

/** Function to import SetInfo details for *ALE_FSI_SWITCH_MMG
  * keyword from file */
   void readSetInfo()
   {
      const char *fields[] = {"SID","STYPE","NQUAD","XOFF","BTIME","DTIME","NFREQ","NFOLD",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         airbagVentHoleFind(wordArray, numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("SetInfo");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import MmgCard details for *ALE_FSI_SWITCH_MMG
  * keyword from file */
   void readMmgCard()
   {
      const char *fields[] = {"FR_MMG","TO_MMG","XLEN",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, 1, };
      unsigned int man_types[] = {SET, SET, };
      unsigned int kw_types[] = {MMG, MMG, };
      unsigned int num_indices = 2;
      numFields = 3;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("MmgCard");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *ALE_FSI_SWITCH_MMG
  * from LSDYNA native file */
   unsigned int importAleFsiSwitchMmg()
   {
      if( strstr(impObj->getKeyword().data(), "_ID") )
      {
         readIDCard();
      }
      if( strstr(impObj->getKeyword().data(), "_TITLE") )
      {
         readTitle();
      }
      readSetInfo();
      readMmgCard();
      return 0;
   }
};

#endif

