#ifndef _AleRefSysGroup_h_
#define _AleRefSysGroup_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *ALE_REFERENCE_SYSTEM_GROUP keyword
  * from LSDYNA native file */

class AleRefSysGroup : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   AleRefSysGroup(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~AleRefSysGroup()
   {
   }

public:
/** Function to import SetInfo details for *ALE_REFERENCE_SYSTEM_GROUP
  * keyword from file */
   void readSetInfo()
   {
      const char *fields[] = {"SID","STYPE","PRTYPE","PRID","BCTRAN","BCEXP","BCROT","ICR/NID",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         aleRefGroupFind(wordArray, numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("SetInfo");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import MeshCard details for *ALE_REFERENCE_SYSTEM_GROUP
  * keyword from file */
   void readMeshCard()
   {
      const char *fields[] = {"XC","YC","ZC","EXPLIM","EFAC","UNUSED","FRCPAD","IEXPND",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_UNUSED, DATA_DOUBLE, DATA_INT, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("MeshCard");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import SetExclude details for *ALE_REFERENCE_SYSTEM_GROUP
  * keyword from file */
   void readSetExclude()
   {
      const char *fields[] = {"IPIDXCL","IPIDTYPE",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, };
      numFields = 2;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         airbagVentHoleFind(wordArray, numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("SetExclude");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *ALE_REFERENCE_SYSTEM_GROUP
  * from LSDYNA native file */
   unsigned int importAleRefSysGroup()
   {
      readSetInfo();
      readMeshCard();
      readSetExclude();
      return 0;
   }
};

#endif

