#ifndef _AleRefSysSwitch_h_
#define _AleRefSysSwitch_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *ALE_REFERENCE_SYSTEM_SWITCH keyword
  * from LSDYNA native file */

class AleRefSysSwitch : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   AleRefSysSwitch(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~AleRefSysSwitch()
   {
   }

public:
/** Function to import SwitchID details for *ALE_REFERENCE_SYSTEM_SWITCH
  * keyword from file */
   void readSwitchID()
   {
      const char *fields[] = {"ID",};
      unsigned int field_types[] = {DATA_INT, };
      numFields = 1;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, ALE, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("SwitchID");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import TimesCard details for *ALE_REFERENCE_SYSTEM_SWITCH
  * keyword from file */
   void readTimesCard()
   {
      const char *fields[] = {"T1","T2","T3","T4","T5","T6","T7",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("TimesCard");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import SysTypes details for *ALE_REFERENCE_SYSTEM_SWITCH
  * keyword from file */
   void readSysTypes()
   {
      const char *fields[] = {"TYPE1","TYPE2","TYPE3","TYPE4","TYPE5","TYPE6","TYPE7","TYPE8",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("SysTypes");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import PRIDs details for *ALE_REFERENCE_SYSTEM_SWITCH
  * keyword from file */
   void readPRIDs()
   {
      const char *fields[] = {"ID1","ID2","ID3","ID4","ID5","ID6","ID7","ID8",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("PRIDs");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *ALE_REFERENCE_SYSTEM_SWITCH
  * from LSDYNA native file */
   unsigned int importAleRefSysSwitch()
   {
      readSwitchID();
      readTimesCard();
      readSysTypes();
      readPRIDs();
      return 0;
   }
};

#endif

