#ifndef _AleUpSwitch_h_
#define _AleUpSwitch_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *ALE_UP_SWITCH keyword
  * from LSDYNA native file */

class AleUpSwitch : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   AleUpSwitch(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~AleUpSwitch()
   {
   }

public:
/** Function to import UpCard details for *ALE_UP_SWITCH
  * keyword from file */
   int readUpCard()
   {
      const char *fields[] = {"UPID","SWTIME",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {AIRBAG, };
      unsigned int kw_types[] = {9999, };
      unsigned int num_indices = 1;
      numFields = 2;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return 0;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("UpCard");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
      if( wordArray[0] )
         return atoi(wordArray[0]);
      else
         return 0;
   }

/** Function to import FsiIDs details for *ALE_UP_SWITCH
  * keyword from file */
   void readFsiIDs()
   {
      const char *fields[] = {"FSI_ID1","FSI_ID2","FSI_ID3","FSI_ID4","FSI_ID5","FSI_ID6","FSI_ID7","FSI_ID8",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, 3, 4, 5, 6, 7, };
      unsigned int man_types[] = {CONST, CONST, CONST, CONST, CONST, CONST, CONST, CONST, };
      unsigned int kw_types[] = {9999, 9999, 9999, 9999, 9999, 9999, 9999, 9999, };
      unsigned int num_indices = 8;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("FsiIDs");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import SetInfo details for *ALE_UP_SWITCH
  * keyword from file */
   void readSetInfo()
   {
      const char *fields[] = {"SID","SIDTYPE","MMGAIR","MMGGAS",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         aleUpSwitchFind(wordArray, numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("SetInfo");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *ALE_UP_SWITCH
  * from LSDYNA native file */
   unsigned int importAleUpSwitch()
   {
      int upid = 0;
      upid = readUpCard();
      readFsiIDs();
      if( !upid )
      {
         readSetInfo();
      }
      return 0;
   }
};

#endif

