#include <iostream>
#include <algorithm>
#include "generic.h"
#include "aletype.h"
#include "aleimport.h"
#include <stdlib.h>
#include <string.h>

using namespace std;

ALEImport::ALEImport
(
   FILE          *fp,
   DataLoc       *data_loc,
   ALEManager    *ale_man
)
{
   filePtr = fp;
   aleManPtr = ale_man;
   dataLocPtr = data_loc;
   dataLine = NULL;

   initAleTypesAndFunctions();
}

ALEType ALEImport::getALETypeFromKeyword
	(
	   const char  *key_word,
	   unsigned int *ale_id
	)
{
   int str_len = strlen(key_word);

   *ale_id = 0;
   if( strstr(key_word, "PROJ") )
      return ALE_FSI_PROJECTION;
   else if( strstr(key_word, "_MUL") )
      return ALE_MULTI_MATERIAL_GROUP;
   else if( strstr(key_word, "_CUR") )
      return ALE_REFERENCE_SYSTEM_CURVE;
   else if( strstr(key_word, "EM_GR") )
      return ALE_REFERENCE_SYSTEM_GROUP;
   else if( strstr(key_word, "EM_NO") )
      return ALE_REFERENCE_SYSTEM_NODE;
   else if( strstr(key_word, "EM_SW") )
      return ALE_REFERENCE_SYSTEM_SWITCH;
   else if( strstr(key_word, "_SMO") )
      return ALE_SMOOTHING;
   else if( strstr(key_word, "_TAN") )
      return ALE_TANK_TEST;
   else if( strstr(key_word, "UP_SW") )
      return ALE_UP_SWITCH;
   else if( strstr(key_word, "_MMG") )
   {
      if( isdigit(key_word[str_len-1]) || strstr(key_word, "_ID") )
      {
	 const char *id_str = strrchr(key_word, '_');
	 id_str++;
	 *ale_id = atoi(id_str);
cout << "ALE ID = " << *ale_id << endl;
	 return ALE_FSI_SWITCH_MMG_ID;
      }
      else if( strstr(key_word, "TITL") )
	 return ALE_FSI_SWITCH_MMG_TITLE;
   }

   return ALE_NEW_TYPE;
}

unsigned int ALEImport::readALEs()
{
   char         new_kw[LINE_LEN];
   unsigned int	i = 0, ale_id = 0, ale_type = 0, num_ales = 0;
   long		loc = 0L;
   VStringIterator   s = dataLocPtr->keywordList.begin(),
		     e = dataLocPtr->keywordList.end(), itr, 
		     pitr = dataLocPtr->keywordList.begin();
   typeFuncIterator  btype_iter = typeFuncMap.begin(),
                     etype_iter = typeFuncMap.end(), type_iter;

   dataLine = new DataLine(filePtr);

   while(true)
   {
      itr = find_if(pitr, e, bind2nd(KeyWordCompare (), "*ALE"));

      if( itr == e )
	 break;

      pitr = itr+1;
      i = (unsigned int)(itr - s);
      loc = dataLocPtr->slocList[i];

      rewind(filePtr);

      if( fseek(filePtr, loc, SEEK_SET) )
      {
	 cout << "ERROR in locating the ALE cards" << endl;
	 break;
      }

      dataLine->clearFlag(KW_READ_END);

      char *str = dataLine->readNextCard(); //get the keyword
      Generic::RemoveLeadingAndTrailingBlanks( str );
cout << "KW = " << str << endl;

      ale_type = getALETypeFromKeyword( str, &ale_id );
cout << "ALE TYPE = " << ale_type << endl;

      if( ale_type == ALE_NEW_TYPE )
      {
         cout << "ALE TYPE NOT SUPPORTED" << endl;
         continue;
      }

      num_ales++;

      strcpy(new_kw, str);

      dataLine->clearFlag(KW_READ_END);
      type_iter = typeFuncMap.find(ale_type);
      if( type_iter != etype_iter )
      {
          impObj = new ImportObject(str, ale_type);
          (type_iter->second)(dataLine, impObj);
          if( ale_id )
          {
             aleManPtr->add(new_kw, impObj);
          }
          else
          {
             sprintf(new_kw, "%s_%d", new_kw, num_ales);
             aleManPtr->add(new_kw, impObj);
          }
      }
      else
         cout << "ALE TYPE NOT FOUND" << endl;
   }

   return num_ales;
}

