#ifndef _Bdry_IMPORT_H_
#define _Bdry_IMPORT_H_

#include <string>
#include <map>
#include "dataloc.h"
#include "bdrymanager.h"
#include "dataline.h"
#include "card.h"
#include "bdrytype.h"
#include "typemap.h"

/** Class to import the data from native LSDYNA file for *BOUNDARY keywords. All
  * the data is imported through this class and stored in the manager object.
  */
class BdryImport
{
public:
   /** Constructor for creating this object
     * \param fp File pointer to the LSDYNA native file
     * \param data_loc Pointer to the list of keywords and their locations in
     * the file
     * \param bdry_man Manager pointer to hold the imported data as a list of
     * ImportObject list
     */
   BdryImport
   (
      FILE          *fp,
      DataLoc       *data_loc,
      BdryManager    *bdry_man
   );

   ~BdryImport()
   {
      filePtr = NULL;
      bdryManPtr = NULL;
      dataLocPtr = NULL;
      delete dataLine;
   }

   /** Function for getting the keyword type from given keyword name from LSDYNA
     * native file. The type is stored in the database
     * \param key_word Name of the keyword from file
     * \param bdry_id ID if exists along with the keyword
     * \return Type for *BOUNDARY group of keywords
     */
   static BdryType getBdryTypeFromKeyword
	   (
	      const char  *key_word,
	      unsigned int *bdry_id
	   );

   /** Reads the *BOUNDARY keywords from file
     * \return Returns 0 on failure else number of *BOUNDARY keywords
     */
   unsigned int readBdrys();

   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initSimpleTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initBEMTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initOrientTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initPrescribedTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initRadiationTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initSpcTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initTemperatureTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initOutflowTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initConvectionTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initFluxTypesAndFunctions();

private:
   FILE          *filePtr;
   /** Manager pointer for holding the imported data for all the keywords */
   BdryManager    *bdryManPtr;
   /** Pointer to keywords and their locations in the file */
   DataLoc       *dataLocPtr;
   /** Pointer to access the file data line by line */
   DataLine      *dataLine;
   /** Object to store imported data from LSDYNA data file */
   ImportObject  *impObj;
   /** A map between the keyword type and pointer to function */
   map<unsigned int, ImportFunctionPtr>  typeFuncMap;
};

#endif

