#ifndef _BEMAcoustic_h_
#define _BEMAcoustic_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *BOUNDARY_ELEMENT_METHOD_ACOUSTIC keyword
  * from LSDYNA native file */

class BEMAcoustic : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   BEMAcoustic(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~BEMAcoustic()
   {
   }

public:
/** Function to import Fluid details for *BOUNDARY_ELEMENT_METHOD_ACOUSTIC
  * keyword from file */
   void readFluid()
   {
      const char *fields[] = {"DENS","SP","MIN_FREQ","MAX_FREQ","NFREQ","NORM","DT","PREF",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Fluid");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Segment details for *BOUNDARY_ELEMENT_METHOD_ACOUSTIC
  * keyword from file */
   int readSegment()
   {
      const char *fields[] = {"SSID","SSTYPE","LCID","OUTID","OUTTYPE","METHOD","IWINDOW",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return 0;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         bemAcousticFind(wordArray, numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Segment");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
      if( wordArray[5] )
         return atoi(wordArray[5]);
      else
         return 0;
   }

/** Function to import Iterative details for *BOUNDARY_ELEMENT_METHOD_ACOUSTIC
  * keyword from file */
   void readIterative()
   {
      const char *fields[] = {"IDIM","MAX_ITER","RES",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, };
      numFields = 3;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Iterative");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *BOUNDARY_ELEMENT_METHOD_ACOUSTIC
  * from LSDYNA native file */
   unsigned int importBEMAcoustic()
   {
      int method = 0;
      readFluid();
      method = readSegment();
      if( method == 1 )
      {
         readIterative();
      }
      return 0;
   }
};

#endif

