#ifndef _BEMControl_h_
#define _BEMControl_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *BOUNDARY_ELEMENT_METHOD_CONTROL keyword
  * from LSDYNA native file */

class BEMControl : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   BEMControl(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~BEMControl()
   {
   }

public:
/** Function to import Control details for *BOUNDARY_ELEMENT_METHOD_CONTROL
  * keyword from file */
   void readControl()
   {
      const char *fields[] = {"LWAKE","DTBEM","IUPBEM","FARBEM",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, };
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Control");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *BOUNDARY_ELEMENT_METHOD_CONTROL
  * from LSDYNA native file */
   unsigned int importBEMControl()
   {
      readControl();
      return 0;
   }
};

#endif

