#ifndef _BEMNeighbor_h_
#define _BEMNeighbor_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *BOUNDARY_ELEMENT_METHOD_NEIGHBOR keyword
  * from LSDYNA native file */

class BEMNeighbor : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   BEMNeighbor(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~BEMNeighbor()
   {
   }

public:
/** Function to import Neighbor details for *BOUNDARY_ELEMENT_METHOD_NEIGHBOR
  * keyword from file */
   void readNeighbor()
   {
      const char *fields[] = {"NELEM","NABOR1","NABOR2","NABOR3","NABOR4",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, 3, 4, };
      unsigned int man_types[] = {ELEMENT, ELEMENT, ELEMENT, ELEMENT, ELEMENT, };
      unsigned int kw_types[] = {SHELL, SHELL, SHELL, SHELL, SHELL, };
      unsigned int num_indices = 5;
      numFields = 5;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Neighbor");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *BOUNDARY_ELEMENT_METHOD_NEIGHBOR
  * from LSDYNA native file */
   unsigned int importBEMNeighbor()
   {
      readNeighbor();
      while(numFields)
      {
         readNeighbor();
      }
      return 0;
   }
};

#endif

