#ifndef _BEMSymmetry_h_
#define _BEMSymmetry_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *BOUNDARY_ELEMENT_METHOD_SYMMETRY keyword
  * from LSDYNA native file */

class BEMSymmetry : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   BEMSymmetry(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~BEMSymmetry()
   {
   }

public:
/** Function to import Sym details for *BOUNDARY_ELEMENT_METHOD_SYMMETRY
  * keyword from file */
   void readSym()
   {
      const char *fields[] = {"BEMSYM",};
      unsigned int field_types[] = {DATA_INT, };
      numFields = 1;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Sym");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *BOUNDARY_ELEMENT_METHOD_SYMMETRY
  * from LSDYNA native file */
   unsigned int importBEMSymmetry()
   {
      readSym();
      return 0;
   }
};

#endif

