#ifndef _BEMWake_h_
#define _BEMWake_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *BOUNDARY_ELEMENT_METHOD_WAKE keyword
  * from LSDYNA native file */

class BEMWake : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   BEMWake(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~BEMWake()
   {
   }

public:
/** Function to import Wake details for *BOUNDARY_ELEMENT_METHOD_WAKE
  * keyword from file */
   void readWake()
   {
      const char *fields[] = {"NELEM","NSIDE",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, };
      unsigned int man_types[] = {ELEMENT, ELEMENT, };
      unsigned int kw_types[] = {SHELL, SHELL, };
      unsigned int num_indices = 2;
      numFields = 2;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Wake");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *BOUNDARY_ELEMENT_METHOD_WAKE
  * from LSDYNA native file */
   unsigned int importBEMWake()
   {
      readWake();
      while(numFields)
      {
         readWake();
      }
      return 0;
   }
};

#endif

