#ifndef _BdryConvecSegment_h_
#define _BdryConvecSegment_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *BOUNDARY_CONVECTION_SEGMENT keyword
  * from LSDYNA native file */

class BdryConvecSegment : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   BdryConvecSegment(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~BdryConvecSegment()
   {
   }

public:
/** Function to import NodeCard details for *BOUNDARY_CONVECTION_SEGMENT
  * keyword from file */
   void readNodeCard()
   {
      const char *fields[] = {"N1","N2","N3","N4",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, 3, };
      unsigned int man_types[] = {NOD, NOD, NOD, NOD, };
      unsigned int kw_types[] = {9999, 9999, 9999, 9999, };
      unsigned int num_indices = 4;
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("NodeCard");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import HeatCard details for *BOUNDARY_CONVECTION_SEGMENT
  * keyword from file */
   void readHeatCard()
   {
      const char *fields[] = {"HLCID","HMULT","TLCID","TMULT","LOC",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_INT, };
      unsigned int field_indices[] = {0, 2, };
      unsigned int man_types[] = {DEFINE, DEFINE, };
      unsigned int kw_types[] = {CURVE, CURVE, };
      unsigned int num_indices = 2;
      numFields = 5;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("HeatCard");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *BOUNDARY_CONVECTION_SEGMENT
  * from LSDYNA native file */
   unsigned int importBdryConvecSegment()
   {
      readNodeCard();
      readHeatCard();
      return 0;
   }
};

#endif

