#ifndef _BdryNonReflect2D_h_
#define _BdryNonReflect2D_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *BOUNDARY_NON_REFLECTING_2D keyword
  * from LSDYNA native file */

class BdryNonReflect2D : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   BdryNonReflect2D(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~BdryNonReflect2D()
   {
   }

public:
/** Function to import NodeSet details for *BOUNDARY_NON_REFLECTING_2D
  * keyword from file */
   void readNodeSet()
   {
      const char *fields[] = {"NSID",};
      unsigned int field_types[] = {DATA_INT, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {SET, };
      unsigned int kw_types[] = {NOD, };
      unsigned int num_indices = 1;
      numFields = 1;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("NodeSet");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *BOUNDARY_NON_REFLECTING_2D
  * from LSDYNA native file */
   unsigned int importBdryNonReflect2D()
   {
      readNodeSet();
      return 0;
   }
};

#endif

