#ifndef _BdryFluxSegment_h_
#define _BdryFluxSegment_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *BOUNDARY_FLUX_SEGMENT keyword
  * from LSDYNA native file */

class BdryFluxSegment : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   BdryFluxSegment(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~BdryFluxSegment()
   {
   }

public:
/** Function to import Segment details for *BOUNDARY_FLUX_SEGMENT
  * keyword from file */
   void readSegment()
   {
      const char *fields[] = {"N1","N2","N3","N4",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, 3, };
      unsigned int man_types[] = {NOD, NOD, NOD, NOD, };
      unsigned int kw_types[] = {9999, 9999, 9999, 9999, };
      unsigned int num_indices = 4;
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Segment");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import LoadCurve details for *BOUNDARY_FLUX_SEGMENT
  * keyword from file */
   int readLoadCurve()
   {
      const char *fields[] = {"LCID","MLC1","MLC2","MLC3","MLC4","LOC","NHISV",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {DEFINE, };
      unsigned int kw_types[] = {CURVE, };
      unsigned int num_indices = 1;
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return 0;
      nhisv = 0;
      if( wordArray[6] )
         nhisv = atoi(wordArray[6]);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("LoadCurve");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
      if( wordArray[6] )
         return atoi(wordArray[6]);
      else
         return 0;
   }

/** Function to import History details for *BOUNDARY_FLUX_SEGMENT
  * keyword from file */
   void readHistory()
   {
      const char *fields[] = {"HISV1","HISV2","HISV3","HISV4","HISV5","HISV6","HISV7","HISV8",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int i, end_loop;
      end_loop = ((nhisv%8) ? (nhisv/8)+1 : nhisv/8);
      for(i = 0; i < end_loop; i++)
      {
         numFields = 8;
         wordArray = dataLine->readNextCardAsWords(numFields);
         if( !numFields && dataLine->isFlagOn(KW_READ_END) ) return;

         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
         {
            cardObj = new Card("History");
            cardObj->addFields(numFields, field_types, fields, wordArray);
            impObj->addCard(cardObj);
         }
      }
   }

/** Function to import all the cards of the keyword *BOUNDARY_FLUX_SEGMENT
  * from LSDYNA native file */
   unsigned int importBdryFluxSegment()
   {
      int nhisv = 0;
      readSegment();
      nhisv = readLoadCurve();
      if( nhisv != 0 )
      {
         readHistory();
      }
      return 0;
   }
public:
   int nhisv;
};

#endif

