#ifndef _BdryPresOrientRigidEulerp_h_
#define _BdryPresOrientRigidEulerp_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *BOUNDARY_PRESCRIBED_ORIENTATION_RIGID_EULERP keyword
  * from LSDYNA native file */

class BdryPresOrientRigidEulerp : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   BdryPresOrientRigidEulerp(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~BdryPresOrientRigidEulerp()
   {
   }

public:
/** Function to import Parts details for *BOUNDARY_PRESCRIBED_ORIENTATION_RIGID_EULERP
  * keyword from file */
   void readParts()
   {
      const char *fields[] = {"PIDB","PIDA","INTRP",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, };
      unsigned int man_types[] = {PARTC, PARTC, };
      unsigned int kw_types[] = {9999, 9999, };
      unsigned int num_indices = 2;
      numFields = 3;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Parts");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import LoadCurves1 details for *BOUNDARY_PRESCRIBED_ORIENTATION_RIGID_EULERP
  * keyword from file */
   void readLoadCurves1()
   {
      const char *fields[] = {"LCIDE1","LCIDE2","LCIDE3","LCIDE4",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, 3, };
      unsigned int man_types[] = {DEFINE, DEFINE, DEFINE, DEFINE, };
      unsigned int kw_types[] = {CURVE, CURVE, CURVE, CURVE, };
      unsigned int num_indices = 4;
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("LoadCurves1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *BOUNDARY_PRESCRIBED_ORIENTATION_RIGID_EULERP
  * from LSDYNA native file */
   unsigned int importBdryPresOrientRigidEulerp()
   {
      readParts();
      readLoadCurves1();
      return 0;
   }
};

#endif

