#ifndef _BdryPresOutflowSeg_h_
#define _BdryPresOutflowSeg_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *BOUNDARY_PRESSURE_OUTFLOW_SEGMENT keyword
  * from LSDYNA native file */

class BdryPresOutflowSeg : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   BdryPresOutflowSeg(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~BdryPresOutflowSeg()
   {
   }

public:
/** Function to import Segment details for *BOUNDARY_PRESSURE_OUTFLOW_SEGMENT
  * keyword from file */
   void readSegment()
   {
      const char *fields[] = {"N1","N2","N3","N4",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, 3, };
      unsigned int man_types[] = {NOD, NOD, NOD, NOD, };
      unsigned int kw_types[] = {9999, 9999, 9999, 9999, };
      unsigned int num_indices = 4;
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Segment");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *BOUNDARY_PRESSURE_OUTFLOW_SEGMENT
  * from LSDYNA native file */
   unsigned int importBdryPresOutflowSeg()
   {
      readSegment();
      return 0;
   }
};

#endif

