#ifndef _BdrySphSymPlane_h_
#define _BdrySphSymPlane_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *BOUNDARY_SPH_SYMMETRY_PLANE keyword
  * from LSDYNA native file */

class BdrySphSymPlane : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   BdrySphSymPlane(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~BdrySphSymPlane()
   {
   }

public:
/** Function to import Vector details for *BOUNDARY_SPH_SYMMETRY_PLANE
  * keyword from file */
   void readVector()
   {
      const char *fields[] = {"VTX","VTY","VTZ","VHX","VHY","VHZ",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Vector");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *BOUNDARY_SPH_SYMMETRY_PLANE
  * from LSDYNA native file */
   unsigned int importBdrySphSymPlane()
   {
      readVector();
      return 0;
   }
};

#endif

