#ifndef _BdryPresMotion_h_
#define _BdryPresMotion_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *BOUNDARY_PRESCRIBED_MOTION_NODE keyword
  * from LSDYNA native file */

class BdryPresMotion : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   BdryPresMotion(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~BdryPresMotion()
   {
   }

public:
/** Function to import Details details for *BOUNDARY_PRESCRIBED_MOTION_NODE
  * keyword from file */
   void readDetails()
   {
      const char *fields[] = {"ID","HEADING",};
      unsigned int field_types[] = {DATA_INT, DATA_CHAR_ARRAY, };
      numFields = 2;
      unsigned int field_widths[] = {10, 70, };
      strBuff = dataLine->readNextCard(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;

      wordArray = dataLine->splitIntoWords(numFields, field_widths);
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, BDRY, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Details");
         cardObj->addFields(numFields, field_types, field_widths, fields, strBuff);
         impObj->addCard(cardObj);
      }
   }

/** Function to import DOFCard details for *BOUNDARY_PRESCRIBED_MOTION_NODE
  * keyword from file */
   void readDOFCard()
   {
      const char *fields[] = {"typeID","DOF","VAD","LCID","SF","VID","DEATH","BIRTH",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      dof = 0;
      if( wordArray[1] )
         dof = atoi(wordArray[1]);
      vad = 0;
      if( wordArray[2] )
         vad = atoi(wordArray[2]);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         bdryPresMotionFind(wordArray, numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("DOFCard");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Offset details for *BOUNDARY_PRESCRIBED_MOTION_NODE
  * keyword from file */
   void readOffset()
   {
      const char *fields[] = {"OFFSET1","OFFSET2","MRB","NODE1","NODE2",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {3, 4, };
      unsigned int man_types[] = {NOD, NOD, };
      unsigned int kw_types[] = {9999, 9999, };
      unsigned int num_indices = 2;
      numFields = 5;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Offset");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *BOUNDARY_PRESCRIBED_MOTION_NODE
  * from LSDYNA native file */
   unsigned int importBdryPresMotion()
   {
      if( strstr(impObj->getKeyword().data(), "_ID") )
      {
         readDetails();
      }
      readDOFCard();
      if( (abs(dof) >= 9) || (vad == 4) )
      {
         readOffset();
      }
      return 0;
   }
public:
   int dof;
   int vad;
};

#endif

