#ifndef _BdryRadiationSetEF_h_
#define _BdryRadiationSetEF_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *BOUNDARY_RADIATION_SET_EF_READ keyword
  * from LSDYNA native file */

class BdryRadiationSetEF : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   BdryRadiationSetEF(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~BdryRadiationSetEF()
   {
   }

public:
/** Function to import Set details for *BOUNDARY_RADIATION_SET_EF_READ
  * keyword from file */
   void readSet()
   {
      const char *fields[] = {"SSID","NMAT","NPHT","ERRMAX",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {SET, };
      unsigned int kw_types[] = {SEGMENT, };
      unsigned int num_indices = 1;
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Set");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *BOUNDARY_RADIATION_SET_EF_READ
  * from LSDYNA native file */
   unsigned int importBdryRadiationSetEF()
   {
      readSet();
      return 0;
   }
};

#endif

