#ifndef _BdryCyclic_h_
#define _BdryCyclic_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *BOUNDARY_CYCLIC keyword
  * from LSDYNA native file */

class BdryCyclic : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   BdryCyclic(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~BdryCyclic()
   {
   }

public:
/** Function to import VecCard details for *BOUNDARY_CYCLIC
  * keyword from file */
   void readVecCard()
   {
      const char *fields[] = {"XC","YC","ZC","NSID1","NSID2","IGLOBAL","ISORT",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {3, 4, };
      unsigned int man_types[] = {SET, SET, };
      unsigned int kw_types[] = {NOD, NOD, };
      unsigned int num_indices = 2;
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("VecCard");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *BOUNDARY_CYCLIC
  * from LSDYNA native file */
   unsigned int importBdryCyclic()
   {
      readVecCard();
      return 0;
   }
};

#endif

