#ifndef _BdryMCOL_h_
#define _BdryMCOL_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *BOUNDARY_MCOL keyword
  * from LSDYNA native file */

class BdryMCOL : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   BdryMCOL(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~BdryMCOL()
   {
   }

public:
/** Function to import Ship details for *BOUNDARY_MCOL
  * keyword from file */
   int readShip()
   {
      const char *fields[] = {"NMCOL","MXSTEP","ENDTMCOL","TSUBC","PRTMCOL",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 5;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return 0;
      nmcol = 0;
      if( wordArray[0] )
         nmcol = atoi(wordArray[0]);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Ship");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
      if( wordArray[0] )
         return atoi(wordArray[0]);
      else
         return 0;
   }

/** Function to import MCol details for *BOUNDARY_MCOL
  * keyword from file */
   void readMCol()
   {
      const char *fields[] = {"RBMCOL","MCOLFILE",};
      unsigned int field_types[] = {DATA_INT, DATA_CHAR_ARRAY, };
      numFields = 2;
      unsigned int i, end_loop;
      end_loop = nmcol;
      for(i = 0; i < end_loop; i++)
      {
         numFields = 2;
      unsigned int field_widths[] = {10, 60, };
         strBuff = dataLine->readNextCard(numFields);
         if( !numFields && dataLine->isFlagOn(KW_READ_END) ) return;

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("MCol");
         cardObj->addFields(numFields, field_types, field_widths, fields, strBuff);
         impObj->addCard(cardObj);
      }
      }
   }

/** Function to import all the cards of the keyword *BOUNDARY_MCOL
  * from LSDYNA native file */
   unsigned int importBdryMCOL()
   {
      int nmcol = 0;
      nmcol = readShip();
      if( nmcol != 0 )
      {
         readMCol();
      }
      return 0;
   }
public:
   int nmcol;
};

#endif

