#ifndef _BdryPresAccelRigid_h_
#define _BdryPresAccelRigid_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *BOUNDARY_PRESCRIBED_ACCELEROMETER_RIGID keyword
  * from LSDYNA native file */

class BdryPresAccelRigid : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   BdryPresAccelRigid(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~BdryPresAccelRigid()
   {
   }

public:
/** Function to import Part details for *BOUNDARY_PRESCRIBED_ACCELEROMETER_RIGID
  * keyword from file */
   void readPart()
   {
      const char *fields[] = {"PID",};
      unsigned int field_types[] = {DATA_INT, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {PARTC, };
      unsigned int kw_types[] = {9999, };
      unsigned int num_indices = 1;
      numFields = 1;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Part");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Accelerometer details for *BOUNDARY_PRESCRIBED_ACCELEROMETER_RIGID
  * keyword from file */
   void readAccelerometer()
   {
      const char *fields[] = {"NID","CID","LCIDX","LCIDY","LCIDZ",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, 3, 4, };
      unsigned int man_types[] = {NOD, DEFINE, DEFINE, DEFINE, DEFINE, };
      unsigned int kw_types[] = {9999, COORDINATE, CURVE, CURVE, CURVE, };
      unsigned int num_indices = 5;
      numFields = 5;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Accelerometer");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *BOUNDARY_PRESCRIBED_ACCELEROMETER_RIGID
  * from LSDYNA native file */
   unsigned int importBdryPresAccelRigid()
   {
      readPart();
      readAccelerometer();
      while(numFields)
      {
         readAccelerometer();
      }
      return 0;
   }
};

#endif

