#ifndef _BdrySpc_h_
#define _BdrySpc_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *BOUNDARY_SPC_NODE keyword
  * from LSDYNA native file */

class BdrySpc : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   BdrySpc(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~BdrySpc()
   {
   }

public:
/** Function to import Details details for *BOUNDARY_SPC_NODE
  * keyword from file */
   void readDetails()
   {
      const char *fields[] = {"ID","HEADING",};
      unsigned int field_types[] = {DATA_INT, DATA_CHAR_ARRAY, };
      numFields = 2;
      unsigned int field_widths[] = {10, 70, };
      strBuff = dataLine->readNextCard(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;

      wordArray = dataLine->splitIntoWords(numFields, field_widths);
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, BDRY, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Details");
         cardObj->addFields(numFields, field_types, field_widths, fields, strBuff);
         impObj->addCard(cardObj);
      }
   }

/** Function to import DOFCard details for *BOUNDARY_SPC_NODE
  * keyword from file */
   void readDOFCard()
   {
      const char *fields[] = {"NID/NSID","CID","DOFX","DOFY","DOFZ","DOFRX","DOFRY","DOFRZ",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         bdrySpcFind(wordArray, numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("DOFCard");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *BOUNDARY_SPC_NODE
  * from LSDYNA native file */
   unsigned int importBdrySpc()
   {
      if( strstr(impObj->getKeyword().data(), "_ID") )
      {
         readDetails();
      }
      readDOFCard();
      return 0;
   }
};

#endif

