#ifndef _BdryTemperature_h_
#define _BdryTemperature_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *BOUNDARY_TEMPERATURE_NODE keyword
  * from LSDYNA native file */

class BdryTemperature : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   BdryTemperature(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~BdryTemperature()
   {
   }

public:
/** Function to import Node details for *BOUNDARY_TEMPERATURE_NODE
  * keyword from file */
   void readNode()
   {
      const char *fields[] = {"NID/SID","LCID","CMULT","LOC",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, DATA_INT, };
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         bdryTempFind(wordArray, numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Node");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *BOUNDARY_TEMPERATURE_NODE
  * from LSDYNA native file */
   unsigned int importBdryTemperature()
   {
      readNode();
      return 0;
   }
};

#endif

