#ifndef _BdryThermalWeld_h_
#define _BdryThermalWeld_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *BOUNDARY_THERMAL_WELD keyword
  * from LSDYNA native file */

class BdryThermalWeld : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   BdryThermalWeld(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~BdryThermalWeld()
   {
   }

public:
/** Function to import Part details for *BOUNDARY_THERMAL_WELD
  * keyword from file */
   int readPart()
   {
      const char *fields[] = {"PID","PTYP","NID","NFLAG","X0","Y0","Z0","N2ID",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return 0;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         bdryThermalFind(wordArray, numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Part");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
      if( wordArray[7] )
         return atoi(wordArray[7]);
      else
         return 0;
   }

/** Function to import Weld details for *BOUNDARY_THERMAL_WELD
  * keyword from file */
   void readWeld()
   {
      const char *fields[] = {"a","b","cf","cr","LCID","Q","Ff","Fr",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {4, };
      unsigned int man_types[] = {DEFINE, };
      unsigned int kw_types[] = {CURVE, };
      unsigned int num_indices = 1;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Weld");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Vector details for *BOUNDARY_THERMAL_WELD
  * keyword from file */
   void readVector()
   {
      const char *fields[] = {"tx","ty","tz",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 3;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Vector");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *BOUNDARY_THERMAL_WELD
  * from LSDYNA native file */
   unsigned int importBdryThermalWeld()
   {
      int n2id = 0;
      n2id = readPart();
      readWeld();
      if( n2id == -1 )
      {
         readVector();
      }
      return 0;
   }
};

#endif

