#include <iostream>
#include <algorithm>
#include "generic.h"
#include "comptype.h"
#include "compimport.h"
#include <stdlib.h>

using namespace std;

CompImport::CompImport
(
   FILE          *fp,
   DataLoc       *data_loc,
   CompManager    *comp_man
)
{
   filePtr = fp;
   compManPtr = comp_man;
   dataLocPtr = data_loc;
   dataLine = NULL;

   initCompTypesAndFunctions();
}

CompType CompImport::getCompTypeFromKeyword
	(
	   const char  *key_word,
	   unsigned int *comp_id
	)
{
   *comp_id = 0;
   if( strstr(key_word, "D_C") )
      return COMPONENT_GEBOD_CHILD;
   else if( strstr(key_word, "D_F") )
      return COMPONENT_GEBOD_FEMALE;
   else if( strstr(key_word, "D_M") )
      return COMPONENT_GEBOD_MALE;
   else if( strstr(key_word, "D_J") )
   {
      if( strstr(key_word, "FT_A") )
         return COMPONENT_GEBOD_JOINT_LEFT_ANKLE;
      else if( strstr(key_word, "FT_E") )
         return COMPONENT_GEBOD_JOINT_LEFT_ELBOW;
      else if( strstr(key_word, "FT_H") )
         return COMPONENT_GEBOD_JOINT_LEFT_HIP;
      else if( strstr(key_word, "FT_K") )
         return COMPONENT_GEBOD_JOINT_LEFT_KNEE;
      else if( strstr(key_word, "FT_S") )
         return COMPONENT_GEBOD_JOINT_LEFT_SHOULDER;
      else if( strstr(key_word, "WER_N") )
         return COMPONENT_GEBOD_JOINT_LOWER_NECK;
      else if( strstr(key_word, "T_P") )
         return COMPONENT_GEBOD_JOINT_PELVIS;
      else if( strstr(key_word, "HT_A") )
         return COMPONENT_GEBOD_JOINT_RIGHT_ANKLE;
      else if( strstr(key_word, "HT_E") )
         return COMPONENT_GEBOD_JOINT_RIGHT_ELBOW;
      else if( strstr(key_word, "HT_H") )
         return COMPONENT_GEBOD_JOINT_RIGHT_HIP;
      else if( strstr(key_word, "HT_K") )
         return COMPONENT_GEBOD_JOINT_RIGHT_KNEE;
      else if( strstr(key_word, "HT_S") )
         return COMPONENT_GEBOD_JOINT_RIGHT_SHOULDER;
      else if( strstr(key_word, "HT_S") )
         return COMPONENT_GEBOD_JOINT_RIGHT_SHOULDER;
      else if( strstr(key_word, "T_U") )
         return COMPONENT_GEBOD_JOINT_UPPER_NECK;
      else if( strstr(key_word, "T_WA") )
         return COMPONENT_GEBOD_JOINT_WAIST;
   }
   else if( strstr(key_word, "I_J") )
   {
      if( strstr(key_word, "FT_A") )
         return COMPONENT_HYBRIDIII_JOINT_LEFT_ANKLE;
      else if( strstr(key_word, "FT_E") )
         return COMPONENT_HYBRIDIII_JOINT_LEFT_ELBOW;
      else if( strstr(key_word, "FT_H") )
         return COMPONENT_HYBRIDIII_JOINT_LEFT_HIP;
      else if( strstr(key_word, "FT_K") )
      {
	 if( strstr(key_word, "_S") )
	    return COMPONENT_HYBRIDIII_JOINT_LEFT_KNEE_SLIDER;
         else
	    return COMPONENT_HYBRIDIII_JOINT_LEFT_KNEE;
      }
      else if( strstr(key_word, "FT_S") )
         return COMPONENT_HYBRIDIII_JOINT_LEFT_SHOULDER;
      else if( strstr(key_word, "FT_W") )
         return COMPONENT_HYBRIDIII_JOINT_LEFT_WRIST;
      else if( strstr(key_word, "WER_N") )
         return COMPONENT_HYBRIDIII_JOINT_LOWER_NECK;
      else if( strstr(key_word, "T_LU") )
         return COMPONENT_HYBRIDIII_JOINT_LUMBAR;
      else if( strstr(key_word, "HT_A") )
         return COMPONENT_HYBRIDIII_JOINT_RIGHT_ANKLE;
      else if( strstr(key_word, "HT_E") )
         return COMPONENT_HYBRIDIII_JOINT_RIGHT_ELBOW;
      else if( strstr(key_word, "HT_H") )
         return COMPONENT_HYBRIDIII_JOINT_RIGHT_HIP;
      else if( strstr(key_word, "HT_K") )
      {
         if( strstr(key_word, "_S") )
            return COMPONENT_HYBRIDIII_JOINT_RIGHT_KNEE_SLIDER;
         else
            return COMPONENT_HYBRIDIII_JOINT_RIGHT_KNEE;
      }
      else if( strstr(key_word, "HT_W") )
         return COMPONENT_HYBRIDIII_JOINT_RIGHT_WRIST;
      else if( strstr(key_word, "HT_S") )
         return COMPONENT_HYBRIDIII_JOINT_RIGHT_SHOULDER;
      else if( strstr(key_word, "T_U") )
         return COMPONENT_HYBRIDIII_JOINT_UPPER_NECK;
      else if( strstr(key_word, "NT_S") )
         return COMPONENT_HYBRIDIII_JOINT_STERNUM;
   }
   else
      return COMPONENT_HYBRIDIII;

   return COMP_NEW_TYPE;
}

unsigned int CompImport::readComps()
{
   char         new_kw[LINE_LEN];
   unsigned int	i = 0, comp_id = 0, comp_type = 0, num_comps = 0;
   long		loc = 0L;
   VStringIterator   s = dataLocPtr->keywordList.begin(),
		     e = dataLocPtr->keywordList.end(), itr, 
		     pitr = dataLocPtr->keywordList.begin();
   typeFuncIterator  btype_iter = typeFuncMap.begin(),
                     etype_iter = typeFuncMap.end(), type_iter;

   dataLine = new DataLine(filePtr);

   while(true)
   {
      itr = find_if(pitr, e, bind2nd(KeyWordCompare (), "*COMPO"));

      if( itr == e )
	 break;

      pitr = itr+1;
      i = (unsigned int)(itr - s);
      loc = dataLocPtr->slocList[i];

      rewind(filePtr);

      if( fseek(filePtr, loc, SEEK_SET) )
      {
	 cout << "ERROR in locating the Boundary cards" << endl;
	 break;
      }

      dataLine->clearFlag(KW_READ_END);

      char *str = dataLine->readNextCard(); //get the keyword
      Generic::RemoveLeadingAndTrailingBlanks( str );
cout << "KW = " << str << endl;

      comp_type = getCompTypeFromKeyword( str, &comp_id );
cout << "Comp TYPE = " << comp_type << endl;

      if( comp_type == COMP_NEW_TYPE )
      {
         cout << "Boundary TYPE NOT SUPPORTED" << endl;
         continue;
      }

      num_comps++;

      strcpy(new_kw, str);

      dataLine->clearFlag(KW_READ_END);
      type_iter = typeFuncMap.find(comp_type);
      if( type_iter != etype_iter )
      {
          impObj = new ImportObject(str, comp_type);
          (type_iter->second)(dataLine, impObj);
          if( comp_id )
          {
             compManPtr->add(new_kw, impObj);
          }
          else
          {
             sprintf(new_kw, "%s_%d", new_kw, num_comps);
             compManPtr->add(new_kw, impObj);
          }
      }
      else
         cout << "Boundary TYPE NOT SUPPORTED" << endl;
   }

   return num_comps;
}

