#ifndef _ComponentGebod_h_
#define _ComponentGebod_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *COMPONENT_GEBOD_MALE keyword
  * from LSDYNA native file */

class ComponentGebod : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ComponentGebod(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ComponentGebod()
   {
   }

public:
/** Function to import IDCard details for *COMPONENT_GEBOD_MALE
  * keyword from file */
   void readIDCard()
   {
      const char *fields[] = {"DID","UNITS","SIZE",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, };
      numFields = 3;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, COMP, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("IDCard");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Velocity details for *COMPONENT_GEBOD_MALE
  * keyword from file */
   void readVelocity()
   {
      const char *fields[] = {"VX","VY","VZ","GX","GY","GZ",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Velocity");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *COMPONENT_GEBOD_MALE
  * from LSDYNA native file */
   unsigned int importComponentGebod()
   {
      readIDCard();
      readVelocity();
      return 0;
   }
};

#endif

