#ifndef _ComponentGebodJoint_h_
#define _ComponentGebodJoint_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *COMPONENT_GEBOD_JOINT_PELVIS keyword
  * from LSDYNA native file */

class ComponentGebodJoint : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ComponentGebodJoint(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ComponentGebodJoint()
   {
   }

public:
/** Function to import IDCard details for *COMPONENT_GEBOD_JOINT_PELVIS
  * keyword from file */
   void readIDCard()
   {
      const char *fields[] = {"DID","LC1","LC2","LC3","SCF1","SCF2","SCF3",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, 1, 2, 3, };
      unsigned int man_types[] = {COMP, DEFINE, DEFINE, DEFINE, };
      unsigned int kw_types[] = {9999, CURVE, CURVE, CURVE, };
      unsigned int num_indices = 4;
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("IDCard");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Viscosity details for *COMPONENT_GEBOD_JOINT_PELVIS
  * keyword from file */
   void readViscosity()
   {
      const char *fields[] = {"C1","C2","C3","NEUT1","NEUT2","NEUT3",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Viscosity");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import StopAngle details for *COMPONENT_GEBOD_JOINT_PELVIS
  * keyword from file */
   void readStopAngle()
   {
      const char *fields[] = {"LOSA1","HISA1","LOSA2","HISA2","LOSA3","HISA3",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("StopAngle");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Stiffness details for *COMPONENT_GEBOD_JOINT_PELVIS
  * keyword from file */
   void readStiffness()
   {
      const char *fields[] = {"UNK1","UNK2","UNK3",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 3;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Stiffness");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *COMPONENT_GEBOD_JOINT_PELVIS
  * from LSDYNA native file */
   unsigned int importComponentGebodJoint()
   {
      readIDCard();
      readViscosity();
      readStopAngle();
      readStiffness();
      return 0;
   }
};

#endif

