#ifndef _ComponentHybridIII_h_
#define _ComponentHybridIII_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *COMPONENT_HYBRIDIII keyword
  * from LSDYNA native file */

class ComponentHybridIII : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ComponentHybridIII(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ComponentHybridIII()
   {
   }

public:
/** Function to import IDCard details for *COMPONENT_HYBRIDIII
  * keyword from file */
   void readIDCard()
   {
      const char *fields[] = {"DID","SIZE","UNITS","DEFRM","VX","VY","VZ",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, COMP, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("IDCard");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import HPoint details for *COMPONENT_HYBRIDIII
  * keyword from file */
   void readHPoint()
   {
      const char *fields[] = {"HX","HY","HZ","RX","RY","RZ",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("HPoint");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *COMPONENT_HYBRIDIII
  * from LSDYNA native file */
   unsigned int importComponentHybridIII()
   {
      readIDCard();
      readHPoint();
      return 0;
   }
};

#endif

