#ifndef _ComponentHybridIIIJoint_h_
#define _ComponentHybridIIIJoint_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *COMPONENT_HYBRIDIII_JOINT_LUMBAR keyword
  * from LSDYNA native file */

class ComponentHybridIIIJoint : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ComponentHybridIIIJoint(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ComponentHybridIIIJoint()
   {
   }

public:
/** Function to import IDCard details for *COMPONENT_HYBRIDIII_JOINT_LUMBAR
  * keyword from file */
   void readIDCard()
   {
      const char *fields[] = {"DID","Q1","Q2","Q3","FRIC",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {COMP, };
      unsigned int kw_types[] = {9999, };
      unsigned int num_indices = 1;
      numFields = 5;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("IDCard");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Coeffs1 details for *COMPONENT_HYBRIDIII_JOINT_LUMBAR
  * keyword from file */
   void readCoeffs1()
   {
      const char *fields[] = {"C1","ALO1","BLO1","AHI1","BHI1","QLO1","QHI1","SCLK1",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Coeffs1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Coeffs2 details for *COMPONENT_HYBRIDIII_JOINT_LUMBAR
  * keyword from file */
   void readCoeffs2()
   {
      const char *fields[] = {"C2","ALO2","BLO2","AHI2","BHI2","QLO2","QHI2","SCLK2",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Coeffs2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Coeffs3 details for *COMPONENT_HYBRIDIII_JOINT_LUMBAR
  * keyword from file */
   void readCoeffs3()
   {
      const char *fields[] = {"C3","ALO3","BLO3","AHI3","BHI3","QLO3","QHI3","SCLK3",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Coeffs3");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *COMPONENT_HYBRIDIII_JOINT_LUMBAR
  * from LSDYNA native file */
   unsigned int importComponentHybridIIIJoint()
   {
      readIDCard();
      readCoeffs1();
      readCoeffs2();
      readCoeffs3();
      return 0;
   }
};

#endif

