#include <iostream>
#include <algorithm>
#include "generic.h"
#include "consttype.h"
#include "constimport.h"
#include <stdlib.h>

using namespace std;

ConstImport::ConstImport
(
   FILE          *fp,
   DataLoc       *data_loc,
   ConstManager    *const_man
)
{
   filePtr = fp;
   constManPtr = const_man;
   dataLocPtr = data_loc;
   dataLine = NULL;

   initSimpleTypesAndFunctions();
   initJointTypesAndFunctions();
   initWeldTypesAndFunctions();
   initCouplingTypesAndFunctions();
   initStiffnessTypesAndFunctions();
   initNodalTypesAndFunctions();
}

ConstType ConstImport::getConstTypeFromKeyword
	(
	   const char  *key_word,
	   unsigned int *const_id
	)
{
   const char *id_ptr, *loc_ptr, *fail_ptr, *titl_ptr, *spc_ptr, *iner_ptr;
   *const_id = 0;

   if( strstr(key_word, "N_S") )
   {
      if( strstr(key_word, "E_T") )
	 return CONSTRAINED_LAGRANGE_IN_SOLID_EDGE_TITLE;
      else if( strstr(key_word, "D_T") )
	 return CONSTRAINED_LAGRANGE_IN_SOLID_TITLE;
      else if( strstr(key_word, "D_E") )
	 return CONSTRAINED_LAGRANGE_IN_SOLID_EDGE;
      else
         return CONSTRAINED_LAGRANGE_IN_SOLID;
   }
   else if( strstr(key_word, "R_G") )
      return CONSTRAINED_LINEAR_GLOBAL;
   else if( strstr(key_word, "EAR_L") )
      return CONSTRAINED_LINEAR_LOCAL;
   else if( strstr(key_word, "ED_LO") )
      return CONSTRAINED_LOCAL;
   else if( strstr(key_word, "IES") )
      return CONSTRAINED_RIGID_BODIES;
   else if( strstr(key_word, "_STO") )
      return CONSTRAINED_RIGID_BODY_STOPPERS;
   else if( strstr(key_word, "_FLEX") )
      return CONSTRAINED_JOINT_STIFFNESS_FLEXION_TORSION;
   else if( strstr(key_word, "SS_GE") )
      return CONSTRAINED_JOINT_STIFFNESS_GENERALIZED;
   else if( strstr(key_word, "SS_TR") )
      return CONSTRAINED_JOINT_STIFFNESS_TRANSLATIONAL;
   else if( strstr(key_word, "IE_BR") )
      return CONSTRAINED_TIE_BREAK;
   else if( strstr(key_word, "ES_FA") )
      return CONSTRAINED_TIED_NODES_FAILURE;
   else if( strstr(key_word, "_SPL") )
      return CONSTRAINED_SPLINE;
   else if( strstr(key_word, "LL_TO") )
      return CONSTRAINED_SHELL_TO_SOLID;
   else if( strstr(key_word, "_INTE") )
   {
      if( strstr(key_word, "_LOC") )
         return CONSTRAINED_INTERPOLATION_LOCAL;
      else
         return CONSTRAINED_INTERPOLATION;
   }
   else if( strstr(key_word, "ES_NO") )
      return CONSTRAINED_EXTRA_NODES_NODE;
   else if( strstr(key_word, "ES_SE") )
      return CONSTRAINED_EXTRA_NODES_SET;
   else if( strstr(key_word, "EUL") )
      return CONSTRAINED_EULER_IN_EULER;
   else if( strstr(key_word, "D_AD") )
      return CONSTRAINED_ADAPTIVITY;
   else if( strstr(key_word, "D_POI") )
      return CONSTRAINED_POINTS;
   else if( strstr(key_word, "D_GLO") )
      return CONSTRAINED_GLOBAL;
   else if( strstr(key_word, "DE_SE") )
   {
      if( strstr(key_word, "_ID") )
         return CONSTRAINED_NODE_SET_ID;
      else
         return CONSTRAINED_NODE_SET;
   }
   else if( strstr(key_word, "D_RIV") )
   {
      if( strstr(key_word, "_ID") )
         return CONSTRAINED_RIVET_ID;
      else
         return CONSTRAINED_RIVET;
   }
   else if( strstr(key_word, "_CYL") )
   {
      id_ptr   = strstr(key_word, "ID");
      fail_ptr = strstr(key_word, "FAIL");
      loc_ptr  = strstr(key_word, "LOC");
      
      if( id_ptr && fail_ptr && loc_ptr )
      {
         if( id_ptr < fail_ptr )
         {
            if( fail_ptr < loc_ptr )
               return CONSTRAINED_JOINT_CYLINDRICAL_ID_FAILURE_LOCAL;
            else if( loc_ptr < id_ptr )
               return CONSTRAINED_JOINT_CYLINDRICAL_LOCAL_ID_FAILURE;
            else
               return CONSTRAINED_JOINT_CYLINDRICAL_ID_LOCAL_FAILURE;
         }
         else
         {
            if( loc_ptr < fail_ptr )
               return CONSTRAINED_JOINT_CYLINDRICAL_LOCAL_FAILURE_ID;
            else if( id_ptr < loc_ptr )
               return CONSTRAINED_JOINT_CYLINDRICAL_FAILURE_ID_LOCAL;
            else
               return CONSTRAINED_JOINT_CYLINDRICAL_FAILURE_LOCAL_ID;
         }
      }
      else if( id_ptr && fail_ptr )
      {
         if( id_ptr < fail_ptr )
            return CONSTRAINED_JOINT_CYLINDRICAL_ID_FAILURE;
         else
            return CONSTRAINED_JOINT_CYLINDRICAL_FAILURE_ID;
      }
      else if( id_ptr && loc_ptr )
      {
         if( id_ptr < loc_ptr )
            return CONSTRAINED_JOINT_CYLINDRICAL_ID_LOCAL;
         else
            return CONSTRAINED_JOINT_CYLINDRICAL_LOCAL_ID;
      }
      else if( loc_ptr && fail_ptr )
      {
         if( loc_ptr < fail_ptr )
            return CONSTRAINED_JOINT_CYLINDRICAL_LOCAL_FAILURE;
         else
            return CONSTRAINED_JOINT_CYLINDRICAL_FAILURE_LOCAL;
      }
      else if( id_ptr )
      {
         return CONSTRAINED_JOINT_CYLINDRICAL_ID;
      }
      else if( fail_ptr )
      {
         return CONSTRAINED_JOINT_CYLINDRICAL_FAILURE;
      }
      else if( loc_ptr )
      {
         return CONSTRAINED_JOINT_CYLINDRICAL_LOCAL;
      }
      else
         return CONSTRAINED_JOINT_CYLINDRICAL;
   }
   else if( strstr(key_word, "GEAR") )
   {
      id_ptr   = strstr(key_word, "ID");
      fail_ptr = strstr(key_word, "FAIL");
      loc_ptr  = strstr(key_word, "LOC");
      
      if( id_ptr && fail_ptr && loc_ptr )
      {
         if( id_ptr < fail_ptr )
         {
            if( fail_ptr < loc_ptr )
               return CONSTRAINED_JOINT_GEARS_ID_FAILURE_LOCAL;
            else if( loc_ptr < id_ptr )
               return CONSTRAINED_JOINT_GEARS_LOCAL_ID_FAILURE;
            else
               return CONSTRAINED_JOINT_GEARS_ID_LOCAL_FAILURE;
         }
         else
         {
            if( loc_ptr < fail_ptr )
               return CONSTRAINED_JOINT_GEARS_LOCAL_FAILURE_ID;
            else if( id_ptr < loc_ptr )
               return CONSTRAINED_JOINT_GEARS_FAILURE_ID_LOCAL;
            else
               return CONSTRAINED_JOINT_GEARS_FAILURE_LOCAL_ID;
         }
      }
      else if( id_ptr && fail_ptr )
      {
         if( id_ptr < fail_ptr )
            return CONSTRAINED_JOINT_GEARS_ID_FAILURE;
         else
            return CONSTRAINED_JOINT_GEARS_FAILURE_ID;
      }
      else if( id_ptr && loc_ptr )
      {
         if( id_ptr < loc_ptr )
            return CONSTRAINED_JOINT_GEARS_ID_LOCAL;
         else
            return CONSTRAINED_JOINT_GEARS_LOCAL_ID;
      }
      else if( loc_ptr && fail_ptr )
      {
         if( loc_ptr < fail_ptr )
            return CONSTRAINED_JOINT_GEARS_LOCAL_FAILURE;
         else
            return CONSTRAINED_JOINT_GEARS_FAILURE_LOCAL;
      }
      else if( id_ptr )
      {
         return CONSTRAINED_JOINT_GEARS_ID;
      }
      else if( fail_ptr )
      {
         return CONSTRAINED_JOINT_GEARS_FAILURE;
      }
      else if( loc_ptr )
      {
         return CONSTRAINED_JOINT_GEARS_LOCAL;
      }
      else
         return CONSTRAINED_JOINT_GEARS;
   }
   else if( strstr(key_word, "LOCK") )
   {
      id_ptr   = strstr(key_word, "ID");
      fail_ptr = strstr(key_word, "FAIL");
      loc_ptr  = strstr(key_word, "LOC");
      
      if( id_ptr && fail_ptr && loc_ptr )
      {
         if( id_ptr < fail_ptr )
         {
            if( fail_ptr < loc_ptr )
               return CONSTRAINED_JOINT_LOCKING_ID_FAILURE_LOCAL;
            else if( loc_ptr < id_ptr )
               return CONSTRAINED_JOINT_LOCKING_LOCAL_ID_FAILURE;
            else
               return CONSTRAINED_JOINT_LOCKING_ID_LOCAL_FAILURE;
         }
         else
         {
            if( loc_ptr < fail_ptr )
               return CONSTRAINED_JOINT_LOCKING_LOCAL_FAILURE_ID;
            else if( id_ptr < loc_ptr )
               return CONSTRAINED_JOINT_LOCKING_FAILURE_ID_LOCAL;
            else
               return CONSTRAINED_JOINT_LOCKING_FAILURE_LOCAL_ID;
         }
      }
      else if( id_ptr && fail_ptr )
      {
         if( id_ptr < fail_ptr )
            return CONSTRAINED_JOINT_LOCKING_ID_FAILURE;
         else
            return CONSTRAINED_JOINT_LOCKING_FAILURE_ID;
      }
      else if( id_ptr && loc_ptr )
      {
         if( id_ptr < loc_ptr )
            return CONSTRAINED_JOINT_LOCKING_ID_LOCAL;
         else
            return CONSTRAINED_JOINT_LOCKING_LOCAL_ID;
      }
      else if( loc_ptr && fail_ptr )
      {
         if( loc_ptr < fail_ptr )
            return CONSTRAINED_JOINT_LOCKING_LOCAL_FAILURE;
         else
            return CONSTRAINED_JOINT_LOCKING_FAILURE_LOCAL;
      }
      else if( id_ptr )
      {
         return CONSTRAINED_JOINT_LOCKING_ID;
      }
      else if( fail_ptr )
      {
         return CONSTRAINED_JOINT_LOCKING_FAILURE;
      }
      else if( loc_ptr )
      {
         return CONSTRAINED_JOINT_LOCKING_LOCAL;
      }
      else
         return CONSTRAINED_JOINT_LOCKING;
   }
   else if( strstr(key_word, "PLAN") )
   {
      id_ptr   = strstr(key_word, "ID");
      fail_ptr = strstr(key_word, "FAIL");
      loc_ptr  = strstr(key_word, "LOC");
      
      if( id_ptr && fail_ptr && loc_ptr )
      {
         if( id_ptr < fail_ptr )
         {
            if( fail_ptr < loc_ptr )
               return CONSTRAINED_JOINT_PLANAR_ID_FAILURE_LOCAL;
            else if( loc_ptr < id_ptr )
               return CONSTRAINED_JOINT_PLANAR_LOCAL_ID_FAILURE;
            else
               return CONSTRAINED_JOINT_PLANAR_ID_LOCAL_FAILURE;
         }
         else
         {
            if( loc_ptr < fail_ptr )
               return CONSTRAINED_JOINT_PLANAR_LOCAL_FAILURE_ID;
            else if( id_ptr < loc_ptr )
               return CONSTRAINED_JOINT_PLANAR_FAILURE_ID_LOCAL;
            else
               return CONSTRAINED_JOINT_PLANAR_FAILURE_LOCAL_ID;
         }
      }
      else if( id_ptr && fail_ptr )
      {
         if( id_ptr < fail_ptr )
            return CONSTRAINED_JOINT_PLANAR_ID_FAILURE;
         else
            return CONSTRAINED_JOINT_PLANAR_FAILURE_ID;
      }
      else if( id_ptr && loc_ptr )
      {
         if( id_ptr < loc_ptr )
            return CONSTRAINED_JOINT_PLANAR_ID_LOCAL;
         else
            return CONSTRAINED_JOINT_PLANAR_LOCAL_ID;
      }
      else if( loc_ptr && fail_ptr )
      {
         if( loc_ptr < fail_ptr )
            return CONSTRAINED_JOINT_PLANAR_LOCAL_FAILURE;
         else
            return CONSTRAINED_JOINT_PLANAR_FAILURE_LOCAL;
      }
      else if( id_ptr )
      {
         return CONSTRAINED_JOINT_PLANAR_ID;
      }
      else if( fail_ptr )
      {
         return CONSTRAINED_JOINT_PLANAR_FAILURE;
      }
      else if( loc_ptr )
      {
         return CONSTRAINED_JOINT_PLANAR_LOCAL;
      }
      else
         return CONSTRAINED_JOINT_PLANAR;
   }
   else if( strstr(key_word, "LLEY") )
   {
      id_ptr   = strstr(key_word, "ID");
      fail_ptr = strstr(key_word, "FAIL");
      loc_ptr  = strstr(key_word, "LOC");
      
      if( id_ptr && fail_ptr && loc_ptr )
      {
         if( id_ptr < fail_ptr )
         {
            if( fail_ptr < loc_ptr )
               return CONSTRAINED_JOINT_PULLEY_ID_FAILURE_LOCAL;
            else if( loc_ptr < id_ptr )
               return CONSTRAINED_JOINT_PULLEY_LOCAL_ID_FAILURE;
            else
               return CONSTRAINED_JOINT_PULLEY_ID_LOCAL_FAILURE;
         }
         else
         {
            if( loc_ptr < fail_ptr )
               return CONSTRAINED_JOINT_PULLEY_LOCAL_FAILURE_ID;
            else if( id_ptr < loc_ptr )
               return CONSTRAINED_JOINT_PULLEY_FAILURE_ID_LOCAL;
            else
               return CONSTRAINED_JOINT_PULLEY_FAILURE_LOCAL_ID;
         }
      }
      else if( id_ptr && fail_ptr )
      {
         if( id_ptr < fail_ptr )
            return CONSTRAINED_JOINT_PULLEY_ID_FAILURE;
         else
            return CONSTRAINED_JOINT_PULLEY_FAILURE_ID;
      }
      else if( id_ptr && loc_ptr )
      {
         if( id_ptr < loc_ptr )
            return CONSTRAINED_JOINT_PULLEY_ID_LOCAL;
         else
            return CONSTRAINED_JOINT_PULLEY_LOCAL_ID;
      }
      else if( loc_ptr && fail_ptr )
      {
         if( loc_ptr < fail_ptr )
            return CONSTRAINED_JOINT_PULLEY_LOCAL_FAILURE;
         else
            return CONSTRAINED_JOINT_PULLEY_FAILURE_LOCAL;
      }
      else if( id_ptr )
      {
         return CONSTRAINED_JOINT_PULLEY_ID;
      }
      else if( fail_ptr )
      {
         return CONSTRAINED_JOINT_PULLEY_FAILURE;
      }
      else if( loc_ptr )
      {
         return CONSTRAINED_JOINT_PULLEY_LOCAL;
      }
      else
         return CONSTRAINED_JOINT_PULLEY;
   }
   else if( strstr(key_word, "PINI") )
   {
      id_ptr   = strstr(key_word, "ID");
      fail_ptr = strstr(key_word, "FAIL");
      loc_ptr  = strstr(key_word, "LOC");
      
      if( id_ptr && fail_ptr && loc_ptr )
      {
         if( id_ptr < fail_ptr )
         {
            if( fail_ptr < loc_ptr )
               return CONSTRAINED_JOINT_RACK_AND_PINION_ID_FAILURE_LOCAL;
            else if( loc_ptr < id_ptr )
               return CONSTRAINED_JOINT_RACK_AND_PINION_LOCAL_ID_FAILURE;
            else
               return CONSTRAINED_JOINT_RACK_AND_PINION_ID_LOCAL_FAILURE;
         }
         else
         {
            if( loc_ptr < fail_ptr )
               return CONSTRAINED_JOINT_RACK_AND_PINION_LOCAL_FAILURE_ID;
            else if( id_ptr < loc_ptr )
               return CONSTRAINED_JOINT_RACK_AND_PINION_FAILURE_ID_LOCAL;
            else
               return CONSTRAINED_JOINT_RACK_AND_PINION_FAILURE_LOCAL_ID;
         }
      }
      else if( id_ptr && fail_ptr )
      {
         if( id_ptr < fail_ptr )
            return CONSTRAINED_JOINT_RACK_AND_PINION_ID_FAILURE;
         else
            return CONSTRAINED_JOINT_RACK_AND_PINION_FAILURE_ID;
      }
      else if( id_ptr && loc_ptr )
      {
         if( id_ptr < loc_ptr )
            return CONSTRAINED_JOINT_RACK_AND_PINION_ID_LOCAL;
         else
            return CONSTRAINED_JOINT_RACK_AND_PINION_LOCAL_ID;
      }
      else if( loc_ptr && fail_ptr )
      {
         if( loc_ptr < fail_ptr )
            return CONSTRAINED_JOINT_RACK_AND_PINION_LOCAL_FAILURE;
         else
            return CONSTRAINED_JOINT_RACK_AND_PINION_FAILURE_LOCAL;
      }
      else if( id_ptr )
      {
         return CONSTRAINED_JOINT_RACK_AND_PINION_ID;
      }
      else if( fail_ptr )
      {
         return CONSTRAINED_JOINT_RACK_AND_PINION_FAILURE;
      }
      else if( loc_ptr )
      {
         return CONSTRAINED_JOINT_RACK_AND_PINION_LOCAL;
      }
      else
         return CONSTRAINED_JOINT_RACK_AND_PINION;
   }
   else if( strstr(key_word, "REVOL") )
   {
      id_ptr   = strstr(key_word, "ID");
      fail_ptr = strstr(key_word, "FAIL");
      loc_ptr  = strstr(key_word, "LOC");
      
      if( id_ptr && fail_ptr && loc_ptr )
      {
         if( id_ptr < fail_ptr )
         {
            if( fail_ptr < loc_ptr )
               return CONSTRAINED_JOINT_REVOLUTE_ID_FAILURE_LOCAL;
            else if( loc_ptr < id_ptr )
               return CONSTRAINED_JOINT_REVOLUTE_LOCAL_ID_FAILURE;
            else
               return CONSTRAINED_JOINT_REVOLUTE_ID_LOCAL_FAILURE;
         }
         else
         {
            if( loc_ptr < fail_ptr )
               return CONSTRAINED_JOINT_REVOLUTE_LOCAL_FAILURE_ID;
            else if( id_ptr < loc_ptr )
               return CONSTRAINED_JOINT_REVOLUTE_FAILURE_ID_LOCAL;
            else
               return CONSTRAINED_JOINT_REVOLUTE_FAILURE_LOCAL_ID;
         }
      }
      else if( id_ptr && fail_ptr )
      {
         if( id_ptr < fail_ptr )
            return CONSTRAINED_JOINT_REVOLUTE_ID_FAILURE;
         else
            return CONSTRAINED_JOINT_REVOLUTE_FAILURE_ID;
      }
      else if( id_ptr && loc_ptr )
      {
         if( id_ptr < loc_ptr )
            return CONSTRAINED_JOINT_REVOLUTE_ID_LOCAL;
         else
            return CONSTRAINED_JOINT_REVOLUTE_LOCAL_ID;
      }
      else if( loc_ptr && fail_ptr )
      {
         if( loc_ptr < fail_ptr )
            return CONSTRAINED_JOINT_REVOLUTE_LOCAL_FAILURE;
         else
            return CONSTRAINED_JOINT_REVOLUTE_FAILURE_LOCAL;
      }
      else if( id_ptr )
      {
         return CONSTRAINED_JOINT_REVOLUTE_ID;
      }
      else if( fail_ptr )
      {
         return CONSTRAINED_JOINT_REVOLUTE_FAILURE;
      }
      else if( loc_ptr )
      {
         return CONSTRAINED_JOINT_REVOLUTE_LOCAL;
      }
      else
         return CONSTRAINED_JOINT_REVOLUTE;
   }
   else if( strstr(key_word, "MOTO") )
   {
      if( strstr(key_word, "TRAN") )
      {
	 id_ptr   = strstr(key_word, "ID");
	 fail_ptr = strstr(key_word, "FAIL");
	 loc_ptr  = strstr(key_word, "LOC");
	 
	 if( id_ptr && fail_ptr && loc_ptr )
	 {
	    if( id_ptr < fail_ptr )
	    {
	       if( fail_ptr < loc_ptr )
		  return CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_ID_FAILURE_LOCAL;
	       else if( loc_ptr < id_ptr )
		  return CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_LOCAL_ID_FAILURE;
	       else
		  return CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_ID_LOCAL_FAILURE;
	    }
	    else
	    {
	       if( loc_ptr < fail_ptr )
		  return CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_LOCAL_FAILURE_ID;
	       else if( id_ptr < loc_ptr )
		  return CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_FAILURE_ID_LOCAL;
	       else
		  return CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_FAILURE_LOCAL_ID;
	    }
	 }
	 else if( id_ptr && fail_ptr )
	 {
	    if( id_ptr < fail_ptr )
	       return CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_ID_FAILURE;
	    else
	       return CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_FAILURE_ID;
	 }
	 else if( id_ptr && loc_ptr )
	 {
	    if( id_ptr < loc_ptr )
	       return CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_ID_LOCAL;
	    else
	       return CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_LOCAL_ID;
	 }
	 else if( loc_ptr && fail_ptr )
	 {
	    if( loc_ptr < fail_ptr )
	       return CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_LOCAL_FAILURE;
	    else
	       return CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_FAILURE_LOCAL;
	 }
	 else if( id_ptr )
	 {
	    return CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_ID;
	 }
	 else if( fail_ptr )
	 {
	    return CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_FAILURE;
	 }
	 else if( loc_ptr )
	 {
	    return CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_LOCAL;
	 }
	 else
	    return CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR;
      }
      else
      {
	 id_ptr   = strstr(key_word, "ID");
	 fail_ptr = strstr(key_word, "FAIL");
	 loc_ptr  = strstr(key_word, "LOC");
	 
	 if( id_ptr && fail_ptr && loc_ptr )
	 {
	    if( id_ptr < fail_ptr )
	    {
	       if( fail_ptr < loc_ptr )
		  return CONSTRAINED_JOINT_ROTATIONAL_MOTOR_ID_FAILURE_LOCAL;
	       else if( loc_ptr < id_ptr )
		  return CONSTRAINED_JOINT_ROTATIONAL_MOTOR_LOCAL_ID_FAILURE;
	       else
		  return CONSTRAINED_JOINT_ROTATIONAL_MOTOR_ID_LOCAL_FAILURE;
	    }
	    else
	    {
	       if( loc_ptr < fail_ptr )
		  return CONSTRAINED_JOINT_ROTATIONAL_MOTOR_LOCAL_FAILURE_ID;
	       else if( id_ptr < loc_ptr )
		  return CONSTRAINED_JOINT_ROTATIONAL_MOTOR_FAILURE_ID_LOCAL;
	       else
		  return CONSTRAINED_JOINT_ROTATIONAL_MOTOR_FAILURE_LOCAL_ID;
	    }
	 }
	 else if( id_ptr && fail_ptr )
	 {
	    if( id_ptr < fail_ptr )
	       return CONSTRAINED_JOINT_ROTATIONAL_MOTOR_ID_FAILURE;
	    else
	       return CONSTRAINED_JOINT_ROTATIONAL_MOTOR_FAILURE_ID;
	 }
	 else if( id_ptr && loc_ptr )
	 {
	    if( id_ptr < loc_ptr )
	       return CONSTRAINED_JOINT_ROTATIONAL_MOTOR_ID_LOCAL;
	    else
	       return CONSTRAINED_JOINT_ROTATIONAL_MOTOR_LOCAL_ID;
	 }
	 else if( loc_ptr && fail_ptr )
	 {
	    if( loc_ptr < fail_ptr )
	       return CONSTRAINED_JOINT_ROTATIONAL_MOTOR_LOCAL_FAILURE;
	    else
	       return CONSTRAINED_JOINT_ROTATIONAL_MOTOR_FAILURE_LOCAL;
	 }
	 else if( id_ptr )
	 {
	    return CONSTRAINED_JOINT_ROTATIONAL_MOTOR_ID;
	 }
	 else if( fail_ptr )
	 {
	    return CONSTRAINED_JOINT_ROTATIONAL_MOTOR_FAILURE;
	 }
	 else if( loc_ptr )
	 {
	    return CONSTRAINED_JOINT_ROTATIONAL_MOTOR_LOCAL;
	 }
	 else
	    return CONSTRAINED_JOINT_ROTATIONAL_MOTOR;
      }
   }
   else if( strstr(key_word, "TRAN") )
   {
      id_ptr   = strstr(key_word, "ID");
      fail_ptr = strstr(key_word, "FAIL");
      loc_ptr  = strstr(key_word, "LOC");
      
      if( id_ptr && fail_ptr && loc_ptr )
      {
	 if( id_ptr < fail_ptr )
	 {
	    if( fail_ptr < loc_ptr )
	       return CONSTRAINED_JOINT_TRANSLATIONAL_ID_FAILURE_LOCAL;
	    else if( loc_ptr < id_ptr )
	       return CONSTRAINED_JOINT_TRANSLATIONAL_LOCAL_ID_FAILURE;
	    else
	       return CONSTRAINED_JOINT_TRANSLATIONAL_ID_LOCAL_FAILURE;
	 }
	 else
	 {
	    if( loc_ptr < fail_ptr )
	       return CONSTRAINED_JOINT_TRANSLATIONAL_LOCAL_FAILURE_ID;
	    else if( id_ptr < loc_ptr )
	       return CONSTRAINED_JOINT_TRANSLATIONAL_FAILURE_ID_LOCAL;
	    else
	       return CONSTRAINED_JOINT_TRANSLATIONAL_FAILURE_LOCAL_ID;
	 }
      }
      else if( id_ptr && fail_ptr )
      {
	 if( id_ptr < fail_ptr )
	    return CONSTRAINED_JOINT_TRANSLATIONAL_ID_FAILURE;
	 else
	    return CONSTRAINED_JOINT_TRANSLATIONAL_FAILURE_ID;
      }
      else if( id_ptr && loc_ptr )
      {
	 if( id_ptr < loc_ptr )
	    return CONSTRAINED_JOINT_TRANSLATIONAL_ID_LOCAL;
	 else
	    return CONSTRAINED_JOINT_TRANSLATIONAL_LOCAL_ID;
      }
      else if( loc_ptr && fail_ptr )
      {
	 if( loc_ptr < fail_ptr )
	    return CONSTRAINED_JOINT_TRANSLATIONAL_LOCAL_FAILURE;
	 else
	    return CONSTRAINED_JOINT_TRANSLATIONAL_FAILURE_LOCAL;
      }
      else if( id_ptr )
      {
	 return CONSTRAINED_JOINT_TRANSLATIONAL_ID;
      }
      else if( fail_ptr )
      {
	 return CONSTRAINED_JOINT_TRANSLATIONAL_FAILURE;
      }
      else if( loc_ptr )
      {
	 return CONSTRAINED_JOINT_TRANSLATIONAL_LOCAL;
      }
      else
	 return CONSTRAINED_JOINT_TRANSLATIONAL;
   }
   else if( strstr(key_word, "CREW") )
   {
      id_ptr   = strstr(key_word, "ID");
      fail_ptr = strstr(key_word, "FAIL");
      loc_ptr  = strstr(key_word, "LOC");
      
      if( id_ptr && fail_ptr && loc_ptr )
      {
	 if( id_ptr < fail_ptr )
	 {
	    if( fail_ptr < loc_ptr )
	       return CONSTRAINED_JOINT_SCREW_ID_FAILURE_LOCAL;
	    else if( loc_ptr < id_ptr )
	       return CONSTRAINED_JOINT_SCREW_LOCAL_ID_FAILURE;
	    else
	       return CONSTRAINED_JOINT_SCREW_ID_LOCAL_FAILURE;
	 }
	 else
	 {
	    if( loc_ptr < fail_ptr )
	       return CONSTRAINED_JOINT_SCREW_LOCAL_FAILURE_ID;
	    else if( id_ptr < loc_ptr )
	       return CONSTRAINED_JOINT_SCREW_FAILURE_ID_LOCAL;
	    else
	       return CONSTRAINED_JOINT_SCREW_FAILURE_LOCAL_ID;
	 }
      }
      else if( id_ptr && fail_ptr )
      {
	 if( id_ptr < fail_ptr )
	    return CONSTRAINED_JOINT_SCREW_ID_FAILURE;
	 else
	    return CONSTRAINED_JOINT_SCREW_FAILURE_ID;
      }
      else if( id_ptr && loc_ptr )
      {
	 if( id_ptr < loc_ptr )
	    return CONSTRAINED_JOINT_SCREW_ID_LOCAL;
	 else
	    return CONSTRAINED_JOINT_SCREW_LOCAL_ID;
      }
      else if( loc_ptr && fail_ptr )
      {
	 if( loc_ptr < fail_ptr )
	    return CONSTRAINED_JOINT_SCREW_LOCAL_FAILURE;
	 else
	    return CONSTRAINED_JOINT_SCREW_FAILURE_LOCAL;
      }
      else if( id_ptr )
      {
	 return CONSTRAINED_JOINT_SCREW_ID;
      }
      else if( fail_ptr )
      {
	 return CONSTRAINED_JOINT_SCREW_FAILURE;
      }
      else if( loc_ptr )
      {
	 return CONSTRAINED_JOINT_SCREW_LOCAL;
      }
      else
	 return CONSTRAINED_JOINT_SCREW;
   }
   else if( strstr(key_word, "SPHE") )
   {
      id_ptr   = strstr(key_word, "ID");
      fail_ptr = strstr(key_word, "FAIL");
      loc_ptr  = strstr(key_word, "LOC");
      
      if( id_ptr && fail_ptr && loc_ptr )
      {
	 if( id_ptr < fail_ptr )
	 {
	    if( fail_ptr < loc_ptr )
	       return CONSTRAINED_JOINT_SPHERICAL_ID_FAILURE_LOCAL;
	    else if( loc_ptr < id_ptr )
	       return CONSTRAINED_JOINT_SPHERICAL_LOCAL_ID_FAILURE;
	    else
	       return CONSTRAINED_JOINT_SPHERICAL_ID_LOCAL_FAILURE;
	 }
	 else
	 {
	    if( loc_ptr < fail_ptr )
	       return CONSTRAINED_JOINT_SPHERICAL_LOCAL_FAILURE_ID;
	    else if( id_ptr < loc_ptr )
	       return CONSTRAINED_JOINT_SPHERICAL_FAILURE_ID_LOCAL;
	    else
	       return CONSTRAINED_JOINT_SPHERICAL_FAILURE_LOCAL_ID;
	 }
      }
      else if( id_ptr && fail_ptr )
      {
	 if( id_ptr < fail_ptr )
	    return CONSTRAINED_JOINT_SPHERICAL_ID_FAILURE;
	 else
	    return CONSTRAINED_JOINT_SPHERICAL_FAILURE_ID;
      }
      else if( id_ptr && loc_ptr )
      {
	 if( id_ptr < loc_ptr )
	    return CONSTRAINED_JOINT_SPHERICAL_ID_LOCAL;
	 else
	    return CONSTRAINED_JOINT_SPHERICAL_LOCAL_ID;
      }
      else if( loc_ptr && fail_ptr )
      {
	 if( loc_ptr < fail_ptr )
	    return CONSTRAINED_JOINT_SPHERICAL_LOCAL_FAILURE;
	 else
	    return CONSTRAINED_JOINT_SPHERICAL_FAILURE_LOCAL;
      }
      else if( id_ptr )
      {
	 return CONSTRAINED_JOINT_SPHERICAL_ID;
      }
      else if( fail_ptr )
      {
	 return CONSTRAINED_JOINT_SPHERICAL_FAILURE;
      }
      else if( loc_ptr )
      {
	 return CONSTRAINED_JOINT_SPHERICAL_LOCAL;
      }
      else
	 return CONSTRAINED_JOINT_SPHERICAL;
   }
   else if( strstr(key_word, "UNIVE") )
   {
      id_ptr   = strstr(key_word, "ID");
      fail_ptr = strstr(key_word, "FAIL");
      loc_ptr  = strstr(key_word, "LOC");
      
      if( id_ptr && fail_ptr && loc_ptr )
      {
	 if( id_ptr < fail_ptr )
	 {
	    if( fail_ptr < loc_ptr )
	       return CONSTRAINED_JOINT_UNIVERSAL_ID_FAILURE_LOCAL;
	    else if( loc_ptr < id_ptr )
	       return CONSTRAINED_JOINT_UNIVERSAL_LOCAL_ID_FAILURE;
	    else
	       return CONSTRAINED_JOINT_UNIVERSAL_ID_LOCAL_FAILURE;
	 }
	 else
	 {
	    if( loc_ptr < fail_ptr )
	       return CONSTRAINED_JOINT_UNIVERSAL_LOCAL_FAILURE_ID;
	    else if( id_ptr < loc_ptr )
	       return CONSTRAINED_JOINT_UNIVERSAL_FAILURE_ID_LOCAL;
	    else
	       return CONSTRAINED_JOINT_UNIVERSAL_FAILURE_LOCAL_ID;
	 }
      }
      else if( id_ptr && fail_ptr )
      {
	 if( id_ptr < fail_ptr )
	    return CONSTRAINED_JOINT_UNIVERSAL_ID_FAILURE;
	 else
	    return CONSTRAINED_JOINT_UNIVERSAL_FAILURE_ID;
      }
      else if( id_ptr && loc_ptr )
      {
	 if( id_ptr < loc_ptr )
	    return CONSTRAINED_JOINT_UNIVERSAL_ID_LOCAL;
	 else
	    return CONSTRAINED_JOINT_UNIVERSAL_LOCAL_ID;
      }
      else if( loc_ptr && fail_ptr )
      {
	 if( loc_ptr < fail_ptr )
	    return CONSTRAINED_JOINT_UNIVERSAL_LOCAL_FAILURE;
	 else
	    return CONSTRAINED_JOINT_UNIVERSAL_FAILURE_LOCAL;
      }
      else if( id_ptr )
      {
	 return CONSTRAINED_JOINT_UNIVERSAL_ID;
      }
      else if( fail_ptr )
      {
	 return CONSTRAINED_JOINT_UNIVERSAL_FAILURE;
      }
      else if( loc_ptr )
      {
	 return CONSTRAINED_JOINT_UNIVERSAL_LOCAL;
      }
      else
	 return CONSTRAINED_JOINT_UNIVERSAL;
   }
   else if( strstr(key_word, "NT_VEL") )
   {
      id_ptr   = strstr(key_word, "ID");
      fail_ptr = strstr(key_word, "FAIL");
      loc_ptr  = strstr(key_word, "LOC");
      
      if( id_ptr && fail_ptr && loc_ptr )
      {
	 if( id_ptr < fail_ptr )
	 {
	    if( fail_ptr < loc_ptr )
	       return CONSTRAINED_JOINT_CONSTANT_VELOCITY_ID_FAILURE_LOCAL;
	    else if( loc_ptr < id_ptr )
	       return CONSTRAINED_JOINT_CONSTANT_VELOCITY_LOCAL_ID_FAILURE;
	    else
	       return CONSTRAINED_JOINT_CONSTANT_VELOCITY_ID_LOCAL_FAILURE;
	 }
	 else
	 {
	    if( loc_ptr < fail_ptr )
	       return CONSTRAINED_JOINT_CONSTANT_VELOCITY_LOCAL_FAILURE_ID;
	    else if( id_ptr < loc_ptr )
	       return CONSTRAINED_JOINT_CONSTANT_VELOCITY_FAILURE_ID_LOCAL;
	    else
	       return CONSTRAINED_JOINT_CONSTANT_VELOCITY_FAILURE_LOCAL_ID;
	 }
      }
      else if( id_ptr && fail_ptr )
      {
	 if( id_ptr < fail_ptr )
	    return CONSTRAINED_JOINT_CONSTANT_VELOCITY_ID_FAILURE;
	 else
	    return CONSTRAINED_JOINT_CONSTANT_VELOCITY_FAILURE_ID;
      }
      else if( id_ptr && loc_ptr )
      {
	 if( id_ptr < loc_ptr )
	    return CONSTRAINED_JOINT_CONSTANT_VELOCITY_ID_LOCAL;
	 else
	    return CONSTRAINED_JOINT_CONSTANT_VELOCITY_LOCAL_ID;
      }
      else if( loc_ptr && fail_ptr )
      {
	 if( loc_ptr < fail_ptr )
	    return CONSTRAINED_JOINT_CONSTANT_VELOCITY_LOCAL_FAILURE;
	 else
	    return CONSTRAINED_JOINT_CONSTANT_VELOCITY_FAILURE_LOCAL;
      }
      else if( id_ptr )
      {
	 return CONSTRAINED_JOINT_CONSTANT_VELOCITY_ID;
      }
      else if( fail_ptr )
      {
	 return CONSTRAINED_JOINT_CONSTANT_VELOCITY_FAILURE;
      }
      else if( loc_ptr )
      {
	 return CONSTRAINED_JOINT_CONSTANT_VELOCITY_LOCAL;
      }
      else
	 return CONSTRAINED_JOINT_CONSTANT_VELOCITY;
   }
   else if( strstr(key_word, "BODY") )
   {
      titl_ptr = strstr(key_word, "_TITL");
      spc_ptr = strstr(key_word, "SPC");
      iner_ptr = strstr(key_word, "INER");
      
      if( titl_ptr && spc_ptr && iner_ptr )
         return CONSTRAINED_NODAL_RIGID_BODY_SPC_INERTIA_TITLE;
      else if( titl_ptr && spc_ptr )
         return CONSTRAINED_NODAL_RIGID_BODY_SPC_TITLE;
      else if( iner_ptr && spc_ptr )
         return CONSTRAINED_NODAL_RIGID_BODY_SPC_INERTIA;
      else if( iner_ptr && titl_ptr )
         return CONSTRAINED_NODAL_RIGID_BODY_INERTIA_TITLE;
      else if( iner_ptr )
         return CONSTRAINED_NODAL_RIGID_BODY_INERTIA;
      else if( spc_ptr )
         return CONSTRAINED_NODAL_RIGID_BODY_SPC;
      else if( titl_ptr )
         return CONSTRAINED_NODAL_RIGID_BODY_TITLE;
      else
         return CONSTRAINED_NODAL_RIGID_BODY;
   }
   else if( strstr(key_word, "_WELD") )
   {
      if( strstr(key_word, "_ID") )
      {
         if( strstr(key_word, "_BUTT") )
            return CONSTRAINED_GENERALIZED_WELD_BUTT_ID;
         else if( strstr(key_word, "_SPOT") )
            return CONSTRAINED_GENERALIZED_WELD_SPOT_ID;
         else if( strstr(key_word, "SS_F") )
            return CONSTRAINED_GENERALIZED_WELD_CROSS_FILLET_ID;
         else if( strstr(key_word, "D_FILL") )
            return CONSTRAINED_GENERALIZED_WELD_FILLET_ID;
         else if( strstr(key_word, "D_COM") )
            return CONSTRAINED_GENERALIZED_WELD_COMBINED_ID;
      }
      else
      {
         if( strstr(key_word, "NED_BU") )
            return CONSTRAINED_BUTT_WELD;
         if( strstr(key_word, "LD_BUT") )
            return CONSTRAINED_GENERALIZED_WELD_BUTT;
         else if( strstr(key_word, "_SPOT") )
            return CONSTRAINED_GENERALIZED_WELD_SPOT;
         else if( strstr(key_word, "SS_F") )
            return CONSTRAINED_GENERALIZED_WELD_CROSS_FILLET;
         else if( strstr(key_word, "D_FILL") )
            return CONSTRAINED_GENERALIZED_WELD_FILLET;
         else if( strstr(key_word, "D_COM") )
            return CONSTRAINED_GENERALIZED_WELD_COMBINED;
      }
   }
   else if( strstr(key_word, "OTW") )
   {
      if( strstr(key_word, "_ID") )
      {
         if( strstr(key_word, "ID_FIL") )
            return CONSTRAINED_SPOTWELD_ID_FILTERED_FORCE;
         else if( strstr(key_word, "CE_ID") )
            return CONSTRAINED_SPOTWELD_FILTERED_FORCE_ID;
         else
            return CONSTRAINED_SPOTWELD_ID;
      }
      else
      {
         if( strstr(key_word, "LD_FIL") )
            return CONSTRAINED_SPOTWELD_FILTERED_FORCE;
         else
            return CONSTRAINED_SPOTWELD;
      }
   }

   return CONST_NEW_TYPE;
}

unsigned int ConstImport::readConsts()
{
   char         new_kw[LINE_LEN];
   unsigned int	i = 0, const_id = 0, const_type = 0, num_consts = 0;
   long		loc = 0L;
   VStringIterator   s = dataLocPtr->keywordList.begin(),
		     e = dataLocPtr->keywordList.end(), itr, 
		     pitr = dataLocPtr->keywordList.begin();
   typeFuncIterator  btype_iter = typeFuncMap.begin(),
                     etype_iter = typeFuncMap.end(), type_iter;

   dataLine = new DataLine(filePtr);

   while(true)
   {
      itr = find_if(pitr, e, bind2nd(KeyWordCompare (), "*CONST"));

      if( itr == e )
	 break;

      pitr = itr+1;
      i = (unsigned int)(itr - s);
      loc = dataLocPtr->slocList[i];

      rewind(filePtr);

      if( fseek(filePtr, loc, SEEK_SET) )
      {
	 cout << "ERROR in locating the Constrained cards" << endl;
	 break;
      }

      dataLine->clearFlag(KW_READ_END);

      char *str = dataLine->readNextCard(); //get the keyword
      Generic::RemoveLeadingAndTrailingBlanks( str );
cout << "KW = " << str << endl;

      const_type = getConstTypeFromKeyword( str, &const_id );
cout << "Const TYPE = " << const_type << endl;

      if( const_type == CONST_NEW_TYPE )
      {
         cout << "Constrained TYPE NOT SUPPORTED" << endl;
         continue;
      }

      strcpy(new_kw, str);

      dataLine->clearFlag(KW_READ_END);
      type_iter = typeFuncMap.find(const_type);
      if( type_iter != etype_iter )
      {
         impObj = new ImportObject(str, const_type);
	 (type_iter->second)(dataLine, impObj);
         Card::clearFlag();
         while( !dataLine->isFlagOn(KW_READ_END) )
         {
	    (type_iter->second)(dataLine, impObj);
         }
         num_consts++;
	 sprintf(new_kw, "%s_%d", new_kw, num_consts);
	 constManPtr->add(new_kw, impObj);
      }
      else
         cout << "Constrained TYPE NOT FOUND" << endl;
   }

   return num_consts;
}

