#ifndef _Const_IMPORT_H_
#define _Const_IMPORT_H_

#include <string>
#include <map>
#include "dataloc.h"
#include "constmanager.h"
#include "dataline.h"
#include "card.h"
#include "consttype.h"
#include "typemap.h"

/** Class to import the data from native LSDYNA file for *CONSTRAINED keywords. 
  * All the data is imported through this class and stored in the manager object.
  */
class ConstImport
{
public:
   /** Constructor for creating this object
     * \param fp File pointer to the LSDYNA native file
     * \param data_loc Pointer to the list of keywords and their locations in
     * the file
     * \param const_man Manager pointer to hold the imported data as a list of
     * ImportObject list
     */
   ConstImport
   (
      FILE          *fp,
      DataLoc       *data_loc,
      ConstManager    *const_man
   );

   ~ConstImport()
   {
      filePtr = NULL;
      constManPtr = NULL;
      dataLocPtr = NULL;
      delete dataLine;
   }

   /** Function for getting the keyword type from given keyword name from LSDYNA
     * native file. The type is stored in the database
     * \param key_word Name of the keyword from file
     * \param const_id ID of the keyword if it is there
     * \return Type for *CONSTRAINED group of keywords
     */
   static ConstType getConstTypeFromKeyword
	   (
	      const char  *key_word,
	      unsigned int *const_id
	   );

   /** Reads the *CONSTRAINED keywords from file
     * \return Returns 0 on failure else number of *CONSTRAINED keywords
     */
   unsigned int readConsts();

   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *CONSTRAINED keyword there is a function to call
     */
   void initSimpleTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *CONSTRAINED keyword there is a function to call
     */
   void initJointTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *CONSTRAINED keyword there is a function to call
     */
   void initWeldTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *CONSTRAINED keyword there is a function to call
     */
   void initCouplingTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *CONSTRAINED keyword there is a function to call
     */
   void initStiffnessTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *CONSTRAINED keyword there is a function to call
     */
   void initNodalTypesAndFunctions();

private:
   FILE          *filePtr;
   /** Manager pointer for holding the imported data for all the keywords */
   ConstManager    *constManPtr;
   /** Pointer to keywords and their locations in the file */
   DataLoc       *dataLocPtr;
   /** Pointer to access the file data line by line */
   DataLine      *dataLine;
   /** Object to store imported data from LSDYNA data file */
   ImportObject  *impObj;
   /** A map between the keyword type and pointer to function */
   map<unsigned int, ImportFunctionPtr>  typeFuncMap;
};

#endif

