#ifndef _ConstLagrangeSolid_h_
#define _ConstLagrangeSolid_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *CONSTRAINED_LAGRANGE_IN_SOLID keyword
  * from LSDYNA native file */

class ConstLagrangeSolid : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ConstLagrangeSolid(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ConstLagrangeSolid()
   {
   }

public:
/** Function to import IDCard details for *CONSTRAINED_LAGRANGE_IN_SOLID
  * keyword from file */
   void readIDCard()
   {
      const char *fields[] = {"COUPID","TITLE",};
      unsigned int field_types[] = {DATA_INT, DATA_CHAR_ARRAY, };
      numFields = 2;
      unsigned int field_widths[] = {10, 70, };
      strBuff = dataLine->readNextCard(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;

      wordArray = dataLine->splitIntoWords(numFields, field_widths);
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, CONST, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("IDCard");
         cardObj->addFields(numFields, field_types, field_widths, fields, strBuff);
         impObj->addCard(cardObj);
      }
   }

/** Function to import SlaveMaster details for *CONSTRAINED_LAGRANGE_IN_SOLID
  * keyword from file */
   int readSlaveMaster()
   {
      const char *fields[] = {"SLAVE","MASTER","SSTYP","MSTYP","NQUAD","CTYPE","DIREC","MCOUP",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return 0;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("SlaveMaster");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
      if( wordArray[5] )
         return atoi(wordArray[5]);
      else
         return 0;
   }

/** Function to import TimeCard details for *CONSTRAINED_LAGRANGE_IN_SOLID
  * keyword from file */
   void readTimeCard()
   {
      const char *fields[] = {"START","END","PFAC","FRIC","FRCMIN","NORM","NORMTYP","DAMP",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("TimeCard");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import HeatTransfer details for *CONSTRAINED_LAGRANGE_IN_SOLID
  * keyword from file */
   int readHeatTransfer()
   {
      const char *fields[] = {"CQ","HMIN","HMAX","ILEAK","PLEAK","LCIDPOR","NVENT","IBLOCK",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {5, };
      unsigned int man_types[] = {DEFINE, };
      unsigned int kw_types[] = {CURVE, };
      unsigned int num_indices = 1;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return 0;
      nvent = 0;
      if( wordArray[6] )
         nvent = atoi(wordArray[6]);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("HeatTransfer");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
      if( wordArray[6] )
         return atoi(wordArray[6]);
      else
         return 0;
   }

/** Function to import Card4a details for *CONSTRAINED_LAGRANGE_IN_SOLID
  * keyword from file */
   void readCard4a()
   {
      const char *fields[] = {"IBOXID","IPENCHK","INTFORC","IALESOF","LAGMUL","PFACMM","THKF",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {DEFINE, };
      unsigned int kw_types[] = {BOX, };
      unsigned int num_indices = 1;
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card4a");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card4b details for *CONSTRAINED_LAGRANGE_IN_SOLID
  * keyword from file */
   void readCard4b()
   {
      const char *fields[] = {"A1","B1","A2","B2","A3","B3",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card4b");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card4c details for *CONSTRAINED_LAGRANGE_IN_SOLID
  * keyword from file */
   void readCard4c()
   {
      const char *fields[] = {"VENTSID","VENTYP","VTCOEF","POPPRES","COEFLC",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, };
      numFields = 5;
      unsigned int i, end_loop;
      end_loop = nvent;
      for(i = 0; i < end_loop; i++)
      {
         numFields = 5;
         wordArray = dataLine->readNextCardAsWords(numFields);
         if( !numFields && dataLine->isFlagOn(KW_READ_END) ) return;

         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
         {
            cardObj = new Card("Card4c");
            cardObj->addFields(numFields, field_types, fields, wordArray);
            impObj->addCard(cardObj);
         }
      }
   }

/** Function to import all the cards of the keyword *CONSTRAINED_LAGRANGE_IN_SOLID
  * from LSDYNA native file */
   unsigned int importConstLagrangeSolid()
   {
      int ctype = 0;
      int nvent = 0;
      if( strstr(impObj->getKeyword().data(), "_TITLE") )
      {
         readIDCard();
      }
      ctype = readSlaveMaster();
      readTimeCard();
      nvent = readHeatTransfer();
      if( ctype == 11 || ctype == 12 )
      {
         readCard4a();
         readCard4b();
      }
      if( nvent )
      {
         readCard4c();
      }
      return 0;
   }
public:
   int nvent;
};

#endif

