#ifndef _ConstLocal_h_
#define _ConstLocal_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *CONSTRAINED_LOCAL keyword
  * from LSDYNA native file */

class ConstLocal : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ConstLocal(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ConstLocal()
   {
   }

public:
/** Function to import Constraint details for *CONSTRAINED_LOCAL
  * keyword from file */
   void readConstraint()
   {
      const char *fields[] = {"TC","RC","CIR","X","Y","Z","CID",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, };
      unsigned int field_indices[] = {6, };
      unsigned int man_types[] = {DEFINE, };
      unsigned int kw_types[] = {COORDINATE, };
      unsigned int num_indices = 1;
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Constraint");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *CONSTRAINED_LOCAL
  * from LSDYNA native file */
   unsigned int importConstLocal()
   {
      readConstraint();
      return 0;
   }
};

#endif

