#ifndef _ConstRigidBodyStoppers_h_
#define _ConstRigidBodyStoppers_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *CONSTRAINED_RIGID_BODY_STOPPERS keyword
  * from LSDYNA native file */

class ConstRigidBodyStoppers : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ConstRigidBodyStoppers(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ConstRigidBodyStoppers()
   {
   }

public:
/** Function to import MasterRigid details for *CONSTRAINED_RIGID_BODY_STOPPERS
  * keyword from file */
   void readMasterRigid()
   {
      const char *fields[] = {"PID","LCMAX","LCMIN","PSIDMX","PSIDMN","LCVMNX","DIR","VID",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, 3, 4, 5, 7, };
      unsigned int man_types[] = {PARTC, DEFINE, DEFINE, SET, SET, DEFINE, DEFINE, };
      unsigned int kw_types[] = {9999, CURVE, CURVE, 9999, 9999, CURVE, VECTOR, };
      unsigned int num_indices = 7;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("MasterRigid");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Time details for *CONSTRAINED_RIGID_BODY_STOPPERS
  * keyword from file */
   void readTime()
   {
      const char *fields[] = {"TB","TD",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 2;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Time");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *CONSTRAINED_RIGID_BODY_STOPPERS
  * from LSDYNA native file */
   unsigned int importConstRigidBodyStoppers()
   {
      readMasterRigid();
      readTime();
      return 0;
   }
};

#endif

