#ifndef _ConstJointMotor_h_
#define _ConstJointMotor_h_

#include "manager.h"
#include "dispexport.h"
#include "constjoint.h"

/** This class is used for importing *CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR keyword
  * from LSDYNA native file */

class ConstJointMotor : public ConstJoint
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ConstJointMotor(DataLine *data_line, ImportObject *imp_obj) : ConstJoint (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ConstJointMotor()
   {
   }

public:
/** Function to import Motor details for *CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR
  * keyword from file */
   void readMotor()
   {
      const char *fields[] = {"PARM","LCID","TYPE","R1",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_INT, DATA_INT, DATA_DOUBLE, };
      unsigned int field_indices[] = {1, };
      unsigned int man_types[] = {DEFINE, };
      unsigned int kw_types[] = {CURVE, };
      unsigned int num_indices = 1;
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Motor");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR
  * from LSDYNA native file */
   unsigned int importConstJointMotor()
   {
      importConstJoint();
      readMotor();
      return 0;
   }
};

#endif

