#ifndef _ConstJointMotorLocalFailure_h_
#define _ConstJointMotorLocalFailure_h_

#include "manager.h"
#include "dispexport.h"
#include "constjointmotor.h"

/** This class is used for importing *CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_LOCAL_FAILURE keyword
  * from LSDYNA native file */

class ConstJointMotorLocalFailure : public ConstJointMotor
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ConstJointMotorLocalFailure(DataLine *data_line, ImportObject *imp_obj) : ConstJointMotor (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ConstJointMotorLocalFailure()
   {
   }

public:
/** Function to import Local details for *CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_LOCAL_FAILURE
  * keyword from file */
   void readLocal()
   {
      const char *fields[] = {"RAID","LST",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, };
      numFields = 2;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         constJointFind(wordArray, numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Local");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Failure1 details for *CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_LOCAL_FAILURE
  * keyword from file */
   void readFailure1()
   {
      const char *fields[] = {"CID","TFAIL","COUPL",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {DEFINE, };
      unsigned int kw_types[] = {COORDINATE, };
      unsigned int num_indices = 1;
      numFields = 3;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Failure1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Failure2 details for *CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_LOCAL_FAILURE
  * keyword from file */
   void readFailure2()
   {
      const char *fields[] = {"NXX","NYY","NZZ","MXX","MYY","MZZ",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Failure2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_LOCAL_FAILURE
  * from LSDYNA native file */
   unsigned int importConstJointMotorLocalFailure()
   {
      importConstJointMotor();
      if( strstr(impObj->getKeyword().data(), "_LOCAL") )
      {
         readLocal();
      }
      if( strstr(impObj->getKeyword().data(), "_FAIL") )
      {
         readFailure1();
         readFailure2();
      }
      return 0;
   }
};

#endif

