#ifndef _ConstNodalRigidBody_h_
#define _ConstNodalRigidBody_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *CONSTRAINED_NODAL_RIGID_BODY keyword
  * from LSDYNA native file */

class ConstNodalRigidBody : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ConstNodalRigidBody(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ConstNodalRigidBody()
   {
   }

public:
/** Function to import IDCard details for *CONSTRAINED_NODAL_RIGID_BODY
  * keyword from file */
   void readIDCard()
   {
      const char *fields[] = {"TITLE",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, };
      numFields = 1;
      unsigned int field_widths[] = {80, };
      strBuff = dataLine->readNextCard(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("IDCard");
         cardObj->addFields(numFields, field_types, field_widths, fields, strBuff);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Part details for *CONSTRAINED_NODAL_RIGID_BODY
  * keyword from file */
   void readPart()
   {
      const char *fields[] = {"PID","CID","NSID","PNODE","IPRT","DRFLAG","RRFLAG",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Part");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *CONSTRAINED_NODAL_RIGID_BODY
  * from LSDYNA native file */
   unsigned int importConstNodalRigidBody()
   {
      if( strstr(impObj->getKeyword().data(), "_TITLE") )
      {
         readIDCard();
      }
      readPart();
      return 0;
   }
};

#endif

