#ifndef _ConstNodalRigidBodyInertia_h_
#define _ConstNodalRigidBodyInertia_h_

#include "manager.h"
#include "dispexport.h"
#include "constnodalrigidbody.h"

/** This class is used for importing *CONSTRAINED_NODAL_RIGID_BODY_INERTIA keyword
  * from LSDYNA native file */

class ConstNodalRigidBodyInertia : public ConstNodalRigidBody
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ConstNodalRigidBodyInertia(DataLine *data_line, ImportObject *imp_obj) : ConstNodalRigidBody (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ConstNodalRigidBodyInertia()
   {
   }

public:
/** Function to import NodalPoint details for *CONSTRAINED_NODAL_RIGID_BODY_INERTIA
  * keyword from file */
   int readNodalPoint()
   {
      const char *fields[] = {"XC","YC","ZC","TM","IRCS","NODEID",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return 0;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("NodalPoint");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
      if( wordArray[4] )
         return atoi(wordArray[4]);
      else
         return 0;
   }

/** Function to import Inertia details for *CONSTRAINED_NODAL_RIGID_BODY_INERTIA
  * keyword from file */
   void readInertia()
   {
      const char *fields[] = {"IXX","IXY","IXZ","IYY","IYZ","IZZ",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Inertia");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Velocity details for *CONSTRAINED_NODAL_RIGID_BODY_INERTIA
  * keyword from file */
   void readVelocity()
   {
      const char *fields[] = {"VTX","VTY","VTZ","VRX","VRY","VRZ",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Velocity");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import LocalAxis details for *CONSTRAINED_NODAL_RIGID_BODY_INERTIA
  * keyword from file */
   void readLocalAxis()
   {
      const char *fields[] = {"XL","YL","ZL","XLIP","YLIP","ZLIP","CID2",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, };
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("LocalAxis");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *CONSTRAINED_NODAL_RIGID_BODY_INERTIA
  * from LSDYNA native file */
   unsigned int importConstNodalRigidBodyInertia()
   {
      int ircs = 0;
      importConstNodalRigidBody();
      ircs = readNodalPoint();
      readInertia();
      readVelocity();
      if( ircs == 1 )
      {
         readLocalAxis();
      }
      return 0;
   }
};

#endif

