#ifndef _ConstNodalRigidBodySpc_h_
#define _ConstNodalRigidBodySpc_h_

#include "manager.h"
#include "dispexport.h"
#include "constnodalrigidbody.h"

/** This class is used for importing *CONSTRAINED_NODAL_RIGID_BODY_SPC keyword
  * from LSDYNA native file */

class ConstNodalRigidBodySpc : public ConstNodalRigidBody
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ConstNodalRigidBodySpc(DataLine *data_line, ImportObject *imp_obj) : ConstNodalRigidBody (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ConstNodalRigidBodySpc()
   {
   }

public:
/** Function to import Spc details for *CONSTRAINED_NODAL_RIGID_BODY_SPC
  * keyword from file */
   void readSpc()
   {
      const char *fields[] = {"CMO","CON1","CON2",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 3;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Spc");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *CONSTRAINED_NODAL_RIGID_BODY_SPC
  * from LSDYNA native file */
   unsigned int importConstNodalRigidBodySpc()
   {
      importConstNodalRigidBody();
      readSpc();
      return 0;
   }
};

#endif

