#ifndef _ConstNodeSet_h_
#define _ConstNodeSet_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *CONSTRAINED_NODE_SET keyword
  * from LSDYNA native file */

class ConstNodeSet : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ConstNodeSet(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ConstNodeSet()
   {
   }

public:
/** Function to import IDCard details for *CONSTRAINED_NODE_SET
  * keyword from file */
   void readIDCard()
   {
      const char *fields[] = {"CNSID",};
      unsigned int field_types[] = {DATA_INT, };
      numFields = 1;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, CONST, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("IDCard");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import NodeSet details for *CONSTRAINED_NODE_SET
  * keyword from file */
   void readNodeSet()
   {
      const char *fields[] = {"NSID","DOF","TF",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, };
      numFields = 3;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("NodeSet");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *CONSTRAINED_NODE_SET
  * from LSDYNA native file */
   unsigned int importConstNodeSet()
   {
      if( strstr(impObj->getKeyword().data(), "_ID") )
      {
         readIDCard();
      }
      readNodeSet();
      return 0;
   }
};

#endif

