#ifndef _ConstAdapt_h_
#define _ConstAdapt_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *CONSTRAINED_ADAPTIVITY keyword
  * from LSDYNA native file */

class ConstAdapt : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ConstAdapt(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ConstAdapt()
   {
   }

public:
/** Function to import Slave details for *CONSTRAINED_ADAPTIVITY
  * keyword from file */
   void readSlave()
   {
      const char *fields[] = {"SN","MN1","MN2",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, };
      unsigned int man_types[] = {NOD, NOD, NOD, };
      unsigned int kw_types[] = {9999, 9999, 9999, };
      unsigned int num_indices = 3;
      numFields = 3;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Slave");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *CONSTRAINED_ADAPTIVITY
  * from LSDYNA native file */
   unsigned int importConstAdapt()
   {
      readSlave();
      return 0;
   }
};

#endif

