#ifndef _ConstInterpolLocal_h_
#define _ConstInterpolLocal_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *CONSTRAINED_INTERPOLATION_LOCAL keyword
  * from LSDYNA native file */

class ConstInterpolLocal : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ConstInterpolLocal(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ConstInterpolLocal()
   {
   }

public:
/** Function to import Interpol1 details for *CONSTRAINED_INTERPOLATION_LOCAL
  * keyword from file */
   void readInterpol1()
   {
      const char *fields[] = {"ICID","DNID","DDOF","CIDD",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 3, };
      unsigned int man_types[] = {DEFINE, NOD, DEFINE, };
      unsigned int kw_types[] = {COORDINATE, 9999, COORDINATE, };
      unsigned int num_indices = 3;
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Interpol1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import IndeNode details for *CONSTRAINED_INTERPOLATION_LOCAL
  * keyword from file */
   void readIndeNode()
   {
      const char *fields[] = {"INID","IDOF","TWGHTX","TWGHTY","TWGHTZ","RWGHTX","RWGHTY","RWGHTZ",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {NOD, };
      unsigned int kw_types[] = {9999, };
      unsigned int num_indices = 1;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("IndeNode");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import LocalCID details for *CONSTRAINED_INTERPOLATION_LOCAL
  * keyword from file */
   void readLocalCID()
   {
      const char *fields[] = {"CIDI",};
      unsigned int field_types[] = {DATA_INT, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {DEFINE, };
      unsigned int kw_types[] = {COORDINATE, };
      unsigned int num_indices = 1;
      numFields = 1;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("LocalCID");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *CONSTRAINED_INTERPOLATION_LOCAL
  * from LSDYNA native file */
   unsigned int importConstInterpolLocal()
   {
      readInterpol1();
      readIndeNode();
      readLocalCID();
      while(numFields)
      {
         readIndeNode();
         readLocalCID();
      }
      return 0;
   }
};

#endif

