#ifndef _ConstJointStiffFlexTorsion_h_
#define _ConstJointStiffFlexTorsion_h_

#include "manager.h"
#include "dispexport.h"
#include "constjointstiffness.h"

/** This class is used for importing *CONSTRAINED_JOINT_STIFFNESS_FLEXION_TORSION keyword
  * from LSDYNA native file */

class ConstJointStiffFlexTorsion : public ConstJointStiffness
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ConstJointStiffFlexTorsion(DataLine *data_line, ImportObject *imp_obj) : ConstJointStiffness (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ConstJointStiffFlexTorsion()
   {
   }

public:
/** Function to import LoadCurves details for *CONSTRAINED_JOINT_STIFFNESS_FLEXION_TORSION
  * keyword from file */
   void readLoadCurves()
   {
      const char *fields[] = {"LCIDAL","LCIDG","LCIDBT","DLCIDAL","DLCIDG","DLCIDBT",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("LoadCurves");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import StiffMoment details for *CONSTRAINED_JOINT_STIFFNESS_FLEXION_TORSION
  * keyword from file */
   void readStiffMoment()
   {
      const char *fields[] = {"ESAL","FMAL","ESBT","FMBT",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("StiffMoment");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import StopAngles details for *CONSTRAINED_JOINT_STIFFNESS_FLEXION_TORSION
  * keyword from file */
   void readStopAngles()
   {
      const char *fields[] = {"SAAL","NSABT","PSABT",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 3;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("StopAngles");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *CONSTRAINED_JOINT_STIFFNESS_FLEXION_TORSION
  * from LSDYNA native file */
   unsigned int importConstJointStiffFlexTorsion()
   {
      importConstJointStiffness();
      readLoadCurves();
      readStiffMoment();
      readStopAngles();
      return 0;
   }
};

#endif

