#ifndef _ConstJointStiffGeneral_h_
#define _ConstJointStiffGeneral_h_

#include "manager.h"
#include "dispexport.h"
#include "constjointstiffness.h"

/** This class is used for importing *CONSTRAINED_JOINT_STIFFNESS_GENERALIZED keyword
  * from LSDYNA native file */

class ConstJointStiffGeneral : public ConstJointStiffness
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ConstJointStiffGeneral(DataLine *data_line, ImportObject *imp_obj) : ConstJointStiffness (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ConstJointStiffGeneral()
   {
   }

public:
/** Function to import LoadCurves details for *CONSTRAINED_JOINT_STIFFNESS_GENERALIZED
  * keyword from file */
   void readLoadCurves()
   {
      const char *fields[] = {"LCIDPH","LCIDT","LCIDPS","DLCIDPH","DLCIDT","DLCIDPS",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("LoadCurves");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import StiffMoment details for *CONSTRAINED_JOINT_STIFFNESS_GENERALIZED
  * keyword from file */
   void readStiffMoment()
   {
      const char *fields[] = {"ESPH","FMPH","EST","FMT","ESPS","FMPS",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("StiffMoment");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import StopAngles details for *CONSTRAINED_JOINT_STIFFNESS_GENERALIZED
  * keyword from file */
   void readStopAngles()
   {
      const char *fields[] = {"NSAPH","PSAPH","NSAT","PSAT","NSAPS","PSAPS",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("StopAngles");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *CONSTRAINED_JOINT_STIFFNESS_GENERALIZED
  * from LSDYNA native file */
   unsigned int importConstJointStiffGeneral()
   {
      importConstJointStiffness();
      readLoadCurves();
      readStiffMoment();
      readStopAngles();
      return 0;
   }
};

#endif

