#ifndef _ConstGenWeldCrossFillet_h_
#define _ConstGenWeldCrossFillet_h_

#include "manager.h"
#include "dispexport.h"
#include "constgenweld.h"

/** This class is used for importing *CONSTRAINED_GENERALIZED_WELD_CROSS_FILLET keyword
  * from LSDYNA native file */

class ConstGenWeldCrossFillet : public ConstGenWeld
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ConstGenWeldCrossFillet(DataLine *data_line, ImportObject *imp_obj) : ConstGenWeld (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ConstGenWeldCrossFillet()
   {
   }

public:
/** Function to import Fillet1 details for *CONSTRAINED_GENERALIZED_WELD_CROSS_FILLET
  * keyword from file */
   void readFillet1()
   {
      const char *fields[] = {"TFAIL","EPSF","SIGY","BETA","L","W","A","ALPHA",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Fillet1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Fillet2 details for *CONSTRAINED_GENERALIZED_WELD_CROSS_FILLET
  * keyword from file */
   void readFillet2()
   {
      const char *fields[] = {"NODEA","NODEB","NCID",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, };
      unsigned int man_types[] = {NOD, NOD, DEFINE, };
      unsigned int kw_types[] = {9999, 9999, COORDINATE, };
      unsigned int num_indices = 3;
      numFields = 3;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Fillet2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *CONSTRAINED_GENERALIZED_WELD_CROSS_FILLET
  * from LSDYNA native file */
   unsigned int importConstGenWeldCrossFillet()
   {
      importConstGenWeld();
      for(int i = 0; i < npr; i++)
      {
         readFillet1();
         readFillet2();
      }
      return 0;
   }
};

#endif

