#ifndef _ConstSpotWeld_h_
#define _ConstSpotWeld_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *CONSTRAINED_SPOTWELD keyword
  * from LSDYNA native file */

class ConstSpotWeld : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ConstSpotWeld(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ConstSpotWeld()
   {
   }

public:
/** Function to import IDCard details for *CONSTRAINED_SPOTWELD
  * keyword from file */
   void readIDCard()
   {
      const char *fields[] = {"WID",};
      unsigned int field_types[] = {DATA_INT, };
      numFields = 1;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, CONST, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("IDCard");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import SpotWeld details for *CONSTRAINED_SPOTWELD
  * keyword from file */
   void readSpotWeld()
   {
      const char *fields[] = {"N1","N2","SN","SS","N","M","TF","EP",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("SpotWeld");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *CONSTRAINED_SPOTWELD
  * from LSDYNA native file */
   unsigned int importConstSpotWeld()
   {
      if( strstr(impObj->getKeyword().data(), "_ID") )
      {
         readIDCard();
      }
      readSpotWeld();
      return 0;
   }
};

#endif

