#ifndef _CARD4_IMPORT_H_
#define _CARD4_IMPORT_H_

#include <map>
#include "typemap.h"
#include "card.h"
#include "contacttype.h"

/** Class to import the data from native LSDYNA file the first 4 cards of 
  * *CONTACT keywords. All the data is imported through this class and stored 
  * in the manager object.
  */
class Card4Import
{
public:
   /** Constructor for creating this object
     * \param data_line Pointer to the data in the LSDYNA native file
     * \param imp_obj pointer to hold the imported data as a list of cards
     */
   Card4Import(DataLine *data_line, ImportObject *imp_obj)
   {
      initCard4TypesAndFunctions();
       
      dataLine = data_line;
      impObj = imp_obj; 
   }
   
   ~Card4Import()
   {
      dataLine = NULL;
      impObj = NULL;
      typeFuncMap.clear();
   }

   /** Imports the first 4 cards of *CONTACT
     * \param card4_type Type of *CONTACT
     * \return Returns 0 always
     */
   unsigned int importCard4(unsigned int card4_type)
   {
      typeFuncIterator  btype_iter = typeFuncMap.begin(),
                        etype_iter = typeFuncMap.end(), type_iter;
      type_iter = typeFuncMap.find(card4_type);

      if( type_iter != etype_iter )
      {
         (type_iter->second)(dataLine, impObj);
      }

      return 0;
   }

   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *CONTACT keyword there is a function to call
     */
   void initCard4TypesAndFunctions();

private:
   /** Pointer to access the file data line by line */
   DataLine                              *dataLine;
   /** Object to store imported data from LSDYNA data file */
   ImportObject                          *impObj;
   /** A map between the keyword type and pointer to function */
   map<unsigned int, ImportFunctionPtr>  typeFuncMap;
};

#endif

