#ifndef _Card4TiebreakSurfToSurf_h_
#define _Card4TiebreakSurfToSurf_h_

#include "manager.h"
#include "dispexport.h"
#include "dataline.h"
#include "card.h"

/** This class is used for importing *CONTACT_TIEBREAK_SURFACE_TO_SURFACE keyword
  * from LSDYNA native file */

class Card4TiebreakSurfToSurf
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   Card4TiebreakSurfToSurf(DataLine *data_line, ImportObject *imp_obj)
   {
      dataLine = data_line;
      impObj = imp_obj;
      numFields = 0;
      strBuff = NULL;
      wordArray = NULL;
      cardObj = NULL;
   }

/** Class destructor for releasing the memory.
  */
   virtual ~Card4TiebreakSurfToSurf()
   {
      dataLine = NULL;
      impObj = NULL;
      numFields = 0;
      strBuff = NULL;
      wordArray = NULL;
      cardObj = NULL;
   }

public:
/** Number of fields in each card */
   unsigned int   numFields;
/** Raw buffer read from file */
   char           *strBuff;
/** Array of words in each card after splitting the raw buffer */
   char           **wordArray;
/** Object to hold the imported data from file */
   ImportObject   *impObj;
/** Object that reads data, line by line from file */
   DataLine       *dataLine;
/** Object to store the fields and their values */
   Card           *cardObj;

public:
/** Function to import FailStressCard details for *CONTACT_TIEBREAK_SURFACE_TO_SURFACE
  * keyword from file */
   void readFailStressCard()
   {
      const char *fields[] = {"NFLS","SFLS","TBLCID","THKOFF",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {2, };
      unsigned int man_types[] = {DEFINE, };
      unsigned int kw_types[] = {CURVE, };
      unsigned int num_indices = 1;
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("FailStressCard");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *CONTACT_TIEBREAK_SURFACE_TO_SURFACE
  * from LSDYNA native file */
   unsigned int importCard4TiebreakSurfToSurf()
   {
      readFailStressCard();
      return 0;
   }
};

#endif

