#ifndef _ContactMandatory_h_
#define _ContactMandatory_h_

#include "manager.h"
#include "dispexport.h"
#include "dataline.h"
#include "card.h"

/** This class is used for importing *CONTACT keyword
  * from LSDYNA native file */

class ContactMandatory
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ContactMandatory(DataLine *data_line, ImportObject *imp_obj)
   {
      dataLine = data_line;
      impObj = imp_obj;
      numFields = 0;
      strBuff = NULL;
      wordArray = NULL;
      cardObj = NULL;
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ContactMandatory()
   {
      dataLine = NULL;
      impObj = NULL;
      numFields = 0;
      strBuff = NULL;
      wordArray = NULL;
      cardObj = NULL;
   }

public:
/** Number of fields in each card */
   unsigned int   numFields;
/** Raw buffer read from file */
   char           *strBuff;
/** Array of words in each card after splitting the raw buffer */
   char           **wordArray;
/** Object to hold the imported data from file */
   ImportObject   *impObj;
/** Object that reads data, line by line from file */
   DataLine       *dataLine;
/** Object to store the fields and their values */
   Card           *cardObj;

public:
/** Function to import SlaveMasterCard details for *CONTACT
  * keyword from file */
   void readSlaveMasterCard()
   {
      const char *fields[] = {"SSID","MSID","SSTYP","MSTYP","SBOXID","MBOXID","SPR","MPR",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         contactFind(wordArray, numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("SlaveMasterCard");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import FrictionStressCard details for *CONTACT
  * keyword from file */
   void readFrictionStressCard()
   {
      const char *fields[] = {"FS","FD","DC","VC","VDC","PENCHK","BT","DT",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("FrictionStressCard");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import ScaleFactors details for *CONTACT
  * keyword from file */
   void readScaleFactors()
   {
      const char *fields[] = {"SFS","SFM","SST","MST","SFST","SFMT","FSF","VSF",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("ScaleFactors");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *CONTACT
  * from LSDYNA native file */
   unsigned int importContactMandatory()
   {
      readSlaveMasterCard();
      readFrictionStressCard();
      readScaleFactors();
      return 0;
   }
};

#endif

