#ifndef _Contact2DNoAuto_h_
#define _Contact2DNoAuto_h_

#include "manager.h"
#include "dispexport.h"
#include "dataline.h"
#include "card.h"

/** This class is used for importing *CONTACT_2D_NO_AUTOMATIC keyword
  * from LSDYNA native file */

class Contact2DNoAuto
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   Contact2DNoAuto(DataLine *data_line, ImportObject *imp_obj)
   {
      dataLine = data_line;
      impObj = imp_obj;
      numFields = 0;
      strBuff = NULL;
      wordArray = NULL;
      cardObj = NULL;
   }

/** Class destructor for releasing the memory.
  */
   virtual ~Contact2DNoAuto()
   {
      dataLine = NULL;
      impObj = NULL;
      numFields = 0;
      strBuff = NULL;
      wordArray = NULL;
      cardObj = NULL;
   }

public:
/** Number of fields in each card */
   unsigned int   numFields;
/** Raw buffer read from file */
   char           *strBuff;
/** Array of words in each card after splitting the raw buffer */
   char           **wordArray;
/** Object to hold the imported data from file */
   ImportObject   *impObj;
/** Object that reads data, line by line from file */
   DataLine       *dataLine;
/** Object to store the fields and their values */
   Card           *cardObj;

public:
/** Function to import SlaveMasterNodes details for *CONTACT_2D_NO_AUTOMATIC
  * keyword from file */
   void readSlaveMasterNodes()
   {
      const char *fields[] = {"SSID","MSID","TBIRTH","TDEATH",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, 1, };
      unsigned int man_types[] = {SET, SET, };
      unsigned int kw_types[] = {NOD, NOD, };
      unsigned int num_indices = 2;
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("SlaveMasterNodes");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import SlideLine details for *CONTACT_2D_NO_AUTOMATIC
  * keyword from file */
   void readSlideLine()
   {
      const char *fields[] = {"EXT_PAS","THETA1","THETA2","TOL_IG","PEN","TOLOFF","FRCSCL","ONEWAY",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("SlideLine");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *CONTACT_2D_NO_AUTOMATIC
  * from LSDYNA native file */
   unsigned int importContact2DNoAuto()
   {
      readSlaveMasterNodes();
      readSlideLine();
      return 0;
   }
};

#endif

