#ifndef _Contact2DPenFric_h_
#define _Contact2DPenFric_h_

#include "manager.h"
#include "dispexport.h"
#include "dataline.h"
#include "card.h"

/** This class is used for importing *CONTACT_2D_PENALTY_FRICTION keyword
  * from LSDYNA native file */

class Contact2DPenFric
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   Contact2DPenFric(DataLine *data_line, ImportObject *imp_obj)
   {
      dataLine = data_line;
      impObj = imp_obj;
      numFields = 0;
      strBuff = NULL;
      wordArray = NULL;
      cardObj = NULL;
   }

/** Class destructor for releasing the memory.
  */
   virtual ~Contact2DPenFric()
   {
      dataLine = NULL;
      impObj = NULL;
      numFields = 0;
      strBuff = NULL;
      wordArray = NULL;
      cardObj = NULL;
   }

public:
/** Number of fields in each card */
   unsigned int   numFields;
/** Raw buffer read from file */
   char           *strBuff;
/** Array of words in each card after splitting the raw buffer */
   char           **wordArray;
/** Object to hold the imported data from file */
   ImportObject   *impObj;
/** Object that reads data, line by line from file */
   DataLine       *dataLine;
/** Object to store the fields and their values */
   Card           *cardObj;

public:
/** Function to import FrictionCard details for *CONTACT_2D_PENALTY_FRICTION
  * keyword from file */
   void readFrictionCard()
   {
      const char *fields[] = {"FRIC","FRIC_L","FRIC_H","FRIC_S",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("FrictionCard");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *CONTACT_2D_PENALTY_FRICTION
  * from LSDYNA native file */
   unsigned int importContact2DPenFric()
   {
      readFrictionCard();
      return 0;
   }
};

#endif

