#ifndef _Contact_1D_h_
#define _Contact_1D_h_

#include "manager.h"
#include "dispexport.h"
#include "dataline.h"
#include "card.h"

/** This class is used for importing *CONTACT_1D keyword
  * from LSDYNA native file */

class Contact_1D
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   Contact_1D(DataLine *data_line, ImportObject *imp_obj)
   {
      dataLine = data_line;
      impObj = imp_obj;
      numFields = 0;
      strBuff = NULL;
      wordArray = NULL;
      cardObj = NULL;
   }

/** Class destructor for releasing the memory.
  */
   virtual ~Contact_1D()
   {
      dataLine = NULL;
      impObj = NULL;
      numFields = 0;
      strBuff = NULL;
      wordArray = NULL;
      cardObj = NULL;
   }

public:
/** Number of fields in each card */
   unsigned int   numFields;
/** Raw buffer read from file */
   char           *strBuff;
/** Array of words in each card after splitting the raw buffer */
   char           **wordArray;
/** Object to hold the imported data from file */
   ImportObject   *impObj;
/** Object that reads data, line by line from file */
   DataLine       *dataLine;
/** Object to store the fields and their values */
   Card           *cardObj;

public:
/** Function to import NodeSet details for *CONTACT_1D
  * keyword from file */
   void readNodeSet()
   {
      const char *fields[] = {"NSIDS","NSIDM","ERR","SIGC","GB","SMAX","EXP",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, 1, };
      unsigned int man_types[] = {SET, SET, };
      unsigned int kw_types[] = {NOD, NOD, };
      unsigned int num_indices = 2;
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("NodeSet");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *CONTACT_1D
  * from LSDYNA native file */
   unsigned int importContact_1D()
   {
      readNodeSet();
      return 0;
   }
};

#endif

