#ifndef _ControlAdaptive_h_
#define _ControlAdaptive_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *CONTROL_ADAPTIVE keyword
  * from LSDYNA native file */

class ControlAdaptive : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ControlAdaptive(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ControlAdaptive()
   {
   }

public:
/** Function to import Card1 details for *CONTROL_ADAPTIVE
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"ADPFREQ","ADPTOL","ADPOPT","MAXLVL","TBIRTH","TDEATH","LCADP","IOFLAG",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {6, };
      unsigned int man_types[] = {DEFINE, };
      unsigned int kw_types[] = {CURVE, };
      unsigned int num_indices = 1;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *CONTROL_ADAPTIVE
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"ADPSIZE","ADPASS","IREFLG","ADPENE","ADPTH","MEMORY","ORIENT","MAXEL",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         controlGeneralFind(wordArray, numFields, 2, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3 details for *CONTROL_ADAPTIVE
  * keyword from file */
   void readCard3()
   {
      const char *fields[] = {"IADPN90","IADPGH","NCFREQ","IADPCL","ADPCTL","CBIRTH","CDEATH","LCLVL",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {7, };
      unsigned int man_types[] = {DEFINE, };
      unsigned int kw_types[] = {CURVE, };
      unsigned int num_indices = 1;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card4 details for *CONTROL_ADAPTIVE
  * keyword from file */
   void readCard4()
   {
      const char *fields[] = {"CNLA",};
      unsigned int field_types[] = {DATA_DOUBLE, };
      numFields = 1;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card4");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *CONTROL_ADAPTIVE
  * from LSDYNA native file */
   unsigned int importControlAdaptive()
   {
      readCard1();
      readCard2();
      readCard3();
      readCard4();
      return 0;
   }
};

#endif

