#ifndef _ControlAdaptiveCurve_h_
#define _ControlAdaptiveCurve_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *CONTROL_ADAPTIVE_CURVE keyword
  * from LSDYNA native file */

class ControlAdaptiveCurve : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ControlAdaptiveCurve(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ControlAdaptiveCurve()
   {
   }

public:
/** Function to import Card1 details for *CONTROL_ADAPTIVE_CURVE
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"IDSET","ITYPE","N","SMIN","ITRIOPT",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_INT, };
      numFields = 5;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         controlCurveFind(wordArray, numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *CONTROL_ADAPTIVE_CURVE
  * from LSDYNA native file */
   unsigned int importControlAdaptiveCurve()
   {
      readCard1();
      return 0;
   }
};

#endif

