#include <iostream>
#include <algorithm>
#include "generic.h"
#include "controltype.h"
#include "controlimport.h"
#include <stdlib.h>

using namespace std;

ControlImport::ControlImport
(
   FILE          *fp,
   DataLoc       *data_loc,
   ControlManager    *control_man
)
{
   filePtr = fp;
   controlManPtr = control_man;
   dataLocPtr = data_loc;
   dataLine = NULL;

   initAdaptTypesAndFunctions();
   initElementTypesAndFunctions();
   initFormingTypesAndFunctions();
   initImplicitTypesAndFunctions();
   initMppTypesAndFunctions();
   initSimpleTypesAndFunctions();
   initThermalTypesAndFunctions();
}

int ControlImport::getControlTypeFromKeyword
	(
	   const char  *key_word,
	   unsigned int *control_id
	)
{
   *control_id = 0;

   if( strstr(key_word, "_ACCU") )
      return CONTROL_ACCURACY;
   else if( strstr(key_word, "APST") )
      return CONTROL_ADAPSTEP;
   else if( strstr(key_word, "VE_CUR") )
      return CONTROL_ADAPTIVE_CURVE;
   else if( strstr(key_word, "IVE") )
      return CONTROL_ADAPTIVE;
   else if( strstr(key_word, "_ALE") )
      return CONTROL_ALE;
   else if( strstr(key_word, "_COA") )
      return CONTROL_COARSEN;
   else if( strstr(key_word, "IC_RE") )
      return CONTROL_DYNAMIC_RELAXATION;
   else if( strstr(key_word, "E_SHA") )
      return CONTROL_EXPLOSIVE_SHADOW;
   else if( strstr(key_word, "L_REM") )
      return CONTROL_REMESHING;
   else if( strstr(key_word, "_RIG") )
      return CONTROL_RIGID;
   else if( strstr(key_word, "L_SHE") )
      return CONTROL_SHELL;
   else if( strstr(key_word, "L_SOLI") )
      return CONTROL_SOLID;
   else if( strstr(key_word, "L_SOLU") )
      return CONTROL_SOLUTION;
   else if( strstr(key_word, "L_SPH") )
      return CONTROL_SPH;
   else if( strstr(key_word, "LD_BE") )
      return CONTROL_SPOTWELD_BEAM;
   else if( strstr(key_word, "ED_CON") )
      return CONTROL_STAGED_CONSTRUCTION;
   else if( strstr(key_word, "ED_TE") )
      return CONTROL_STRUCTURED_TERM;
   else if( strstr(key_word, "L_STR") )
      return CONTROL_STRUCTURED;
   else if( strstr(key_word, "L_CPU") )
      return CONTROL_CPU;
   else if( strstr(key_word, "G_POS") )
      return CONTROL_FORMING_POSITION;
   else if( strstr(key_word, "G_PRO") )
      return CONTROL_FORMING_PROJECTION;
   else if( strstr(key_word, "G_TEMP") )
      return CONTROL_FORMING_TEMPLATE;
   else if( strstr(key_word, "G_TRA") )
      return CONTROL_FORMING_TRAVEL;
   else if( strstr(key_word, "G_USE") )
      return CONTROL_FORMING_USER;
   else if( strstr(key_word, "L_OUT") )
      return CONTROL_OUTPUT;
   else if( strstr(key_word, "L_PAR") )
      return CONTROL_PARALLEL;
   else if( strstr(key_word, "L_SUB") )
      return CONTROL_SUBCYCLE;
   else if( strstr(key_word, "IT_AU") )
      return CONTROL_IMPLICIT_AUTO;
   else if( strstr(key_word, "IT_BU") )
      return CONTROL_IMPLICIT_BUCKLE;
   else if( strstr(key_word, "IT_DY") )
      return CONTROL_IMPLICIT_DYNAMICS;
   else if( strstr(key_word, "IA_RE") )
      return CONTROL_IMPLICIT_INERTIA_RELIEF;
   else if( strstr(key_word, "IT_JO") )
      return CONTROL_IMPLICIT_JOINTS;
   else if( strstr(key_word, "IT_MO") )
      return CONTROL_IMPLICIT_MODES;
   else if( strstr(key_word, "T_SOLV") )
      return CONTROL_IMPLICIT_SOLVER;
   else if( strstr(key_word, "T_STA") )
      return CONTROL_IMPLICIT_STABILIZATION;
   else if( strstr(key_word, "T_TER") )
      return CONTROL_IMPLICIT_TERMINATION;
   else if( strstr(key_word, "ON_AU") )
      return CONTROL_MPP_DECOMPOSITION_AUTOMATIC;
   else if( strstr(key_word, "CK_SP") )
      return CONTROL_MPP_DECOMPOSITION_CHECK_SPEED;
   else if( strstr(key_word, "T_DIS") )
      return CONTROL_MPP_DECOMPOSITION_CONTACT_DISTRIBUTE;
   else if( strstr(key_word, "T_ISO") )
      return CONTROL_MPP_DECOMPOSITION_CONTACT_ISOLATE;
   else if( strstr(key_word, "N_FIL") )
      return CONTROL_MPP_DECOMPOSITION_FILE;
   else if( strstr(key_word, "N_MET") )
      return CONTROL_MPP_DECOMPOSITION_METHOD;
   else if( strstr(key_word, "N_NUM") )
      return CONTROL_MPP_DECOMPOSITION_NUMPROC;
   else if( strstr(key_word, "N_SHO") )
      return CONTROL_MPP_DECOMPOSITION_SHOW;
   else if( strstr(key_word, "N_TRA") )
      return CONTROL_MPP_DECOMPOSITION_TRANSFORMATION;
   else if( strstr(key_word, "_NOD3") )
      return CONTROL_MPP_IO_NOD3DUMP;
   else if( strstr(key_word, "NODUM") )
      return CONTROL_MPP_IO_NODUMP;
   else if( strstr(key_word, "NOFUL") )
      return CONTROL_MPP_IO_NOFULL;
   else if( strstr(key_word, "_SWAP") )
      return CONTROL_MPP_IO_SWAPBYTES;
   else if( strstr(key_word, "ONLOC") )
      return CONTROL_NONLOCAL;
   else if( strstr(key_word, "K_VIS") )
      return CONTROL_BULK_VISCOSITY;
   else if( strstr(key_word, "K_SHE") )
      return CONTROL_CHECK_SHELL;
   else if( strstr(key_word, "L_CHE") )
      return CONTROL_CHECK;
   else if( strstr(key_word, "L_CONT") )
      return CONTROL_CONTACT;
   else if( strstr(key_word, "L_COU") )
      return CONTROL_COUPLING;
   else if( strstr(key_word, "L_EFG") )
      return CONTROL_EFG;
   else if( strstr(key_word, "L_ENE") )
      return CONTROL_ENERGY;
   else if( strstr(key_word, "_936") )
      return CONTROL_HOURGLASS_936;
   else if( strstr(key_word, "L_HOU") )
      return CONTROL_HOURGLASS;
   else if( strstr(key_word, "T_EIG") )
      return CONTROL_IMPLICIT_EIGENVALUE;
   else if( strstr(key_word, "T_GEN") )
      return CONTROL_IMPLICIT_GENERAL;
   else if( strstr(key_word, "T_SOLU") )
      return CONTROL_IMPLICIT_SOLUTION;
   else if( strstr(key_word, "L_TER") )
      return CONTROL_TERMINATION;
   else if( strstr(key_word, "NLINEA") )
      return CONTROL_THERMAL_NONLINEAR;
   else if( strstr(key_word, "L_SOLV") )
      return CONTROL_THERMAL_SOLVER;
   else if( strstr(key_word, "MAL_T") )
      return CONTROL_THERMAL_TIMESTEP;
   else if( strstr(key_word, "OL_TI") )
      return CONTROL_TIMESTEP;
   else if( strstr(key_word, "KEYWORD") )
      return KEYWORD;
   else if( strstr(key_word, "TITLE") )
      return TITLE_CARD;
   else if( strstr(key_word, "KEYWORD_ID") )
      return KEYWORD_ID;
   else
      return CONTROL_NEW_TYPE;
}

unsigned int ControlImport::readControls()
{
   char         new_kw[LINE_LEN];
   unsigned int	i = 0, control_id = 0, control_type = 0, num_controls = 0;
   long		loc = 0L;
   VStringIterator   s = dataLocPtr->keywordList.begin(),
		     e = dataLocPtr->keywordList.end(), itr, 
		     pitr = dataLocPtr->keywordList.begin();
   typeFuncIterator  btype_iter = typeFuncMap.begin(),
                     etype_iter = typeFuncMap.end(), type_iter;

   dataLine = new DataLine(filePtr);

   while(true)
   {
      itr = find_if(pitr, e, bind2nd(KeyWordCompare (), "*CONTR"));

      if( itr == e )
	 break;

      pitr = itr+1;
      i = (unsigned int)(itr - s);
      loc = dataLocPtr->slocList[i];

      rewind(filePtr);

      if( fseek(filePtr, loc, SEEK_SET) )
      {
	 cout << "ERROR in locating the Control cards" << endl;
	 break;
      }

      dataLine->clearFlag(KW_READ_END);

      char *str = dataLine->readNextCard(); //get the keyword
      Generic::RemoveLeadingAndTrailingBlanks( str );
cout << "KW = " << str << endl;

      control_type = getControlTypeFromKeyword( str, &control_id );
cout << "Control TYPE = " << control_type << endl;

      if( control_type == CONTROL_NEW_TYPE )
      {
         cout << "Control TYPE NOT SUPPORTED" << endl;
         continue;
      }

      num_controls++;

      strcpy(new_kw, str);

      dataLine->clearFlag(KW_READ_END);
      type_iter = typeFuncMap.find(control_type);
      if( type_iter != etype_iter )
      {
          impObj = new ImportObject(str, control_type);
          (type_iter->second)(dataLine, impObj);
          if( control_id )
          {
             controlManPtr->add(new_kw, impObj);
          }
          else
          {
             sprintf(new_kw, "%s_%d", new_kw, num_controls);
             controlManPtr->add(new_kw, impObj);
          }
      }
      else
         cout << "Control TYPE NOT FOUND" << endl;
   }

   return num_controls;
}

