#ifndef _Control_IMPORT_H_
#define _Control_IMPORT_H_

#include <string>
#include <map>
#include "dataloc.h"
#include "controlmanager.h"
#include "dataline.h"
#include "card.h"
#include "controltype.h"
#include "keywordtype.h"
#include "typemap.h"

/** Class to import the data from native LSDYNA file for *CONTROL keywords. All
  * the data is imported through this class and stored in the manager object.
  */
class ControlImport
{
public:
   /** Constructor for creating this object
     * \param fp File pointer to the LSDYNA native file
     * \param data_loc Pointer to the list of keywords and their locations in
     * the file
     * \param control_man Manager pointer to hold the imported data as a list of
     * ImportObject list
     */
   ControlImport
   (
      FILE          *fp,
      DataLoc       *data_loc,
      ControlManager    *control_man
   );

   ~ControlImport()
   {
      filePtr = NULL;
      controlManPtr = NULL;
      dataLocPtr = NULL;
      delete dataLine;
   }

   /** Function for getting the keyword type from given keyword name from LSDYNA
     * native file. The type is stored in the database
     * \param key_word Name of the keyword from file
     * \param control_id ID of the keyword if it is there
     * \return Type for *CONTROL group of keywords
     */
   static int getControlTypeFromKeyword
	   (
	      const char  *key_word,
	      unsigned int *control_id
	   );

   /** Reads the *CONTROL keywords from file
     * \return Returns 0 on failure else number of *CONTROL keywords
     */
   unsigned int readControls();

   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *PART keyword there is a function to call
     */
   void initAdaptTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *PART keyword there is a function to call
     */
   void initElementTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *PART keyword there is a function to call
     */
   void initFormingTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *PART keyword there is a function to call
     */
   void initImplicitTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *PART keyword there is a function to call
     */
   void initMppTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *PART keyword there is a function to call
     */
   void initSimpleTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *CONTROL keyword there is a function to call
     */
   void initThermalTypesAndFunctions();

private:
   FILE          *filePtr;
   /** Manager pointer for holding the imported data for all the keywords */
   ControlManager    *controlManPtr;
   /** Pointer to keywords and their locations in the file */
   DataLoc       *dataLocPtr;
   /** Pointer to access the file data line by line */
   DataLine      *dataLine;
   /** Object to store imported data from LSDYNA data file */
   ImportObject  *impObj;
   /** A map between the keyword type and pointer to function */
   map<unsigned int, ImportFunctionPtr>  typeFuncMap;
};

#endif

