#ifndef _ControlShell_h_
#define _ControlShell_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *CONTROL_SHELL keyword
  * from LSDYNA native file */

class ControlShell : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ControlShell(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ControlShell()
   {
   }

public:
/** Function to import Card1 details for *CONTROL_SHELL
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"WRPANG","ESORT","IRNXX","ISTUPD","THEORY","BWC","MITER","PROJ",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *CONTROL_SHELL
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"ROTASCL","INTGRD","LAMSHT","CSTYP6","TSHELL","NFAIL1","NFAIL4","PSNFAIL",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {7, };
      unsigned int man_types[] = {SET, };
      unsigned int kw_types[] = {PARTC, };
      unsigned int num_indices = 1;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3 details for *CONTROL_SHELL
  * keyword from file */
   void readCard3()
   {
      const char *fields[] = {"PSSTUPD","IRQUAD",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {SET, };
      unsigned int kw_types[] = {PARTC, };
      unsigned int num_indices = 1;
      numFields = 2;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *CONTROL_SHELL
  * from LSDYNA native file */
   unsigned int importControlShell()
   {
      readCard1();
      readCard2();
      readCard3();
      return 0;
   }
};

#endif

