#ifndef _ControlSpotweldBeam_h_
#define _ControlSpotweldBeam_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *CONTROL_SPOTWELD_BEAM keyword
  * from LSDYNA native file */

class ControlSpotweldBeam : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ControlSpotweldBeam(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ControlSpotweldBeam()
   {
   }

public:
/** Function to import Card details for *CONTROL_SPOTWELD_BEAM
  * keyword from file */
   void readCard()
   {
      const char *fields[] = {"LCT","LCS","T_ORT","PRTFLG","T_ORS","RPBHX",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, 4, };
      unsigned int man_types[] = {DEFINE, DEFINE, DEFINE, DEFINE, };
      unsigned int kw_types[] = {CURVE, CURVE, TABLE, TABLE, };
      unsigned int num_indices = 4;
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *CONTROL_SPOTWELD_BEAM
  * from LSDYNA native file */
   unsigned int importControlSpotweldBeam()
   {
      readCard();
      return 0;
   }
};

#endif

