#ifndef _ControlFormingTemplate_h_
#define _ControlFormingTemplate_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *CONTROL_FORMING_TEMPLATE keyword
  * from LSDYNA native file */

class ControlFormingTemplate : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ControlFormingTemplate(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ControlFormingTemplate()
   {
   }

public:
/** Function to import Card1 details for *CONTROL_FORMING_TEMPLATE
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"IDTEMP","BLKID","DIEID","PNCH","BNDU","BNDL","TYPE","PREBD",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         controlTemplateFind(wordArray, numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *CONTROL_FORMING_TEMPLATE
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"LCSS","AL/FE","R00","R45","R90","E","DENSITY","PR",};
      unsigned int field_types[] = {DATA_INT, DATA_CHAR_ARRAY, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {DEFINE, };
      unsigned int kw_types[] = {CURVE, };
      unsigned int num_indices = 1;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3 details for *CONTROL_FORMING_TEMPLATE
  * keyword from file */
   void readCard3()
   {
      const char *fields[] = {"K","N","MTYP","UNIT","THICK","GAP","FS",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card4 details for *CONTROL_FORMING_TEMPLATE
  * keyword from file */
   void readCard4()
   {
      const char *fields[] = {"PATERN","VMAX","VX","VY","VZ","VID","AMAX",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, };
      unsigned int field_indices[] = {5, };
      unsigned int man_types[] = {DEFINE, };
      unsigned int kw_types[] = {VECTOR, };
      unsigned int num_indices = 1;
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card4");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card5 details for *CONTROL_FORMING_TEMPLATE
  * keyword from file */
   void readCard5()
   {
      const char *fields[] = {"LVLADA","SIZEADA","TIMSADA","D3PLT",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, DATA_INT, DATA_INT, };
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card5");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *CONTROL_FORMING_TEMPLATE
  * from LSDYNA native file */
   unsigned int importControlFormingTemplate()
   {
      readCard1();
      readCard2();
      readCard3();
      readCard4();
      readCard5();
      return 0;
   }
};

#endif

