#ifndef _ControlFormingTravel_h_
#define _ControlFormingTravel_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *CONTROL_FORMING_TRAVEL keyword
  * from LSDYNA native file */

class ControlFormingTravel : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ControlFormingTravel(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ControlFormingTravel()
   {
   }

public:
/** Function to import Card1 details for *CONTROL_FORMING_TRAVEL
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"PID","VID","TRAVEL","TARGET","GAP","PHASE","FOLLOW",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 3, 6, };
      unsigned int man_types[] = {PARTC, DEFINE, PARTC, PARTC, };
      unsigned int kw_types[] = {9999, VECTOR, 9999, 9999, };
      unsigned int num_indices = 4;
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *CONTROL_FORMING_TRAVEL
  * from LSDYNA native file */
   unsigned int importControlFormingTravel()
   {
      readCard1();
      return 0;
   }
};

#endif

