#ifndef _ControlImplicitStabilization_h_
#define _ControlImplicitStabilization_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *CONTROL_IMPLICIT_STABILIZATION keyword
  * from LSDYNA native file */

class ControlImplicitStabilization : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ControlImplicitStabilization(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ControlImplicitStabilization()
   {
   }

public:
/** Function to import Card details for *CONTROL_IMPLICIT_STABILIZATION
  * keyword from file */
   void readCard()
   {
      const char *fields[] = {"IAS","SCALE","TSTART","TEND",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         controlGeneralFind(wordArray, numFields, 1, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *CONTROL_IMPLICIT_STABILIZATION
  * from LSDYNA native file */
   unsigned int importControlImplicitStabilization()
   {
      readCard();
      return 0;
   }
};

#endif

