#ifndef _ControlMppDecompositionTransformation_h_
#define _ControlMppDecompositionTransformation_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *CONTROL_MPP_DECOMPOSITION_TRANSFORMATION keyword
  * from LSDYNA native file */

class ControlMppDecompositionTransformation : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ControlMppDecompositionTransformation(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ControlMppDecompositionTransformation()
   {
   }

public:
/** Function to import Card details for *CONTROL_MPP_DECOMPOSITION_TRANSFORMATION
  * keyword from file */
   void readCard()
   {
      const char *fields[] = {"TYPE","VAL",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_DOUBLE, };
      numFields = 2;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card1 details for *CONTROL_MPP_DECOMPOSITION_TRANSFORMATION
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"TRAN_TYPE","V1","V2","V3","V4","V5","V6",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *CONTROL_MPP_DECOMPOSITION_TRANSFORMATION
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"V7","V8","V9",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 3;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *CONTROL_MPP_DECOMPOSITION_TRANSFORMATION
  * from LSDYNA native file */
   unsigned int importControlMppDecompositionTransformation()
   {
      readCard();
      readCard1();
      readCard2();
      return 0;
   }
};

#endif

