#ifndef _ControlBulkViscosity_h_
#define _ControlBulkViscosity_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *CONTROL_BULK_VISCOSITY keyword
  * from LSDYNA native file */

class ControlBulkViscosity : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ControlBulkViscosity(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ControlBulkViscosity()
   {
   }

public:
/** Function to import Card details for *CONTROL_BULK_VISCOSITY
  * keyword from file */
   void readCard()
   {
      const char *fields[] = {"Q1","Q2","TYPE",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_INT, };
      numFields = 3;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *CONTROL_BULK_VISCOSITY
  * from LSDYNA native file */
   unsigned int importControlBulkViscosity()
   {
      readCard();
      return 0;
   }
};

#endif

