#ifndef _ControlContact_h_
#define _ControlContact_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *CONTROL_CONTACT keyword
  * from LSDYNA native file */

class ControlContact : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ControlContact(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ControlContact()
   {
   }

public:
/** Function to import Card1 details for *CONTROL_CONTACT
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"SLSFAC","RWPNAL","ISLCHK","SHLTHK","PENOPT","THKCHG","ORIEN","ENMASS",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *CONTROL_CONTACT
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"USRSTR","USRFRC","NSBCS","INTERM","XPENE","SSTHK","ECDT","TIEDPRJ",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3 details for *CONTROL_CONTACT
  * keyword from file */
   void readCard3()
   {
      const char *fields[] = {"SFRIC","DFRIC","EDC","VFC","TH","TH_SF","PEN_SF",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card4 details for *CONTROL_CONTACT
  * keyword from file */
   void readCard4()
   {
      const char *fields[] = {"IGNORE","FRCENG","SKIPRWG","OUTSEG","SPOTSTP","SPOTDEL","SPOTHIN",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, };
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card4");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card5 details for *CONTROL_CONTACT
  * keyword from file */
   void readCard5()
   {
      const char *fields[] = {"ISYM","NSEROD","RWGAPS","RWGDTH","RWKSF","ICOV","SWRADF","ITHOFF",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_INT, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card5");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card6 details for *CONTROL_CONTACT
  * keyword from file */
   void readCard6()
   {
      const char *fields[] = {"SHLEDG",};
      unsigned int field_types[] = {DATA_INT, };
      numFields = 1;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card6");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *CONTROL_CONTACT
  * from LSDYNA native file */
   unsigned int importControlContact()
   {
      readCard1();
      readCard2();
      readCard3();
      readCard4();
      readCard5();
      readCard6();
      return 0;
   }
};

#endif

