#ifndef _ControlCoupling_h_
#define _ControlCoupling_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *CONTROL_COUPLING keyword
  * from LSDYNA native file */

class ControlCoupling : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ControlCoupling(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ControlCoupling()
   {
   }

public:
/** Function to import Card1 details for *CONTROL_COUPLING
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"UNLENG","UNTIME","UNFORC","TIMIDL","FLIPX","FLIPY","FLIPZ","SUBCYL",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *CONTROL_COUPLING
  * from LSDYNA native file */
   unsigned int importControlCoupling()
   {
      readCard1();
      return 0;
   }
};

#endif

