#ifndef _ControlImplicitEigenvalue_h_
#define _ControlImplicitEigenvalue_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *CONTROL_IMPLICIT_EIGENVALUE keyword
  * from LSDYNA native file */

class ControlImplicitEigenvalue : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ControlImplicitEigenvalue(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ControlImplicitEigenvalue()
   {
   }

public:
/** Function to import Card1 details for *CONTROL_IMPLICIT_EIGENVALUE
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"NEIG","CENTER","LFLAG","LFTEND","RFLAG","RHTEND","EIGMTH","SHFSCL",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         controlGeneralFind(wordArray, numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *CONTROL_IMPLICIT_EIGENVALUE
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"ISOLID","IBEAM","ISHELL","ITSHELL",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *CONTROL_IMPLICIT_EIGENVALUE
  * from LSDYNA native file */
   unsigned int importControlImplicitEigenvalue()
   {
      readCard1();
      readCard2();
      return 0;
   }
};

#endif

