#ifndef _ControlThermalSolver_h_
#define _ControlThermalSolver_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *CONTROL_THERMAL_SOLVER keyword
  * from LSDYNA native file */

class ControlThermalSolver : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ControlThermalSolver(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ControlThermalSolver()
   {
   }

public:
/** Function to import Card1 details for *CONTROL_THERMAL_SOLVER
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"ATYPE","PTYPE","SOLVER","CGTOL","GPT","EQHEAT","FWORK","SBC",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *CONTROL_THERMAL_SOLVER
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"MSGLVL","MAXITR","ABSTOL","RELTOL","OMEGA",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 5;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *CONTROL_THERMAL_SOLVER
  * from LSDYNA native file */
   unsigned int importControlThermalSolver()
   {
      readCard1();
      readCard2();
      return 0;
   }
};

#endif

