#ifndef _DampingPartMass_h_
#define _DampingPartMass_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *DAMPING_PART_MASS keyword
  * from LSDYNA native file */

class DampingPartMass : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   DampingPartMass(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~DampingPartMass()
   {
   }

public:
/** Function to import Card1 details for *DAMPING_PART_MASS
  * keyword from file */
   int readCard1()
   {
      const char *fields[] = {"PID","LCID","SF","FLAG",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, DATA_INT, };
      unsigned int field_indices[] = {0, 1, };
      unsigned int man_types[] = {PARTC, DEFINE, };
      unsigned int kw_types[] = {9999, CURVE, };
      unsigned int num_indices = 2;
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return 0;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
      if( wordArray[3] )
         return atoi(wordArray[3]);
      else
         return 0;
   }

/** Function to import Card2 details for *DAMPING_PART_MASS
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"STX","STY","STZ","SRX","SRY","SRZ",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *DAMPING_PART_MASS
  * from LSDYNA native file */
   unsigned int importDampingPartMass()
   {
      int flag = 0;
      flag = readCard1();
      if( flag == 1 )
      {
         readCard2();
      }
      return 0;
   }
};

#endif

