#include <iostream>
#include <algorithm>
#include "generic.h"
#include "dampingtype.h"
#include "dampingimport.h"
#include <stdlib.h>

using namespace std;

DampingImport::DampingImport
(
   FILE          *fp,
   DataLoc       *data_loc,
   DampingManager    *damping_man
)
{
   filePtr = fp;
   dampingManPtr = damping_man;
   dataLocPtr = data_loc;
   dataLine = NULL;

   initDampingTypesAndFunctions();
}

DampingType DampingImport::getDampingTypeFromKeyword
	(
	   const char  *key_word,
	   unsigned int *damping_id
	)
{
   *damping_id = 0;

   if( strstr(key_word, "_RANG") )
      return DAMPING_FREQUENCY_RANGE;
   else if( strstr(key_word, "_GLOB") )
      return DAMPING_GLOBAL;
   else if( strstr(key_word, "_MASS") )
      return DAMPING_PART_MASS;
   else if( strstr(key_word, "_STIF") )
      return DAMPING_PART_STIFFNESS;
   else if( strstr(key_word, "_REL") )
      return DAMPING_RELATIVE;

   return DAMPING_NEW_TYPE;
}

unsigned int DampingImport::readDampings()
{
   char         new_kw[LINE_LEN];
   unsigned int	i = 0, damping_id = 0, damping_type = 0, num_dampings = 0;
   long		loc = 0L;
   VStringIterator   s = dataLocPtr->keywordList.begin(),
		     e = dataLocPtr->keywordList.end(), itr, 
		     pitr = dataLocPtr->keywordList.begin();
   typeFuncIterator  btype_iter = typeFuncMap.begin(),
                     etype_iter = typeFuncMap.end(), type_iter;

   dataLine = new DataLine(filePtr);

   while(true)
   {
      itr = find_if(pitr, e, bind2nd(KeyWordCompare (), "*DAMP"));

      if( itr == e )
	 break;

      pitr = itr+1;
      i = (unsigned int)(itr - s);
      loc = dataLocPtr->slocList[i];

      rewind(filePtr);

      if( fseek(filePtr, loc, SEEK_SET) )
      {
	 cout << "ERROR in locating the Damping cards" << endl;
	 break;
      }

      dataLine->clearFlag(KW_READ_END);

      char *str = dataLine->readNextCard(); //get the keyword
      Generic::RemoveLeadingAndTrailingBlanks( str );
cout << "KW = " << str << endl;

      damping_type = getDampingTypeFromKeyword( str, &damping_id );
cout << "Damping TYPE = " << damping_type << endl;

      if( damping_type == DAMPING_NEW_TYPE )
      {
         cout << "Damping TYPE NOT SUPPORTED" << endl;
         continue;
      }

      strcpy(new_kw, str);

      dataLine->clearFlag(KW_READ_END);
      type_iter = typeFuncMap.find(damping_type);
      if( type_iter != etype_iter )
      {
         impObj = new ImportObject(str, damping_type);
	 (type_iter->second)(dataLine, impObj);
         Card::clearFlag();
         while( !dataLine->isFlagOn(KW_READ_END) )
         {
	    (type_iter->second)(dataLine, impObj);
         }
         num_dampings++;
         sprintf(new_kw, "%s_%d", new_kw, num_dampings);
         dampingManPtr->add(new_kw, impObj);
      }
      else
         cout << "Damping TYPE NOT FOUND" << endl;
   }

   return num_dampings;
}

