#ifndef _Damping_IMPORT_H_
#define _Damping_IMPORT_H_

#include <string>
#include <map>
#include "dataloc.h"
#include "dampingmanager.h"
#include "dataline.h"
#include "card.h"
#include "dampingtype.h"
#include "typemap.h"

/** Class to import the data from native LSDYNA file for *DAMPING keywords. All
  * the data is imported through this class and stored in the manager object.
  */
class DampingImport
{
public:
   /** Constructor for creating this object
     * \param fp File pointer to the LSDYNA native file
     * \param data_loc Pointer to the list of keywords and their locations in
     * the file
     * \param damping_man Manager pointer to hold the imported data as a list of
     * ImportObject list
     */
   DampingImport
   (
      FILE          *fp,
      DataLoc       *data_loc,
      DampingManager    *damping_man
   );

   ~DampingImport()
   {
      filePtr = NULL;
      dampingManPtr = NULL;
      dataLocPtr = NULL;
      delete dataLine;
   }

   /** Function for getting the keyword type from given keyword name from LSDYNA
     * native file. The type is stored in the database
     * \param key_word Name of the keyword from file
     * \param damping_id If ID of the object is there with the keyword, it
     * returns the ID
     * \return Type of keyword for *DAMPING group of keywords
     */
   static DampingType getDampingTypeFromKeyword
	   (
	      const char  *key_word,
	      unsigned int *damping_id
	   );

   /** Reads the *DAMPING keywords from file
     * \return Returns 0 on failure else number of dampings imported
     */
   unsigned int readDampings();

   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords.
     * For each type of *DAMPING keyword there is a function to call
     */
   void initDampingTypesAndFunctions();

private:
   FILE          *filePtr;
   /** Manager pointer for holding the imported data for all the keywords */
   DampingManager    *dampingManPtr;
   /** Pointer to keywords and their locations in the file */
   DataLoc       *dataLocPtr;
   /** Pointer to access the file data line by line */
   DataLine      *dataLine;
   /** Object to store imported data from LSDYNA data file */
   ImportObject  *impObj;
   /** A map between the keyword type and pointer to function */
   map<unsigned int, ImportFunctionPtr>  typeFuncMap;
};

#endif

