#ifndef _DatabaseBinary_h_
#define _DatabaseBinary_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *DATABASE_BINARY_D3DRLF keyword
  * from LSDYNA native file */

class DatabaseBinary : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   DatabaseBinary(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~DatabaseBinary()
   {
   }

public:
/** Function to import BinCard details for *DATABASE_BINARY_D3DRLF
  * keyword from file */
   void readBinCard()
   {
      const char *fields[] = {"DT/CYCL","LCDT/NR","BEAM","NPLTC","PSETID",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {4, };
      unsigned int man_types[] = {SET, };
      unsigned int kw_types[] = {PARTC, };
      unsigned int num_indices = 1;
      numFields = 5;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("BinCard");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *DATABASE_BINARY_D3DRLF
  * from LSDYNA native file */
   unsigned int importDatabaseBinary()
   {
      readBinCard();
      return 0;
   }
};

#endif

