#ifndef _DatabaseCrossSectionPlane_h_
#define _DatabaseCrossSectionPlane_h_

#include "manager.h"
#include "dispexport.h"
#include "databasecsid.h"

/** This class is used for importing *DATABASE_CROSS_SECTION_PLANE keyword
  * from LSDYNA native file */

class DatabaseCrossSectionPlane : public DatabaseCSId
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   DatabaseCrossSectionPlane(DataLine *data_line, ImportObject *imp_obj) : DatabaseCSId (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~DatabaseCrossSectionPlane()
   {
   }

public:
/** Function to import Card1 details for *DATABASE_CROSS_SECTION_PLANE
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"PSID","XCT","YCT","ZCT","XCH","YCH","ZCH","RADIUS",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {SET, };
      unsigned int kw_types[] = {PARTC, };
      unsigned int num_indices = 1;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *DATABASE_CROSS_SECTION_PLANE
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"XHEV","YHEV","ZHEV","LENL","LENM","ID","ITYPE",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, };
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         databaseCSFind(wordArray, numFields, 5, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *DATABASE_CROSS_SECTION_PLANE
  * from LSDYNA native file */
   unsigned int importDatabaseCrossSectionPlane()
   {
      importDatabaseCSId();
      readCard1();
      readCard2();
      return 0;
   }
};

#endif

