#ifndef _DatabaseCrossSectionSet_h_
#define _DatabaseCrossSectionSet_h_

#include "manager.h"
#include "dispexport.h"
#include "databasecsid.h"

/** This class is used for importing *DATABASE_CROSS_SECTION_SET keyword
  * from LSDYNA native file */

class DatabaseCrossSectionSet : public DatabaseCSId
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   DatabaseCrossSectionSet(DataLine *data_line, ImportObject *imp_obj) : DatabaseCSId (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~DatabaseCrossSectionSet()
   {
   }

public:
/** Function to import Card details for *DATABASE_CROSS_SECTION_SET
  * keyword from file */
   void readCard()
   {
      const char *fields[] = {"NSID","HSID","BSID","SSID","TSID","DSID","ID","ITYPE",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         databaseCSSetFind(wordArray, numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *DATABASE_CROSS_SECTION_SET
  * from LSDYNA native file */
   unsigned int importDatabaseCrossSectionSet()
   {
      importDatabaseCSId();
      readCard();
      return 0;
   }
};

#endif

