#ifndef _DatabaseCSId_h_
#define _DatabaseCSId_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *DATABASE_CROSS_SECTION_ID keyword
  * from LSDYNA native file */

class DatabaseCSId : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   DatabaseCSId(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~DatabaseCSId()
   {
   }

public:
/** Function to import Card details for *DATABASE_CROSS_SECTION_ID
  * keyword from file */
   void readCard()
   {
      const char *fields[] = {"CSID","HEADING",};
      unsigned int field_types[] = {DATA_INT, DATA_CHAR_ARRAY, };
      numFields = 2;
      unsigned int field_widths[] = {10, 70, };
      strBuff = dataLine->readNextCard(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;

      wordArray = dataLine->splitIntoWords(numFields, field_widths);
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, DATABASE, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card");
         cardObj->addFields(numFields, field_types, field_widths, fields, strBuff);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *DATABASE_CROSS_SECTION_ID
  * from LSDYNA native file */
   unsigned int importDatabaseCSId()
   {
      if( strstr(impObj->getKeyword().data(), "_ID") )
      {
         readCard();
      }
      return 0;
   }
};

#endif

