#include <iostream>
#include <algorithm>
#include "generic.h"
#include "databasetype.h"
#include "databaseimport.h"
#include <stdlib.h>

using namespace std;

DatabaseImport::DatabaseImport
(
   FILE          *fp,
   DataLoc       *data_loc,
   DatabaseManager    *database_man
)
{
   filePtr = fp;
   databaseManPtr = database_man;
   dataLocPtr = data_loc;
   dataLine = NULL;

   initBinaryTypesAndFunctions();
   initCrossSectionTypesAndFunctions();
   initExtentTypesAndFunctions();
   initHistryTypesAndFunctions();
   initOptionTypesAndFunctions();
   initSimpleTypesAndFunctions();
}

DatabaseType DatabaseImport::getDatabaseTypeFromKeyword
	(
	   const char  *key_word,
	   unsigned int *database_id
	)
{
   *database_id = 0;

   if( strstr(key_word, "DRLF") )
      return DATABASE_BINARY_D3DRLF;
   else if( strstr(key_word, "CRAC") )
      return DATABASE_BINARY_D3CRACK;
   else if( strstr(key_word, "DUMP") )
      return DATABASE_BINARY_D3DUMP;
   else if( strstr(key_word, "PART") )
      return DATABASE_BINARY_D3PART;
   else if( strstr(key_word, "PLOT") )
      return DATABASE_BINARY_D3PLOT;
   else if( strstr(key_word, "3PROP") )
      return DATABASE_BINARY_D3PROP;
   else if( strstr(key_word, "THDT") )
      return DATABASE_BINARY_D3THDT;
   else if( strstr(key_word, "SIFOR") )
      return DATABASE_BINARY_FSIFOR;
   else if( strstr(key_word, "Y_INTF") )
      return DATABASE_BINARY_INTFOR;
   else if( strstr(key_word, "NRSF") )
      return DATABASE_BINARY_RUNRSF;
   else if( strstr(key_word, "TFILE") )
      return DATABASE_BINARY_XTFILE;
   else if( strstr(key_word, "E_GRO") )
      return DATABASE_NODAL_FORCE_GROUP;
   else if( strstr(key_word, "T_AVS") )
      return DATABASE_EXTENT_AVS;
   else if( strstr(key_word, "NT_BI") )
      return DATABASE_EXTENT_BINARY;
   else if( strstr(key_word, "NT_MO") )
      return DATABASE_EXTENT_MOVIE;
   else if( strstr(key_word, "NT_MP") )
      return DATABASE_EXTENT_MPGS;
   else if( strstr(key_word, "NT_SS") )
      return DATABASE_EXTENT_SSSTAT;
   else if( strstr(key_word, "AVSFL") )
      return DATABASE_AVSFLT;
   else if( strstr(key_word, "BNDO") )
      return DATABASE_BNDOUT;
   else if( strstr(key_word, "DCFA") )
      return DATABASE_DCFAIL;
   else if( strstr(key_word, "DEFG") )
      return DATABASE_DEFGEO;
   else if( strstr(key_word, "DEFO") )
      return DATABASE_DEFORC;
   else if( strstr(key_word, "ELOU") )
      return DATABASE_ELOUT;
   else if( strstr(key_word, "I_SEN") )
      return DATABASE_FSI_SENSOR;
   else if( strstr(key_word, "E_FSI") )
      return DATABASE_FSI;
   else if( strstr(key_word, "GCEO") )
      return DATABASE_GCEOUT;
   else if( strstr(key_word, "LSTAT_M") )
      return DATABASE_GLSTAT_MASS_PROPERTIES;
   else if( strstr(key_word, "GLST") )
      return DATABASE_GLSTAT;
   else if( strstr(key_word, "H3OU") )
      return DATABASE_H3OUT;
   else if( strstr(key_word, "JNTFO") )
      return DATABASE_JNTFORC;
   else if( strstr(key_word, "MATSU") )
      return DATABASE_MATSUM;
   else if( strstr(key_word, "E_MOV") )
      return DATABASE_MOVIE;
   else if( strstr(key_word, "E_MPG") )
      return DATABASE_MPGS;
   else if( strstr(key_word, "E_NCF") )
      return DATABASE_NCFORC;
   else if( strstr(key_word, "E_NODF") )
      return DATABASE_NODFOR;
   else if( strstr(key_word, "E_NODO") )
      return DATABASE_NODOUT;
   else if( strstr(key_word, "E_ABS") )
      return DATABASE_ABSTAT;
   else if( strstr(key_word, "E_RBD") )
      return DATABASE_RBDOUT;
   else if( strstr(key_word, "RCFO") )
      return DATABASE_RCFORC;
   else if( strstr(key_word, "RWFO") )
      return DATABASE_RWFORC;
   else if( strstr(key_word, "SBTO") )
      return DATABASE_SBTOUT;
   else if( strstr(key_word, "SECF") )
      return DATABASE_SECFORC;
   else if( strstr(key_word, "SLEO") )
      return DATABASE_SLEOUT;
   else if( strstr(key_word, "SPCF") )
      return DATABASE_SPCFORC;
   else if( strstr(key_word, "SPHO") )
      return DATABASE_SPHOUT;
   else if( strstr(key_word, "SSTAT_M") )
      return DATABASE_SSSTAT_MASS_PROPERTIES;
   else if( strstr(key_word, "E_SSS") )
      return DATABASE_SSSTAT;
   else if( strstr(key_word, "SWFO") )
      return DATABASE_SWFORC;
   else if( strstr(key_word, "TPRIN") )
      return DATABASE_TPRINT;
   else if( strstr(key_word, "TRHI") )
      return DATABASE_TRHIST;
   else if( strstr(key_word, "NE_ID") )
      return DATABASE_CROSS_SECTION_PLANE_ID;
   else if( strstr(key_word, "ON_PL") )
      return DATABASE_CROSS_SECTION_PLANE;
   else if( strstr(key_word, "ET_ID") )
      return DATABASE_CROSS_SECTION_SET_ID;
   else if( strstr(key_word, "N_SET") )
      return DATABASE_CROSS_SECTION_SET;
   else if( strstr(key_word, "E_TRA") )
      return DATABASE_TRACER;
   else if( strstr(key_word, "AM_ID") )
      return DATABASE_HISTORY_BEAM_ID;
   else if( strstr(key_word, "AM_SE") )
      return DATABASE_HISTORY_BEAM_SET;
   else if( strstr(key_word, "RY_BE") )
      return DATABASE_HISTORY_BEAM;
   else if( strstr(key_word, "TE_ID") )
      return DATABASE_HISTORY_DISCRETE_ID;
   else if( strstr(key_word, "TE_SE") )
      return DATABASE_HISTORY_DISCRETE_SET;
   else if( strstr(key_word, "RY_DI") )
      return DATABASE_HISTORY_DISCRETE;
   else if( strstr(key_word, "DE_ID") )
      return DATABASE_HISTORY_NODE_ID;
   else if( strstr(key_word, "AL_ID") )
      return DATABASE_HISTORY_NODE_LOCAL_ID;
   else if( strstr(key_word, "DE_LO") )
      return DATABASE_HISTORY_NODE_LOCAL;
   else if( strstr(key_word, "ET_LO") )
      return DATABASE_HISTORY_NODE_SET_LOCAL;
   else if( strstr(key_word, "DE_SE") )
      return DATABASE_HISTORY_NODE_SET;
   else if( strstr(key_word, "RY_NO") )
      return DATABASE_HISTORY_NODE;
   else if( strstr(key_word, "LT_ID") )
      return DATABASE_HISTORY_SEATBELT_ID;
   else if( strstr(key_word, "RY_SE") )
      return DATABASE_HISTORY_SEATBELT;
   else if( strstr(key_word, "Y_SHELL_I") )
      return DATABASE_HISTORY_SHELL_ID;
   else if( strstr(key_word, "Y_SHELL_S") )
      return DATABASE_HISTORY_SHELL_SET;
   else if( strstr(key_word, "RY_SH") )
      return DATABASE_HISTORY_SHELL;
   else if( strstr(key_word, "ID_ID") )
      return DATABASE_HISTORY_SOLID_ID;
   else if( strstr(key_word, "ID_SE") )
      return DATABASE_HISTORY_SOLID_SET;
   else if( strstr(key_word, "Y_SOL") )
      return DATABASE_HISTORY_SOLID;
   else if( strstr(key_word, "PH_SE") )
      return DATABASE_HISTORY_SPH_SET;
   else if( strstr(key_word, "Y_SPH") )
      return DATABASE_HISTORY_SPH;
   else if( strstr(key_word, "Y_TSHELL_I") )
      return DATABASE_HISTORY_TSHELL_ID;
   else if( strstr(key_word, "Y_TSHELL_S") )
      return DATABASE_HISTORY_TSHELL_SET;
   else if( strstr(key_word, "Y_TSH") )
      return DATABASE_HISTORY_TSHELL;
   else if( strstr(key_word, "ADAM") )
      return DATABASE_ADAMS;
   else if( strstr(key_word, "E_FOR") )
      return DATABASE_FORMAT;
   else if( strstr(key_word, "NG_FO") )
      return DATABASE_SPRING_FORWARD;
   else if( strstr(key_word, "IC_FO") )
      return DATABASE_SUPERPLASTIC_FORMING;

   return DATABASE_NEW_TYPE;
}

unsigned int DatabaseImport::readDatabases()
{
   char         new_kw[LINE_LEN];
   unsigned int	i = 0, database_id = 0, database_type = 0, num_databases = 0;
   long		loc = 0L;
   VStringIterator   s = dataLocPtr->keywordList.begin(),
		     e = dataLocPtr->keywordList.end(), itr, 
		     pitr = dataLocPtr->keywordList.begin();
   typeFuncIterator  btype_iter = typeFuncMap.begin(),
                     etype_iter = typeFuncMap.end(), type_iter;

   dataLine = new DataLine(filePtr);

   while(true)
   {
      itr = find_if(pitr, e, bind2nd(KeyWordCompare (), "*DATAB"));

      if( itr == e )
	 break;

      pitr = itr+1;
      i = (unsigned int)(itr - s);
      loc = dataLocPtr->slocList[i];

      rewind(filePtr);

      if( fseek(filePtr, loc, SEEK_SET) )
      {
	 cout << "ERROR in locating the Database cards" << endl;
	 break;
      }

      dataLine->clearFlag(KW_READ_END);

      char *str = dataLine->readNextCard(); //get the keyword
      Generic::RemoveLeadingAndTrailingBlanks( str );
cout << "KW = " << str << endl;

      database_type = getDatabaseTypeFromKeyword( str, &database_id );
cout << "Database TYPE = " << database_type << endl;

      if( database_type == DATABASE_NEW_TYPE )
      {
         cout << "Database TYPE NOT SUPPORTED" << endl;
         continue;
      }

      num_databases++;

      strcpy(new_kw, str);

      dataLine->clearFlag(KW_READ_END);
      type_iter = typeFuncMap.find(database_type);
      if( type_iter != etype_iter )
      {
          impObj = new ImportObject(str, database_type);
          (type_iter->second)(dataLine, impObj);
          if( database_id )
          {
             databaseManPtr->add(new_kw, impObj);
          }
          else
          {
             sprintf(new_kw, "%s_%d", new_kw, num_databases);
             databaseManPtr->add(new_kw, impObj);
          }
      }
      else
         cout << "Database TYPE NOT FOUND" << endl;
   }

   return num_databases;
}

