#ifndef _Database_IMPORT_H_
#define _Database_IMPORT_H_

#include <string>
#include <map>
#include "dataloc.h"
#include "databasemanager.h"
#include "dataline.h"
#include "card.h"
#include "databasetype.h"
#include "typemap.h"

/** Class to import the data from native LSDYNA file for *DATABASE keywords. All
  * the data is imported through this class and stored in the manager object.
  */
class DatabaseImport
{
public:
   /** Constructor for creating this object
     * \param fp File pointer to the LSDYNA native file
     * \param data_loc Pointer to the list of keywords and their locations in
     * the file
     * \param database_man Manager pointer to hold the imported data as a list of
     * ImportObject list
     */
   DatabaseImport
   (
      FILE          *fp,
      DataLoc       *data_loc,
      DatabaseManager    *database_man
   );

   ~DatabaseImport()
   {
      filePtr = NULL;
      databaseManPtr = NULL;
      dataLocPtr = NULL;
      delete dataLine;
   }

   /** Function for getting the keyword type from given keyword name from LSDYNA
     * native file. The type is stored in the database
     * \param key_word Name of the keyword from file
     * \param database_id ID if exists along with the keyword
     * \return Type for *DATABASE group of keywords
     */
   static DatabaseType getDatabaseTypeFromKeyword
	   (
	      const char  *key_word,
	      unsigned int *database_id
	   );

   /** Reads the *DATABASE keywords from file
     * \return Returns 0 on failure else number of *DATABASE keywords
     */
   unsigned int readDatabases();

   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *DATABASE keyword there is a function to call
     */
   void initBinaryTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *DATABASE keyword there is a function to call
     */
   void initCrossSectionTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *DATABASE keyword there is a function to call
     */
   void initExtentTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *DATABASE keyword there is a function to call
     */
   void initHistryTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *DATABASE keyword there is a function to call
     */
   void initOptionTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *DATABASE keyword there is a function to call
     */
   void initSimpleTypesAndFunctions();

private:
   FILE          *filePtr;
   /** Manager pointer for holding the imported data for all the keywords */
   DatabaseManager    *databaseManPtr;
   /** Pointer to keywords and their locations in the file */
   DataLoc       *dataLocPtr;
   /** Pointer to access the file data line by line */
   DataLine      *dataLine;
   /** Object to store imported data from LSDYNA data file */
   ImportObject  *impObj;
   /** A map between the keyword type and pointer to function */
   map<unsigned int, ImportFunctionPtr>  typeFuncMap;
};

#endif

