#ifndef _DatabaseExtentBinary_h_
#define _DatabaseExtentBinary_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *DATABASE_EXTENT_BINARY keyword
  * from LSDYNA native file */

class DatabaseExtentBinary : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   DatabaseExtentBinary(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~DatabaseExtentBinary()
   {
   }

public:
/** Function to import Card1 details for *DATABASE_EXTENT_BINARY
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"NEIPH","NEIPS","MAXINT","STRFLG","SIGFLG","EPSFLG","RLTFLG","ENGFLG",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *DATABASE_EXTENT_BINARY
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"CMPFLG","IEVERP","BEAMIP","DCOMP","SHGE","STSSZ","N3THDT","IALEMAT",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3 details for *DATABASE_EXTENT_BINARY
  * keyword from file */
   void readCard3()
   {
      const char *fields[] = {"NINTSLD","PKP_SEN","SCLP","UNUSED","MSSCL","THERM",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, DATA_UNUSED, DATA_INT, DATA_INT, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *DATABASE_EXTENT_BINARY
  * from LSDYNA native file */
   unsigned int importDatabaseExtentBinary()
   {
      readCard1();
      readCard2();
      readCard3();
      return 0;
   }
};

#endif

