#ifndef _DatabaseExtentSsstat_h_
#define _DatabaseExtentSsstat_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *DATABASE_EXTENT_SSSTAT keyword
  * from LSDYNA native file */

class DatabaseExtentSsstat : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   DatabaseExtentSsstat(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~DatabaseExtentSsstat()
   {
   }

public:
/** Function to import Card details for *DATABASE_EXTENT_SSSTAT
  * keyword from file */
   void readCard()
   {
      const char *fields[] = {"PSID1","PSID2","PSID3","PSID4","PSID5","PSID6","PSID7","PSID8",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, 3, 4, 5, 6, 7, };
      unsigned int man_types[] = {SET, SET, SET, SET, SET, SET, SET, SET, };
      unsigned int kw_types[] = {PARTC, PARTC, PARTC, PARTC, PARTC, PARTC, PARTC, PARTC, };
      unsigned int num_indices = 8;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *DATABASE_EXTENT_SSSTAT
  * from LSDYNA native file */
   unsigned int importDatabaseExtentSsstat()
   {
      readCard();
      while(numFields)
      {
         readCard();
      }
      return 0;
   }
};

#endif

