#ifndef _DatabaseHistoryNodeLocalId_h_
#define _DatabaseHistoryNodeLocalId_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *DATABASE_HISTORY_NODE_LOCAL_ID keyword
  * from LSDYNA native file */

class DatabaseHistoryNodeLocalId : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   DatabaseHistoryNodeLocalId(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~DatabaseHistoryNodeLocalId()
   {
   }

public:
/** Function to import Card1 details for *DATABASE_HISTORY_NODE_LOCAL_ID
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"ID","CID","REF","HFO",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         databaseHistoryLocalFind(wordArray, numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *DATABASE_HISTORY_NODE_LOCAL_ID
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"HEADING",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, };
      numFields = 1;
      unsigned int field_widths[] = {70, };
      strBuff = dataLine->readNextCard(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, field_widths, fields, strBuff);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *DATABASE_HISTORY_NODE_LOCAL_ID
  * from LSDYNA native file */
   unsigned int importDatabaseHistoryNodeLocalId()
   {
      readCard1();
      readCard2();
      while(numFields)
      {
         readCard1();
         readCard2();
      }
      return 0;
   }
};

#endif

