#ifndef _DatabaseFsi_h_
#define _DatabaseFsi_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *DATABASE_FSI keyword
  * from LSDYNA native file */

class DatabaseFsi : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   DatabaseFsi(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~DatabaseFsi()
   {
   }

public:
/** Function to import Card1 details for *DATABASE_FSI
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"DT",};
      unsigned int field_types[] = {DATA_DOUBLE, };
      numFields = 1;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *DATABASE_FSI
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"DBFSI_ID","SID","SIDTYPE","SWID","CONVID",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 5;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, DATABASE, impObj);

      if( Card::isFlagOn(SAVE_REFERENCES) )
         databaseFsiFind(wordArray, numFields, 1, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *DATABASE_FSI
  * from LSDYNA native file */
   unsigned int importDatabaseFsi()
   {
      readCard1();
      readCard2();
      while(numFields)
      {
         readCard2();
      }
      return 0;
   }
};

#endif

