#ifndef _DatabaseFsiSensor_h_
#define _DatabaseFsiSensor_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *DATABASE_FSI_SENSOR keyword
  * from LSDYNA native file */

class DatabaseFsiSensor : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   DatabaseFsiSensor(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~DatabaseFsiSensor()
   {
   }

public:
/** Function to import Card1 details for *DATABASE_FSI_SENSOR
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"DT",};
      unsigned int field_types[] = {DATA_DOUBLE, };
      numFields = 1;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *DATABASE_FSI_SENSOR
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"DBFSI_ID","NID","SEGMID","OFFSET",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, 1, 2, };
      unsigned int man_types[] = {SENSOR, NOD, ELEMENT, };
      unsigned int kw_types[] = {9999, 9999, SHELL, };
      unsigned int num_indices = 3;
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *DATABASE_FSI_SENSOR
  * from LSDYNA native file */
   unsigned int importDatabaseFsiSensor()
   {
      readCard1();
      readCard2();
      while(numFields)
      {
         readCard2();
      }
      return 0;
   }
};

#endif

