#ifndef _DefineAlebagBag_h_
#define _DefineAlebagBag_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *DEFINE_ALEBAG_BAG keyword
  * from LSDYNA native file */

class DefineAlebagBag : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   DefineAlebagBag(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~DefineAlebagBag()
   {
   }

public:
/** Function to import Card1 details for *DEFINE_ALEBAG_BAG
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"BAGID","SID","SIDTYPE","CVBAG","IBLOCK","VTCOEF","VENTSID","VENTYP",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_INT, DATA_INT, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, DEFINE, impObj);

      if( Card::isFlagOn(SAVE_REFERENCES) )
         defineAleBagFind(wordArray, numFields, 1, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *DEFINE_ALEBAG_BAG
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"NQUAD","CTYPE","PFAC","FRIC","FRCMIN","NORMTYP","ILEAK","PLEAK",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3 details for *DEFINE_ALEBAG_BAG
  * keyword from file */
   void readCard3()
   {
      const char *fields[] = {"NORM","START","END",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 3;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *DEFINE_ALEBAG_BAG
  * from LSDYNA native file */
   unsigned int importDefineAlebagBag()
   {
      readCard1();
      readCard2();
      readCard3();
      return 0;
   }
};

#endif

