#ifndef _DefineDeathTimesOption_h_
#define _DefineDeathTimesOption_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *DEFINE_DEATH_TIMES_NODES keyword
  * from LSDYNA native file */

class DefineDeathTimesOption : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   DefineDeathTimesOption(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~DefineDeathTimesOption()
   {
   }

public:
/** Function to import Card1 details for *DEFINE_DEATH_TIMES_NODES
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"GEO","N1","N2","N3",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {1, 2, 3, };
      unsigned int man_types[] = {NOD, NOD, NOD, };
      unsigned int kw_types[] = {9999, 9999, 9999, };
      unsigned int num_indices = 3;
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *DEFINE_DEATH_TIMES_NODES
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"X_T","Y_T","Z_T","X_H","Y_H","Z_H","R","FLAG",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3 details for *DEFINE_DEATH_TIMES_NODES
  * keyword from file */
   void readCard3()
   {
      const char *fields[] = {"NSID1","NSID2","NSID3","NSID4","NSID5","NSID6","NSID7","NSID8",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         defineDTimesFind(wordArray, numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *DEFINE_DEATH_TIMES_NODES
  * from LSDYNA native file */
   unsigned int importDefineDeathTimesOption()
   {
      readCard1();
      readCard2();
      readCard3();
      while(numFields)
      {
         readCard3();
      }
      return 0;
   }
};

#endif

