#ifndef _DefineBoxCoarsen_h_
#define _DefineBoxCoarsen_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *DEFINE_BOX_COARSEN keyword
  * from LSDYNA native file */

class DefineBoxCoarsen : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   DefineBoxCoarsen(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~DefineBoxCoarsen()
   {
   }

public:
/** Function to import Card details for *DEFINE_BOX_COARSEN
  * keyword from file */
   void readCard()
   {
      const char *fields[] = {"BOXID","XMN","XMX","YMN","YMX","ZMN","ZMX","IFLAG",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, DEFINE, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *DEFINE_BOX_COARSEN
  * from LSDYNA native file */
   unsigned int importDefineBoxCoarsen()
   {
      readCard();
      return 0;
   }
};

#endif

