#ifndef _DefineCurveSmooth_h_
#define _DefineCurveSmooth_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *DEFINE_CURVE_SMOOTH keyword
  * from LSDYNA native file */

class DefineCurveSmooth : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   DefineCurveSmooth(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~DefineCurveSmooth()
   {
   }

public:
/** Function to import Card details for *DEFINE_CURVE_SMOOTH
  * keyword from file */
   void readCard()
   {
      const char *fields[] = {"LCID","SIDR","DIST","TSTART","TEND","TRISE","V0",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, DEFINE, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *DEFINE_CURVE_SMOOTH
  * from LSDYNA native file */
   unsigned int importDefineCurveSmooth()
   {
      readCard();
      return 0;
   }
};

#endif

