#ifndef _DefineCoordinateNodes_h_
#define _DefineCoordinateNodes_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *DEFINE_COORDINATE_NODES keyword
  * from LSDYNA native file */

class DefineCoordinateNodes : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   DefineCoordinateNodes(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~DefineCoordinateNodes()
   {
   }

public:
/** Function to import Card details for *DEFINE_COORDINATE_NODES
  * keyword from file */
   void readCard()
   {
      const char *fields[] = {"CID","N1","N2","N3","FLAG","DIR",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_CHAR_ARRAY, };
      unsigned int field_indices[] = {1, 2, 3, };
      unsigned int man_types[] = {NOD, NOD, NOD, };
      unsigned int kw_types[] = {9999, 9999, 9999, };
      unsigned int num_indices = 3;
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, DEFINE, impObj);

      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *DEFINE_COORDINATE_NODES
  * from LSDYNA native file */
   unsigned int importDefineCoordinateNodes()
   {
      readCard();
      return 0;
   }
};

#endif

