#ifndef _DefineCoordinateSystem_h_
#define _DefineCoordinateSystem_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *DEFINE_COORDINATE_SYSTEM keyword
  * from LSDYNA native file */

class DefineCoordinateSystem : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   DefineCoordinateSystem(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~DefineCoordinateSystem()
   {
   }

public:
/** Function to import Card1 details for *DEFINE_COORDINATE_SYSTEM
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"CID","XO","YO","ZO","XL","YL","ZL",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, DEFINE, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *DEFINE_COORDINATE_SYSTEM
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"XP","YP","ZP",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 3;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *DEFINE_COORDINATE_SYSTEM
  * from LSDYNA native file */
   unsigned int importDefineCoordinateSystem()
   {
      readCard1();
      readCard2();
      return 0;
   }
};

#endif

