#ifndef _DefineCurveFunction_h_
#define _DefineCurveFunction_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *DEFINE_CURVE_FUNCTION keyword
  * from LSDYNA native file */

class DefineCurveFunction : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   DefineCurveFunction(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~DefineCurveFunction()
   {
   }

public:
/** Function to import Card1 details for *DEFINE_CURVE_FUNCTION
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"LCID","SIDR","SFA","SFO","OFFA","OFFO","DATTYP",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, };
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, DEFINE, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *DEFINE_CURVE_FUNCTION
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"FUNCTION",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, };
      numFields = 1;
      unsigned int field_widths[] = {80, };
      strBuff = dataLine->readNextCard(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, field_widths, fields, strBuff);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *DEFINE_CURVE_FUNCTION
  * from LSDYNA native file */
   unsigned int importDefineCurveFunction()
   {
      readCard1();
      readCard2();
      while(numFields)
      {
         readCard2();
      }
      return 0;
   }
};

#endif

