#ifndef _DefineCurveFeedback_h_
#define _DefineCurveFeedback_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *DEFINE_CURVE_FEEDBACK keyword
  * from LSDYNA native file */

class DefineCurveFeedback : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   DefineCurveFeedback(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~DefineCurveFeedback()
   {
   }

public:
/** Function to import Card1 details for *DEFINE_CURVE_FEEDBACK
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"LCID","PID","BOXID","FLDID",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, 3, };
      unsigned int man_types[] = {DEFINE, PARTC, DEFINE, DEFINE, };
      unsigned int kw_types[] = {CURVE, 9999, BOX, CURVE, };
      unsigned int num_indices = 4;
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *DEFINE_CURVE_FEEDBACK
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"FSL","TSL","SFF","SFT","BIAS",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 5;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *DEFINE_CURVE_FEEDBACK
  * from LSDYNA native file */
   unsigned int importDefineCurveFeedback()
   {
      readCard1();
      readCard2();
      return 0;
   }
};

#endif

