#ifndef _DefineCurveTrim_h_
#define _DefineCurveTrim_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *DEFINE_CURVE_TRIM keyword
  * from LSDYNA native file */

class DefineCurveTrim : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   DefineCurveTrim(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~DefineCurveTrim()
   {
   }

public:
/** Function to import Card1 details for *DEFINE_CURVE_TRIM
  * keyword from file */
   int readCard1()
   {
      const char *fields[] = {"TCID","TCTYPE","TFLG","TDIR","TCTOL","TOLN/IGB","NSEED",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, };
      unsigned int field_indices[] = {3, };
      unsigned int man_types[] = {DEFINE, };
      unsigned int kw_types[] = {VECTOR, };
      unsigned int num_indices = 1;
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return 0;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, DEFINE, impObj);

      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
      if( wordArray[1] )
         return atoi(wordArray[1]);
      else
         return 0;
   }

/** Function to import Card2 details for *DEFINE_CURVE_TRIM
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"CX","CY",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 2;
      unsigned int field_widths[] = {20, 20, };
      strBuff = dataLine->readNextCard(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, field_widths, fields, strBuff);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3 details for *DEFINE_CURVE_TRIM
  * keyword from file */
   void readCard3()
   {
      const char *fields[] = {"FILENAME",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, };
      numFields = 1;
      unsigned int field_widths[] = {20, };
      strBuff = dataLine->readNextCard(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3");
         cardObj->addFields(numFields, field_types, field_widths, fields, strBuff);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *DEFINE_CURVE_TRIM
  * from LSDYNA native file */
   unsigned int importDefineCurveTrim()
   {
      int tctype = 0;
      tctype = readCard1();
      if( tctype == 1 )
      {
         readCard2();
      }
      else if( tctype == 2 )
      {
         readCard3();
      }
      return 0;
   }
};

#endif

