#include <iostream>
#include <algorithm>
#include "generic.h"
#include "definetype.h"
#include "defineimport.h"
#include "title.h"
#include <stdlib.h>

using namespace std;

DefineImport::DefineImport
(
   FILE          *fp,
   DataLoc       *data_loc,
   DefineManager    *define_man
)
{
   filePtr = fp;
   defineManPtr = define_man;
   dataLocPtr = data_loc;
   dataLine = NULL;

   initAleTypesAndFunctions();
   initBoxTypesAndFunctions();
   initCoordTypesAndFunctions();
   initCurveTypesAndFunctions();
   initSimpleTypesAndFunctions();
   initWeldTypesAndFunctions();
}

DefineType DefineImport::getDefineTypeFromKeyword
	(
	   const char  *key_word,
	   unsigned int *define_id
	)
{
   *define_id = 0;

   if( strstr(key_word, "X_AD") )
      return DEFINE_BOX_ADAPTIVE;
   else if( strstr(key_word, "X_CO") )
      return DEFINE_BOX_COARSEN;
   else if( strstr(key_word, "X_DR") )
      return DEFINE_BOX_DRAWBEAD;
   else if( strstr(key_word, "X_SPH") )
      return DEFINE_BOX_SPH;
   else if( strstr(key_word, "NE_BO") )
      return DEFINE_BOX;
   else if( strstr(key_word, "TE_NO") )
      return DEFINE_COORDINATE_NODES;
   else if( strstr(key_word, "TE_SY") )
      return DEFINE_COORDINATE_SYSTEM;
   else if( strstr(key_word, "TE_VE") )
      return DEFINE_COORDINATE_VECTOR;
   else if( strstr(key_word, "SD_OR") )
      return DEFINE_SD_ORIENTATION;
   else if( strstr(key_word, "E_TRA") )
      return DEFINE_TRANSFORMATION;
   else if( strstr(key_word, "E_38") )
      return DEFINE_CURVE_3858;
   else if( strstr(key_word, "E_54") )
      return DEFINE_CURVE_5434a;
   else if( strstr(key_word, "VE_CO") )
      return DEFINE_CURVE_COMPENSATION;
   else if( strstr(key_word, "VE_DR") )
      return DEFINE_CURVE_DRAWBEAD;
   else if( strstr(key_word, "VE_EN") )
      return DEFINE_CURVE_ENTITY;
   else if( strstr(key_word, "VE_FE") )
      return DEFINE_CURVE_FEEDBACK;
   else if( strstr(key_word, "VE_FU") )
      return DEFINE_CURVE_FUNCTION;
   else if( strstr(key_word, "VE_SM") )
      return DEFINE_CURVE_SMOOTH;
   else if( strstr(key_word, "IM_3D") )
      return DEFINE_CURVE_TRIM_3D;
   else if( strstr(key_word, "VE_TR") )
      return DEFINE_CURVE_TRIM;
   else if( strstr(key_word, "NE_CU") )
      return DEFINE_CURVE;
   else if( strstr(key_word, "AG_BA") )
      return DEFINE_ALEBAG_BAG;
   else if( strstr(key_word, "AG_HO") )
      return DEFINE_ALEBAG_HOLE;
   else if( strstr(key_word, "AG_IN") )
      return DEFINE_ALEBAG_INFLATOR;
   else if( strstr(key_word, "ON_ST") )
      return DEFINE_CONSTRUCTION_STAGES;
   else if( strstr(key_word, "NE_FR") )
      return DEFINE_FRICTION;
   else if( strstr(key_word, "ET_AD") )
      return DEFINE_SET_ADAPTIVE;
   else if( strstr(key_word, "ON_PA") )
      return DEFINE_STAGED_CONSTRUCTION_PART;
   else if( strstr(key_word, "NE_TA") )
      return DEFINE_TABLE;
   else if( strstr(key_word, "NE_VE") )
      return DEFINE_VECTOR;
   else if( strstr(key_word, "ES_AD") )
      return DEFINE_CONNECTION_PROPERTIES_ADD;
   else if( strstr(key_word, "ON_PR") )
      return DEFINE_CONNECTION_PROPERTIES;
   else if( strstr(key_word, "T_VOL") )
      return DEFINE_CONTACT_VOLUME;
   else if( strstr(key_word, "ES_NO") )
      return DEFINE_DEATH_TIMES_NODES;
   else if( strstr(key_word, "ES_RI") )
      return DEFINE_DEATH_TIMES_RIGID;
   else if( strstr(key_word, "ES_SE") )
      return DEFINE_DEATH_TIMES_SET;
   else if( strstr(key_word, "MBLY_") )
      return DEFINE_HEX_SPOTWELD_ASSEMBLY_N;
   else if( strstr(key_word, "LD_AS") )
      return DEFINE_HEX_SPOTWELD_ASSEMBLY;
   else if( strstr(key_word, "RE_RE") )
      return DEFINE_SPOTWELD_FAILURE_RESULTANTS;
   else if( strstr(key_word, "RE_PA") )
      return DEFINE_SPOTWELD_RUPTURE_PARAMETER;
   else if( strstr(key_word, "RE_ST") )
      return DEFINE_SPOTWELD_RUPTURE_STRESS;

   return DEFINE_NEW_TYPE;
}

unsigned int DefineImport::readDefines()
{
   char         new_kw[LINE_LEN];
   unsigned int	i = 0, define_id = 0, define_type = 0, num_defines = 0, 
                title_flag = 0;
   long		loc = 0L;
   VStringIterator   s = dataLocPtr->keywordList.begin(),
		     e = dataLocPtr->keywordList.end(), itr, 
		     pitr = dataLocPtr->keywordList.begin();
   typeFuncIterator  btype_iter = typeFuncMap.begin(),
                     etype_iter = typeFuncMap.end(), type_iter;

   dataLine = new DataLine(filePtr);

   while(true)
   {
      itr = find_if(pitr, e, bind2nd(KeyWordCompare (), "*DEFIN"));

      if( itr == e )
	 break;

      pitr = itr+1;
      i = (unsigned int)(itr - s);
      loc = dataLocPtr->slocList[i];

      rewind(filePtr);

      if( fseek(filePtr, loc, SEEK_SET) )
      {
	 cout << "ERROR in locating the Define cards" << endl;
	 break;
      }

      dataLine->clearFlag(KW_READ_END);

      char *str = dataLine->readNextCard(); //get the keyword
      Generic::RemoveLeadingAndTrailingBlanks( str );
cout << "KW = " << str << endl;

      define_type = getDefineTypeFromKeyword( str, &define_id );
cout << "Define TYPE = " << define_type << endl;

      if( define_type == DEFINE_NEW_TYPE )
      {
         cout << "Define TYPE NOT SUPPORTED" << endl;
         continue;
      }

      num_defines++;

      strcpy(new_kw, str);

      dataLine->clearFlag(KW_READ_END);
      type_iter = typeFuncMap.find(define_type);

      title_flag = 0;
      if( strstr(new_kw, "_TITL") )
      {
	 define_type += TITLE_CARD;
         title_flag = 1;
      }
      
      if( type_iter != etype_iter )
      {
          impObj = new ImportObject(str, define_type);

          if( title_flag )
          {
	     Title title(dataLine, impObj);
	     title.readCard();
          }

          (type_iter->second)(dataLine, impObj);
          sprintf(new_kw, "%s_%d", new_kw, num_defines);
          defineManPtr->add(new_kw, impObj);
      }
      else
         cout << "Define TYPE NOT FOUND" << endl;
   }

   return num_defines;
}

