#ifndef _Define_IMPORT_H_
#define _Define_IMPORT_H_

#include <string>
#include <map>
#include "dataloc.h"
#include "definemanager.h"
#include "dataline.h"
#include "card.h"
#include "definetype.h"
#include "typemap.h"

/** Class to import the data from native LSDYNA file for *DEFINE keywords. All
  * the data is imported through this class and stored in the manager object.
  */
class DefineImport
{
public:
   /** Constructor for creating this object
     * \param fp File pointer to the LSDYNA native file
     * \param data_loc Pointer to the list of keywords and their locations in
     * the file
     * \param define_man Manager pointer to hold the imported data as a list of
     * ImportObject list
     */
   DefineImport
   (
      FILE          *fp,
      DataLoc       *data_loc,
      DefineManager    *define_man
   );

   ~DefineImport()
   {
      filePtr = NULL;
      defineManPtr = NULL;
      dataLocPtr = NULL;
      delete dataLine;
   }

   /** Function for getting the keyword type from given keyword name from LSDYNA
     * native file. The type is stored in the database
     * \param key_word Name of the keyword from file
     * \param define_id ID of the keyword if it is there
     * \return Type for *DEFINE group of keywords
     */
   static DefineType getDefineTypeFromKeyword
	   (
	      const char  *key_word,
	      unsigned int *define_id
	   );

   /** Reads the *DEFINE keywords from file
     * \return Returns 0 on failure else number of *DEFINE keywords
     */
   unsigned int readDefines();

   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *PART keyword there is a function to call
     */
   void initAleTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *PART keyword there is a function to call
     */
   void initBoxTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *PART keyword there is a function to call
     */
   void initCoordTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *PART keyword there is a function to call
     */
   void initCurveTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *PART keyword there is a function to call
     */
   void initSimpleTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *DEFINE keyword there is a function to call
     */
   void initWeldTypesAndFunctions();

private:
   FILE          *filePtr;
   /** Manager pointer for holding the imported data for all the keywords */
   DefineManager    *defineManPtr;
   /** Pointer to keywords and their locations in the file */
   DataLoc       *dataLocPtr;
   /** Pointer to access the file data line by line */
   DataLine      *dataLine;
   /** Object to store imported data from LSDYNA data file */
   ImportObject  *impObj;
   /** A map between the keyword type and pointer to function */
   map<unsigned int, ImportFunctionPtr>  typeFuncMap;
};

#endif

