#ifndef _DefineFriction_h_
#define _DefineFriction_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *DEFINE_FRICTION keyword
  * from LSDYNA native file */

class DefineFriction : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   DefineFriction(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~DefineFriction()
   {
   }

public:
/** Function to import Card1 details for *DEFINE_FRICTION
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"ID","FS_D","FD_D","DC_D","VC_D",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 5;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, DEFINE, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *DEFINE_FRICTION
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"PID_I","PID_J","FS_IJ","FD_IJ","DC_IJ","VC_IJ",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, 1, };
      unsigned int man_types[] = {PARTC, PARTC, };
      unsigned int kw_types[] = {9999, 9999, };
      unsigned int num_indices = 2;
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *DEFINE_FRICTION
  * from LSDYNA native file */
   unsigned int importDefineFriction()
   {
      readCard1();
      readCard2();
      while(numFields)
      {
         readCard2();
      }
      return 0;
   }
};

#endif

