#ifndef _DefineVector_h_
#define _DefineVector_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *DEFINE_VECTOR keyword
  * from LSDYNA native file */

class DefineVector : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   DefineVector(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~DefineVector()
   {
   }

public:
/** Function to import Card details for *DEFINE_VECTOR
  * keyword from file */
   void readCard()
   {
      const char *fields[] = {"VID","XT","YT","ZT","XH","YH","ZH","CID",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, };
      unsigned int field_indices[] = {7, };
      unsigned int man_types[] = {DEFINE, };
      unsigned int kw_types[] = {COORDINATE, };
      unsigned int num_indices = 1;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, DEFINE, impObj);

      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *DEFINE_VECTOR
  * from LSDYNA native file */
   unsigned int importDefineVector()
   {
      readCard();
      while(numFields)
      {
         readCard();
      }
      return 0;
   }
};

#endif

