#ifndef _DefineConnectionProperties_h_
#define _DefineConnectionProperties_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *DEFINE_CONNECTION_PROPERTIES keyword
  * from LSDYNA native file */

class DefineConnectionProperties : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   DefineConnectionProperties(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~DefineConnectionProperties()
   {
   }

public:
/** Function to import Card1 details for *DEFINE_CONNECTION_PROPERTIES
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"CON_ID","PROPRUL","AREAEQ","UNUSED","DG_TYP",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_UNUSED, DATA_INT, };
      numFields = 5;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, DEFINE, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *DEFINE_CONNECTION_PROPERTIES
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"UNUSED","D_SIGY","D_ETAN","D_DG_PR","D_RANK","D_SN","D_SB","D_SS",};
      unsigned int field_types[] = {DATA_UNUSED, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3 details for *DEFINE_CONNECTION_PROPERTIES
  * keyword from file */
   void readCard3()
   {
      const char *fields[] = {"D_EXSN","D_EXSB","D_EXSS","D_LCSN","D_LCSB","D_LCSS",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {3, 4, 5, };
      unsigned int man_types[] = {DEFINE, DEFINE, DEFINE, };
      unsigned int kw_types[] = {CURVE, CURVE, CURVE, };
      unsigned int num_indices = 3;
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card4 details for *DEFINE_CONNECTION_PROPERTIES
  * keyword from file */
   void readCard4()
   {
      const char *fields[] = {"MID","SGIY","ETAN","DG_PR","RANK","SN","SB","SS",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {MAT, };
      unsigned int kw_types[] = {9999, };
      unsigned int num_indices = 1;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card4");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card5 details for *DEFINE_CONNECTION_PROPERTIES
  * keyword from file */
   void readCard5()
   {
      const char *fields[] = {"EXSN","EXSB","EXSS","LCSN","LCSB","LCSS",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {3, 4, 5, };
      unsigned int man_types[] = {DEFINE, DEFINE, DEFINE, };
      unsigned int kw_types[] = {CURVE, CURVE, CURVE, };
      unsigned int num_indices = 3;
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card5");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *DEFINE_CONNECTION_PROPERTIES
  * from LSDYNA native file */
   unsigned int importDefineConnectionProperties()
   {
      readCard1();
      readCard2();
      readCard3();
      readCard4();
      readCard5();
      while(numFields)
      {
         readCard4();
         readCard5();
      }
      return 0;
   }
};

#endif

