#ifndef _DeformableToRigidAutomatic_h_
#define _DeformableToRigidAutomatic_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *DEFORMABLE_TO_RIGID_AUTOMATIC keyword
  * from LSDYNA native file */

class DeformableToRigidAutomatic : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   DeformableToRigidAutomatic(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~DeformableToRigidAutomatic()
   {
   }

public:
/** Function to import Card1 details for *DEFORMABLE_TO_RIGID_AUTOMATIC
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"SWSET","CODE","TIME1","TIME2","TIME3","ENTNO","RELSW","PAIRED",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {SET, };
      unsigned int kw_types[] = {9999, };
      unsigned int num_indices = 1;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *DEFORMABLE_TO_RIGID_AUTOMATIC
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"NRBF","NCSF","RWF","DTMAX","D2R","R2D",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_INT, DATA_INT, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      d2r = 0;
      if( wordArray[4] )
         d2r = atoi(wordArray[4]);
      r2d = 0;
      if( wordArray[5] )
         r2d = atoi(wordArray[5]);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3 details for *DEFORMABLE_TO_RIGID_AUTOMATIC
  * keyword from file */
   void readCard3()
   {
      const char *fields[] = {"PID","MRB",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, };
      unsigned int man_types[] = {PARTC, PARTC, };
      unsigned int kw_types[] = {9999, 9999, };
      unsigned int num_indices = 2;
      numFields = 2;
      unsigned int i, end_loop;
      end_loop = d2r;
      for(i = 0; i < end_loop; i++)
      {
         numFields = 2;
         wordArray = dataLine->readNextCardAsWords(numFields);
         if( !numFields && dataLine->isFlagOn(KW_READ_END) ) return;

         if( Card::isFlagOn(SAVE_REFERENCES) )
            addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
         {
            cardObj = new Card("Card3");
            cardObj->addFields(numFields, field_types, fields, wordArray);
            impObj->addCard(cardObj);
         }
      }
   }

/** Function to import Card4 details for *DEFORMABLE_TO_RIGID_AUTOMATIC
  * keyword from file */
   void readCard4()
   {
      const char *fields[] = {"PID",};
      unsigned int field_types[] = {DATA_INT, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {PARTC, };
      unsigned int kw_types[] = {9999, };
      unsigned int num_indices = 1;
      numFields = 1;
      unsigned int i, end_loop;
      end_loop = r2d;
      for(i = 0; i < end_loop; i++)
      {
         numFields = 1;
         wordArray = dataLine->readNextCardAsWords(numFields);
         if( !numFields && dataLine->isFlagOn(KW_READ_END) ) return;

         if( Card::isFlagOn(SAVE_REFERENCES) )
            addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
         {
            cardObj = new Card("Card4");
            cardObj->addFields(numFields, field_types, fields, wordArray);
            impObj->addCard(cardObj);
         }
      }
   }

/** Function to import all the cards of the keyword *DEFORMABLE_TO_RIGID_AUTOMATIC
  * from LSDYNA native file */
   unsigned int importDeformableToRigidAutomatic()
   {
      readCard1();
      readCard2();
      if( d2r )
      {
         readCard3();
      }
      if( r2d )
      {
         readCard4();
      }
      return 0;
   }
public:
   int d2r;
   int r2d;
};

#endif

