#include <iostream>
#include <algorithm>
#include "generic.h"
#include "deformtype.h"
#include "deformimport.h"
#include <stdlib.h>

using namespace std;

DeformImport::DeformImport
(
   FILE          *fp,
   DataLoc       *data_loc,
   DeformManager    *deform_man
)
{
   filePtr = fp;
   deformManPtr = deform_man;
   dataLocPtr = data_loc;
   dataLine = NULL;

   initDeformTypesAndFunctions();
}

DeformType DeformImport::getDeformTypeFromKeyword
	(
	   const char  *key_word,
	   unsigned int *deform_id
	)
{
   *deform_id = 0;

   if( strstr(key_word, "ID_AU") )
      return DEFORMABLE_TO_RIGID_AUTOMATIC;
   else if( strstr(key_word, "ID_IN") )
      return DEFORMABLE_TO_RIGID_INERTIA;
   else if( strstr(key_word, "TO_RI") )
      return DEFORMABLE_TO_RIGID;

   return DEFORM_NEW_TYPE;
}

unsigned int DeformImport::readDeforms()
{
   char         new_kw[LINE_LEN];
   unsigned int	i = 0, deform_id = 0, deform_type = 0, num_deforms = 0;
   long		loc = 0L;
   VStringIterator   s = dataLocPtr->keywordList.begin(),
		     e = dataLocPtr->keywordList.end(), itr, 
		     pitr = dataLocPtr->keywordList.begin();
   typeFuncIterator  btype_iter = typeFuncMap.begin(),
                     etype_iter = typeFuncMap.end(), type_iter;

   dataLine = new DataLine(filePtr);

   while(true)
   {
      itr = find_if(pitr, e, bind2nd(KeyWordCompare (), "*DEFORM"));

      if( itr == e )
	 break;

      pitr = itr+1;
      i = (unsigned int)(itr - s);
      loc = dataLocPtr->slocList[i];

      rewind(filePtr);

      if( fseek(filePtr, loc, SEEK_SET) )
      {
	 cout << "ERROR in locating the Deform cards" << endl;
	 break;
      }

      dataLine->clearFlag(KW_READ_END);

      char *str = dataLine->readNextCard(); //get the keyword
      Generic::RemoveLeadingAndTrailingBlanks( str );
cout << "KW = " << str << endl;

      deform_type = getDeformTypeFromKeyword( str, &deform_id );
cout << "Deform TYPE = " << deform_type << endl;

      if( deform_type == DEFORM_NEW_TYPE )
      {
         cout << "Deform TYPE NOT SUPPORTED" << endl;
         continue;
      }

      num_deforms++;

      strcpy(new_kw, str);

      dataLine->clearFlag(KW_READ_END);
      type_iter = typeFuncMap.find(deform_type);
      if( type_iter != etype_iter )
      {
          impObj = new ImportObject(str, deform_type);
          (type_iter->second)(dataLine, impObj);
          if( deform_id )
          {
             deformManPtr->add(new_kw, impObj);
          }
          else
          {
             sprintf(new_kw, "%s_%d", new_kw, num_deforms);
             deformManPtr->add(new_kw, impObj);
          }
      }
      else
         cout << "Deform TYPE NOT FOUND" << endl;
   }

   return num_deforms;
}

