#ifndef _Deform_IMPORT_H_
#define _Deform_IMPORT_H_

#include <string>
#include <map>
#include "dataloc.h"
#include "deformmanager.h"
#include "dataline.h"
#include "card.h"
#include "deformtype.h"
#include "typemap.h"

/** Class to import the data from native LSDYNA file for *DEFORMABLE keywords. All
  * the data is imported through this class and stored in the manager object.
  */
class DeformImport
{
public:
   /** Constructor for creating this object
     * \param fp File pointer to the LSDYNA native file
     * \param data_loc Pointer to the list of keywords and their locations in
     * the file
     * \param deform_man Manager pointer to hold the imported data as a list of
     * ImportObject list
     */
   DeformImport
   (
      FILE          *fp,
      DataLoc       *data_loc,
      DeformManager    *deform_man
   );

   ~DeformImport()
   {
      filePtr = NULL;
      deformManPtr = NULL;
      dataLocPtr = NULL;
      delete dataLine;
   }

   /** Function for getting the keyword type from given keyword name from LSDYNA
     * native file. The type is stored in the database
     * \param key_word Name of the keyword from file
     * \param deform_id ID of the keyword if it is there
     * \return Type for *DEFORMABLE group of keywords
     */
   static DeformType getDeformTypeFromKeyword
	   (
	      const char  *key_word,
	      unsigned int *deform_id
	   );

   /** Reads the *DEFORMABLE keywords from file
     * \return Returns 0 on failure else number of *DEFORMABLE keywords
     */
   unsigned int readDeforms();

   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *DEFORMABLE keyword there is a function to call
     */
   void initDeformTypesAndFunctions();

private:
   FILE          *filePtr;
   /** Manager pointer for holding the imported data for all the keywords */
   DeformManager    *deformManPtr;
   /** Pointer to keywords and their locations in the file */
   DataLoc       *dataLocPtr;
   /** Pointer to access the file data line by line */
   DataLine      *dataLine;
   /** Object to store imported data from LSDYNA data file */
   ImportObject  *impObj;
   /** A map between the keyword type and pointer to function */
   map<unsigned int, ImportFunctionPtr>  typeFuncMap;
};

#endif

