#ifndef _EfControl_h_
#define _EfControl_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *EF_CONTROL keyword
  * from LSDYNA native file */

class EfControl : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   EfControl(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~EfControl()
   {
   }

public:
/** Function to import Card1 details for *EF_CONTROL
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"NPHTON","NREFS","NWARNS","NLOST","NLOOPS","ERRDEF","INSEED",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_INT, };
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *EF_CONTROL
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"DELT","SPLTOL","AREATOL","NINCR",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, };
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *EF_CONTROL
  * from LSDYNA native file */
   unsigned int importEfControl()
   {
      readCard1();
      readCard2();
      return 0;
   }
};

#endif

