#ifndef _EfMaterial_h_
#define _EfMaterial_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *EF_MATERIAL keyword
  * from LSDYNA native file */

class EfMaterial : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   EfMaterial(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~EfMaterial()
   {
   }

public:
/** Function to import Card1 details for *EF_MATERIAL
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"NMAT","NAME",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_CHAR_ARRAY, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {MAT, };
      unsigned int kw_types[] = {9999, };
      unsigned int num_indices = 1;
      numFields = 2;
      unsigned int field_widths[] = {10, 70, };
      strBuff = dataLine->readNextCard(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, field_widths, fields, strBuff);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *EF_MATERIAL
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"MTYP","EXE","EYE","EZE",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3 details for *EF_MATERIAL
  * keyword from file */
   void readCard3()
   {
      const char *fields[] = {"RHOS","RHOD","TAUS","TAUD","RDIFFR","RDIFFT",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *EF_MATERIAL
  * from LSDYNA native file */
   unsigned int importEfMaterial()
   {
      readCard1();
      readCard2();
      readCard3();
      return 0;
   }
};

#endif

