#include <iostream>
#include <algorithm>
#include "generic.h"
#include "eftype.h"
#include "efimport.h"
#include <stdlib.h>

using namespace std;

EFImport::EFImport
(
   FILE          *fp,
   DataLoc       *data_loc,
   EFManager    *ef_man
)
{
   filePtr = fp;
   efManPtr = ef_man;
   dataLocPtr = data_loc;
   dataLine = NULL;

   initEFTypesAndFunctions();
}

EFType EFImport::getEFTypeFromKeyword
	(
	   const char  *key_word,
	   unsigned int *ef_id
	)
{
   *ef_id = 0;

   if( strstr(key_word, "F_C") )
      return EF_CONTROL;
   else if( strstr(key_word, "F_G") )
      return EF_GRID;
   else if( strstr(key_word, "F_M") )
      return EF_MATERIAL;
   else if( strstr(key_word, "F_T") )
      return EF_TOGGLES;

   return EF_NEW_TYPE;
}

unsigned int EFImport::readEFs()
{
   char         new_kw[LINE_LEN];
   unsigned int	i = 0, ef_id = 0, ef_type = 0, num_efs = 0;
   long		loc = 0L;
   VStringIterator   s = dataLocPtr->keywordList.begin(),
		     e = dataLocPtr->keywordList.end(), itr, 
		     pitr = dataLocPtr->keywordList.begin();
   typeFuncIterator  btype_iter = typeFuncMap.begin(),
                     etype_iter = typeFuncMap.end(), type_iter;

   dataLine = new DataLine(filePtr);

   while(true)
   {
      itr = find_if(pitr, e, bind2nd(KeyWordCompare (), "*EF_"));

      if( itr == e )
	 break;

      pitr = itr+1;
      i = (unsigned int)(itr - s);
      loc = dataLocPtr->slocList[i];

      rewind(filePtr);

      if( fseek(filePtr, loc, SEEK_SET) )
      {
	 cout << "ERROR in locating the EF cards" << endl;
	 break;
      }

      dataLine->clearFlag(KW_READ_END);

      char *str = dataLine->readNextCard(); //get the keyword
      Generic::RemoveLeadingAndTrailingBlanks( str );
cout << "KW = " << str << endl;

      ef_type = getEFTypeFromKeyword( str, &ef_id );
cout << "EF TYPE = " << ef_type << endl;

      if( ef_type == EF_NEW_TYPE )
      {
         cout << "EF TYPE NOT SUPPORTED" << endl;
         continue;
      }

      num_efs++;

      strcpy(new_kw, str);

      dataLine->clearFlag(KW_READ_END);
      type_iter = typeFuncMap.find(ef_type);
      if( type_iter != etype_iter )
      {
          impObj = new ImportObject(str, ef_type);
          (type_iter->second)(dataLine, impObj);
          if( ef_id )
          {
             efManPtr->add(new_kw, impObj);
          }
          else
          {
             sprintf(new_kw, "%s_%d", new_kw, num_efs);
             efManPtr->add(new_kw, impObj);
          }
      }
      else
         cout << "EF TYPE NOT FOUND" << endl;
   }

   return num_efs;
}

