#ifndef _EF_IMPORT_H_
#define _EF_IMPORT_H_

#include <string>
#include <map>
#include "dataloc.h"
#include "efmanager.h"
#include "dataline.h"
#include "card.h"
#include "eftype.h"
#include "typemap.h"

/** Class to import the data from native LSDYNA file for *EF keywords. All
  * the data is imported through this class and stored in the manager object.
  */
class EFImport
{
public:
   /** Constructor for creating this object
     * \param fp File pointer to the LSDYNA native file
     * \param data_loc Pointer to the list of keywords and their locations in
     * the file
     * \param ef_man Manager pointer to hold the imported data as a list of
     * ImportObject list
     */
   EFImport
   (
      FILE          *fp,
      DataLoc       *data_loc,
      EFManager    *ef_man
   );

   ~EFImport()
   {
      filePtr = NULL;
      efManPtr = NULL;
      dataLocPtr = NULL;
      delete dataLine;
   }

   /** Function for getting the keyword type from given keyword name from LSDYNA
     * native file. The type is stored in the database
     * \param key_word Name of the keyword from file
     * \param ef_id If ID of the object is there with the keyword, it
     * returns the ID
     * \return Type of keyword for *EF group of keywords
     */
   static EFType getEFTypeFromKeyword
	   (
	      const char  *key_word,
	      unsigned int *ef_id
	   );

   /** Reads the *EF keywords from file
     * \return Returns 0 on failure else number of components imported
     */
   unsigned int readEFs();

   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *EF keyword there is a function to call
     */
   void initEFTypesAndFunctions();

private:
   FILE          *filePtr;
   /** Manager pointer for holding the imported data for all the keywords */
   EFManager    *efManPtr;
   /** Pointer to keywords and their locations in the file */
   DataLoc       *dataLocPtr;
   /** Pointer to access the file data line by line */
   DataLine      *dataLine;
   /** Object to store imported data from LSDYNA data file */
   ImportObject  *impObj;
   /** A map between the keyword type and pointer to function */
   map<unsigned int, ImportFunctionPtr>  typeFuncMap;
};

#endif

