#ifndef _ElementBeamOffset_h_
#define _ElementBeamOffset_h_

#include "manager.h"
#include "dispexport.h"
#include "elementbeam.h"

/** This class is used for importing *ELEMENT_BEAM_OFFSET keyword
  * from LSDYNA native file */

class ElementBeamOffset : public ElementBeam
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ElementBeamOffset(DataLine *data_line, ImportObject *imp_obj) : ElementBeam (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ElementBeamOffset()
   {
   }

public:
/** Function to import Card details for *ELEMENT_BEAM_OFFSET
  * keyword from file */
   void readCard()
   {
      const char *fields[] = {"WX1","WY1","WZ1","WX2","WY2","WZ2",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *ELEMENT_BEAM_OFFSET
  * from LSDYNA native file */
   unsigned int importElementBeamOffset()
   {
      importElementBeam();
      readCard();
      return 0;
   }
};

#endif

