#ifndef _ElementBeamPid_h_
#define _ElementBeamPid_h_

#include "manager.h"
#include "dispexport.h"
#include "elementbeam.h"

/** This class is used for importing *ELEMENT_BEAM_PID keyword
  * from LSDYNA native file */

class ElementBeamPid : public ElementBeam
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ElementBeamPid(DataLine *data_line, ImportObject *imp_obj) : ElementBeam (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ElementBeamPid()
   {
   }

public:
/** Function to import Card details for *ELEMENT_BEAM_PID
  * keyword from file */
   void readCard()
   {
      const char *fields[] = {"PID1","PID2",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, };
      unsigned int man_types[] = {PARTC, PARTC, };
      unsigned int kw_types[] = {9999, 9999, };
      unsigned int num_indices = 2;
      numFields = 2;
      unsigned int field_widths[] = {8, 8, };
      strBuff = dataLine->readNextCard(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card");
         cardObj->addFields(numFields, field_types, field_widths, fields, strBuff);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *ELEMENT_BEAM_PID
  * from LSDYNA native file */
   unsigned int importElementBeamPid()
   {
      importElementBeam();
      readCard();
      return 0;
   }
};

#endif

