#ifndef _ElementBeamScalr_h_
#define _ElementBeamScalr_h_

#include "manager.h"
#include "dispexport.h"
#include "elementbeam.h"

/** This class is used for importing *ELEMENT_BEAM_SCALR keyword
  * from LSDYNA native file */

class ElementBeamScalr : public ElementBeam
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ElementBeamScalr(DataLine *data_line, ImportObject *imp_obj) : ElementBeam (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ElementBeamScalr()
   {
   }

public:
/** Function to import Card1 details for *ELEMENT_BEAM_SCALR
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"VOL","INER","CID1","CID2","DOFNS",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {2, 3, };
      unsigned int man_types[] = {DEFINE, DEFINE, };
      unsigned int kw_types[] = {COORDINATE, COORDINATE, };
      unsigned int num_indices = 2;
      numFields = 5;
      unsigned int field_widths[] = {16, 16, 8, 8, 8, };
      strBuff = dataLine->readNextCard(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, field_widths, fields, strBuff);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *ELEMENT_BEAM_SCALR
  * from LSDYNA native file */
   unsigned int importElementBeamScalr()
   {
      importElementBeam();
      readCard1();
      return 0;
   }
};

#endif

