#ifndef _ElementBeamSection_h_
#define _ElementBeamSection_h_

#include "manager.h"
#include "dispexport.h"
#include "elementbeam.h"

/** This class is used for importing *ELEMENT_BEAM_SECTION keyword
  * from LSDYNA native file */

class ElementBeamSection : public ElementBeam
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ElementBeamSection(DataLine *data_line, ImportObject *imp_obj) : ElementBeam (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ElementBeamSection()
   {
   }

public:
/** Function to import Card details for *ELEMENT_BEAM_SECTION
  * keyword from file */
   void readCard()
   {
      const char *fields[] = {"STYPE","D1","D2","D3","D4","D5","D6",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *ELEMENT_BEAM_SECTION
  * from LSDYNA native file */
   unsigned int importElementBeamSection()
   {
      importElementBeam();
      readCard();
      return 0;
   }
};

#endif

