#ifndef _ElementBeamWarpage_h_
#define _ElementBeamWarpage_h_

#include "manager.h"
#include "dispexport.h"
#include "elementbeam.h"

/** This class is used for importing *ELEMENT_BEAM_WARPAGE keyword
  * from LSDYNA native file */

class ElementBeamWarpage : public ElementBeam
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ElementBeamWarpage(DataLine *data_line, ImportObject *imp_obj) : ElementBeam (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ElementBeamWarpage()
   {
   }

public:
/** Function to import Card details for *ELEMENT_BEAM_WARPAGE
  * keyword from file */
   void readCard()
   {
      const char *fields[] = {"SN1","SN2",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, };
      unsigned int man_types[] = {NOD, NOD, };
      unsigned int kw_types[] = {9999, 9999, };
      unsigned int num_indices = 2;
      numFields = 2;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *ELEMENT_BEAM_WARPAGE
  * from LSDYNA native file */
   unsigned int importElementBeamWarpage()
   {
      importElementBeam();
      readCard();
      return 0;
   }
};

#endif

