#include <iostream>
#include <algorithm>
#include "generic.h"
#include "elementtype.h"
#include "elementimport.h"
#include <stdlib.h>
#include "filepath.h"

using namespace std;

ElementImport::ElementImport
(
   FILE          *fp,
   DataLoc       *data_loc,
   ElementManager    *element_man
)
{
   filePtr = fp;
   elementManPtr = element_man;
   dataLocPtr = data_loc;
   dataLine = NULL;

   initBeamTypesAndFunctions();
   initSeatbeltTypesAndFunctions();
   initShellTypesAndFunctions();
   initSimpleTypesAndFunctions();
}

ElementType ElementImport::getElementTypeFromKeyword
	(
	   const char  *key_word,
	   unsigned int *element_id
	)
{
   *element_id = 0;

   if( strstr(key_word, "BEA") )
   {
      if( strstr(key_word, "OFF") )
	 return ELEMENT_BEAM_OFFSET;
      else if( strstr(key_word, "ORI") )
	 return ELEMENT_BEAM_ORIENTATION;
      else if( strstr(key_word, "PID") )
	 return ELEMENT_BEAM_PID;
      else if( strstr(key_word, "LAR") )
	 return ELEMENT_BEAM_SCALAR;
      else if( strstr(key_word, "ALR") )
	 return ELEMENT_BEAM_SCALR;
      else if( strstr(key_word, "SEC") )
	 return ELEMENT_BEAM_SECTION;
      else if( strstr(key_word, "THI") )
	 return ELEMENT_BEAM_THICKNESS;
      else if( strstr(key_word, "WAR") )
	 return ELEMENT_BEAM_WARPAGE;
      else
	 return ELEMENT_BEAM;
   }
   else if( strstr(key_word, "SEA") )
   {
      if( strstr(key_word, "ACC") )
	 return ELEMENT_SEATBELT_ACCELEROMETER;
      else if( strstr(key_word, "PRE") )
	 return ELEMENT_SEATBELT_PRETENSIONER;
      else if( strstr(key_word, "RET") )
	 return ELEMENT_SEATBELT_RETRACTOR;
      else if( strstr(key_word, "SEN") )
	 return ELEMENT_SEATBELT_SENSOR;
      else if( strstr(key_word, "SLI") )
	 return ELEMENT_SEATBELT_SLIPRING;
      else
	 return ELEMENT_SEATBELT;
   }
   else if( strstr(key_word, "SHE") )
   {
      if( strstr(key_word, "BET") )
	 return ELEMENT_SHELL_BETA;
      else if( strstr(key_word, "DOF") )
	 return ELEMENT_SHELL_DOF;
      else if( strstr(key_word, "MCD") )
	 return ELEMENT_SHELL_MCD;
      else if( strstr(key_word, "OFF") )
	 return ELEMENT_SHELL_OFFSET;
      else if( strstr(key_word, "SOU") )
	 return ELEMENT_SHELL_SOURCE_SINK;
      else if( strstr(key_word, "THI") )
	 return ELEMENT_SHELL_THICKNESS;
      else
	 return ELEMENT_SHELL;
   }
   else if( strstr(key_word, "SOL") )
   {
      if( strstr(key_word, "DOF") )
	 return ELEMENT_SOLID_DOF;
      else if( strstr(key_word, "ORT") )
	 return ELEMENT_SOLID_ORTHO;
      else
	 return ELEMENT_SOLID;
   }
   else if( strstr(key_word, "TSH") )
      return ELEMENT_TSHELL;
   else if( strstr(key_word, "INP") )
      return ELEMENT_DIRECT_MATRIX_INPUT;
   else if( strstr(key_word, "DIS") )
      return ELEMENT_DISCRETE;
   else if( strstr(key_word, "A_OF") )
      return ELEMENT_INERTIA_OFFSET;
   else if( strstr(key_word, "INE") )
      return ELEMENT_INERTIA;
   else if( strstr(key_word, "MAS") )
   {
      if( strstr(key_word, "NOD") )
	 return ELEMENT_MASS_NODE_SET;
      else if( strstr(key_word, "SET") )
	 return ELEMENT_MASS_PART_SET;
      else if( strstr(key_word, "PAR") )
	 return ELEMENT_MASS_PART;
      else
	 return ELEMENT_MASS;
   }
   else if( strstr(key_word, "PLO") )
      return ELEMENT_PLOTEL;
   else if( strstr(key_word, "SPH") )
      return ELEMENT_SPH;
   else if( strstr(key_word, "RIM") )
      return ELEMENT_TRIM;

   return ELEMENT_NEW_TYPE;
}

unsigned int ElementImport::readElements()
{
   char         new_kw[LINE_LEN];
   unsigned int	i = 0, element_id = 0, element_type = 0, num_elements = 0;
   long		loc = 0L;
   VStringIterator   s = dataLocPtr->keywordList.begin(),
		     e = dataLocPtr->keywordList.end(), itr, 
		     pitr = dataLocPtr->keywordList.begin();
   typeFuncIterator  btype_iter = typeFuncMap.begin(),
                     etype_iter = typeFuncMap.end(), type_iter;

   dataLine = new DataLine(filePtr);

   while(true)
   {
      itr = find_if(pitr, e, bind2nd(KeyWordCompare (), "*ELE"));

      if( itr == e )
	 break;

      pitr = itr+1;
      i = (unsigned int)(itr - s);
      loc = dataLocPtr->slocList[i];

      rewind(filePtr);

      if( fseek(filePtr, loc, SEEK_SET) )
      {
	 cout << "ERROR in locating the Element cards" << endl;
	 break;
      }

      dataLine->clearFlag(KW_READ_END);

      char *str = dataLine->readNextCard(); //get the keyword
      Generic::RemoveLeadingAndTrailingBlanks( str );
cout << "KW = " << str << endl;

      element_type = getElementTypeFromKeyword( str, &element_id );
cout << "Element TYPE = " << element_type << endl;

      if( element_type == ELEMENT_NEW_TYPE )
      {
         cout << "Element TYPE NOT SUPPORTED" << endl;
         continue;
      }

      num_elements++;

      strcpy(new_kw, str);

      dataLine->clearFlag(KW_READ_END);
      type_iter = typeFuncMap.find(element_type);
      if( type_iter != etype_iter )
      {
	 impObj = new ImportObject(str, element_type);
	 (type_iter->second)(dataLine, impObj);
	 Card::clearFlag();
	 while( !dataLine->isFlagOn(KW_READ_END) )
	 {
	    (type_iter->second)(dataLine, impObj);
	 }

	 sprintf(new_kw, "%s_%d", new_kw, num_elements);
	 elementManPtr->add(new_kw, impObj);
      }
      else
         cout << "Element TYPE NOT FOUND" << endl;
      FilePath::closeFile();
   }

   FilePath::closeIDFile();

   return num_elements;
}

