#ifndef _Element_IMPORT_H_
#define _Element_IMPORT_H_

#include <string>
#include <map>
#include "dataloc.h"
#include "elementmanager.h"
#include "dataline.h"
#include "card.h"
#include "elementtype.h"
#include "typemap.h"

/** Class to import the data from native LSDYNA file for *ELEMENT keywords. All
  * the data is imported through this class and stored in the manager object.
  */
class ElementImport
{
public:
   /** Constructor for creating this object
     * \param fp File pointer to the LSDYNA native file
     * \param data_loc Pointer to the list of keywords and their locations in
     * the file
     * \param element_man Manager pointer to hold the imported data as a list of
     * ImportObject list
     */
   ElementImport
   (
      FILE          *fp,
      DataLoc       *data_loc,
      ElementManager    *element_man
   );

   ~ElementImport()
   {
      filePtr = NULL;
      elementManPtr = NULL;
      dataLocPtr = NULL;
      delete dataLine;
   }

   /** Function for getting the keyword type from given keyword name from LSDYNA
     * native file. The type is stored in the database
     * \param key_word Name of the keyword from file
     * \param element_id ID of the keyword if it is there
     * \return Type for *ELEMENT group of keywords
     */
   static ElementType getElementTypeFromKeyword
	   (
	      const char  *key_word,
	      unsigned int *element_id
	   );

   /** Reads the *ELEMENT keywords from file
     * \return Returns 0 on failure else number of *ELEMENT keywords
     */
   unsigned int readElements();

   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *ELEMENT keyword there will be function to call
     */
   void initBeamTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *ELEMENT keyword there will be function to call
     */
   void initSeatbeltTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *ELEMENT keyword there will be function to call
     */
   void initShellTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *ELEMENT keyword there is a function to call
     */
   void initSimpleTypesAndFunctions();

private:
   FILE          *filePtr;
   /** Manager pointer for holding the imported data for all the keywords */
   ElementManager    *elementManPtr;
   /** Pointer to keywords and their locations in the file */
   DataLoc       *dataLocPtr;
   /** Pointer to access the file data line by line */
   DataLine      *dataLine;
   /** Object to store imported data from LSDYNA data file */
   ImportObject  *impObj;
   /** A map between the keyword type and pointer to function */
   map<unsigned int, ImportFunctionPtr>  typeFuncMap;
};

#endif

