#ifndef _ElementSeatbeltAccelerometer_h_
#define _ElementSeatbeltAccelerometer_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *ELEMENT_SEATBELT_ACCELEROMETER keyword
  * from LSDYNA native file */

class ElementSeatbeltAccelerometer : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ElementSeatbeltAccelerometer(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ElementSeatbeltAccelerometer()
   {
   }

public:
/** Function to import Card1 details for *ELEMENT_SEATBELT_ACCELEROMETER
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"SBACID","NID1","NID2","NID3","IGRAV","INTOPT","MASS",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, };
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, ELEMENT, impObj);

      if( Card::isFlagOn(SAVE_REFERENCES) )
         saveSBAccelerometers(wordArray, numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *ELEMENT_SEATBELT_ACCELEROMETER
  * from LSDYNA native file */
   unsigned int importElementSeatbeltAccelerometer()
   {
      readCard1();
      return 0;
   }
};

#endif

