#ifndef _ElementSeatbeltSensor_h_
#define _ElementSeatbeltSensor_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *ELEMENT_SEATBELT_SENSOR keyword
  * from LSDYNA native file */

class ElementSeatbeltSensor : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ElementSeatbeltSensor(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ElementSeatbeltSensor()
   {
   }

public:
/** Function to import Card1 details for *ELEMENT_SEATBELT_SENSOR
  * keyword from file */
   int readCard1()
   {
      const char *fields[] = {"SBSID","SBSTYP","SBSFL",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, };
      numFields = 3;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return 0;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, ELEMENT, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
      if( wordArray[1] )
         return atoi(wordArray[1]);
      else
         return 0;
   }

/** Function to import CardSBSTYP1 details for *ELEMENT_SEATBELT_SENSOR
  * keyword from file */
   void readCardSBSTYP1()
   {
      const char *fields[] = {"NID","DOF","ACC","ATIME",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {NOD, };
      unsigned int kw_types[] = {9999, };
      unsigned int num_indices = 1;
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("CardSBSTYP1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import CardSBSTYP2 details for *ELEMENT_SEATBELT_SENSOR
  * keyword from file */
   void readCardSBSTYP2()
   {
      const char *fields[] = {"SBRID","PULRAT","PULTIM",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {ELEMENT, };
      unsigned int kw_types[] = {SBRETRACTOR, };
      unsigned int num_indices = 1;
      numFields = 3;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("CardSBSTYP2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import CardSBSTYP3 details for *ELEMENT_SEATBELT_SENSOR
  * keyword from file */
   void readCardSBSTYP3()
   {
      const char *fields[] = {"TIME",};
      unsigned int field_types[] = {DATA_DOUBLE, };
      numFields = 1;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("CardSBSTYP3");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import CardSBSTYP4 details for *ELEMENT_SEATBELT_SENSOR
  * keyword from file */
   void readCardSBSTYP4()
   {
      const char *fields[] = {"NID1","NID2","DMX","DMN",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, 1, };
      unsigned int man_types[] = {NOD, NOD, };
      unsigned int kw_types[] = {9999, 9999, };
      unsigned int num_indices = 2;
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("CardSBSTYP4");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *ELEMENT_SEATBELT_SENSOR
  * from LSDYNA native file */
   unsigned int importElementSeatbeltSensor()
   {
      int sbstyp = 0;
      sbstyp = readCard1();
      if( sbstyp == 1 )
      {
         readCardSBSTYP1();
      }
      else if( sbstyp == 2 )
      {
         readCardSBSTYP2();
      }
      else if( sbstyp == 3 )
      {
         readCardSBSTYP3();
      }
      else if( sbstyp == 4 )
      {
         readCardSBSTYP4();
      }
      return 0;
   }
};

#endif

