#ifndef _ElementShell_h_
#define _ElementShell_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *ELEMENT_SHELL keyword
  * from LSDYNA native file */

class ElementShell : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ElementShell(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ElementShell()
   {
   }

public:
/** Function to import Card1 details for *ELEMENT_SHELL
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"EID","PID","N1","N2","N3","N4","N5","N6","N7","N8",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 10;
      unsigned int field_widths[] = {8, 8, 8, 8, 8, 8, 8, 8, 8, 8, };
      strBuff = dataLine->readNextCard(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;

      wordArray = dataLine->splitIntoWords(numFields, field_widths);
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, ELEMENT, impObj);

      if( Card::isFlagOn(SAVE_REFERENCES) )
         saveShellElements(wordArray, numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, field_widths, fields, strBuff);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *ELEMENT_SHELL
  * from LSDYNA native file */
   unsigned int importElementShell()
   {
      readCard1();
      return 0;
   }
};

#endif

