#ifndef _ElementShellThickness_h_
#define _ElementShellThickness_h_

#include "manager.h"
#include "dispexport.h"
#include "elementshell.h"

/** This class is used for importing *ELEMENT_SHELL_THICKNESS keyword
  * from LSDYNA native file */

class ElementShellThickness : public ElementShell
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ElementShellThickness(DataLine *data_line, ImportObject *imp_obj) : ElementShell (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ElementShellThickness()
   {
   }

public:
/** Function to import Card2 details for *ELEMENT_SHELL_THICKNESS
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"THIC1","THIC2","THIC3","THIC4","BETA/MCID",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {4, };
      unsigned int man_types[] = {DEFINE, };
      unsigned int kw_types[] = {COORDINATE, };
      unsigned int num_indices = 1;
      numFields = 5;
      unsigned int field_widths[] = {16, 16, 16, 16, 16, };
      strBuff = dataLine->readNextCard(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, field_widths, fields, strBuff);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *ELEMENT_SHELL_THICKNESS
  * from LSDYNA native file */
   unsigned int importElementShellThickness()
   {
      importElementShell();
      readCard2();
      return 0;
   }
};

#endif

