#ifndef _ElementSolid_h_
#define _ElementSolid_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *ELEMENT_SOLID keyword
  * from LSDYNA native file */

class ElementSolid : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ElementSolid(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ElementSolid()
   {
   }

public:
/** Function to import Card1 details for *ELEMENT_SOLID
  * keyword from file */
   int readCard1()
   {
      const char *fields[] = {"EID","PID","N1","N2","N3","N4","N5","N6","N7","N8",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 10;
      unsigned int field_widths[] = {8, 8, 8, 8, 8, 8, 8, 8, 8, 8, };
      strBuff = dataLine->readNextCard(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return 0;

      wordArray = dataLine->splitIntoWords(numFields, field_widths);
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, ELEMENT, impObj);

      if( Card::isFlagOn(SAVE_REFERENCES) )
         saveSolidElements(wordArray, numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, field_widths, fields, strBuff);
         impObj->addCard(cardObj);
      }
      if( wordArray[2] )
         return atoi(wordArray[2]);
      else
         return 0;
   }

/** Function to import Card2 details for *ELEMENT_SOLID
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"N1_971","N2_971","N3_971","N4_971","N5_971","N6_971","N7_971","N8_971","N9_971","N10_971",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 10;
      unsigned int field_widths[] = {8, 8, 8, 8, 8, 8, 8, 8, 8, 8, };
      strBuff = dataLine->readNextCard(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         saveSolidElements971(wordArray, numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, field_widths, fields, strBuff);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *ELEMENT_SOLID
  * from LSDYNA native file */
   unsigned int importElementSolid()
   {
      int n1 = 0;
      n1 = readCard1();
      if( n1 == 0 )
      {
         readCard2();
      }
      return 0;
   }
};

#endif

