#ifndef _ElementSolidDof_h_
#define _ElementSolidDof_h_

#include "manager.h"
#include "dispexport.h"
#include "elementsolid.h"

/** This class is used for importing *ELEMENT_SOLID_DOF keyword
  * from LSDYNA native file */

class ElementSolidDof : public ElementSolid
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ElementSolidDof(DataLine *data_line, ImportObject *imp_obj) : ElementSolid (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ElementSolidDof()
   {
   }

public:
/** Function to import CardDOF details for *ELEMENT_SOLID_DOF
  * keyword from file */
   void readCardDOF()
   {
      const char *fields[] = {"UNUSED","UNUSED","NS1","NS2","NS3","NS4","NS5","NS6","NS7","NS8",};
      unsigned int field_types[] = {DATA_UNUSED, DATA_UNUSED, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {2, 3, 4, 5, 6, 7, 8, 9, };
      unsigned int man_types[] = {NOD, NOD, NOD, NOD, NOD, NOD, NOD, NOD, };
      unsigned int kw_types[] = {9999, 9999, 9999, 9999, 9999, 9999, 9999, 9999, };
      unsigned int num_indices = 8;
      numFields = 10;
      unsigned int field_widths[] = {8, 8, 8, 8, 8, 8, 8, 8, 8, 8, };
      strBuff = dataLine->readNextCard(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("CardDOF");
         cardObj->addFields(numFields, field_types, field_widths, fields, strBuff);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *ELEMENT_SOLID_DOF
  * from LSDYNA native file */
   unsigned int importElementSolidDof()
   {
      importElementSolid();
      readCardDOF();
      return 0;
   }
};

#endif

