#ifndef _ElementSolidOrtho_h_
#define _ElementSolidOrtho_h_

#include "manager.h"
#include "dispexport.h"
#include "elementsolid.h"

/** This class is used for importing *ELEMENT_SOLID_ORTHO keyword
  * from LSDYNA native file */

class ElementSolidOrtho : public ElementSolid
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   ElementSolidOrtho(DataLine *data_line, ImportObject *imp_obj) : ElementSolid (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~ElementSolidOrtho()
   {
   }

public:
/** Function to import CardOrtho1 details for *ELEMENT_SOLID_ORTHO
  * keyword from file */
   void readCardOrtho1()
   {
      const char *fields[] = {"A1","A2","A3",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 3;
      unsigned int field_widths[] = {16, 16, 16, };
      strBuff = dataLine->readNextCard(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("CardOrtho1");
         cardObj->addFields(numFields, field_types, field_widths, fields, strBuff);
         impObj->addCard(cardObj);
      }
   }

/** Function to import CardOrtho2 details for *ELEMENT_SOLID_ORTHO
  * keyword from file */
   void readCardOrtho2()
   {
      const char *fields[] = {"D1","D2","D3",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 3;
      unsigned int field_widths[] = {16, 16, 16, };
      strBuff = dataLine->readNextCard(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("CardOrtho2");
         cardObj->addFields(numFields, field_types, field_widths, fields, strBuff);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *ELEMENT_SOLID_ORTHO
  * from LSDYNA native file */
   unsigned int importElementSolidOrtho()
   {
      importElementSolid();
      readCardOrtho1();
      readCardOrtho2();
      return 0;
   }
};

#endif

