#include <iostream>
#include <algorithm>
#include "generic.h"
#include "eostype.h"
#include "eosimport.h"
#include "title.h"
#include <stdlib.h>

using namespace std;

EosImport::EosImport
(
   FILE          *fp,
   DataLoc       *data_loc,
   EosManager    *eos_man
)
{
   filePtr = fp;
   eosManPtr = eos_man;
   dataLocPtr = data_loc;
   dataLine = NULL;

   initJwlTypesAndFunctions();
   initPolyTypesAndFunctions();
   initTableTypesAndFunctions();
}

EosType EosImport::getEosTypeFromKeyword
	(
	   const char  *key_word,
	   unsigned int *eos_id
	)
{
   *eos_id = 0;

   if( strstr(key_word, "L_G") )
      return EOS_IDEAL_GAS;
   else if( strstr(key_word, "N_HE") )
      return EOS_IGNITION_AND_GROWTH_OF_REACTION_IN_HE;
   else if( strstr(key_word, "WLB") )
      return EOS_JWLB;
   else if( strstr(key_word, "JWL") )
      return EOS_JWL;
   else if( strstr(key_word, "T_DE") )
      return EOS_PROPELLANT_DEFLAGRATION;
   else if( strstr(key_word, "E_CO") )
      return EOS_TENSOR_PORE_COLLAPSE;
   else if( strstr(key_word, "S_GR") )
      return EOS_GRUNEISEN;
   else if( strstr(key_word, "Y_LE") )
      return EOS_LINEAR_POLYNOMIAL_WITH_ENERGY_LEAK;
   else if( strstr(key_word, "R_POL") )
      return EOS_LINEAR_POLYNOMIAL;
   else if( strstr(key_word, "F_PO") )
      return EOS_RATIO_OF_POLYNOMIALS;
   else if( strstr(key_word, "K_TU") )
      return EOS_SACK_TUESDAY;
   else if( strstr(key_word, "S_GA") )
      return EOS_GASKET;
   else if( strstr(key_word, "D_CO") )
      return EOS_TABULATED_COMPACTION;
   else if( strstr(key_word, "S_TA") )
      return EOS_TABULATED;
   else if( strstr(key_word, "R_DE") )
      return EOS_USER_DEFINED;

   return EOS_NEW_TYPE;
}

unsigned int EosImport::readEoss()
{
   char         new_kw[LINE_LEN];
   unsigned int	i = 0, eos_id = 0, eos_type = 0, num_eoss = 0, title_flag = 0;
   long		loc = 0L;
   VStringIterator   s = dataLocPtr->keywordList.begin(),
		     e = dataLocPtr->keywordList.end(), itr, 
		     pitr = dataLocPtr->keywordList.begin();
   typeFuncIterator  btype_iter = typeFuncMap.begin(),
                     etype_iter = typeFuncMap.end(), type_iter;

   dataLine = new DataLine(filePtr);

   while(true)
   {
      itr = find_if(pitr, e, bind2nd(KeyWordCompare (), "*EOS_"));

      if( itr == e )
	 break;

      pitr = itr+1;
      i = (unsigned int)(itr - s);
      loc = dataLocPtr->slocList[i];

      rewind(filePtr);

      if( fseek(filePtr, loc, SEEK_SET) )
      {
	 cout << "ERROR in locating the Eos cards" << endl;
	 break;
      }

      dataLine->clearFlag(KW_READ_END);

      char *str = dataLine->readNextCard(); //get the keyword
      Generic::RemoveLeadingAndTrailingBlanks( str );
cout << "KW = " << str << endl;

      eos_type = getEosTypeFromKeyword( str, &eos_id );
cout << "Eos TYPE = " << eos_type << endl;

      if( eos_type == EOS_NEW_TYPE )
      {
         cout << "Eos TYPE NOT SUPPORTED" << endl;
         continue;
      }

      num_eoss++;

      strcpy(new_kw, str);

      dataLine->clearFlag(KW_READ_END);
      type_iter = typeFuncMap.find(eos_type);

      title_flag = 0;
      if( strstr(new_kw, "_TITL") )
      {
         title_flag = 1;
	 eos_type += TITLE_CARD;
      }

      if( type_iter != etype_iter )
      {
	 impObj = new ImportObject(str, eos_type);

	 if( title_flag )
	 {
	    Title title(dataLine, impObj);
	    title.readCard();
	 }

	 (type_iter->second)(dataLine, impObj);
	 sprintf(new_kw, "%s_%d", new_kw, num_eoss);
	 eosManPtr->add(new_kw, impObj);
      }
      else
         cout << "Eos TYPE NOT FOUND" << endl;
   }

   return num_eoss;
}

