#ifndef _Eos_IMPORT_H_
#define _Eos_IMPORT_H_

#include <string>
#include <map>
#include "dataloc.h"
#include "eosmanager.h"
#include "dataline.h"
#include "card.h"
#include "eostype.h"
#include "typemap.h"

/** Class to import the data from native LSDYNA file for *EOS keywords. All
  * the data is imported through this class and stored in the manager object.
  */
class EosImport
{
public:
   /** Constructor for creating this object
     * \param fp File pointer to the LSDYNA native file
     * \param data_loc Pointer to the list of keywords and their locations in
     * the file
     * \param eos_man Manager pointer to hold the imported data as a list of
     * ImportObject list
     */
   EosImport
   (
      FILE          *fp,
      DataLoc       *data_loc,
      EosManager    *eos_man
   );

   ~EosImport()
   {
      filePtr = NULL;
      eosManPtr = NULL;
      dataLocPtr = NULL;
      delete dataLine;
   }

   /** Function for getting the keyword type from given keyword name from LSDYNA
     * native file. The type is stored in the database
     * \param key_word Name of the keyword from file
     * \param eos_id If ID of the object is there with the keyword, it
     * returns the ID
     * \return Type of keyword for *EOS group of keywords
     */
   static EosType getEosTypeFromKeyword
	   (
	      const char  *key_word,
	      unsigned int *eos_id
	   );

   /** Reads the *EOS keywords from file
     * \return Returns 1 on failure else number of components imported
     */
   unsigned int readEoss();

   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *EOS keyword there will be function to call.
     */
   void initJwlTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *EOS keyword there will be function to call.
     */
   void initPolyTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *EOS keyword there is a function to call.
     */
   void initTableTypesAndFunctions();

private:
   FILE          *filePtr;
   /** Manager pointer for holding the imported data for all the keywords */
   EosManager    *eosManPtr;
   /** Pointer to keywords and their locations in the file */
   DataLoc       *dataLocPtr;
   /** Pointer to access the file data line by line */
   DataLine      *dataLine;
   /** Object to store imported data from LSDYNA data file */
   ImportObject  *impObj;
   /** A map between the keyword type and pointer to function */
   map<unsigned int, ImportFunctionPtr>  typeFuncMap;
};

#endif

