#ifndef _EosPropellantDeflagration_h_
#define _EosPropellantDeflagration_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *EOS_PROPELLANT_DEFLAGRATION keyword
  * from LSDYNA native file */

class EosPropellantDeflagration : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   EosPropellantDeflagration(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~EosPropellantDeflagration()
   {
   }

public:
/** Function to import Card1 details for *EOS_PROPELLANT_DEFLAGRATION
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"EOSID","A","B","XP1","XP2","FRER",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, EOS, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *EOS_PROPELLANT_DEFLAGRATION
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"g","R1","R2","R3","R5",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 5;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3 details for *EOS_PROPELLANT_DEFLAGRATION
  * keyword from file */
   void readCard3()
   {
      const char *fields[] = {"R6","FMXIG","FREQ","GROW1","EM",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 5;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card4 details for *EOS_PROPELLANT_DEFLAGRATION
  * keyword from file */
   void readCard4()
   {
      const char *fields[] = {"AR1","ES1","CVP","CVR","EETAL","CCRIT","ENQ","TMP0",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card4");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card5 details for *EOS_PROPELLANT_DEFLAGRATION
  * keyword from file */
   void readCard5()
   {
      const char *fields[] = {"GROW2","AR2","ES2","EN","FMXGR","FMNGR",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card5");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *EOS_PROPELLANT_DEFLAGRATION
  * from LSDYNA native file */
   unsigned int importEosPropellantDeflagration()
   {
      readCard1();
      readCard2();
      readCard3();
      readCard4();
      readCard5();
      return 0;
   }
};

#endif

