#ifndef _EosGruneisen_h_
#define _EosGruneisen_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *EOS_GRUNEISEN keyword
  * from LSDYNA native file */

class EosGruneisen : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   EosGruneisen(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~EosGruneisen()
   {
   }

public:
/** Function to import Card1 details for *EOS_GRUNEISEN
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"EOSID","C","S1","S2","S3","GAMAO","A","E0",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, EOS, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *EOS_GRUNEISEN
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"V0",};
      unsigned int field_types[] = {DATA_DOUBLE, };
      numFields = 1;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *EOS_GRUNEISEN
  * from LSDYNA native file */
   unsigned int importEosGruneisen()
   {
      readCard1();
      readCard2();
      return 0;
   }
};

#endif

