#ifndef _EosUserDefined_h_
#define _EosUserDefined_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *EOS_USER_DEFINED keyword
  * from LSDYNA native file */

class EosUserDefined : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   EosUserDefined(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~EosUserDefined()
   {
   }

public:
/** Function to import Card1 details for *EOS_USER_DEFINED
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"EOSID","EOST","LMC","NHV","IVECT","EO","VO","BULK",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      lmc = 0;
      if( wordArray[2] )
         lmc = atoi(wordArray[2]);
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, EOS, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *EOS_USER_DEFINED
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"P1","P2","P3","P4","P5","P6","P7","P8",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int i, end_loop;
      end_loop = ((lmc%8) ? (lmc/8)+1 : lmc/8);
      for(i = 0; i < end_loop; i++)
      {
         numFields = 8;
         wordArray = dataLine->readNextCardAsWords(numFields);
         if( !numFields && dataLine->isFlagOn(KW_READ_END) ) return;

         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
         {
            cardObj = new Card("Card2");
            cardObj->addFields(numFields, field_types, fields, wordArray);
            impObj->addCard(cardObj);
         }
      }
   }

/** Function to import all the cards of the keyword *EOS_USER_DEFINED
  * from LSDYNA native file */
   unsigned int importEosUserDefined()
   {
      readCard1();
      readCard2();
      return 0;
   }
public:
   int lmc;
};

#endif

