#ifndef _DISP_EXPORT_H_
#define _DISP_EXPORT_H_

#include <string>
#include "object.h"
#include "card.h"

using namespace std;

/** Function to save IDS for a given type of keyword to file. File names are
  * created internally. This function is useful to get IDS of *AIRBAG, *PART etc
  * and write them into *.ids file.
  * \param field_list List of fields from file or database from which ID is taken
  * \param id_index Index of the field from which ID is taken
  * \man_type Type of group to which the IDs belongs like AIRBAG,CONTACT etc
  * \imp_obj ImportObject pointer to which the list is saved
  */
void addIDToFile
     (
        char         **field_list,
        unsigned int id_index,
        unsigned int man_type,
        ImportObject *imp_obj
     );

/** Function to save IDS of referred entities in a keyword to a file as 
  * entity_display.bin. This information is used to display the referred entities   * along with the given entity or keyword. File names are created internally. 
  * For example, *AIRBAG refers a set ID and *DEFINE_CURVE ID. So these IDs and 
  * keyword types are saved to the airbag_display.bin file.
  * \param id_list List of fields from file or database from which IDs are taken
  * \param num_indices Count of indices of fields from which IDs are taken
  * \param field_indices Indices of fields from which IDs are taken
  * \param man_types Groups of referred entites to which they belong
  * \param kw_types Keyword types of referred entites to which they belong
  * \imp_obj ImportObject pointer to which the list is saved
  */
void addIDToRefFile
     (
        char         **id_list,
        unsigned int & num_indices,
        unsigned int *field_indices,
        unsigned int *man_types,
        unsigned int *kw_types,
        ImportObject *imp_obj
     );

/** Function to validate a material for given section type. If material matches
  * with section, then returns true else false.
  * \param mat_type Type of material
  * \param sec_type Type of section
  * \return Returns true if matched else false
  */
bool validateMaterialForSectionType
     (
        int mat_type, 
        int sec_type
     );

/** Function to decide which type of set is referred in *AIRBAG cards
  * \param field_list List of fields from file or database
  * \param man_type Not required
  * \param id_index Index of field from which set type can be decided
  * \param imp_obj Not used
  */
void airbagFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *
     );

/** Function to decide which type of set is referred in *AIRBAG cards
  * \param field_list List of fields from file or database
  * \param man_type Not required 
  * \param id_index Index of field from which set type can be decided
  * \param imp_obj Not used
  */
void airbagVentHoleFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *
     );

/** Function to decide which type of set is referred in *ALE cards
  * \param field_list List of fields from file or database
  * \param man_type Not used 
  * \param id_index Index of field from which set type can be decided
  * \param imp_obj Not used
  */
void aleFsiFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *
     );

/** Function to decide which type of object is referred in *AIRBAG_ALE cards. The
  * type can be *NODE or *PART.
  * \param field_list List of fields from file or database
  * \param man_type Not used 
  * \param id_index Index of field from which set type can be decided
  * \param imp_obj Not used
  */
void airbagAdvancedAle
     (
        char         **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *
     );

/** Function to decide which type of object is referred in *ALE cards.
  * \param field_list List of fields from file or database
  * \param man_type Not used 
  * \param id_index Index of field from which set type can be decided
  * \param imp_obj Not used
  */
void aleRefGroupFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *
     );

void aleUpSwitchFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *
     );

void bemAcousticFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *
     );

void bdrySphFlowFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *
     );

void bdryPresMotionFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *imp_obj
     );

void bdrySpcFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *imp_obj
     );

void bdryTempFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *imp_obj
     );

void bdryThermalFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *imp_obj
     );

void constExtraNodes
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *imp_obj
     );

void constJointFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *
     );

void contact2dAutoFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *
     );

void contactFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *
     );

void contactCouplingFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *
     );

void contactEntityFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *
     );

void contactGebodFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *
     );

void contactGuidedFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *imp_obj
     );

void controlCurveFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *imp_obj
     );

void controlTemplateFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *
     );

void controlUserFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *
     );

void controlGeneralFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *
     );

void databaseCSFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *
     );

void databaseCSSetFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *imp_obj
     );

void databaseHistoryLocalFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *imp_obj
     );

void databaseHistoryIDFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *imp_obj
     );

void databaseHistoryFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *imp_obj
     );

void databaseFsiFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *imp_obj
     );

void defineAleBagFind
     (
        char **field_list,
        unsigned int & num_fields,
        unsigned int id_index,
        ImportObject *imp_obj
     );

void defineDTimesFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *imp_obj
     );

void defineDrawbeadFind
     (
        char **field_list,
        unsigned int & num_fields,
        unsigned int id_index,
        ImportObject *imp_obj
     );

void defineAdaptiveFind
     (
        char **field_list,
        unsigned int & num_fields,
        unsigned int id_index,
        ImportObject *
     );

void sbRetractorFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *imp_obj
     );

void sbPretenFind
     (
        char **field_list,
        unsigned int & num_fields,
        unsigned int id_index,
        ImportObject *imp_obj
     );

void sbSlipringFind
     (
        char **field_list,
        unsigned int & num_fields,
        unsigned int id_index,
        ImportObject *imp_obj
     );

void elementMassFind
     (
        char **field_list,
        unsigned int & num_fields,
        unsigned int id_index,
        ImportObject *imp_obj
     );

void initialGasFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *
     );

void initialTempFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *imp_obj
     );

void initialShellFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *imp_obj
     );

void initialVelGenFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *
     );

void initialVelocityFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *
     );

void initialPartFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *imp_obj
     );

void interfaceNodeFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *imp_obj
     );

void interfaceLinkFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *imp_obj
     );

void loadBeamFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *imp_obj
     );

void loadHeatGenFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *imp_obj
     );

void loadMovingPressureFind
     (
        char **field_list,
        unsigned int & num_fields,
        unsigned int id_index,
        ImportObject *
     );

void loadShellFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *imp_obj
     );

void loadNodeFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *imp_obj
     );

void sectionIntegrationFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *imp_obj
     );

void sensorElementFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *
     );

void sensorControlFind
     (
        char **field_list,
        unsigned int & ,
        unsigned int id_index,
        ImportObject *
     );

void sensorForceFind
     (
        char **field_list,
        unsigned int & num_fields,
        unsigned int id_index,
        ImportObject *imp_obj
     );

void setNodeAddFind
     (
        char **field_list,
        unsigned int & num_fields,
        unsigned int id_index,
        ImportObject *imp_obj
     );

void setGenFind
     (
        char **field_list,
        unsigned int & num_fields,
        unsigned int id_index,
        ImportObject *imp_obj
     );

void saveShellElements
     (
        char **field_list,
        unsigned int & num_fields,
        unsigned int id_index,
        ImportObject *imp_obj
     );

void saveSolidElements
     (
        char **field_list,
        unsigned int & num_fields,
        unsigned int id_index,
        ImportObject *imp_obj
     );

void saveSolidElements971
     (
        char **field_list,
        unsigned int & num_fields,
        unsigned int id_index,
        ImportObject *imp_obj
     );

void saveTShells
     (
        char **field_list,
        unsigned int &,
        unsigned int ,
        ImportObject *
     );

void saveDiscretes
     (
        char **field_list,
        unsigned int &,
        unsigned int ,
        ImportObject *
     );

void saveBeams
     (
        char **field_list,
        unsigned int &,
        unsigned int ,
        ImportObject *
     );

void saveSBAccelerometers
     (
        char **field_list,
        unsigned int &,
        unsigned int ,
        ImportObject *
     );

void saveSeatbelts
     (
        char **field_list,
        unsigned int &,
        unsigned int ,
        ImportObject *imp_obj
     );

void saveElementIDs(char **field_list, ImportObject *imp_obj);

#endif

