#ifndef _IMPORT_BASE_H_
#define _IMPORT_BASE_H_

#include "dataline.h"
#include "card.h"

/** Base class for all import classes to import LSDYNA keywords from a 
  * native file
  */
class ImportBase
{
public:
   /** Constructor to create this object
     * \param data_line DataLine object pointer to access the file data
     * \param imp_obj ImportObject pointer to save data that is imported
     */
   ImportBase(DataLine *data_line, ImportObject *imp_obj)
   {
      dataLine = data_line;
      impObj = imp_obj;
      numFields = 0;
      strBuff = NULL;
      wordArray = NULL;
      dblArray = NULL;
      cardObj = NULL;
   }

   /** Constructor to release memory in this object */
   virtual ~ImportBase()
   {
      dataLine = NULL;
      impObj = NULL;
      numFields = 0;
      strBuff = NULL;
      wordArray = NULL;
      dblArray = NULL;
      cardObj = NULL;
   }

public:
   /** Number of fields in a card */
   unsigned int   numFields;
   /** Each line of data from the data file */
   char           *strBuff;
   /** Each line of data splitted into words and stored here as a pointer */
   char           **wordArray;
   /** Each line of data splitted into words and stored here as a pointer to
     * array of doubles */
   double         *dblArray;
   /** Object to store data read from file */
   ImportObject   *impObj;
   /** Object to read each line of data from file */
   DataLine       *dataLine;
   /** Card object that represents a line of data or a card in a keyword */
   Card           *cardObj;
};

#endif

