#ifndef _Hg_IMPORT_H_
#define _Hg_IMPORT_H_

#include <string>
#include <map>
#include "dataloc.h"
#include "hgmanager.h"
#include "dataline.h"
#include "card.h"
#include "hgtype.h"
#include "typemap.h"

/** Class to import the data from native LSDYNA file for *HOURGLASS keywords. All
  * the data is imported through this class and stored in the manager object.
  */
class HgImport
{
public:
   /** Constructor for creating this object
     * \param fp File pointer to the LSDYNA native file
     * \param data_loc Pointer to the list of keywords and their locations in
     * the file
     * \param hg_man Manager pointer to hold the imported data as a list of
     * ImportObject list
     */
   HgImport
   (
      FILE          *fp,
      DataLoc       *data_loc,
      HgManager    *hg_man
   );

   ~HgImport()
   {
      filePtr = NULL;
      hgManPtr = NULL;
      dataLocPtr = NULL;
      delete dataLine;
   }

   /** Reads the *HOURGLASS keywords from file
     * \return Returns 0 on failure else number of *HOURGLASS keywords
     */
   unsigned int readHgs();

private:
   FILE          *filePtr;
   /** Manager pointer for holding the imported data for all the keywords */
   HgManager    *hgManPtr;
   /** Pointer to keywords and their locations in the file */
   DataLoc       *dataLocPtr;
   /** Pointer to access the file data line by line */
   DataLine      *dataLine;
   /** Object to store imported data from LSDYNA data file */
   ImportObject  *impObj;
   /** A map between the keyword type and pointer to function */
   map<unsigned int, ImportFunctionPtr>  typeFuncMap;
};

#endif

