#ifndef _IncludeNastran_h_
#define _IncludeNastran_h_

#include "manager.h"
#include "dispexport.h"
#include "include.h"

/** This class is used for importing *INCLUDE_NASTRAN keyword
  * from LSDYNA native file */

class IncludeNastran : public Include
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   IncludeNastran(DataLine *data_line, ImportObject *imp_obj) : Include (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~IncludeNastran()
   {
   }

public:
/** Function to import Card2 details for *INCLUDE_NASTRAN
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"BEAMDF","SHELLDF","SOLIDDF",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, };
      numFields = 3;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *INCLUDE_NASTRAN
  * from LSDYNA native file */
   unsigned int importIncludeNastran()
   {
      importInclude();
      readCard2();
      return 0;
   }
};

#endif

