#ifndef _IncludeStampedPart_h_
#define _IncludeStampedPart_h_

#include "manager.h"
#include "dispexport.h"
#include "include.h"

/** This class is used for importing *INCLUDE_STAMPED_PART_SET keyword
  * from LSDYNA native file */

class IncludeStampedPart : public Include
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   IncludeStampedPart(DataLine *data_line, ImportObject *imp_obj) : Include (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~IncludeStampedPart()
   {
   }

public:
/** Function to import Card2 details for *INCLUDE_STAMPED_PART_SET
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"PID","THICK","PSTRN","STRAIN","STRESS","INCOUT","RMAX",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {PARTC, };
      unsigned int kw_types[] = {9999, };
      unsigned int num_indices = 1;
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3 details for *INCLUDE_STAMPED_PART_SET
  * keyword from file */
   void readCard3()
   {
      const char *fields[] = {"N1S","N2S","N3S","N1C","N2C","N3C","TENSOR",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, 3, 4, 5, };
      unsigned int man_types[] = {NOD, NOD, NOD, NOD, NOD, NOD, };
      unsigned int kw_types[] = {9999, 9999, 9999, 9999, 9999, 9999, };
      unsigned int num_indices = 6;
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card4 details for *INCLUDE_STAMPED_PART_SET
  * keyword from file */
   void readCard4()
   {
      const char *fields[] = {"ISYM","IAFTER",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, };
      numFields = 2;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card4");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card5 details for *INCLUDE_STAMPED_PART_SET
  * keyword from file */
   void readCard5()
   {
      const char *fields[] = {"X01","Y01","Z01",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 3;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card5");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card6 details for *INCLUDE_STAMPED_PART_SET
  * keyword from file */
   void readCard6()
   {
      const char *fields[] = {"X02","Y02","Z02","X03","Y03","Z03",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card6");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *INCLUDE_STAMPED_PART_SET
  * from LSDYNA native file */
   unsigned int importIncludeStampedPart()
   {
      importInclude();
      readCard2();
      readCard3();
      readCard4();
      readCard5();
      readCard6();
      return 0;
   }
};

#endif

