#ifndef _IncludeTransform_h_
#define _IncludeTransform_h_

#include "manager.h"
#include "dispexport.h"
#include "include.h"

/** This class is used for importing *INCLUDE_TRANSFORM keyword
  * from LSDYNA native file */

class IncludeTransform : public Include
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   IncludeTransform(DataLine *data_line, ImportObject *imp_obj) : Include (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~IncludeTransform()
   {
   }

public:
/** Function to import Card2 details for *INCLUDE_TRANSFORM
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"IDNOFF","IDEOFF","IDPOFF","IDMOFF","IDSOFF","IDFOFF","IDDOFF",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3 details for *INCLUDE_TRANSFORM
  * keyword from file */
   void readCard3()
   {
      const char *fields[] = {"IDROFF",};
      unsigned int field_types[] = {DATA_INT, };
      numFields = 1;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card4 details for *INCLUDE_TRANSFORM
  * keyword from file */
   void readCard4()
   {
      const char *fields[] = {"FCTMAS","FCTTIM","FCTLEN","FCTTEM","INCOUT1",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_CHAR_ARRAY, DATA_INT, };
      numFields = 5;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card4");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card5 details for *INCLUDE_TRANSFORM
  * keyword from file */
   void readCard5()
   {
      const char *fields[] = {"TRANID",};
      unsigned int field_types[] = {DATA_INT, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {DEFINE, };
      unsigned int kw_types[] = {TRANS, };
      unsigned int num_indices = 1;
      numFields = 1;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card5");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *INCLUDE_TRANSFORM
  * from LSDYNA native file */
   unsigned int importIncludeTransform()
   {
      importInclude();
      readCard2();
      readCard3();
      readCard4();
      readCard5();
      return 0;
   }
};

#endif

