#include <iostream>
#include <algorithm>
#include "generic.h"
#include "includetype.h"
#include "includeimport.h"
#include <stdlib.h>

using namespace std;

IncludeImport::IncludeImport
(
   FILE          *fp,
   DataLoc       *data_loc,
   IncludeManager    *include_man
)
{
   filePtr = fp;
   includeManPtr = include_man;
   dataLocPtr = data_loc;
   dataLine = NULL;

   initCompensateTypesAndFunctions();
   initIncludeTypesAndFunctions();
}

IncludeType IncludeImport::getIncludeTypeFromKeyword
	(
	   const char  *key_word,
	   unsigned int *include_id
	)
{
   *include_id = 0;

   if( strstr(key_word, "ER_SP") )
      return INCLUDE_COMPENSATION_BLANK_AFTER_SPRINGBACK;
   else if( strstr(key_word, "RE_SP") )
      return INCLUDE_COMPENSATION_BLANK_BEFORE_SPRINGBACK;
   else if( strstr(key_word, "ED_SH") )
      return INCLUDE_COMPENSATION_COMPENSATED_SHAPE;
   else if( strstr(key_word, "NT_TO") )
      return INCLUDE_COMPENSATION_CURRENT_TOOLS;
   else if( strstr(key_word, "NK_SH") )
      return INCLUDE_COMPENSATION_DESIRED_BLANK_SHAPE;
   else if( strstr(key_word, "DE_BI") )
      return INCLUDE_BINARY;
   else if( strstr(key_word, "DE_NA") )
      return INCLUDE_NASTRAN;
   else if( strstr(key_word, "DE_PA") )
      return INCLUDE_PATH;
   else if( strstr(key_word, "RT_IN") )
      return INCLUDE_STAMPED_PART_INVERSE;
   else if( strstr(key_word, "RT_MA") )
      return INCLUDE_STAMPED_PART_MATRIX;
   else if( strstr(key_word, "RT_SE") )
      return INCLUDE_STAMPED_PART_SET;
   else if( strstr(key_word, "ED_SE") )
      return INCLUDE_STAMPED_SET;
   else if( strstr(key_word, "RM_BI") )
      return INCLUDE_TRANSFORM_BINARY;
   else if( strstr(key_word, "DE_TR") )
      return INCLUDE_TRANSFORM;
   else if( strstr(key_word, "INC") )
      return INCLUDE;

   return INCLUDE_NEW_TYPE;
}

unsigned int IncludeImport::readIncludes()
{
   char         new_kw[LINE_LEN];
   unsigned int	i = 0, include_id = 0, include_type = 0, num_includes = 0;
   long		loc = 0L;
   VStringIterator   s = dataLocPtr->keywordList.begin(),
		     e = dataLocPtr->keywordList.end(), itr, 
		     pitr = dataLocPtr->keywordList.begin();
   typeFuncIterator  btype_iter = typeFuncMap.begin(),
                     etype_iter = typeFuncMap.end(), type_iter;

   dataLine = new DataLine(filePtr);

   while(true)
   {
      itr = find_if(pitr, e, bind2nd(KeyWordCompare (), "*INCL"));

      if( itr == e )
	 break;

      pitr = itr+1;
      i = (unsigned int)(itr - s);
      loc = dataLocPtr->slocList[i];

      rewind(filePtr);

      if( fseek(filePtr, loc, SEEK_SET) )
      {
	 cout << "ERROR in locating the Include cards" << endl;
	 break;
      }

      dataLine->clearFlag(KW_READ_END);

      char *str = dataLine->readNextCard(); //get the keyword
      Generic::RemoveLeadingAndTrailingBlanks( str );
cout << "KW = " << str << endl;

      include_type = getIncludeTypeFromKeyword( str, &include_id );
cout << "Include TYPE = " << include_type << endl;

      if( include_type == INCLUDE_NEW_TYPE )
      {
         cout << "Include TYPE NOT SUPPORTED" << endl;
         continue;
      }

      num_includes++;

      strcpy(new_kw, str);

      dataLine->clearFlag(KW_READ_END);
      type_iter = typeFuncMap.find(include_type);
      if( type_iter != etype_iter )
      {
          impObj = new ImportObject(str, include_type);
          (type_iter->second)(dataLine, impObj);
          if( include_id )
          {
             includeManPtr->add(new_kw, impObj);
          }
          else
          {
             sprintf(new_kw, "%s_%d", new_kw, num_includes);
             includeManPtr->add(new_kw, impObj);
          }
      }
      else
         cout << "Include TYPE NOT FOUND" << endl;
   }

   return num_includes;
}

