#ifndef _Include_IMPORT_H_
#define _Include_IMPORT_H_

#include <string>
#include <map>
#include "dataloc.h"
#include "includemanager.h"
#include "dataline.h"
#include "card.h"
#include "includetype.h"
#include "typemap.h"

/** Class to import the data from native LSDYNA file for *INCLUDE keywords. All
  * the data is imported through this class and stored in the manager object.
  */
class IncludeImport
{
public:
   /** Constructor for creating this object
     * \param fp File pointer to the LSDYNA native file
     * \param data_loc Pointer to the list of keywords and their locations in
     * the file
     * \param include_man Manager pointer to hold the imported data as a list of
     * ImportObject list
     */
   IncludeImport
   (
      FILE          *fp,
      DataLoc       *data_loc,
      IncludeManager    *include_man
   );

   ~IncludeImport()
   {
      filePtr = NULL;
      includeManPtr = NULL;
      dataLocPtr = NULL;
      delete dataLine;
   }

   /** Function for getting the keyword type from given keyword name from LSDYNA
     * native file. The type is stored in the database
     * \param key_word Name of the keyword from file
     * \param include_id ID if exists along with the keyword
     * \return Type for *INCLUDE group of keywords
     */
   static IncludeType getIncludeTypeFromKeyword
	   (
	      const char  *key_word,
	      unsigned int *include_id
	   );

   /** Reads the *INCLUDE keywords from file
     * \return Returns 0 on failure else number of *INCLUDE keywords
     */
   unsigned int readIncludes();

   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *INCLUDE keyword there is a function to call
     */
   void initCompensateTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *INCLUDE keyword there is a function to call
     */
   void initIncludeTypesAndFunctions();

private:
   FILE          *filePtr;
   /** Manager pointer for holding the imported data for all the keywords */
   IncludeManager    *includeManPtr;
   /** Pointer to keywords and their locations in the file */
   DataLoc       *dataLocPtr;
   /** Pointer to access the file data line by line */
   DataLine      *dataLine;
   /** Object to store imported data from LSDYNA data file */
   ImportObject  *impObj;
   /** A map between the keyword type and pointer to function */
   map<unsigned int, ImportFunctionPtr>  typeFuncMap;
};

#endif

