#include <iostream>
#include <algorithm>
#include "generic.h"
#include "initialtype.h"
#include "initialimport.h"
#include <stdlib.h>

using namespace std;

InitialImport::InitialImport
(
   FILE          *fp,
   DataLoc       *data_loc,
   InitialManager    *initial_man
)
{
   filePtr = fp;
   initialManPtr = initial_man;
   dataLocPtr = data_loc;
   dataLine = NULL;

   initSimpleTypesAndFunctions();
   initStrainTypesAndFunctions();
   initStressTypesAndFunctions();
   initVelocityTypesAndFunctions();
   initVolumeTypesAndFunctions();
}

InitialType InitialImport::getInitialTypeFromKeyword
	(
	   const char  *key_word,
	   unsigned int *initial_id
	)
{
   *initial_id = 0;

   if( strstr(key_word, "AL_DE") )
      return INITIAL_DETONATION;
   else if( strstr(key_word, "AS_MI") )
      return INITIAL_GAS_MIXTURE;
   else if( strstr(key_word, "AL_MO") )
      return INITIAL_MOMENTUM;
   else if( strstr(key_word, "LE_KI") )
      return INITIAL_VEHICLE_KINEMATICS;
   else if( strstr(key_word, "CE_GE") )
      return INITIAL_FOAM_REFERENCE_GEOMETRY;
   else if( strstr(key_word, "IN_SH") )
      return INITIAL_STRAIN_SHELL;
   else if( strstr(key_word, "IN_SO") )
      return INITIAL_STRAIN_SOLID;
   else if( strstr(key_word, "RE_NO") )
      return INITIAL_TEMPERATURE_NODE;
   else if( strstr(key_word, "RE_SE") )
      return INITIAL_TEMPERATURE_SET;
   else if( strstr(key_word, "SS_BE") )
      return INITIAL_STRESS_BEAM;
   else if( strstr(key_word, "SS_DE") )
      return INITIAL_STRESS_DEPTH;
   else if( strstr(key_word, "S_SEC") )
      return INITIAL_STRESS_SECTION;
   else if( strstr(key_word, "LL_SE") )
      return INITIAL_STRESS_SHELL_SET;
   else if( strstr(key_word, "S_SHE") )
      return INITIAL_STRESS_SHELL;
   else if( strstr(key_word, "S_SOL") )
      return INITIAL_STRESS_SOLID;
   else if( strstr(key_word, "S_TSH") )
      return INITIAL_STRESS_TSHELL;
   else if( strstr(key_word, "Y_GEN") )
      return INITIAL_VELOCITY_GENERATION;
   else if( strstr(key_word, "Y_NOD") )
      return INITIAL_VELOCITY_NODE;
   else if( strstr(key_word, "D_BOD") )
      return INITIAL_VELOCITY_RIGID_BODY;
   else if( strstr(key_word, "L_VEL") )
      return INITIAL_VELOCITY;
   else if( strstr(key_word, "ID_PA") )
      return INITIAL_VOID_PART;
   else if( strstr(key_word, "ID_SE") )
      return INITIAL_VOID_SET;
   else if( strstr(key_word, "ON_GE") )
      return INITIAL_VOLUME_FRACTION_GEOMETRY;
   else if( strstr(key_word, "ME_FR") )
      return INITIAL_VOLUME_FRACTION;

   return INITIAL_NEW_TYPE;
}

unsigned int InitialImport::readInitials()
{
   char         new_kw[LINE_LEN];
   unsigned int	i = 0, initial_id = 0, initial_type = 0, num_initials = 0;
   long		loc = 0L;
   VStringIterator   s = dataLocPtr->keywordList.begin(),
		     e = dataLocPtr->keywordList.end(), itr, 
		     pitr = dataLocPtr->keywordList.begin();
   typeFuncIterator  btype_iter = typeFuncMap.begin(),
                     etype_iter = typeFuncMap.end(), type_iter;

   dataLine = new DataLine(filePtr);

   while(true)
   {
      itr = find_if(pitr, e, bind2nd(KeyWordCompare (), "*INIT"));

      if( itr == e )
	 break;

      pitr = itr+1;
      i = (unsigned int)(itr - s);
      loc = dataLocPtr->slocList[i];

      rewind(filePtr);

      if( fseek(filePtr, loc, SEEK_SET) )
      {
	 cout << "ERROR in locating the Initial cards" << endl;
	 break;
      }

      dataLine->clearFlag(KW_READ_END);

      char *str = dataLine->readNextCard(); //get the keyword
      Generic::RemoveLeadingAndTrailingBlanks( str );
cout << "KW = " << str << endl;

      initial_type = getInitialTypeFromKeyword( str, &initial_id );
cout << "Initial TYPE = " << initial_type << endl;

      if( initial_type == INITIAL_NEW_TYPE )
      {
         cout << "Initial TYPE NOT SUPPORTED" << endl;
         continue;
      }

      num_initials++;

      strcpy(new_kw, str);

      dataLine->clearFlag(KW_READ_END);
      type_iter = typeFuncMap.find(initial_type);
      if( type_iter != etype_iter )
      {
          impObj = new ImportObject(str, initial_type);
          (type_iter->second)(dataLine, impObj);
          if( initial_id )
          {
             initialManPtr->add(new_kw, impObj);
          }
          else
          {
             sprintf(new_kw, "%s_%d", new_kw, num_initials);
             initialManPtr->add(new_kw, impObj);
          }
      }
      else
         cout << "Initial TYPE NOT FOUND" << endl;
   }

   return num_initials;
}

