#ifndef _Initial_IMPORT_H_
#define _Initial_IMPORT_H_

#include <string>
#include <map>
#include "dataloc.h"
#include "initialmanager.h"
#include "dataline.h"
#include "card.h"
#include "initialtype.h"
#include "typemap.h"

/** Class to import the data from native LSDYNA file for *INITIAL keywords. All
  * the data is imported through this class and stored in the manager object.
  */
class InitialImport
{
public:
   /** Constructor for creating this object
     * \param fp File pointer to the LSDYNA native file
     * \param data_loc Pointer to the list of keywords and their locations in
     * the file
     * \param initial_man Manager pointer to hold the imported data as a list of
     * ImportObject list
     */
   InitialImport
   (
      FILE          *fp,
      DataLoc       *data_loc,
      InitialManager    *initial_man
   );

   ~InitialImport()
   {
      filePtr = NULL;
      initialManPtr = NULL;
      dataLocPtr = NULL;
      delete dataLine;
   }

   /** Function for getting the keyword type from given keyword name from LSDYNA
     * native file. The type is stored in the database
     * \param key_word Name of the keyword from file
     * \param initial_id ID if exists along with the keyword
     * \return Type for *INITIAL group of keywords
     */
   static InitialType getInitialTypeFromKeyword
	   (
	      const char  *key_word,
	      unsigned int *initial_id
	   );

   /** Reads the *INITIAL keywords from file
     * \return Returns 0 on failure else number of *INITIAL keywords
     */
   unsigned int readInitials();

   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *INITIAL keyword there is a function to call
     */
   void initSimpleTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *INITIAL keyword there is a function to call
     */
   void initStrainTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *INITIAL keyword there is a function to call
     */
   void initStressTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *INITIAL keyword there is a function to call
     */
   void initVelocityTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *INITIAL keyword there is a function to call
     */
   void initVolumeTypesAndFunctions();

private:
   FILE          *filePtr;
   /** Manager pointer for holding the imported data for all the keywords */
   InitialManager    *initialManPtr;
   /** Pointer to keywords and their locations in the file */
   DataLoc       *dataLocPtr;
   /** Pointer to access the file data line by line */
   DataLine      *dataLine;
   /** Object to store imported data from LSDYNA data file */
   ImportObject  *impObj;
   /** A map between the keyword type and pointer to function */
   map<unsigned int, ImportFunctionPtr>  typeFuncMap;
};

#endif

