#ifndef _InitialDetonation_h_
#define _InitialDetonation_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *INITIAL_DETONATION keyword
  * from LSDYNA native file */

class InitialDetonation : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   InitialDetonation(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~InitialDetonation()
   {
   }

public:
/** Function to import Card1 details for *INITIAL_DETONATION
  * keyword from file */
   int readCard1()
   {
      const char *fields[] = {"PID","X","Y","Z","LT",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {PARTC, };
      unsigned int kw_types[] = {9999, };
      unsigned int num_indices = 1;
      numFields = 5;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return 0;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
      if( wordArray[0] )
         return atoi(wordArray[0]);
      else
         return 0;
   }

/** Function to import Card2 details for *INITIAL_DETONATION
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"PEAK","DECAY","XS","YS","ZS","NID",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, };
      unsigned int field_indices[] = {5, };
      unsigned int man_types[] = {NOD, };
      unsigned int kw_types[] = {9999, };
      unsigned int num_indices = 1;
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *INITIAL_DETONATION
  * from LSDYNA native file */
   unsigned int importInitialDetonation()
   {
      int pid = 0;
      pid = readCard1();
      if( pid == -1 )
      {
         readCard2();
      }
      return 0;
   }
};

#endif

