#ifndef _InitialVehicleKinematics_h_
#define _InitialVehicleKinematics_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *INITIAL_VEHICLE_KINEMATICS keyword
  * from LSDYNA native file */

class InitialVehicleKinematics : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   InitialVehicleKinematics(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~InitialVehicleKinematics()
   {
   }

public:
/** Function to import Card1 details for *INITIAL_VEHICLE_KINEMATICS
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"GRAV","PSID","XO","YO","ZO","XF","YF","ZF",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {1, };
      unsigned int man_types[] = {SET, };
      unsigned int kw_types[] = {PARTC, };
      unsigned int num_indices = 1;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *INITIAL_VEHICLE_KINEMATICS
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"VX","VY","VZ","AAXIS","BAXIS","CAXIS",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3 details for *INITIAL_VEHICLE_KINEMATICS
  * keyword from file */
   void readCard3()
   {
      const char *fields[] = {"AANG","BANG","CANG","WA","WB","WC",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *INITIAL_VEHICLE_KINEMATICS
  * from LSDYNA native file */
   unsigned int importInitialVehicleKinematics()
   {
      readCard1();
      readCard2();
      readCard3();
      return 0;
   }
};

#endif

