#ifndef _InitialFoamReferenceGeometry_h_
#define _InitialFoamReferenceGeometry_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *INITIAL_FOAM_REFERENCE_GEOMETRY keyword
  * from LSDYNA native file */

class InitialFoamReferenceGeometry : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   InitialFoamReferenceGeometry(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~InitialFoamReferenceGeometry()
   {
   }

public:
/** Function to import Card1 details for *INITIAL_FOAM_REFERENCE_GEOMETRY
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"NID","X","Y","Z",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {NOD, };
      unsigned int kw_types[] = {9999, };
      unsigned int num_indices = 1;
      numFields = 4;
      unsigned int field_widths[] = {8, 16, 16, 16, };
      strBuff = dataLine->readNextCard(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, field_widths, fields, strBuff);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *INITIAL_FOAM_REFERENCE_GEOMETRY
  * from LSDYNA native file */
   unsigned int importInitialFoamReferenceGeometry()
   {
      readCard1();
      return 0;
   }
};

#endif

