#ifndef _InitialTemperatureNode_h_
#define _InitialTemperatureNode_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *INITIAL_TEMPERATURE_NODE keyword
  * from LSDYNA native file */

class InitialTemperatureNode : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   InitialTemperatureNode(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~InitialTemperatureNode()
   {
   }

public:
/** Function to import Card1 details for *INITIAL_TEMPERATURE_NODE
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"NSID/NID","TEMP","LOC",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, };
      numFields = 3;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         initialTempFind(wordArray, numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *INITIAL_TEMPERATURE_NODE
  * from LSDYNA native file */
   unsigned int importInitialTemperatureNode()
   {
      readCard1();
      return 0;
   }
};

#endif

