#ifndef _InitialStressBeam_h_
#define _InitialStressBeam_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *INITIAL_STRESS_BEAM keyword
  * from LSDYNA native file */

class InitialStressBeam : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   InitialStressBeam(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~InitialStressBeam()
   {
   }

public:
/** Function to import Card1 details for *INITIAL_STRESS_BEAM
  * keyword from file */
   int readCard1()
   {
      const char *fields[] = {"EID","RULE","NPTS","LOCAL",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {ELEMENT, };
      unsigned int kw_types[] = {BEAM, };
      unsigned int num_indices = 1;
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return 0;
      npts = 0;
      if( wordArray[2] )
         npts = atoi(wordArray[2]);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
      if( wordArray[2] )
         return atoi(wordArray[2]);
      else
         return 0;
   }

/** Function to import Card2 details for *INITIAL_STRESS_BEAM
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"SIG11","SIG22","SIG33","SIG12","SIG23","SIG31","EPS",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 7;
      unsigned int i, end_loop;
      end_loop = npts;
      for(i = 0; i < end_loop; i++)
      {
         numFields = 7;
         wordArray = dataLine->readNextCardAsWords(numFields);
         if( !numFields && dataLine->isFlagOn(KW_READ_END) ) return;

         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
         {
            cardObj = new Card("Card2");
            cardObj->addFields(numFields, field_types, fields, wordArray);
            impObj->addCard(cardObj);
         }
      }
   }

/** Function to import all the cards of the keyword *INITIAL_STRESS_BEAM
  * from LSDYNA native file */
   unsigned int importInitialStressBeam()
   {
      int npts = 0;
      npts = readCard1();
      if( npts )
      {
         readCard2();
      }
      return 0;
   }
public:
   int npts;
};

#endif

