#ifndef _InitialStressSection_h_
#define _InitialStressSection_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *INITIAL_STRESS_SECTION keyword
  * from LSDYNA native file */

class InitialStressSection : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   InitialStressSection(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~InitialStressSection()
   {
   }

public:
/** Function to import Card1 details for *INITIAL_STRESS_SECTION
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"ISSID","CSID","LCID","PSID","VID",};
      unsigned int field_types[] = {DATA_INT, DATA_CHAR_ARRAY, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {1, 2, 3, 4, };
      unsigned int man_types[] = {DATABASE, DEFINE, SET, DEFINE, };
      unsigned int kw_types[] = {9999, CURVE, PARTC, VECTOR, };
      unsigned int num_indices = 4;
      numFields = 5;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, DEFINE, impObj);

      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *INITIAL_STRESS_SECTION
  * from LSDYNA native file */
   unsigned int importInitialStressSection()
   {
      readCard1();
      return 0;
   }
};

#endif

