#ifndef _InitialStressShell_h_
#define _InitialStressShell_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *INITIAL_STRESS_SHELL keyword
  * from LSDYNA native file */

class InitialStressShell : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   InitialStressShell(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~InitialStressShell()
   {
   }

public:
/** Function to import Card1 details for *INITIAL_STRESS_SHELL
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"EID/SID","NPLANE","NTHICK","NHISV","NTENSR",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 5;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      nplane = 0;
      if( wordArray[1] )
         nplane = atoi(wordArray[1]);
      nthick = 0;
      if( wordArray[2] )
         nthick = atoi(wordArray[2]);
      nhisv = 0;
      if( wordArray[3] )
         nhisv = atoi(wordArray[3]);
      ntensr = 0;
      if( wordArray[4] )
         ntensr = atoi(wordArray[4]);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         initialShellFind(wordArray, numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *INITIAL_STRESS_SHELL
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"T","SIGXX","SIGYY","SIGZZ","SIGXY","SIGYZ","SIGZX","EPS",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3 details for *INITIAL_STRESS_SHELL
  * keyword from file */
   void readCard3()
   {
      const char *fields[] = {"HISV1","HISV2","HISV3","HISV4","HISV5","HISV6","HISV7","HISV8",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int i, end_loop;
      end_loop = ((nhisv%8) ? (nhisv/8)+1 : nhisv/8);
      for(i = 0; i < end_loop; i++)
      {
         numFields = 8;
         wordArray = dataLine->readNextCardAsWords(numFields);
         if( !numFields && dataLine->isFlagOn(KW_READ_END) ) return;

         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
         {
            cardObj = new Card("Card3");
            cardObj->addFields(numFields, field_types, fields, wordArray);
            impObj->addCard(cardObj);
         }
      }
   }

/** Function to import Card4 details for *INITIAL_STRESS_SHELL
  * keyword from file */
   void readCard4()
   {
      const char *fields[] = {"TENXX","TENYY","TENZZ","TENXY","TENYZ","TENZX",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      unsigned int i, end_loop;
      end_loop = ((ntensr%6) ? (ntensr/6)+1 : ntensr/6);
      for(i = 0; i < end_loop; i++)
      {
         numFields = 6;
         wordArray = dataLine->readNextCardAsWords(numFields);
         if( !numFields && dataLine->isFlagOn(KW_READ_END) ) return;

         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
         {
            cardObj = new Card("Card4");
            cardObj->addFields(numFields, field_types, fields, wordArray);
            impObj->addCard(cardObj);
         }
      }
   }

/** Function to import all the cards of the keyword *INITIAL_STRESS_SHELL
  * from LSDYNA native file */
   unsigned int importInitialStressShell()
   {
      readCard1();
      for(int i = 0; i < (nplane * nthick); i++)
      {
         readCard2();
         if( nhisv )
         {
            readCard3();
         }
         if( ntensr )
         {
            readCard4();
         }
      }
      return 0;
   }
public:
   int nplane;
   int nthick;
   int nhisv;
   int ntensr;
};

#endif

