#ifndef _InitialStressSolid_h_
#define _InitialStressSolid_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *INITIAL_STRESS_SOLID keyword
  * from LSDYNA native file */

class InitialStressSolid : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   InitialStressSolid(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~InitialStressSolid()
   {
   }

public:
/** Function to import Card1 details for *INITIAL_STRESS_SOLID
  * keyword from file */
   int readCard1()
   {
      const char *fields[] = {"EID","NINT","NHISV","LARGE","IVFLG",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {ELEMENT, };
      unsigned int kw_types[] = {SOLID, };
      unsigned int num_indices = 1;
      numFields = 5;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return 0;
      nint = 0;
      if( wordArray[1] )
         nint = atoi(wordArray[1]);
      nhisv = 0;
      if( wordArray[2] )
         nhisv = atoi(wordArray[2]);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
      if( wordArray[3] )
         return atoi(wordArray[3]);
      else
         return 0;
   }

/** Function to import Card2 details for *INITIAL_STRESS_SOLID
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"SIGXX","SIGYY","SIGZZ","SIGXY","SIGYZ","SIGZX","EPS",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 7;
      unsigned int i, end_loop;
      end_loop = nint;
      for(i = 0; i < end_loop; i++)
      {
         numFields = 7;
         wordArray = dataLine->readNextCardAsWords(numFields);
         if( !numFields && dataLine->isFlagOn(KW_READ_END) ) return;

         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
         {
            cardObj = new Card("Card2");
            cardObj->addFields(numFields, field_types, fields, wordArray);
            impObj->addCard(cardObj);
         }
      }
   }

/** Function to import Card3 details for *INITIAL_STRESS_SOLID
  * keyword from file */
   void readCard3()
   {
      const char *fields[] = {"SIGXX","SIGYY","SIGZZ","SIGXY","SIGYZ",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 5;
      unsigned int field_widths[] = {16, 16, 16, 16, 16, };
      strBuff = dataLine->readNextCard(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3");
         cardObj->addFields(numFields, field_types, field_widths, fields, strBuff);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card4 details for *INITIAL_STRESS_SOLID
  * keyword from file */
   void readCard4()
   {
      const char *fields[] = {"SIGZX","EPS","HISV1","HISV2","HISV3",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 5;
      unsigned int field_widths[] = {16, 16, 16, 16, 16, };
      strBuff = dataLine->readNextCard(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card4");
         cardObj->addFields(numFields, field_types, field_widths, fields, strBuff);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card5 details for *INITIAL_STRESS_SOLID
  * keyword from file */
   void readCard5()
   {
      const char *fields[] = {"HISV4","HISV5","HISV6","HISV7","HISV8",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 5;
      unsigned int i, end_loop;
      end_loop = (((nhisv - 3)%5) ? ((nhisv-3)/5)+1 : (nhisv-3)/5);
      for(i = 0; i < end_loop; i++)
      {
         numFields = 5;
      unsigned int field_widths[] = {16, 16, 16, 16, 16, };
         strBuff = dataLine->readNextCard(numFields);
         if( !numFields && dataLine->isFlagOn(KW_READ_END) ) return;

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card5");
         cardObj->addFields(numFields, field_types, field_widths, fields, strBuff);
         impObj->addCard(cardObj);
      }
      }
   }

/** Function to import all the cards of the keyword *INITIAL_STRESS_SOLID
  * from LSDYNA native file */
   unsigned int importInitialStressSolid()
   {
      int large = 0;
      large = readCard1();
      if( large == 0 )
      {
         readCard2();
      }
      if( large == 1 )
      {
         for(int i = 0; i < nint; i++)
         {
            readCard3();
            readCard4();
            if( nhisv > 3 )
            {
               readCard5();
            }
         }
      }
      return 0;
   }
public:
   int nint;
   int nhisv;
};

#endif

