#ifndef _InitialStressTshell_h_
#define _InitialStressTshell_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *INITIAL_STRESS_TSHELL keyword
  * from LSDYNA native file */

class InitialStressTshell : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   InitialStressTshell(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~InitialStressTshell()
   {
   }

public:
/** Function to import Card1 details for *INITIAL_STRESS_TSHELL
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"EID","NPLANE","NTHICK",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {ELEMENT, };
      unsigned int kw_types[] = {TSHELL, };
      unsigned int num_indices = 1;
      numFields = 3;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      nplane = 0;
      if( wordArray[1] )
         nplane = atoi(wordArray[1]);
      nthick = 0;
      if( wordArray[2] )
         nthick = atoi(wordArray[2]);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *INITIAL_STRESS_TSHELL
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"T","SIGXX","SIGYY","SIGZZ","SIGXY","SIGYZ","SIGZX","EPS",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *INITIAL_STRESS_TSHELL
  * from LSDYNA native file */
   unsigned int importInitialStressTshell()
   {
      readCard1();
      for(int i = 0; i < (nplane * nthick); i++)
      {
         readCard2();
      }
      return 0;
   }
public:
   int nplane;
   int nthick;
};

#endif

