#ifndef _InitialVelocity_h_
#define _InitialVelocity_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *INITIAL_VELOCITY keyword
  * from LSDYNA native file */

class InitialVelocity : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   InitialVelocity(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~InitialVelocity()
   {
   }

public:
/** Function to import Card1 details for *INITIAL_VELOCITY
  * keyword from file */
   int readCard1()
   {
      const char *fields[] = {"NSID","NSIDEX","BOXID","IRIGID",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return 0;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         initialVelocityFind(wordArray, numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
      if( wordArray[1] )
         return atoi(wordArray[1]);
      else
         return 0;
   }

/** Function to import Card2 details for *INITIAL_VELOCITY
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"VX","VY","VZ","VXR","VYR","VZR",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3 details for *INITIAL_VELOCITY
  * keyword from file */
   void readCard3()
   {
      const char *fields[] = {"VXE","VYE","VZE","VXRE","VYRE","VZRE",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *INITIAL_VELOCITY
  * from LSDYNA native file */
   unsigned int importInitialVelocity()
   {
      int nsidex = 0;
      nsidex = readCard1();
      readCard2();
      if( nsidex > 0 )
      {
         readCard3();
      }
      return 0;
   }
};

#endif

