#ifndef _InitialVelocityGeneration_h_
#define _InitialVelocityGeneration_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *INITIAL_VELOCITY_GENERATION keyword
  * from LSDYNA native file */

class InitialVelocityGeneration : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   InitialVelocityGeneration(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~InitialVelocityGeneration()
   {
   }

public:
/** Function to import Card1 details for *INITIAL_VELOCITY_GENERATION
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"ID","STYP","OMEGA","VX","VY","VZ","IVATN",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, };
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         initialVelGenFind(wordArray, numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *INITIAL_VELOCITY_GENERATION
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"XC","YC","ZC","NX","NY","NZ","PHASE",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, };
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *INITIAL_VELOCITY_GENERATION
  * from LSDYNA native file */
   unsigned int importInitialVelocityGeneration()
   {
      readCard1();
      readCard2();
      return 0;
   }
};

#endif

