#ifndef _InitialVolumeFractionGeometry_h_
#define _InitialVolumeFractionGeometry_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *INITIAL_VOLUME_FRACTION_GEOMETRY keyword
  * from LSDYNA native file */

class InitialVolumeFractionGeometry : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   InitialVolumeFractionGeometry(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~InitialVolumeFractionGeometry()
   {
   }

public:
/** Function to import Card1 details for *INITIAL_VOLUME_FRACTION_GEOMETRY
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"FMSID","FMIDTYP","BAMMG","NTRACE",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         initialGasFind(wordArray, numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Carda details for *INITIAL_VOLUME_FRACTION_GEOMETRY
  * keyword from file */
   int readCarda()
   {
      const char *fields[] = {"CONTTYP","FILLOPT","FAMMG",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {2, };
      unsigned int man_types[] = {ALE, };
      unsigned int kw_types[] = {MMG, };
      unsigned int num_indices = 1;
      numFields = 3;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return 0;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Carda");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
      if( wordArray[0] )
         return atoi(wordArray[0]);
      else
         return 0;
   }

/** Function to import Cardb1 details for *INITIAL_VOLUME_FRACTION_GEOMETRY
  * keyword from file */
   void readCardb1()
   {
      const char *fields[] = {"SID","STYPE","NORMDIR","XOFFSET",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, };
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         airbagVentHoleFind(wordArray, numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Cardb1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Cardb2 details for *INITIAL_VOLUME_FRACTION_GEOMETRY
  * keyword from file */
   void readCardb2()
   {
      const char *fields[] = {"SGSID","NORMDIR","XOFFSET",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {SET, };
      unsigned int kw_types[] = {SEGMENT, };
      unsigned int num_indices = 1;
      numFields = 3;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Cardb2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Cardb3 details for *INITIAL_VOLUME_FRACTION_GEOMETRY
  * keyword from file */
   void readCardb3()
   {
      const char *fields[] = {"X0","Y0","Z0","XCOS","YCOS","ZCOS",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Cardb3");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Cardb4 details for *INITIAL_VOLUME_FRACTION_GEOMETRY
  * keyword from file */
   void readCardb4()
   {
      const char *fields[] = {"X0","Y0","Z0","X1","Y1","Z1","R1","R2",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Cardb4");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Cardb5 details for *INITIAL_VOLUME_FRACTION_GEOMETRY
  * keyword from file */
   void readCardb5()
   {
      const char *fields[] = {"X0","Y0","Z0","X1","Y1","Z1",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Cardb5");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Cardb6 details for *INITIAL_VOLUME_FRACTION_GEOMETRY
  * keyword from file */
   void readCardb6()
   {
      const char *fields[] = {"X0","Y0","Z0","R0",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Cardb6");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *INITIAL_VOLUME_FRACTION_GEOMETRY
  * from LSDYNA native file */
   unsigned int importInitialVolumeFractionGeometry()
   {
      int conttyp = 0;
      readCard1();
      conttyp = readCarda();
      if( conttyp == 1 )
      {
         readCardb1();
      }
      else if( conttyp == 2 )
      {
         readCardb2();
      }
      else if( conttyp == 3 )
      {
         readCardb3();
      }
      else if( conttyp == 4 )
      {
         readCardb4();
      }
      else if( conttyp == 5 )
      {
         readCardb5();
      }
      else if( conttyp == 6 )
      {
         readCardb6();
      }
      while(numFields)
      {
         conttyp = readCarda();
         if( conttyp == 1 )
         {
            readCardb1();
         }
         else if( conttyp == 2 )
         {
            readCardb2();
         }
         else if( conttyp == 3 )
         {
            readCardb3();
         }
         else if( conttyp == 4 )
         {
            readCardb4();
         }
         else if( conttyp == 5 )
         {
            readCardb5();
         }
         else if( conttyp == 6 )
         {
            readCardb6();
         }
      }
      return 0;
   }
};

#endif

