#ifndef _IntegrationBeam_h_
#define _IntegrationBeam_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *INTEGRATION_BEAM keyword
  * from LSDYNA native file */

class IntegrationBeam : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   IntegrationBeam(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~IntegrationBeam()
   {
   }

public:
/** Function to import Card1 details for *INTEGRATION_BEAM
  * keyword from file */
   int readCard1()
   {
      const char *fields[] = {"IRID","NIP","RA","ICST","K",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, DATA_INT, DATA_INT, };
      numFields = 5;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return 0;
      nip = 0;
      if( wordArray[1] )
         nip = atoi(wordArray[1]);
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, INTEGRATION, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
      if( wordArray[3] )
         return atoi(wordArray[3]);
      else
         return 0;
   }

/** Function to import Card2 details for *INTEGRATION_BEAM
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"D1","D2","D3","D4","SREF","TREF","D5","D6",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3 details for *INTEGRATION_BEAM
  * keyword from file */
   void readCard3()
   {
      const char *fields[] = {"S","T","WF","PID",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, };
      unsigned int field_indices[] = {3, };
      unsigned int man_types[] = {PARTC, };
      unsigned int kw_types[] = {9999, };
      unsigned int num_indices = 1;
      numFields = 4;
      unsigned int i, end_loop;
      end_loop = nip;
      for(i = 0; i < end_loop; i++)
      {
         numFields = 4;
         wordArray = dataLine->readNextCardAsWords(numFields);
         if( !numFields && dataLine->isFlagOn(KW_READ_END) ) return;

         if( Card::isFlagOn(SAVE_REFERENCES) )
            addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
         {
            cardObj = new Card("Card3");
            cardObj->addFields(numFields, field_types, fields, wordArray);
            impObj->addCard(cardObj);
         }
      }
   }

/** Function to import all the cards of the keyword *INTEGRATION_BEAM
  * from LSDYNA native file */
   unsigned int importIntegrationBeam()
   {
      int icst = 0;
      icst = readCard1();
      if( icst > 0 )
      {
         readCard2();
      }
      readCard3();
      return 0;
   }
public:
   int nip;
};

#endif

