#ifndef _IntegrationShell_h_
#define _IntegrationShell_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *INTEGRATION_SHELL keyword
  * from LSDYNA native file */

class IntegrationShell : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   IntegrationShell(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~IntegrationShell()
   {
   }

public:
/** Function to import Card1 details for *INTEGRATION_SHELL
  * keyword from file */
   int readCard1()
   {
      const char *fields[] = {"IRID","NIP","ESOP","FAILOPT",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return 0;
      nip = 0;
      if( wordArray[1] )
         nip = atoi(wordArray[1]);
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, INTEGRATION, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
      if( wordArray[2] )
         return atoi(wordArray[2]);
      else
         return 0;
   }

/** Function to import Card2 details for *INTEGRATION_SHELL
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"S","WF","PID",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_INT, };
      unsigned int field_indices[] = {2, };
      unsigned int man_types[] = {PARTC, };
      unsigned int kw_types[] = {9999, };
      unsigned int num_indices = 1;
      numFields = 3;
      unsigned int i, end_loop;
      end_loop = nip;
      for(i = 0; i < end_loop; i++)
      {
         numFields = 3;
         wordArray = dataLine->readNextCardAsWords(numFields);
         if( !numFields && dataLine->isFlagOn(KW_READ_END) ) return;

         if( Card::isFlagOn(SAVE_REFERENCES) )
            addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
         {
            cardObj = new Card("Card2");
            cardObj->addFields(numFields, field_types, fields, wordArray);
            impObj->addCard(cardObj);
         }
      }
   }

/** Function to import all the cards of the keyword *INTEGRATION_SHELL
  * from LSDYNA native file */
   unsigned int importIntegrationShell()
   {
      int esop = 0;
      esop = readCard1();
      if( esop == 0 )
      {
         readCard2();
      }
      return 0;
   }
public:
   int nip;
};

#endif

