#include <iostream>
#include <algorithm>
#include "generic.h"
#include "integrationtype.h"
#include "integrationimport.h"
#include <stdlib.h>

using namespace std;

IntegrationImport::IntegrationImport
(
   FILE          *fp,
   DataLoc       *data_loc,
   IntegrationManager    *integration_man
)
{
   filePtr = fp;
   integrationManPtr = integration_man;
   dataLocPtr = data_loc;
   dataLine = NULL;

   initIntegrationTypesAndFunctions();
}

IntegrationType IntegrationImport::getIntegrationTypeFromKeyword
	(
	   const char  *key_word,
	   unsigned int *integration_id
	)
{
   *integration_id = 0;

   if( strstr(key_word, "ON_BE") )
      return INTEGRATION_BEAM;
   else if( strstr(key_word, "ON_SH") )
      return INTEGRATION_SHELL;

   return INTEGRATION_NEW_TYPE;
}

unsigned int IntegrationImport::readIntegrations()
{
   char         new_kw[LINE_LEN];
   unsigned int	i = 0, integration_id = 0, integration_type = 0, num_integrations = 0;
   long		loc = 0L;
   VStringIterator   s = dataLocPtr->keywordList.begin(),
		     e = dataLocPtr->keywordList.end(), itr, 
		     pitr = dataLocPtr->keywordList.begin();
   typeFuncIterator  btype_iter = typeFuncMap.begin(),
                     etype_iter = typeFuncMap.end(), type_iter;

   dataLine = new DataLine(filePtr);

   while(true)
   {
      itr = find_if(pitr, e, bind2nd(KeyWordCompare (), "*INTEG"));

      if( itr == e )
	 break;

      pitr = itr+1;
      i = (unsigned int)(itr - s);
      loc = dataLocPtr->slocList[i];

      rewind(filePtr);

      if( fseek(filePtr, loc, SEEK_SET) )
      {
	 cout << "ERROR in locating the Integration cards" << endl;
	 break;
      }

      dataLine->clearFlag(KW_READ_END);

      char *str = dataLine->readNextCard(); //get the keyword
      Generic::RemoveLeadingAndTrailingBlanks( str );
cout << "KW = " << str << endl;

      integration_type = getIntegrationTypeFromKeyword( str, &integration_id );
cout << "Integration TYPE = " << integration_type << endl;

      if( integration_type == INTEGRATION_NEW_TYPE )
      {
         cout << "Integration TYPE NOT SUPPORTED" << endl;
         continue;
      }

      num_integrations++;

      strcpy(new_kw, str);

      dataLine->clearFlag(KW_READ_END);
      type_iter = typeFuncMap.find(integration_type);
      if( type_iter != etype_iter )
      {
          impObj = new ImportObject(str, integration_type);
          (type_iter->second)(dataLine, impObj);
          if( integration_id )
          {
             integrationManPtr->add(new_kw, impObj);
          }
          else
          {
             sprintf(new_kw, "%s_%d", new_kw, num_integrations);
             integrationManPtr->add(new_kw, impObj);
          }
      }
      else
         cout << "Integration TYPE NOT FOUND" << endl;
   }

   return num_integrations;
}

