#ifndef _Integration_IMPORT_H_
#define _Integration_IMPORT_H_

#include <string>
#include <map>
#include "dataloc.h"
#include "integrationmanager.h"
#include "dataline.h"
#include "card.h"
#include "integrationtype.h"
#include "typemap.h"

/** Class to import the data from native LSDYNA file for *INTEGRATION keywords. 
  * All the data is imported through this class and stored in the manager object.
  */
class IntegrationImport
{
public:
   /** Constructor for creating this object
     * \param fp File pointer to the LSDYNA native file
     * \param data_loc Pointer to the list of keywords and their locations in
     * the file
     * \param integration_man Manager pointer to hold the imported data as a 
     * list of ImportObject list
     */
   IntegrationImport
   (
      FILE          *fp,
      DataLoc       *data_loc,
      IntegrationManager    *integration_man
   );

   ~IntegrationImport()
   {
      filePtr = NULL;
      integrationManPtr = NULL;
      dataLocPtr = NULL;
      delete dataLine;
   }

   /** Function for getting the keyword type from given keyword name from LSDYNA
     * native file. The type is stored in the database
     * \param key_word Name of the keyword from file
     * \param integration_id ID of the keyword if it is there
     * \return Type for *INTEGRATION group of keywords
     */
   static IntegrationType getIntegrationTypeFromKeyword
	   (
	      const char  *key_word,
	      unsigned int *integration_id
	   );

   /** Reads the *INTEGRATION keywords from file
     * \return Returns 0 on failure else number of *INTEGRATION keywords
     */
   unsigned int readIntegrations();

   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *INTEGRATION keyword there is a function to call
     */
   void initIntegrationTypesAndFunctions();

private:
   FILE          *filePtr;
   /** Manager pointer for holding the imported data for all the keywords */
   IntegrationManager    *integrationManPtr;
   /** Pointer to keywords and their locations in the file */
   DataLoc       *dataLocPtr;
   /** Pointer to access the file data line by line */
   DataLine      *dataLine;
   /** Object to store imported data from LSDYNA data file */
   ImportObject  *impObj;
   /** A map between the keyword type and pointer to function */
   map<unsigned int, ImportFunctionPtr>  typeFuncMap;
};

#endif

