#include <iostream>
#include <algorithm>
#include "generic.h"
#include "interfacetype.h"
#include "interfaceimport.h"
#include <stdlib.h>

using namespace std;

InterfaceImport::InterfaceImport
(
   FILE          *fp,
   DataLoc       *data_loc,
   InterfaceManager    *interface_man
)
{
   filePtr = fp;
   interfaceManPtr = interface_man;
   dataLocPtr = data_loc;
   dataLine = NULL;

   initInterfaceTypesAndFunctions();
}

InterfaceType InterfaceImport::getInterfaceTypeFromKeyword
	(
	   const char  *key_word,
	   unsigned int *interface_id
	)
{
   *interface_id = 0;

   if( strstr(key_word, "ON_NE") )
      return INTERFACE_COMPENSATION_NEW;
   else if( strstr(key_word, "NT_NO") )
      return INTERFACE_COMPONENT_NODE;
   else if( strstr(key_word, "NT_SE") )
      return INTERFACE_COMPONENT_SEGMENT;
   else if( strstr(key_word, "_JOY") )
      return INTERFACE_JOY;
   else if( strstr(key_word, "DE_NO") )
      return INTERFACE_LINKING_DISCRETE_NODE_NODE;
   else if( strstr(key_word, "DE_SE") )
      return INTERFACE_LINKING_DISCRETE_NODE_SET;
   else if( strstr(key_word, "NG_ED") )
      return INTERFACE_LINKING_EDGE;
   else if( strstr(key_word, "NG_SE") )
      return INTERFACE_LINKING_SEGMENT;
   else if( strstr(key_word, "NA_NO") )
      return INTERFACE_SPRINGBACK_LSDYNA_NOTHICKNESS;
   else if( strstr(key_word, "NA_TH") )
      return INTERFACE_SPRINGBACK_LSDYNA_THICKNESS;
   else if( strstr(key_word, "AN_NO") )
      return INTERFACE_SPRINGBACK_NASTRAN_NOTHICKNESS;
   else if( strstr(key_word, "AN_TH") )
      return INTERFACE_SPRINGBACK_NASTRAN_THICKNESS;
   else if( strstr(key_word, "SS_NO") )
      return INTERFACE_SPRINGBACK_SEAMLESS_NOTHICKNESS;
   else if( strstr(key_word, "SS_TH") )
      return INTERFACE_SPRINGBACK_SEAMLESS_THICKNESS;

   return INTERFACE_NEW_TYPE;
}

unsigned int InterfaceImport::readInterfaces()
{
   char         new_kw[LINE_LEN];
   unsigned int	i = 0, interface_id = 0, interface_type = 0, num_interfaces = 0;
   long		loc = 0L;
   VStringIterator   s = dataLocPtr->keywordList.begin(),
		     e = dataLocPtr->keywordList.end(), itr, 
		     pitr = dataLocPtr->keywordList.begin();
   typeFuncIterator  btype_iter = typeFuncMap.begin(),
                     etype_iter = typeFuncMap.end(), type_iter;

   dataLine = new DataLine(filePtr);

   while(true)
   {
      itr = find_if(pitr, e, bind2nd(KeyWordCompare (), "*INTERF"));

      if( itr == e )
	 break;

      pitr = itr+1;
      i = (unsigned int)(itr - s);
      loc = dataLocPtr->slocList[i];

      rewind(filePtr);

      if( fseek(filePtr, loc, SEEK_SET) )
      {
	 cout << "ERROR in locating the Interface cards" << endl;
	 break;
      }

      dataLine->clearFlag(KW_READ_END);

      char *str = dataLine->readNextCard(); //get the keyword
      Generic::RemoveLeadingAndTrailingBlanks( str );
cout << "KW = " << str << endl;

      interface_type = getInterfaceTypeFromKeyword( str, &interface_id );
cout << "Interface TYPE = " << interface_type << endl;

      if( interface_type == INTERFACE_NEW_TYPE )
      {
         cout << "Interface TYPE NOT SUPPORTED" << endl;
         continue;
      }

      num_interfaces++;

      strcpy(new_kw, str);

      dataLine->clearFlag(KW_READ_END);
      type_iter = typeFuncMap.find(interface_type);
      if( type_iter != etype_iter )
      {
          impObj = new ImportObject(str, interface_type);
          (type_iter->second)(dataLine, impObj);
          if( interface_id )
          {
             interfaceManPtr->add(new_kw, impObj);
          }
          else
          {
             sprintf(new_kw, "%s_%d", new_kw, num_interfaces);
             interfaceManPtr->add(new_kw, impObj);
          }
      }
      else
         cout << "Interface TYPE NOT FOUND" << endl;
   }

   return num_interfaces;
}

