#ifndef _Interface_IMPORT_H_
#define _Interface_IMPORT_H_

#include <string>
#include <map>
#include "dataloc.h"
#include "interfacemanager.h"
#include "dataline.h"
#include "card.h"
#include "interfacetype.h"
#include "typemap.h"

/** Class to import the data from native LSDYNA file for *INTERFACE keywords. All
  * the data is imported through this class and stored in the manager object.
  */
class InterfaceImport
{
public:
   /** Constructor for creating this object
     * \param fp File pointer to the LSDYNA native file
     * \param data_loc Pointer to the list of keywords and their locations in
     * the file
     * \param interface_man Manager pointer to hold the imported data as a list of
     * ImportObject list
     */
   InterfaceImport
   (
      FILE          *fp,
      DataLoc       *data_loc,
      InterfaceManager    *interface_man
   );

   ~InterfaceImport()
   {
      filePtr = NULL;
      interfaceManPtr = NULL;
      dataLocPtr = NULL;
      delete dataLine;
   }

   /** Function for getting the keyword type from given keyword name from LSDYNA
     * native file. The type is stored in the database
     * \param key_word Name of the keyword from file
     * \param interface_id ID of the keyword if it is there
     * \return Type for *INTERFACE group of keywords
     */
   static InterfaceType getInterfaceTypeFromKeyword
	   (
	      const char  *key_word,
	      unsigned int *interface_id
	   );

   /** Reads the *INTERFACE keywords from file
     * \return Returns 0 on failure else number of *INTERFACE keywords
     */
   unsigned int readInterfaces();

   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *INTERFACE keyword there is a function to call
     */
   void initInterfaceTypesAndFunctions();

private:
   FILE          *filePtr;
   /** Manager pointer for holding the imported data for all the keywords */
   InterfaceManager    *interfaceManPtr;
   /** Pointer to keywords and their locations in the file */
   DataLoc       *dataLocPtr;
   /** Pointer to access the file data line by line */
   DataLine      *dataLine;
   /** Object to store imported data from LSDYNA data file */
   ImportObject  *impObj;
   /** A map between the keyword type and pointer to function */
   map<unsigned int, ImportFunctionPtr>  typeFuncMap;
};

#endif

