#ifndef _KEYWORD_IMPORT_H_
#define _KEYWORD_IMPORT_H_

#include <string>
#include <map>
#include "dataloc.h"
#include "controlmanager.h"
#include "dataline.h"
#include "card.h"
#include "keywordtype.h"
#include "typemap.h"

/** Class to import the data from native LSDYNA file for *KEYWORD keywords. All
  * the data is imported through this class and stored in the manager object.
  */
class KeywordImport
{
public:
   /** Constructor for creating this object
     * \param fp File pointer to the LSDYNA native file
     * \param data_loc Pointer to the list of keywords and their locations in
     * the file
     * \param ctrl_man Manager pointer to hold the imported data as a list of
     * ImportObject list
     */
   KeywordImport
   (
      FILE          *fp,
      DataLoc       *data_loc,
      ControlManager    *ctrl_man
   );

   ~KeywordImport()
   {
      filePtr = NULL;
      controlManPtr = NULL;
      dataLocPtr = NULL;
      delete dataLine;
   }

   /** Function for getting the keyword type from given keyword name from LSDYNA
     * native file. The type is stored in the database
     * \param key_word Name of the keyword from file
     * \return Type for *KEYWORD group of keywords
     */
   static int getTypeFromKeyword
	      (
		 const char *key_word
	      );

   /** Reads the *KEYWORD and *TITLE keywords from file
     * \return Returns 1 always
     */
   unsigned int readKWAndTitle();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *KEYWORD and *TITLE keyword there is a function 
     * to call.
     */
   void initKeywordTypesAndFunctions();

private:
   FILE          *filePtr;
   /** Manager pointer for holding the imported data for all the keywords */
   ControlManager *controlManPtr;
   /** Pointer to keywords and their locations in the file */
   DataLoc       *dataLocPtr;
   /** Pointer to access the file data line by line */
   DataLine      *dataLine;
   /** Object to store imported data from LSDYNA data file */
   ImportObject  *impObj;
   /** A map between the keyword type and pointer to function */
   map<unsigned int, ImportFunctionPtr>  typeFuncMap;
};

#endif

