#ifndef _LoadGravityPart_h_
#define _LoadGravityPart_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *LOAD_GRAVITY_PART keyword
  * from LSDYNA native file */

class LoadGravityPart : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   LoadGravityPart(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~LoadGravityPart()
   {
   }

public:
/** Function to import Card1 details for *LOAD_GRAVITY_PART
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"PID","DOF","LC","ACCEL","LCDR","STGA","STGR",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 2, 4, };
      unsigned int man_types[] = {PARTC, DEFINE, DEFINE, };
      unsigned int kw_types[] = {9999, CURVE, CURVE, };
      unsigned int num_indices = 3;
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *LOAD_GRAVITY_PART
  * from LSDYNA native file */
   unsigned int importLoadGravityPart()
   {
      readCard1();
      return 0;
   }
};

#endif

