#ifndef _LoadBeamElement_h_
#define _LoadBeamElement_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *LOAD_BEAM_ELEMENT keyword
  * from LSDYNA native file */

class LoadBeamElement : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   LoadBeamElement(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~LoadBeamElement()
   {
   }

public:
/** Function to import Card details for *LOAD_BEAM_ELEMENT
  * keyword from file */
   void readCard()
   {
      const char *fields[] = {"EID/ESID","DAL","LCID","SF",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, };
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         loadBeamFind(wordArray, numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *LOAD_BEAM_ELEMENT
  * from LSDYNA native file */
   unsigned int importLoadBeamElement()
   {
      readCard();
      return 0;
   }
};

#endif

