#ifndef _LoadHeatGenerationSet_h_
#define _LoadHeatGenerationSet_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *LOAD_HEAT_GENERATION_SET keyword
  * from LSDYNA native file */

class LoadHeatGenerationSet : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   LoadHeatGenerationSet(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~LoadHeatGenerationSet()
   {
   }

public:
/** Function to import Card details for *LOAD_HEAT_GENERATION_SET
  * keyword from file */
   void readCard()
   {
      const char *fields[] = {"SID","LCID","CMULT","WBLCID","CBLCID","TBLCID",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         loadHeatGenFind(wordArray, numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *LOAD_HEAT_GENERATION_SET
  * from LSDYNA native file */
   unsigned int importLoadHeatGenerationSet()
   {
      readCard();
      return 0;
   }
};

#endif

