#ifndef _LoadMovingPressure_h_
#define _LoadMovingPressure_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *LOAD_MOVING_PRESSURE keyword
  * from LSDYNA native file */

class LoadMovingPressure : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   LoadMovingPressure(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~LoadMovingPressure()
   {
   }

public:
/** Function to import Card1 details for *LOAD_MOVING_PRESSURE
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"LOADID",};
      unsigned int field_types[] = {DATA_INT, };
      numFields = 1;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, LOAD, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Cardn details for *LOAD_MOVING_PRESSURE
  * keyword from file */
   void readCardn()
   {
      const char *fields[] = {"NODE1","NODE2","LCID","CUTOFF","LCIDT",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, 4, };
      unsigned int man_types[] = {NOD, NOD, DEFINE, DEFINE, };
      unsigned int kw_types[] = {9999, 9999, CURVE, CURVE, };
      unsigned int num_indices = 4;
      numFields = 5;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Cardn");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import CardnPlus1 details for *LOAD_MOVING_PRESSURE
  * keyword from file */
   void readCardnPlus1()
   {
      const char *fields[] = {"ID","IDTYPE","NIP",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, };
      numFields = 3;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         loadMovingPressureFind(wordArray, numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("CardnPlus1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *LOAD_MOVING_PRESSURE
  * from LSDYNA native file */
   unsigned int importLoadMovingPressure()
   {
      readCard1();
      readCardn();
      readCardnPlus1();
      return 0;
   }
};

#endif

