#ifndef _LoadRigidBody_h_
#define _LoadRigidBody_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *LOAD_RIGID_BODY keyword
  * from LSDYNA native file */

class LoadRigidBody : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   LoadRigidBody(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~LoadRigidBody()
   {
   }

public:
/** Function to import Card details for *LOAD_RIGID_BODY
  * keyword from file */
   void readCard()
   {
      const char *fields[] = {"PID","DOF","LCID","SF","CID","M1","M2","M3",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 2, 4, 5, 6, 7, };
      unsigned int man_types[] = {PARTC, DEFINE, DEFINE, NOD, NOD, NOD, };
      unsigned int kw_types[] = {9999, CURVE, COORDINATE, 9999, 9999, 9999, };
      unsigned int num_indices = 6;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *LOAD_RIGID_BODY
  * from LSDYNA native file */
   unsigned int importLoadRigidBody()
   {
      readCard();
      return 0;
   }
};

#endif

