#ifndef _LoadSuperplasticForming_h_
#define _LoadSuperplasticForming_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *LOAD_SUPERPLASTIC_FORMING keyword
  * from LSDYNA native file */

class LoadSuperplasticForming : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   LoadSuperplasticForming(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~LoadSuperplasticForming()
   {
   }

public:
/** Function to import Card1 details for *LOAD_SUPERPLASTIC_FORMING
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"LCP1","CSP1","NCP1","LCP2","CSP2","NCP2",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, 1, 3, 4, };
      unsigned int man_types[] = {DEFINE, CONTACT, DEFINE, CONTACT, };
      unsigned int kw_types[] = {CURVE, 9999, CURVE, 9999, };
      unsigned int num_indices = 4;
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *LOAD_SUPERPLASTIC_FORMING
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"ERATE","SCMIN","SCMAX","NCYL",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, };
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *LOAD_SUPERPLASTIC_FORMING
  * from LSDYNA native file */
   unsigned int importLoadSuperplasticForming()
   {
      readCard1();
      readCard2();
      return 0;
   }
};

#endif

