#ifndef _LoadSurfaceStress_h_
#define _LoadSurfaceStress_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *LOAD_SURFACE_STRESS keyword
  * from LSDYNA native file */

class LoadSurfaceStress : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   LoadSurfaceStress(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~LoadSurfaceStress()
   {
   }

public:
/** Function to import Card1 details for *LOAD_SURFACE_STRESS
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"PID/PSID",};
      unsigned int field_types[] = {DATA_INT, };
      numFields = 1;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         initialPartFind(wordArray, numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *LOAD_SURFACE_STRESS
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"LSCID1","LSCID2","LSCID3","LSCID4","LSCID5","LSCID6","LSCID7","LSCID8",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, 3, 4, 5, 6, 7, };
      unsigned int man_types[] = {CONTACT, CONTACT, CONTACT, CONTACT, CONTACT, CONTACT, CONTACT, CONTACT, };
      unsigned int kw_types[] = {9999, 9999, 9999, 9999, 9999, 9999, 9999, 9999, };
      unsigned int num_indices = 8;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3 details for *LOAD_SURFACE_STRESS
  * keyword from file */
   void readCard3()
   {
      const char *fields[] = {"USCID1","USCID2","USCID3","USCID4","USCID5","USCID6","USCID7","USCID8",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, 3, 4, 5, 6, 7, };
      unsigned int man_types[] = {CONTACT, CONTACT, CONTACT, CONTACT, CONTACT, CONTACT, CONTACT, CONTACT, };
      unsigned int kw_types[] = {9999, 9999, 9999, 9999, 9999, 9999, 9999, 9999, };
      unsigned int num_indices = 8;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *LOAD_SURFACE_STRESS
  * from LSDYNA native file */
   unsigned int importLoadSurfaceStress()
   {
      readCard1();
      readCard2();
      readCard3();
      return 0;
   }
};

#endif

