#include <iostream>
#include <algorithm>
#include "generic.h"
#include "loadtype.h"
#include "loadimport.h"
#include <stdlib.h>

using namespace std;

LoadImport::LoadImport
(
   FILE          *fp,
   DataLoc       *data_loc,
   LoadManager    *load_man
)
{
   filePtr = fp;
   loadManPtr = load_man;
   dataLocPtr = data_loc;
   dataLine = NULL;

   initBodyTypesAndFunctions();
   initElementTypesAndFunctions();
   initSegmentTypesAndFunctions();
   initSimpleTypesAndFunctions();
   initThermalTypesAndFunctions();
}

LoadType LoadImport::getLoadTypeFromKeyword
	(
	   const char  *key_word,
	   unsigned int *load_id
	)
{
   *load_id = 0;

   if( strstr(key_word, "VAR") )
   {
      if( strstr(key_word, "NOD") )
	 return LOAD_THERMAL_VARIABLE_NODE;
      else if( strstr(key_word, "SET") )
	 return LOAD_THERMAL_VARIABLE_SHELL_SET;
      else if( strstr(key_word, "SHE") )
	 return LOAD_THERMAL_VARIABLE_SHELL;
      else
	 return LOAD_THERMAL_VARIABLE;
   }
   else if( strstr(key_word, "ZED") )
      return LOAD_BODY_GENERALIZED;
   else if( strstr(key_word, "RTS") )
      return LOAD_BODY_PARTS;
   else if( strstr(key_word, "POR") )
      return LOAD_BODY_POROUS;
   else if( strstr(key_word, "RX") )
      return LOAD_BODY_RX;
   else if( strstr(key_word, "RY") )
      return LOAD_BODY_RY;
   else if( strstr(key_word, "RZ") )
      return LOAD_BODY_RZ;
   else if( strstr(key_word, "_X") )
      return LOAD_BODY_X;
   else if( strstr(key_word, "_Y") )
      return LOAD_BODY_Y;
   else if( strstr(key_word, "_Z") )
      return LOAD_BODY_Z;
   else if( strstr(key_word, "GRA") )
      return LOAD_GRAVITY_PART;
   else if( strstr(key_word, "REM") )
      return LOAD_REMOVE_PART;
   else if( strstr(key_word, "STIF") )
      return LOAD_STIFFEN_PART;
   else if( strstr(key_word, "M_EL") )
      return LOAD_BEAM_ELEMENT;
   else if( strstr(key_word, "M_SE") )
      return LOAD_BEAM_SET;
   else if( strstr(key_word, "N_SE") )
      return LOAD_HEAT_GENERATION_SET;
   else if( strstr(key_word, "N_SO") )
      return LOAD_HEAT_GENERATION_SOLID;
   else if( strstr(key_word, "PRE") )
      return LOAD_MOVING_PRESSURE;
   else if( strstr(key_word, "RIG") )
      return LOAD_RIGID_BODY;
   else if( strstr(key_word, "D_SHE") )
   {
      if( strstr(key_word, "NT_I") )
	 return LOAD_SHELL_ELEMENT_ID;
      else if( strstr(key_word, "LL_E") )
	 return LOAD_SHELL_ELEMENT;
      else if( strstr(key_word, "ET_I") )
	 return LOAD_SHELL_SET_ID;
      else
	 return LOAD_SHELL_SET;
   }
   else if( strstr(key_word, "SUP") )
      return LOAD_SUPERPLASTIC_FORMING;
   else if( strstr(key_word, "SS_S") )
      return LOAD_SURFACE_STRESS_SET;
   else if( strstr(key_word, "CE_S") )
      return LOAD_SURFACE_STRESS;
   else if( strstr(key_word, "CONT") )
      return LOAD_HEAT_CONTROLLER;
   else if( strstr(key_word, "MOT") )
      return LOAD_MOTION_NODE;
   else if( strstr(key_word, "POI") )
      return LOAD_NODE_POINT;
   else if( strstr(key_word, "E_SE") )
      return LOAD_NODE_SET;
   else if( strstr(key_word, "SEG") )
   {
      if( strstr(key_word, "SET") )
      {
	 if( strstr(key_word, "RM_I") )
	    return LOAD_SEGMENT_SET_NONUNIFORM_ID;
	 else if( strstr(key_word, "ET_N") )
	    return LOAD_SEGMENT_SET_NONUNIFORM;
	 else if( strstr(key_word, "ET_I") )
	    return LOAD_SEGMENT_SET_ID;
	 else
	    return LOAD_SEGMENT_SET;
      }
      else
      {
	 if( strstr(key_word, "RM_I") )
	    return LOAD_SEGMENT_NONUNIFORM_ID;
	 else if( strstr(key_word, "NT_N") )
	    return LOAD_SEGMENT_NONUNIFORM;
	 else if( strstr(key_word, "NT_I") )
	    return LOAD_SEGMENT_ID;
	 else
	    return LOAD_SEGMENT;
      }
   }
   else if( strstr(key_word, "ON_I") )
      return LOAD_ALE_CONVECTION_ID;
   else if( strstr(key_word, "CONV") )
      return LOAD_ALE_CONVECTION;
   else if( strstr(key_word, "BLA") )
      return LOAD_BLAST;
   else if( strstr(key_word, "BRO") )
      return LOAD_BRODE;
   else if( strstr(key_word, "DEN") )
      return LOAD_DENSITY_DEPTH;
   else if( strstr(key_word, "MAS") )
      return LOAD_MASK;
   else if( strstr(key_word, "SSA") )
      return LOAD_SSA;
   else if( strstr(key_word, "LOS") )
      return LOAD_VOLUME_LOSS;
   else if( strstr(key_word, "ANT_N") )
      return LOAD_THERMAL_CONSTANT_NODE;
   else if( strstr(key_word, "NST") )
      return LOAD_THERMAL_CONSTANT;
   else if( strstr(key_word, "CUR") )
      return LOAD_THERMAL_LOAD_CURVE;
   else if( strstr(key_word, "PAZ") )
      return LOAD_THERMAL_TOPAZ;

   return LOAD_NEW_TYPE;
}

unsigned int LoadImport::readLoads()
{
   char         new_kw[LINE_LEN];
   unsigned int	i = 0, load_id = 0, load_type = 0, num_loads = 0;
   long		loc = 0L;
   VStringIterator   s = dataLocPtr->keywordList.begin(),
		     e = dataLocPtr->keywordList.end(), itr, 
		     pitr = dataLocPtr->keywordList.begin();
   typeFuncIterator  btype_iter = typeFuncMap.begin(),
                     etype_iter = typeFuncMap.end(), type_iter;

   dataLine = new DataLine(filePtr);

   while(true)
   {
      itr = find_if(pitr, e, bind2nd(KeyWordCompare (), "*LOAD"));

      if( itr == e )
	 break;

      pitr = itr+1;
      i = (unsigned int)(itr - s);
      loc = dataLocPtr->slocList[i];

      rewind(filePtr);

      if( fseek(filePtr, loc, SEEK_SET) )
      {
	 cout << "ERROR in locating the Load cards" << endl;
	 break;
      }

      dataLine->clearFlag(KW_READ_END);

      char *str = dataLine->readNextCard(); //get the keyword
      Generic::RemoveLeadingAndTrailingBlanks( str );
cout << "KW = " << str << endl;

      load_type = getLoadTypeFromKeyword( str, &load_id );
cout << "Load TYPE = " << load_type << endl;

      if( load_type == LOAD_NEW_TYPE )
      {
         cout << "Load TYPE NOT SUPPORTED" << endl;
         continue;
      }

      num_loads++;

      strcpy(new_kw, str);

      dataLine->clearFlag(KW_READ_END);
      type_iter = typeFuncMap.find(load_type);
      if( type_iter != etype_iter )
      {
          impObj = new ImportObject(str, load_type);
          (type_iter->second)(dataLine, impObj);
          if( load_id )
          {
             loadManPtr->add(new_kw, impObj);
          }
          else
          {
             sprintf(new_kw, "%s_%d", new_kw, num_loads);
             loadManPtr->add(new_kw, impObj);
          }
      }
      else
         cout << "Load TYPE NOT FOUND" << endl;
   }

   return num_loads;
}

