#ifndef _Load_IMPORT_H_
#define _Load_IMPORT_H_

#include <string>
#include <map>
#include "dataloc.h"
#include "loadmanager.h"
#include "dataline.h"
#include "card.h"
#include "loadtype.h"
#include "typemap.h"

/** Class to import the data from native LSDYNA file for *LOAD keywords. All
  * the data is imported through this class and stored in the manager object.
  */
class LoadImport
{
public:
   /** Constructor for creating this object
     * \param fp File pointer to the LSDYNA native file
     * \param data_loc Pointer to the list of keywords and their locations in
     * the file
     * \param load_man Manager pointer to hold the imported data as a list of
     * ImportObject list
     */
   LoadImport
   (
      FILE          *fp,
      DataLoc       *data_loc,
      LoadManager    *load_man
   );

   ~LoadImport()
   {
      filePtr = NULL;
      loadManPtr = NULL;
      dataLocPtr = NULL;
      delete dataLine;
   }

   /** Function for getting the keyword type from given keyword name from LSDYNA
     * native file. The type is stored in the database
     * \param key_word Name of the keyword from file
     * \param load_id ID if exists along with the keyword
     * \return Type for *LOAD group of keywords
     */
   static LoadType getLoadTypeFromKeyword
	   (
	      const char  *key_word,
	      unsigned int *load_id
	   );

   /** Reads the *LOAD keywords from file
     * \return Returns 0 on failure else number of *LOAD keywords
     */
   unsigned int readLoads();

   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *LOAD keyword there is a function to call
     */
   void initBodyTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *LOAD keyword there is a function to call
     */
   void initElementTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *LOAD keyword there is a function to call
     */
   void initSegmentTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *LOAD keyword there is a function to call
     */
   void initSimpleTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *LOAD keyword there is a function to call
     */
   void initThermalTypesAndFunctions();

private:
   FILE          *filePtr;
   /** Manager pointer for holding the imported data for all the keywords */
   LoadManager    *loadManPtr;
   /** Pointer to keywords and their locations in the file */
   DataLoc       *dataLocPtr;
   /** Pointer to access the file data line by line */
   DataLine      *dataLine;
   /** Object to store imported data from LSDYNA data file */
   ImportObject  *impObj;
   /** A map between the keyword type and pointer to function */
   map<unsigned int, ImportFunctionPtr>  typeFuncMap;
};

#endif

