#ifndef _LoadHeatController_h_
#define _LoadHeatController_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *LOAD_HEAT_CONTROLLER keyword
  * from LSDYNA native file */

class LoadHeatController : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   LoadHeatController(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~LoadHeatController()
   {
   }

public:
/** Function to import Card1 details for *LOAD_HEAT_CONTROLLER
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"NODE","PID","LOAD","TSET","TYPE","GP","GI",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, 1, };
      unsigned int man_types[] = {NOD, PARTC, };
      unsigned int kw_types[] = {9999, 9999, };
      unsigned int num_indices = 2;
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *LOAD_HEAT_CONTROLLER
  * from LSDYNA native file */
   unsigned int importLoadHeatController()
   {
      readCard1();
      return 0;
   }
};

#endif

