#ifndef _LoadNodePoint_h_
#define _LoadNodePoint_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *LOAD_NODE_POINT keyword
  * from LSDYNA native file */

class LoadNodePoint : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   LoadNodePoint(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~LoadNodePoint()
   {
   }

public:
/** Function to import Card details for *LOAD_NODE_POINT
  * keyword from file */
   void readCard()
   {
      const char *fields[] = {"NODE/NSID","DOF","LCID","SF","CID","M1","M2","M3",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         loadNodeFind(wordArray, numFields, 0, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *LOAD_NODE_POINT
  * from LSDYNA native file */
   unsigned int importLoadNodePoint()
   {
      readCard();
      return 0;
   }
};

#endif

