#ifndef _LoadSegment_h_
#define _LoadSegment_h_

#include "manager.h"
#include "dispexport.h"
#include "loadid.h"

/** This class is used for importing *LOAD_SEGMENT keyword
  * from LSDYNA native file */

class LoadSegment : public LoadID
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   LoadSegment(DataLine *data_line, ImportObject *imp_obj) : LoadID (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~LoadSegment()
   {
   }

public:
/** Function to import Card2 details for *LOAD_SEGMENT
  * keyword from file */
   int readCard2()
   {
      const char *fields[] = {"LCID","SF","AT","N1","N2","N3","N4","N5",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 3, 4, 5, 6, 7, };
      unsigned int man_types[] = {DEFINE, NOD, NOD, NOD, NOD, NOD, };
      unsigned int kw_types[] = {CURVE, 9999, 9999, 9999, 9999, 9999, };
      unsigned int num_indices = 6;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return 0;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
      if( wordArray[7] )
         return atoi(wordArray[7]);
      else
         return 0;
   }

/** Function to import Card3 details for *LOAD_SEGMENT
  * keyword from file */
   void readCard3()
   {
      const char *fields[] = {"N6","N7","N8",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, };
      unsigned int man_types[] = {NOD, NOD, NOD, };
      unsigned int kw_types[] = {9999, 9999, 9999, };
      unsigned int num_indices = 3;
      numFields = 3;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *LOAD_SEGMENT
  * from LSDYNA native file */
   unsigned int importLoadSegment()
   {
      int n5 = 0;
      importLoadID();
      n5 = readCard2();
      if( n5 != 0 )
      {
         readCard3();
      }
      return 0;
   }
};

#endif

