#ifndef _LoadSegmentSet_h_
#define _LoadSegmentSet_h_

#include "manager.h"
#include "dispexport.h"
#include "loadid.h"

/** This class is used for importing *LOAD_SEGMENT_SET keyword
  * from LSDYNA native file */

class LoadSegmentSet : public LoadID
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   LoadSegmentSet(DataLine *data_line, ImportObject *imp_obj) : LoadID (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~LoadSegmentSet()
   {
   }

public:
/** Function to import Card1 details for *LOAD_SEGMENT_SET
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"SSID","LCID","SF","AT","DT",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, 1, };
      unsigned int man_types[] = {SET, DEFINE, };
      unsigned int kw_types[] = {SEGMENT, CURVE, };
      unsigned int num_indices = 2;
      numFields = 5;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *LOAD_SEGMENT_SET
  * from LSDYNA native file */
   unsigned int importLoadSegmentSet()
   {
      importLoadID();
      readCard1();
      return 0;
   }
};

#endif

