#ifndef _LoadAleConvection_h_
#define _LoadAleConvection_h_

#include "manager.h"
#include "dispexport.h"
#include "loadid.h"

/** This class is used for importing *LOAD_ALE_CONVECTION keyword
  * from LSDYNA native file */

class LoadAleConvection : public LoadID
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   LoadAleConvection(DataLine *data_line, ImportObject *imp_obj) : LoadID (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~LoadAleConvection()
   {
   }

public:
/** Function to import Card details for *LOAD_ALE_CONVECTION
  * keyword from file */
   void readCard()
   {
      const char *fields[] = {"LAGPID","LAGT","LAGCP","H","LAGMAS",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {PARTC, };
      unsigned int kw_types[] = {9999, };
      unsigned int num_indices = 1;
      numFields = 5;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *LOAD_ALE_CONVECTION
  * from LSDYNA native file */
   unsigned int importLoadAleConvection()
   {
      importLoadID();
      readCard();
      return 0;
   }
};

#endif

