#ifndef _LoadMask_h_
#define _LoadMask_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *LOAD_MASK keyword
  * from LSDYNA native file */

class LoadMask : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   LoadMask(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~LoadMask()
   {
   }

public:
/** Function to import Card1 details for *LOAD_MASK
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"PID","LCID","VID1","OFF","BOXID","LCIDM","VID2","INOUT",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, 4, 5, 6, };
      unsigned int man_types[] = {PARTC, DEFINE, DEFINE, DEFINE, DEFINE, DEFINE, };
      unsigned int kw_types[] = {9999, CURVE, VECTOR, BOX, CURVE, VECTOR, };
      unsigned int num_indices = 6;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *LOAD_MASK
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"ICYCLE",};
      unsigned int field_types[] = {DATA_INT, };
      numFields = 1;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *LOAD_MASK
  * from LSDYNA native file */
   unsigned int importLoadMask()
   {
      readCard1();
      readCard2();
      return 0;
   }
};

#endif

