#ifndef _LoadVolumeLoss_h_
#define _LoadVolumeLoss_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *LOAD_VOLUME_LOSS keyword
  * from LSDYNA native file */

class LoadVolumeLoss : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   LoadVolumeLoss(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~LoadVolumeLoss()
   {
   }

public:
/** Function to import Card details for *LOAD_VOLUME_LOSS
  * keyword from file */
   void readCard()
   {
      const char *fields[] = {"PSID","COORD","LCUR","FX","FY","FZ","PMIN","FACTOR",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, 2, };
      unsigned int man_types[] = {SET, DEFINE, };
      unsigned int kw_types[] = {PARTC, CURVE, };
      unsigned int num_indices = 2;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *LOAD_VOLUME_LOSS
  * from LSDYNA native file */
   unsigned int importLoadVolumeLoss()
   {
      readCard();
      return 0;
   }
};

#endif

