#ifndef _LoadThermalConstant_h_
#define _LoadThermalConstant_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *LOAD_THERMAL_CONSTANT keyword
  * from LSDYNA native file */

class LoadThermalConstant : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   LoadThermalConstant(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~LoadThermalConstant()
   {
   }

public:
/** Function to import Card1 details for *LOAD_THERMAL_CONSTANT
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"NSID","NSIDEX","BOXID",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, };
      unsigned int man_types[] = {SET, SET, DEFINE, };
      unsigned int kw_types[] = {NOD, NOD, BOX, };
      unsigned int num_indices = 3;
      numFields = 3;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *LOAD_THERMAL_CONSTANT
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"T","TE",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 2;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *LOAD_THERMAL_CONSTANT
  * from LSDYNA native file */
   unsigned int importLoadThermalConstant()
   {
      readCard1();
      readCard2();
      return 0;
   }
};

#endif

