#ifndef _LoadThermalLoadCurve_h_
#define _LoadThermalLoadCurve_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *LOAD_THERMAL_LOAD_CURVE keyword
  * from LSDYNA native file */

class LoadThermalLoadCurve : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   LoadThermalLoadCurve(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~LoadThermalLoadCurve()
   {
   }

public:
/** Function to import Card details for *LOAD_THERMAL_LOAD_CURVE
  * keyword from file */
   void readCard()
   {
      const char *fields[] = {"LCID","LCIDDR",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, };
      unsigned int man_types[] = {DEFINE, DEFINE, };
      unsigned int kw_types[] = {CURVE, CURVE, };
      unsigned int num_indices = 2;
      numFields = 2;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *LOAD_THERMAL_LOAD_CURVE
  * from LSDYNA native file */
   unsigned int importLoadThermalLoadCurve()
   {
      readCard();
      return 0;
   }
};

#endif

