#ifndef _LoadThermalVariableNode_h_
#define _LoadThermalVariableNode_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *LOAD_THERMAL_VARIABLE_NODE keyword
  * from LSDYNA native file */

class LoadThermalVariableNode : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   LoadThermalVariableNode(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~LoadThermalVariableNode()
   {
   }

public:
/** Function to import Card details for *LOAD_THERMAL_VARIABLE_NODE
  * keyword from file */
   void readCard()
   {
      const char *fields[] = {"NID","TS","TB","LCID",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, };
      unsigned int field_indices[] = {0, 3, };
      unsigned int man_types[] = {NOD, DEFINE, };
      unsigned int kw_types[] = {9999, CURVE, };
      unsigned int num_indices = 2;
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *LOAD_THERMAL_VARIABLE_NODE
  * from LSDYNA native file */
   unsigned int importLoadThermalVariableNode()
   {
      readCard();
      return 0;
   }
};

#endif

