#ifndef _LoadThermalVariableShell_h_
#define _LoadThermalVariableShell_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *LOAD_THERMAL_VARIABLE_SHELL keyword
  * from LSDYNA native file */

class LoadThermalVariableShell : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   LoadThermalVariableShell(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~LoadThermalVariableShell()
   {
   }

public:
/** Function to import Card1 details for *LOAD_THERMAL_VARIABLE_SHELL
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"ID","EID/SID",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, };
      numFields = 2;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, LOAD, impObj);

      if( Card::isFlagOn(SAVE_REFERENCES) )
         initialShellFind(wordArray, numFields, 1, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *LOAD_THERMAL_VARIABLE_SHELL
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"TBASE","TSCALE","TCURVE","TCURDR","ZCO",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_DOUBLE, };
      unsigned int field_indices[] = {2, 3, };
      unsigned int man_types[] = {DEFINE, DEFINE, };
      unsigned int kw_types[] = {CURVE, CURVE, };
      unsigned int num_indices = 2;
      numFields = 5;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *LOAD_THERMAL_VARIABLE_SHELL
  * from LSDYNA native file */
   unsigned int importLoadThermalVariableShell()
   {
      readCard1();
      readCard2();
      while(numFields)
      {
         readCard2();
      }
      return 0;
   }
};

#endif

