#ifndef _MatAleGasMixture_h_
#define _MatAleGasMixture_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *MAT_ALE_GAS_MIXTURE keyword
  * from LSDYNA native file */

class MatAleGasMixture : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   MatAleGasMixture(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~MatAleGasMixture()
   {
   }

public:
/** Function to import Card1 details for *MAT_ALE_GAS_MIXTURE
  * keyword from file */
   double readCard1()
   {
      const char *fields[] = {"MID","IADIAB","RUNIV",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_INT, DATA_DOUBLE, };
      numFields = 3;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return 0.0;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, MAT, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
      if( wordArray[2] )
         return atof(wordArray[2]);
      else
         return 0;
   }

/** Function to import Card2RUNIV0 details for *MAT_ALE_GAS_MIXTURE
  * keyword from file */
   void readCard2RUNIV0()
   {
      const char *fields[] = {"CVmass1","CVmass2","CVmass3","CVmass4","CVmass5","CVmass6","CVmass7","Cvmass8",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2RUNIV0");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3RUNIV0 details for *MAT_ALE_GAS_MIXTURE
  * keyword from file */
   void readCard3RUNIV0()
   {
      const char *fields[] = {"CPmass1","CPmass2","CPmass3","CPmass4","CPmass5","CPmass6","CPmass7","Cpmass8",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3RUNIV0");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2RUNIV1 details for *MAT_ALE_GAS_MIXTURE
  * keyword from file */
   void readCard2RUNIV1()
   {
      const char *fields[] = {"MOLWT1","MOLWT2","MOLWT3","MOLWT4","MOLWT5","MOLWT6","MOLWT7","MOLWT8",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2RUNIV1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3RUNIV1 details for *MAT_ALE_GAS_MIXTURE
  * keyword from file */
   void readCard3RUNIV1()
   {
      const char *fields[] = {"CPmole1","CPmole2","CPmole3","CPmole4","CPmole5","CPmole6","Cpmole7","CPmole8",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3RUNIV1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card4RUNIV1 details for *MAT_ALE_GAS_MIXTURE
  * keyword from file */
   void readCard4RUNIV1()
   {
      const char *fields[] = {"B1","B2","B3","B4","B5","B6","B7","B8",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card4RUNIV1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card5RUNIV1 details for *MAT_ALE_GAS_MIXTURE
  * keyword from file */
   void readCard5RUNIV1()
   {
      const char *fields[] = {"C1","C2","C3","C4","C5","C6","C7","C8",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card5RUNIV1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *MAT_ALE_GAS_MIXTURE
  * from LSDYNA native file */
   unsigned int importMatAleGasMixture()
   {
      double runiv = 0.0;
      runiv = readCard1();
      if( runiv == 0.0 )
      {
         readCard2RUNIV0();
         readCard3RUNIV0();
      }
      if( runiv != 0.0 )
      {
         readCard2RUNIV1();
         readCard3RUNIV1();
         readCard4RUNIV1();
         readCard5RUNIV1();
      }
      return 0;
   }
};

#endif

