#ifndef _MatIsotropicElasticPlastic_h_
#define _MatIsotropicElasticPlastic_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *MAT_ISOTROPIC_ELASTIC_PLASTIC keyword
  * from LSDYNA native file */

class MatIsotropicElasticPlastic : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   MatIsotropicElasticPlastic(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~MatIsotropicElasticPlastic()
   {
   }

public:
/** Function to import Card1 details for *MAT_ISOTROPIC_ELASTIC_PLASTIC
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"MID","RO","G","SIGY","ETAN","BULK",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, MAT, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *MAT_ISOTROPIC_ELASTIC_PLASTIC
  * from LSDYNA native file */
   unsigned int importMatIsotropicElasticPlastic()
   {
      readCard1();
      return 0;
   }
};

#endif

