#ifndef _MatCompositeMatrix_h_
#define _MatCompositeMatrix_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *MAT_COMPOSITE_MATRIX keyword
  * from LSDYNA native file */

class MatCompositeMatrix : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   MatCompositeMatrix(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~MatCompositeMatrix()
   {
   }

public:
/** Function to import Card1 details for *MAT_COMPOSITE_MATRIX
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"MID","RO",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_DOUBLE, };
      numFields = 2;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, MAT, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *MAT_COMPOSITE_MATRIX
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"C11","C12","C22","C13","C23","C33","C14","C24",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3 details for *MAT_COMPOSITE_MATRIX
  * keyword from file */
   void readCard3()
   {
      const char *fields[] = {"C34","C44","C15","C25","C35","C45","C55","C16",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card4 details for *MAT_COMPOSITE_MATRIX
  * keyword from file */
   void readCard4()
   {
      const char *fields[] = {"C26","C36","C46","C56","C66","AOPT",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card4");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card5 details for *MAT_COMPOSITE_MATRIX
  * keyword from file */
   void readCard5()
   {
      const char *fields[] = {"XP","YP","ZP","A1","A2","A3",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card5");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card6 details for *MAT_COMPOSITE_MATRIX
  * keyword from file */
   void readCard6()
   {
      const char *fields[] = {"V1","V2","V3","D1","D2","D3","BETA",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card6");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *MAT_COMPOSITE_MATRIX
  * from LSDYNA native file */
   unsigned int importMatCompositeMatrix()
   {
      readCard1();
      readCard2();
      readCard3();
      readCard4();
      readCard5();
      readCard6();
      return 0;
   }
};

#endif

