#ifndef _MatWinfrithConcreteReinforcement_h_
#define _MatWinfrithConcreteReinforcement_h_

#include "manager.h"
#include "dispexport.h"
#include "matwinfrithconcrete.h"

/** This class is used for importing *MAT_WINFRITH_CONCRETE_REINFORCEMENT keyword
  * from LSDYNA native file */

class MatWinfrithConcreteReinforcement : public MatWinfrithConcrete
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   MatWinfrithConcreteReinforcement(DataLine *data_line, ImportObject *imp_obj) : MatWinfrithConcrete (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~MatWinfrithConcreteReinforcement()
   {
   }

public:
/** Function to import Card1 details for *MAT_WINFRITH_CONCRETE_REINFORCEMENT
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"EID1","EID2","INC","XR","YR","ZR",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *MAT_WINFRITH_CONCRETE_REINFORCEMENT
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"UNUSED","PID","AXIS","COOR","RQA","RQB",};
      unsigned int field_types[] = {DATA_UNUSED, DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *MAT_WINFRITH_CONCRETE_REINFORCEMENT
  * from LSDYNA native file */
   unsigned int importMatWinfrithConcreteReinforcement()
   {
      importMatWinfrithConcrete();
      readCard1();
      readCard2();
      return 0;
   }
};

#endif

