#ifndef _MatHydraulicGasDamperDiscreteBeam_h_
#define _MatHydraulicGasDamperDiscreteBeam_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *MAT_HYDRAULIC_GAS_DAMPER_DISCRETE_BEAM keyword
  * from LSDYNA native file */

class MatHydraulicGasDamperDiscreteBeam : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   MatHydraulicGasDamperDiscreteBeam(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~MatHydraulicGasDamperDiscreteBeam()
   {
   }

public:
/** Function to import Card1 details for *MAT_HYDRAULIC_GAS_DAMPER_DISCRETE_BEAM
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"MID","RO","CO","N","P0","PA","AP","KH",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, MAT, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *MAT_HYDRAULIC_GAS_DAMPER_DISCRETE_BEAM
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"LCID","FR","SCLF","CLEAR",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {DEFINE, };
      unsigned int kw_types[] = {CURVE, };
      unsigned int num_indices = 1;
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *MAT_HYDRAULIC_GAS_DAMPER_DISCRETE_BEAM
  * from LSDYNA native file */
   unsigned int importMatHydraulicGasDamperDiscreteBeam()
   {
      readCard1();
      readCard2();
      return 0;
   }
};

#endif

