#ifndef _MatLinearElasticDiscreteBeam_h_
#define _MatLinearElasticDiscreteBeam_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *MAT_LINEAR_ELASTIC_DISCRETE_BEAM keyword
  * from LSDYNA native file */

class MatLinearElasticDiscreteBeam : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   MatLinearElasticDiscreteBeam(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~MatLinearElasticDiscreteBeam()
   {
   }

public:
/** Function to import Card1 details for *MAT_LINEAR_ELASTIC_DISCRETE_BEAM
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"MID","RO","TKR","TKS","TKT","RKR","RKS","RKT",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, MAT, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *MAT_LINEAR_ELASTIC_DISCRETE_BEAM
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"TDR","TDS","TDT","RDR","RDS","RDT",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3 details for *MAT_LINEAR_ELASTIC_DISCRETE_BEAM
  * keyword from file */
   void readCard3()
   {
      const char *fields[] = {"FOR","FOS","FOT","MOR","MOS","MOT",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *MAT_LINEAR_ELASTIC_DISCRETE_BEAM
  * from LSDYNA native file */
   unsigned int importMatLinearElasticDiscreteBeam()
   {
      readCard1();
      readCard2();
      readCard3();
      return 0;
   }
};

#endif

