#ifndef _MatGeneralNonlinear1dofDiscreteBeam_h_
#define _MatGeneralNonlinear1dofDiscreteBeam_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *MAT_GENERAL_NONLINEAR_1DOF_DISCRETE_BEAM keyword
  * from LSDYNA native file */

class MatGeneralNonlinear1dofDiscreteBeam : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   MatGeneralNonlinear1dofDiscreteBeam(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~MatGeneralNonlinear1dofDiscreteBeam()
   {
   }

public:
/** Function to import Card1 details for *MAT_GENERAL_NONLINEAR_1DOF_DISCRETE_BEAM
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"MID","RO","K","UNLDOPT","OFFSET","DAMPF",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, MAT, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *MAT_GENERAL_NONLINEAR_1DOF_DISCRETE_BEAM
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"LCIDT","LCIDTU","LCIDTD","LCIDTE",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, 3, };
      unsigned int man_types[] = {DEFINE, DEFINE, DEFINE, DEFINE, };
      unsigned int kw_types[] = {CURVE, CURVE, CURVE, CURVE, };
      unsigned int num_indices = 4;
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3 details for *MAT_GENERAL_NONLINEAR_1DOF_DISCRETE_BEAM
  * keyword from file */
   void readCard3()
   {
      const char *fields[] = {"UTFAIL","UCFAIL","IU",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 3;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *MAT_GENERAL_NONLINEAR_1DOF_DISCRETE_BEAM
  * from LSDYNA native file */
   unsigned int importMatGeneralNonlinear1dofDiscreteBeam()
   {
      readCard1();
      readCard2();
      readCard3();
      return 0;
   }
};

#endif

