#ifndef _MatStrainRateDependentPlasticity_h_
#define _MatStrainRateDependentPlasticity_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *MAT_STRAIN_RATE_DEPENDENT_PLASTICITY keyword
  * from LSDYNA native file */

class MatStrainRateDependentPlasticity : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   MatStrainRateDependentPlasticity(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~MatStrainRateDependentPlasticity()
   {
   }

public:
/** Function to import Card1 details for *MAT_STRAIN_RATE_DEPENDENT_PLASTICITY
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"MID","RO","E","PR","VP",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 5;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, MAT, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *MAT_STRAIN_RATE_DEPENDENT_PLASTICITY
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"LC1","ETAN","LC2","LC3","LC4","TDEL","RDEF",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, 2, 3, 4, };
      unsigned int man_types[] = {DEFINE, DEFINE, DEFINE, DEFINE, };
      unsigned int kw_types[] = {CURVE, CURVE, CURVE, CURVE, };
      unsigned int num_indices = 4;
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *MAT_STRAIN_RATE_DEPENDENT_PLASTICITY
  * from LSDYNA native file */
   unsigned int importMatStrainRateDependentPlasticity()
   {
      readCard1();
      readCard2();
      return 0;
   }
};

#endif

