#ifndef _MatGeneralSpringDiscreteBeam_h_
#define _MatGeneralSpringDiscreteBeam_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *MAT_GENERAL_SPRING_DISCRETE_BEAM keyword
  * from LSDYNA native file */

class MatGeneralSpringDiscreteBeam : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   MatGeneralSpringDiscreteBeam(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~MatGeneralSpringDiscreteBeam()
   {
   }

public:
/** Function to import Card1 details for *MAT_GENERAL_SPRING_DISCRETE_BEAM
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"MID","RO",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_DOUBLE, };
      numFields = 2;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, MAT, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2Loop details for *MAT_GENERAL_SPRING_DISCRETE_BEAM
  * keyword from file */
   void readCard2Loop()
   {
      const char *fields[] = {"DOF","TYPE","K","D","CDF","TDF",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2Loop");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3Loop details for *MAT_GENERAL_SPRING_DISCRETE_BEAM
  * keyword from file */
   void readCard3Loop()
   {
      const char *fields[] = {"FLCID","HLCID","C1","C2","DLE","GLCID",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 5, };
      unsigned int man_types[] = {DEFINE, DEFINE, DEFINE, };
      unsigned int kw_types[] = {CURVE, CURVE, CURVE, };
      unsigned int num_indices = 3;
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3Loop");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *MAT_GENERAL_SPRING_DISCRETE_BEAM
  * from LSDYNA native file */
   unsigned int importMatGeneralSpringDiscreteBeam()
   {
      readCard1();
      readCard2Loop();
      readCard3Loop();
      while(numFields)
      {
         readCard2Loop();
         readCard3Loop();
      }
      return 0;
   }
};

#endif

