#ifndef _MatLowDensitySyntheticFoam_h_
#define _MatLowDensitySyntheticFoam_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *MAT_LOW_DENSITY_SYNTHETIC_FOAM keyword
  * from LSDYNA native file */

class MatLowDensitySyntheticFoam : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   MatLowDensitySyntheticFoam(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~MatLowDensitySyntheticFoam()
   {
   }

public:
/** Function to import Card1 details for *MAT_LOW_DENSITY_SYNTHETIC_FOAM
  * keyword from file */
   int readCard1()
   {
      const char *fields[] = {"MID","RO","E","LCID1","LCID2","HU","BETA","DAMP",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {3, 4, };
      unsigned int man_types[] = {DEFINE, DEFINE, };
      unsigned int kw_types[] = {CURVE, CURVE, };
      unsigned int num_indices = 2;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return 0;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, MAT, impObj);

      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
      if( wordArray[3] )
         return atoi(wordArray[3]);
      else
         return 0;
   }

/** Function to import Card2 details for *MAT_LOW_DENSITY_SYNTHETIC_FOAM
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"SHAPE","FAIL","BVFLAG","ED","BETA1","KCON","REF","TC",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3LCIDM1 details for *MAT_LOW_DENSITY_SYNTHETIC_FOAM
  * keyword from file */
   void readCard3LCIDM1()
   {
      const char *fields[] = {"RFLAG","DTRT",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 2;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3LCIDM1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *MAT_LOW_DENSITY_SYNTHETIC_FOAM
  * from LSDYNA native file */
   unsigned int importMatLowDensitySyntheticFoam()
   {
      int lcid1 = 0;
      lcid1 = readCard1();
      readCard2();
      if( lcid1 < 0 )
      {
         readCard3LCIDM1();
      }
      return 0;
   }
};

#endif

