#ifndef _MatLowDensitySyntheticFoamWithFailure_h_
#define _MatLowDensitySyntheticFoamWithFailure_h_

#include "manager.h"
#include "dispexport.h"
#include "matlowdensitysyntheticfoam.h"

/** This class is used for importing *MAT_LOW_DENSITY_SYNTHETIC_FOAM_WITH_FAILURE keyword
  * from LSDYNA native file */

class MatLowDensitySyntheticFoamWithFailure : public MatLowDensitySyntheticFoam
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   MatLowDensitySyntheticFoamWithFailure(DataLine *data_line, ImportObject *imp_obj) : MatLowDensitySyntheticFoam (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~MatLowDensitySyntheticFoamWithFailure()
   {
   }

public:
/** Function to import Card4 details for *MAT_LOW_DENSITY_SYNTHETIC_FOAM_WITH_FAILURE
  * keyword from file */
   void readCard4()
   {
      const char *fields[] = {"K","GAMA1","GAMA2","EH",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card4");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *MAT_LOW_DENSITY_SYNTHETIC_FOAM_WITH_FAILURE
  * from LSDYNA native file */
   unsigned int importMatLowDensitySyntheticFoamWithFailure()
   {
      importMatLowDensitySyntheticFoam();
      readCard4();
      return 0;
   }
};

#endif

