#include <iostream>
#include <algorithm>
#include "generic.h"
#include "mattype.h"
#include "matimport.h"
#include "title.h"
#include <stdlib.h>

using namespace std;

MatImport::MatImport
(
   FILE          *fp,
   DataLoc       *data_loc,
   MatManager    *mat_man
)
{
   filePtr = fp;
   matManPtr = mat_man;
   dataLocPtr = data_loc;
   dataLine = NULL;

   initAleTypesAndFunctions();
   initAnisotropicTypesAndFunctions();
   initBammanTypesAndFunctions();
   initBarlatTypesAndFunctions();
   initBlatzTypesAndFunctions();
   initCohesiveTypesAndFunctions();
   initCompoTypesAndFunctions();
   initCompositeTypesAndFunctions();
   initConcreteTypesAndFunctions();
   initDamperTypesAndFunctions();
   initDiscreteTypesAndFunctions();
   initDofTypesAndFunctions();
   initElasticTypesAndFunctions();
   initFoamTypesAndFunctions();
   initGeneralTypesAndFunctions();
   initGensprTypesAndFunctions();
   initGursonTypesAndFunctions();
   initHoneyTypesAndFunctions();
   initLowdenseTypesAndFunctions();
   initModifiedTypesAndFunctions();
   initModifyTypesAndFunctions();
   initMohrTypesAndFunctions();
   initOrthoTypesAndFunctions();
   initOthersTypesAndFunctions();
   initPlasticTypesAndFunctions();
   initPlasticityTypesAndFunctions();
   initSeatbeltTypesAndFunctions();
   initSeismicTypesAndFunctions();
   initSensitiveTypesAndFunctions();
   initSimpleTypesAndFunctions();
   initSoilTypesAndFunctions();
   initSpringTypesAndFunctions();
   initSpringdisTypesAndFunctions();
   initThermalTypesAndFunctions();
   initViscoelasticTypesAndFunctions();
   initViscoplasticTypesAndFunctions();
   initWeldTypesAndFunctions();
}

/* This function has to corrected based on the real mat types from solver */
MatType MatImport::getMatTypeFrom6thDigit
	(
	   const char *key_word
        )
{
   char  num_str[8];
   unsigned int num = 0;

   num_str[0] = key_word[5];
   num_str[1] = key_word[6];
   num_str[2] = key_word[7];
   num_str[3] = '\0';
   num = atoi( num_str );

   switch( num )
   {
      case 1:
         if( key_word[9] == 'F' )
            return MAT_ELASTIC_FLUID;
         else
            return MAT_ELASTIC;
      case 2:
         if( key_word[9] == 'A' )
            return MAT_ANISOTROPIC_ELASTIC;
         else
            return MAT_ORTHOTROPIC_ELASTIC;
      case 3:
         return MAT_PLASTIC_KINEMATIC;
      case 4:
         return MAT_ELASTIC_PLASTIC_THERMAL;
      case 5:
         return MAT_SOIL_AND_FOAM;
      case 6:
         return MAT_VISCOELASTIC;
      case 7:
         return MAT_BLATZ_KO_RUBBER;
      case 8:
         return MAT_HIGH_EXPLOSIVE_BURN;
      case 9:
         return MAT_NULL;
      case 10:
         if( key_word[9] == 'S' )
            return MAT_ELASTIC_PLASTIC_HYDRO_SPALL;
         else
            return MAT_ELASTIC_PLASTIC_HYDRO;
      case 11:
         if( key_word[9] == 'L' )
            return MAT_STEINBERG_LUND;
         else
            return MAT_STEINBERG;
      case 12:
         return MAT_ISOTROPIC_ELASTIC_PLASTIC;
      case 13:
         return MAT_ISOTROPIC_ELASTIC_FAILURE;
      case 14:
         return MAT_SOIL_AND_FOAM_FAILURE;
      case 15:
         return MAT_JOHNSON_COOK;
      case 16:
         return MAT_PSEUDO_TENSOR;
      case 17:
         return MAT_ORIENTED_CRACK;
      case 18:
         return MAT_POWER_LAW_PLASTICITY;
      case 19:
         return MAT_STRAIN_RATE_DEPENDENT_PLASTICITY;
      case 20:
         return MAT_RIGID;
      case 21:
         return MAT_ORTHOTROPIC_THERMAL;
      case 22:
         return MAT_COMPOSITE_DAMAGE;
      case 23:
         return MAT_TEMPERATURE_DEPENDENT_ORTHOTROPIC;
      case 24:
         return MAT_PIECEWISE_LINEAR_PLASTICITY;
      case 25:
         return MAT_GEOLOGIC_CAP_MODEL;
      case 26:
         return MAT_HONEYCOMB;
      case 27:
         return MAT_MOONEY_RIVLIN_RUBBER;
      case 28:
         return MAT_RESULTANT_PLASTICITY;
      case 29:
         return MAT_FORCE_LIMITED;
      case 30:
         return MAT_SHAPE_MEMORY;
      case 31:
         return MAT_FRAZER_NASH_RUBBER_MODEL;
      case 32:
         return MAT_LAMINATED_GLASS;
      case 33:
         if( key_word[9] == '9' )
            return MAT_BARLAT_YLD96;
         else
            return MAT_BARLAT_ANISOTROPIC_PLASTICITY;
      case 34:
         return MAT_FABRIC;
      case 35:
         return MAT_PLASTIC_GREEN_NAGHDI_RATE;
      case 36:
         return MAT_3_PARAMETER_BARLAT;
      case 37:
         if( key_word[8] == '_' )
            return MAT_TRANSVERSELY_ANISOTROPIC_ELASTIC_PLASTIC_ECHANGE;
         else
            return MAT_TRANSVERSELY_ANISOTROPIC_ELASTIC_PLASTIC;
      case 38:
         return MAT_BLATZ_KO_FOAM;
      case 39:
         return MAT_FLD_TRANSVERSELY_ANISOTROPIC;
      case 40:
         return MAT_NONLINEAR_ORTHOTROPIC;
      case 41:
         return MAT_USER_DEFINED_MATERIAL_MODELS;
      case 42:
         return MAT_USER_DEFINED_MATERIAL_MODELS;
      case 43:
         return MAT_USER_DEFINED_MATERIAL_MODELS;
      case 44:
         return MAT_USER_DEFINED_MATERIAL_MODELS;
      case 45:
         return MAT_USER_DEFINED_MATERIAL_MODELS;
      case 46:
         return MAT_USER_DEFINED_MATERIAL_MODELS;
      case 47:
         return MAT_USER_DEFINED_MATERIAL_MODELS;
      case 48:
         return MAT_USER_DEFINED_MATERIAL_MODELS;
      case 49:
         return MAT_USER_DEFINED_MATERIAL_MODELS;
      case 50:
         return MAT_USER_DEFINED_MATERIAL_MODELS;
      case 51:
         return MAT_BAMMAN;
      case 52:
         return MAT_BAMMAN_DAMAGE;
      case 53:
         return MAT_CLOSED_CELL_FOAM;
      case 54:
         return MAT_ENHANCED_COMPOSITE_DAMAGE;
      case 55:
         return MAT_ENHANCED_COMPOSITE_DAMAGE;
      case 57:
         return MAT_LOW_DENSITY_FOAM;
      case 58:
         return MAT_LAMINATED_COMPOSITE_FABRIC;
      case 59:
         if( key_word[10] == 'H' )
            return MAT_COMPOSITE_FAILURE_SHELL_MODEL;
         else if( key_word[10] == 'O' )
            return MAT_COMPOSITE_FAILURE_SOLID_MODEL;
      case 60:
         if( key_word[8] == 'C' )
            return MAT_ELASTIC_WITH_VISCOSITY_CURVE;
         else
            return MAT_ELASTIC_WITH_VISCOSITY;
      case 61:
         return MAT_KELVIN_MAXWELL_VISCOELASTIC;
      case 62:
         return MAT_VISCOUS_FOAM;
      case 63:
         return MAT_CRUSHABLE_FOAM;
      case 64:
         return MAT_RATE_SENSITIVE_POWERLAW_PLASTICITY;
      case 65:
         return MAT_MODIFIED_ZERILLI_ARMSTRONG;
      case 66:
         return MAT_LINEAR_ELASTIC_DISCRETE_BEAM;
      case 67:
         return MAT_NONLINEAR_ELASTIC_DISCRETE_BEAM;
      case 68:
         return MAT_NONLINEAR_PLASTIC_DISCRETE_BEAM;
      case 69:
         return MAT_SID_DAMPER_DISCRETE_BEAM;
      case 70:
         return MAT_HYDRAULIC_GAS_DAMPER_DISCRETE_BEAM;
      case 71:
         return MAT_CABLE_DISCRETE_BEAM;
      case 72:
         if( key_word[8] == 'R' )
            return MAT_CONCRETE_DAMAGE_REL3;
         else
            return MAT_CONCRETE_DAMAGE;
      case 73:
         return MAT_LOW_DENSITY_VISCOUS_FOAM;
      case 74:
         return MAT_ELASTIC_SPRING_DISCRETE_BEAM;
      case 75:
         return MAT_BILKHU_DUBOIS_FOAM;
      case 76:
         return MAT_GENERAL_VISCOELASTIC;
      case 77:
         if( key_word[9] == 'H' )
            return MAT_HYPERELASTIC_RUBBER;
         else if( key_word[9] == 'O' )
            return MAT_OGDEN_RUBBER;
         break;
      case 78:
         return MAT_SOIL_CONCRETE;
      case 79:
         return MAT_HYSTERETIC_SOIL;
      case 80:
         return MAT_RAMBERG_OSGOOD;
      case 81:
         return MAT_PLASTICITY_WITH_DAMAGE;
      case 82:
         if( key_word[9] == 'R' )
            return MAT_PLASTICITY_WITH_DAMAGE_ORTHO_RCDC;
         else
            return MAT_PLASTICITY_WITH_DAMAGE_ORTHO;
      case 83:
         return MAT_FU_CHANG_FOAM;
      case 84:
         return MAT_WINFRITH_CONCRETE;
      case 85:
         return MAT_WINFRITH_CONCRETE_REINFORCEMENT;
      case 86:
         return MAT_ORTHOTROPIC_VISCOELASTIC;
      case 87:
         return MAT_CELLULAR_RUBBER;
      case 88:
         return MAT_MTS;
      case 89:
         return MAT_PLASTICITY_POLYMER;
      case 90:
         return MAT_ACOUSTIC;
      case 91:
         return MAT_SOFT_TISSUE;
      case 92:
         return MAT_SOFT_TISSUE_VISCO;
      case 93:
         return MAT_ELASTIC_6DOF_SPRING_DISCRETE_BEAM;
      case 94:
         return MAT_INELASTIC_SPRING_DISCRETE_BEAM;
      case 95:
         return MAT_INELASTIC_6DOF_SPRING_DISCRETE_BEAM;
      case 96:
         return MAT_BRITTLE_DAMAGE;
      case 97:
         return MAT_GENERAL_JOINT_DISCRETE_BEAM;
      case 98:
         return MAT_SIMPLIFIED_JOHNSON_COOK;
      case 99:
         return MAT_SIMPLIFIED_JOHNSON_COOK_ORTHOTROPIC_DAMAGE;
      case 100:
         if( key_word[10] == 'A' )
            return MAT_SPOTWELD_DAIMLERCHRYSLER;
         else if( key_word[9] == 'D' )
            return MAT_SPOTWELD_DAMAGE_FAILURE;
         else
            return MAT_SPOTWELD;
      case 101:
         return MAT_GEPLASTIC_SRATE_2000a;
      case 102:
         return MAT_INV_HYPERBOLIC_SIN;
      case 103:
         if( key_word[9] == 'P' )
            return MAT_ANISOTROPIC_PLASTIC;
         else
            return MAT_ANISOTROPIC_VISCOPLASTIC;
      case 104:
         return MAT_DAMAGE_1;
      case 105:
         return MAT_DAMAGE_2;
      case 106:
         return MAT_ELASTIC_VISCOPLASTIC_THERMAL;
      case 107:
         return MAT_MODIFIED_JOHNSON_COOK;
      case 108:
         return MAT_ORTHO_ELASTIC_PLASTIC;
      case 110:
         return MAT_JOHNSON_HOLMQUIST_CERAMICS;
      case 111:
         return MAT_JOHNSON_HOLMQUIST_CONCRETE;
      case 112:
         return MAT_FINITE_ELASTIC_STRAIN_PLASTICITY;
      case 113:
         return MAT_TRIP;
      case 114:
         return MAT_LAYERED_LINEAR_PLASTICITY;
      case 115:
         return MAT_UNIFIED_CREEP;
      case 116:
         return MAT_COMPOSITE_LAYUP;
      case 117:
         return MAT_COMPOSITE_MATRIX;
      case 118:
         return MAT_COMPOSITE_DIRECT;
      case 119:
         return MAT_GENERAL_NONLINEAR_6DOF_DISCRETE_BEAM;
      case 120:
         if( key_word[9] == 'J' )
            return MAT_GURSON_JC;
         else if( key_word[9] == 'R' )
            return MAT_GURSON_RCDC;
         else
            return MAT_GURSON;
      case 121:
         return MAT_GENERAL_NONLINEAR_1DOF_DISCRETE_BEAM;
      case 122:
         return MAT_HILL_3R;
      case 123:
         if( key_word[9] == 'R' )
            return MAT_MODIFIED_PIECEWISE_LINEAR_PLASTICITY_RATE;
         else
            return MAT_MODIFIED_PIECEWISE_LINEAR_PLASTICITY;
      case 124:
         return MAT_PLASTICITY_COMPRESSION_TENSION;
      case 125:
         return MAT_KINEMATIC_HARDENING_TRANSVERSELY_ANISOTROPIC;
      case 126:
         return MAT_MODIFIED_HONEYCOMB;
      case 127:
         return MAT_ARRUDA_BOYCE_RUBBER;
      case 128:
         return MAT_HEART_TISSUE;
      case 129:
         return MAT_LUNG_TISSUE;
      case 130:
         return MAT_SPECIAL_ORTHOTROPIC;
      case 131:
         return MAT_ISOTROPIC_SMEARED_CRACK;
      case 132:
         return MAT_ORTHOTROPIC_SMEARED_CRACK;
      case 133:
         return MAT_BARLAT_YLD2000;
      case 135:
         if( key_word[9] == 'P' )
            return MAT_WTM_STM_PLC;
         else
            return MAT_WTM_STM;
      case 136:
         return MAT_CORUS_VEGTER;
      case 138:
         return MAT_COHESIVE_MIXED_MODE;
      case 139:
         return MAT_MODIFIED_FORCE_LIMITED;
      case 140:
         return MAT_VACUUM;
      case 141:
         return MAT_RATE_SENSITIVE_POLYMER;
      case 142:
         return MAT_TRANSVERSELY_ISOTROPIC_CRUSHABLE_FOAM;
      case 143:
         if( key_word[9] == 'P' || key_word[8] == 'P' )
            return MAT_WOOD_PINE;
         else if( key_word[9] == 'F' || key_word[8] == 'F' )
            return MAT_WOOD_FIR;
         else
            return MAT_WOOD;
      case 144:
         return MAT_PITZER_CRUSHABLE_FOAM;
      case 145:
         return MAT_SCHWER_MURRAY_CAP_MODEL;
      case 146:
         return MAT_1DOF_GENERALIZED_SPRING;
      case 147:
         if( key_word[9] == 'N' )
            return MAT_FHWA_SOIL_NEBRASKA;
         else
            return MAT_FHWA_SOIL;
      case 148:
         return MAT_GAS_MIXTURE;
      case 151:
         return MAT_EMMI;
      case 153:
         return MAT_DAMAGE_3;
      case 154:
         return MAT_DESHPANDE_FLECK_FOAM;
      case 155:
         return MAT_PLASTICITY_COMPRESSION_TENSION_EOS;
      case 156:
         return MAT_MUSCLE;
      case 157:
         return MAT_ANISOTROPIC_ELASTIC_PLASTIC;
      case 158:
         return MAT_RATE_SENSITIVE_COMPOSITE_FABRIC;
      case 159:
         if( key_word[9] == 'C' || key_word[8] == 'C' )
            return MAT_CSCM_CONCRETE;
         else
            return MAT_CSCM;
      case 161:
         return MAT_COMPOSITE_MSC;
      case 162:
         return MAT_COMPOSITE_MSC_DMG;
      case 163:
         return MAT_MODIFIED_CRUSHABLE_FOAM;
      case 164:
         return MAT_BRAIN_LINEAR_VISCOELASTIC;
      case 165:
         return MAT_PLASTIC_NONLINEAR_KINEMATIC;
      case 166:
         return MAT_MOMENT_CURVATURE_BEAM;
      case 167:
         return MAT_MCCORMICK;
      case 168:
         return MAT_POLYMER;
      case 169:
         return MAT_ARUP_ADHESIVE;
      case 170:
         return MAT_RESULTANT_ANISOTROPIC;
      case 171:
         return MAT_STEEL_CONCENTRIC_BRACE;
      case 172:
         return MAT_CONCRETE_EC2;
      case 173:
         return MAT_MOHR_COULOMB;
      case 174:
         return MAT_RC_BEAM;
      case 175:
         return MAT_VISCOELASTIC_THERMAL;
      case 176:
         return MAT_QUASILINEAR_VISCOELASTIC;
      case 177:
         return MAT_HILL_FOAM;
      case 178:
         return MAT_VISCOELASTIC_HILL_FOAM;
      case 179:
         if( key_word[8] == '_' )
            return MAT_LOW_DENSITY_SYNTHETIC_FOAM_WITH_FAILURE;
         else
            return MAT_LOW_DENSITY_SYNTHETIC_FOAM;
      case 180:
         if( key_word[8] == '_' )
            return MAT_LOW_DENSITY_SYNTHETIC_FOAM_ORTHO_WITH_FAILURE;
         else
            return MAT_LOW_DENSITY_SYNTHETIC_FOAM_ORTHO;
      case 181:
         if( key_word[8] == '_' )
            return MAT_SIMPLIFIED_RUBBER_FOAM_WITH_FAILURE;
         else
            return MAT_SIMPLIFIED_RUBBER_FOAM;
      case 183:
         return MAT_SIMPLIFIED_RUBBER_WITH_DAMAGE;
      case 184:
         return MAT_COHESIVE_ELASTIC;
      case 185:
         return MAT_COHESIVE_TH;
      case 186:
         return MAT_COHESIVE_GENERAL;
      case 187:
         return MAT_SAMP_1;
      case 188:
         return MAT_THERMO_ELASTO_VISCOPLASTIC_CREEP;
      case 189:
         return MAT_ANISOTROPIC_THERMOELASTIC;
      case 190:
         return MAT_FLD_3_PARAMETER_BARLAT;
      case 191:
         return MAT_SEISMIC_BEAM;
      case 192:
         return MAT_SOIL_BRICK;
      case 193:
         return MAT_DRUCKER_PRAGER;
      case 194:
         return MAT_RC_SHEAR_WALL;
      case 195:
         return MAT_CONCRETE_BEAM;
      case 196:
         return MAT_GENERAL_SPRING_DISCRETE_BEAM;
      case 197:
         return MAT_SEISMIC_ISOLATOR;
      case 198:
         return MAT_JOINTED_ROCK;
   }
   return MAT_NEW_TYPE;
}

MatType MatImport::getMatTypeFrom7thDigit
	(
	   const char *key_word
        )
{
   char  num_str[8];
   unsigned int num = 0;

   num_str[0] = key_word[6];
   num_str[1] = key_word[7];
   num_str[2] = '\0';
   num = atoi( num_str );

   switch( key_word[5] )
   {
      case 'B':
         return MAT_SEATBELT;
      case 'S':
         switch( num )
         {
            case 1:
               return MAT_SPRING_ELASTIC;
            case 2:
               return MAT_DAMPER_VISCOUS;
            case 3:
               return MAT_SPRING_ELASTOPLASTIC;
            case 4:
               return MAT_SPRING_NONLINEAR_ELASTIC;
            case 5:
               return MAT_DAMPER_NONLINEAR_VISCOUS;
            case 6:
               return MAT_SPRING_GENERAL_NONLINEAR;
            case 7:
               return MAT_SPRING_MAXWELL;
            case 8:
               return MAT_SPRING_INELASTIC;
            case 13:
               return MAT_SPRING_TRILINEAR_DEGRADING;
            case 14:
               return MAT_SPRING_SQUAT_SHEARWALL;
            case 15:
               return MAT_SPRING_MUSCLE;
         }
         break;
      case 'T':
         switch( num )
         {
            case 1:
               return MAT_THERMAL_ISOTROPIC;
            case 2:
               return MAT_THERMAL_ORTHOTROPIC;
            case 3:
               return MAT_THERMAL_ISOTROPIC_TD;
            case 4:
               return MAT_THERMAL_ORTHOTROPIC_TD;
            case 5:
               return MAT_THERMAL_ISOTROPIC_PHASE_CHANGE;
            case 6:
               return MAT_THERMAL_ISOTROPIC_TD_LC;
            case 11:
               return MAT_THERMAL_USER_DEFINED;
            case 12:
               return MAT_THERMAL_USER_DEFINED;
            case 13:
               return MAT_THERMAL_USER_DEFINED;
            case 14:
               return MAT_THERMAL_USER_DEFINED;
            case 15:
               return MAT_THERMAL_USER_DEFINED;
         }
   }
   return MAT_NEW_TYPE;
}

MatType MatImport::getMatTypeFromKeyword
	(
	   const char *key_word,
	   unsigned int *mat_id
	)
{
   *mat_id = 0;

   if( isdigit(key_word[5]) )
   {
      if( key_word[6] == 'D' )
	 return MAT_1DOF_GENERALIZED_SPRING;
      else if(key_word[7] == 'P')
	 return MAT_3_PARAMETER_BARLAT;
      else
         return getMatTypeFrom6thDigit(key_word);
   }
   else if( isdigit(key_word[6]) )
   {
      return getMatTypeFrom7thDigit(key_word);
   }
   else if( isdigit(key_word[9]) && key_word[5] == 'A' )
   {
      switch(key_word[10])
      {
         case '1':
            return MAT_ALE_VACUUM;
         case '2':
            return MAT_ALE_VISCOUS;
         case '3':
            return MAT_ALE_GAS_MIXTURE;
      }
   }
   else if(key_word[5] == 'A')
   {
      if(key_word[6] == 'C')
	 return MAT_ACOUSTIC;
      else if(key_word[9] == 'E')
	 return MAT_ADD_EROSION;
      else if(key_word[9] == 'T')
	 return MAT_ADD_THERMAL_EXPANSION;
      else if(key_word[9] == 'G')
	 return MAT_ALE_GAS_MIXTURE;
      else if(key_word[9] == 'V')
      {
	 if(key_word[10] == 'A')
	    return MAT_ALE_VACUUM;
	 else if(key_word[10] == 'I')
	    return MAT_ALE_VISCOUS;
      }
      else if(key_word[6] == 'N')
      {
	 if(key_word[25] == 'P')
	    return MAT_ANISOTROPIC_ELASTIC_PLASTIC;
	 else if(key_word[17] == 'P')
	    return MAT_ANISOTROPIC_PLASTIC;
	 else if(key_word[17] == 'T')
	    return MAT_ANISOTROPIC_THERMOELASTIC;
	 else if(key_word[17] == 'V')
	    return MAT_ANISOTROPIC_VISCOPLASTIC;
	 else if(key_word[17] == 'E')
	    return MAT_ANISOTROPIC_ELASTIC;
      }
      else if(key_word[7] == 'R')
	 return MAT_ARRUDA_BOYCE_RUBBER;
      else if(key_word[7] == 'U')
	 return MAT_ARUP_ADHESIVE;
   }
   else if(key_word[5] == 'B')
   {
      if(key_word[10] == 'N')
      {
	 if(key_word[12] == 'D')
	    return MAT_BAMMAN_DAMAGE;
	 else
	    return MAT_BAMMAN;
      }
      else if(key_word[12] == 'A')
	 return MAT_BARLAT_ANISOTROPIC_PLASTICITY;
      else if(key_word[15] == '2')
	 return MAT_BARLAT_YLD2000;
      else if(key_word[15] == '9')
	 return MAT_BARLAT_YLD96;
      else if(key_word[6] == 'I')
	 return MAT_BILKHU_DUBOIS_FOAM;
      else if(key_word[14] == 'F')
	 return MAT_BLATZ_KO_FOAM;
      else if(key_word[14] == 'R')
	 return MAT_BLATZ_KO_RUBBER;
      else if(key_word[18] == 'V')
	 return MAT_BRAIN_LINEAR_VISCOELASTIC;
      else if(key_word[7] == 'I')
	 return MAT_BRITTLE_DAMAGE;
   }
   else if(key_word[5] == 'C')
   {
      if(key_word[6] == 'A')
	 return MAT_CABLE_DISCRETE_BEAM;
      else if(key_word[6] == 'E')
	 return MAT_CELLULAR_RUBBER;
      else if(key_word[6] == 'L')
	 return MAT_CLOSED_CELL_FOAM;
      else if(key_word[7] == 'H')
      {
	 if(key_word[14] == 'E')
	    return MAT_COHESIVE_ELASTIC;
	 else if(key_word[14] == 'G')
	    return MAT_COHESIVE_GENERAL;
	 else if(key_word[14] == 'M')
	    return MAT_COHESIVE_MIXED_MODE;
	 else if(key_word[14] == 'T')
	    return MAT_COHESIVE_TH;
      }
      else if(key_word[7] == 'M')
      {
	 if(key_word[17] == 'M')
	    return MAT_COMPOSITE_DAMAGE;
	 else if(key_word[17] == 'R')
	    return MAT_COMPOSITE_DIRECT;
	 else if(key_word[24] == 'H')
	    return MAT_COMPOSITE_FAILURE_SHELL_MODEL;
	 else if(key_word[24] == 'O')
	    return MAT_COMPOSITE_FAILURE_SOLID_MODEL;
	 else if(key_word[15] == 'L')
	    return MAT_COMPOSITE_LAYUP;
	 else if(key_word[17] == 'T')
	    return MAT_COMPOSITE_MATRIX;
	 else if(key_word[19] == 'D')
	    return MAT_COMPOSITE_MSC_DMG;
	 else if(key_word[17] == 'C')
	    return MAT_COMPOSITE_MSC;
      }
      else if(key_word[7] == 'N')
      {
	 if(key_word[14] == 'B')
	    return MAT_CONCRETE_BEAM;
	 else if(key_word[21] == 'R')
	    return MAT_CONCRETE_DAMAGE_REL3;
	 else if(key_word[19] == 'E')
	    return MAT_CONCRETE_DAMAGE;
	 else if(key_word[14] == 'E')
	    return MAT_CONCRETE_EC2;
      }
      else if(key_word[7] == 'R')
	 return MAT_CORUS_VEGTER;
      else if(key_word[7] == 'U')
	 return MAT_CRUSHABLE_FOAM;
      else if(key_word[10] == 'C')
	 return MAT_CSCM_CONCRETE;
      else if(key_word[8] == 'M')
	 return MAT_CSCM;
   }
   else if(key_word[5] == 'D')
   {
      if(key_word[12] == '1')
	 return MAT_DAMAGE_1;
      else if(key_word[12] == '2')
	 return MAT_DAMAGE_2;
      else if(key_word[12] == '3')
	 return MAT_DAMAGE_3;
      else if(key_word[12] == 'N')
	 return MAT_DAMPER_NONLINEAR_VISCOUS;
      else if(key_word[12] == 'V')
	 return MAT_DAMPER_VISCOUS;
      else if(key_word[6] == 'E')
	 return MAT_DESHPANDE_FLECK_FOAM;
      else if(key_word[6] == 'R')
	 return MAT_DRUCKER_PRAGER;
   }
   else if(key_word[5] == 'E')
   {
      if(key_word[6] == 'L')
      {
	 if(key_word[13] == '6')
	    return MAT_ELASTIC_6DOF_SPRING_DISCRETE_BEAM;
	 else if(key_word[13] == 'F')
	    return MAT_ELASTIC_FLUID;
	 else if(key_word[27] == 'S')
	    return MAT_ELASTIC_PLASTIC_HYDRO_SPALL;
	 else if(key_word[21] == 'H')
	    return MAT_ELASTIC_PLASTIC_HYDRO;
	 else if(key_word[21] == 'T')
	    return MAT_ELASTIC_PLASTIC_THERMAL;
	 else if(key_word[13] == 'S')
	    return MAT_ELASTIC_SPRING_DISCRETE_BEAM;
	 else if(key_word[13] == 'V')
	    return MAT_ELASTIC_VISCOPLASTIC_THERMAL;
	 else if(key_word[28] == 'C')
	    return MAT_ELASTIC_WITH_VISCOSITY_CURVE;
	 else if(key_word[26] == 'Y')
	    return MAT_ELASTIC_WITH_VISCOSITY;
	 else if(key_word[11] == 'C')
	    return MAT_ELASTIC;
      }
      else if(key_word[6] == 'M')
	 return MAT_EMMI;
      else if(key_word[6] == 'N')
	 return MAT_ENHANCED_COMPOSITE_DAMAGE;
   }
   else if(key_word[5] == 'F')
   {
      if(key_word[6] == 'A')
	 return MAT_FABRIC;
      else if(key_word[15] == 'N')
	 return MAT_FHWA_SOIL_NEBRASKA;
      else if(key_word[10] == 'S')
	 return MAT_FHWA_SOIL;
      else if(key_word[6] == 'I')
	 return MAT_FINITE_ELASTIC_STRAIN_PLASTICITY;
      else if(key_word[9] == '3')
	 return MAT_FLD_3_PARAMETER_BARLAT;
      else if(key_word[9] == 'T')
	 return MAT_FLD_TRANSVERSELY_ANISOTROPIC;
      else if(key_word[6] == 'O')
	 return MAT_FORCE_LIMITED;
      else if(key_word[6] == 'R')
	 return MAT_FRAZER_NASH_RUBBER_MODEL;
      else if(key_word[6] == 'U')
	 return MAT_FU_CHANG_FOAM;
   }
   else if(key_word[5] == 'G')
   {
      if(key_word[6] == 'A')
	 return MAT_GAS_MIXTURE;
      else if(key_word[13] == 'J')
	 return MAT_GENERAL_JOINT_DISCRETE_BEAM;
      else if(key_word[23] == '1')
	 return MAT_GENERAL_NONLINEAR_1DOF_DISCRETE_BEAM;
      else if(key_word[23] == '6')
	 return MAT_GENERAL_NONLINEAR_6DOF_DISCRETE_BEAM;
      else if(key_word[13] == 'S')
	 return MAT_GENERAL_SPRING_DISCRETE_BEAM;
      else if(key_word[13] == 'V')
	 return MAT_GENERAL_VISCOELASTIC;
      else if(key_word[7] == 'O')
	 return MAT_GEOLOGIC_CAP_MODEL;
      else if(key_word[7] == 'P')
	 return MAT_GEPLASTIC_SRATE_2000a;
      else if(key_word[12] == 'J')
	 return MAT_GURSON_JC;
      else if(key_word[12] == 'R')
	 return MAT_GURSON_RCDC;
      else if(key_word[10] == 'N')
	 return MAT_GURSON;
   }
   else if(key_word[5] == 'H')
   {
      if(key_word[6] == 'E')
	 return MAT_HEART_TISSUE;
      else if(key_word[7] == 'G')
	 return MAT_HIGH_EXPLOSIVE_BURN;
      else if(key_word[10] == '3')
	 return MAT_HILL_3R;
      else if(key_word[10] == 'F')
	 return MAT_HILL_FOAM;
      else if(key_word[6] == 'O')
	 return MAT_HONEYCOMB;
      else if(key_word[7] == 'D')
	 return MAT_HYDRAULIC_GAS_DAMPER_DISCRETE_BEAM;
      else if(key_word[7] == 'P')
	 return MAT_HYPERELASTIC_RUBBER;
      else if(key_word[7] == 'S')
	 return MAT_HYSTERETIC_SOIL;
   }
   else if(key_word[5] == 'I')
   {
      if(key_word[15] == '6')
	 return MAT_INELASTIC_6DOF_SPRING_DISCRETE_BEAM;
      else if(key_word[7] == 'E')
	 return MAT_INELASTIC_SPRING_DISCRETE_BEAM;
      else if(key_word[7] == 'V')
	 return MAT_INV_HYPERBOLIC_SIN;
      else if(key_word[23] == 'F')
	 return MAT_ISOTROPIC_ELASTIC_FAILURE;
      else if(key_word[23] == 'P')
	 return MAT_ISOTROPIC_ELASTIC_PLASTIC;
      else if(key_word[15] == 'S')
	 return MAT_ISOTROPIC_SMEARED_CRACK;
   }
   else if(key_word[5] == 'J')
   {
      if(key_word[13] == 'C')
	 return MAT_JOHNSON_COOK;
      else if(key_word[24] == 'E')
	 return MAT_JOHNSON_HOLMQUIST_CERAMICS;
      else if(key_word[24] == 'O')
	 return MAT_JOHNSON_HOLMQUIST_CONCRETE;
      else if(key_word[7] == 'I')
	 return MAT_JOINTED_ROCK;
   }
   else if(key_word[5] == 'K')
   {
      if(key_word[6] == 'E')
	 return MAT_KELVIN_MAXWELL_VISCOELASTIC;
      else if(key_word[6] == 'I')
	 return MAT_KINEMATIC_HARDENING_TRANSVERSELY_ANISOTROPIC;
   }
   else if(key_word[5] == 'L')
   {
      if(key_word[15] == 'C')
	 return MAT_LAMINATED_COMPOSITE_FABRIC;
      else if(key_word[15] == 'G')
	 return MAT_LAMINATED_GLASS;
      else if(key_word[7] == 'Y')
	 return MAT_LAYERED_LINEAR_PLASTICITY;
      else if(key_word[6] == 'I')
	 return MAT_LINEAR_ELASTIC_DISCRETE_BEAM;
      else if(key_word[17] == 'F')
	 return MAT_LOW_DENSITY_FOAM;
      else if(key_word[38] == 'W')
	 return MAT_LOW_DENSITY_SYNTHETIC_FOAM_ORTHO_WITH_FAILURE;
      else if(key_word[36] == 'O')
	 return MAT_LOW_DENSITY_SYNTHETIC_FOAM_ORTHO;
      else if(key_word[32] == 'W')
	 return MAT_LOW_DENSITY_SYNTHETIC_FOAM_WITH_FAILURE;
      else if(key_word[30] == 'M')
	 return MAT_LOW_DENSITY_SYNTHETIC_FOAM;
      else if(key_word[28] == 'M')
	 return MAT_LOW_DENSITY_VISCOUS_FOAM;
      else if(key_word[6] == 'U')
	 return MAT_LUNG_TISSUE;
   }
   else if(key_word[5] == 'M')
   {
      if(key_word[6] == 'C')
	 return MAT_MCCORMICK;
      else if(key_word[14] == 'C')
	 return MAT_MODIFIED_CRUSHABLE_FOAM;
      else if(key_word[14] == 'F')
	 return MAT_MODIFIED_FORCE_LIMITED;
      else if(key_word[14] == 'H')
	 return MAT_MODIFIED_HONEYCOMB;
      else if(key_word[14] == 'J')
	 return MAT_MODIFIED_JOHNSON_COOK;
      else if(key_word[42] == 'R')
	 return MAT_MODIFIED_PIECEWISE_LINEAR_PLASTICITY_RATE;
      else if(key_word[40] == 'Y')
	 return MAT_MODIFIED_PIECEWISE_LINEAR_PLASTICITY;
      else if(key_word[14] == 'Z')
	 return MAT_MODIFIED_ZERILLI_ARMSTRONG;
      else if(key_word[7] == 'H')
	 return MAT_MOHR_COULOMB;
      else if(key_word[7] == 'M')
	 return MAT_MOMENT_CURVATURE_BEAM;
      else if(key_word[7] == 'O')
	 return MAT_MOONEY_RIVLIN_RUBBER;
      else if(key_word[6] == 'T')
	 return MAT_MTS;
      else if(key_word[6] == 'U')
	 return MAT_MUSCLE;
   }
   else if(key_word[5] == 'N')
   {
      if(key_word[15] == 'E')
	 return MAT_NONLINEAR_ELASTIC_DISCRETE_BEAM;
      else if(key_word[15] == 'O')
	 return MAT_NONLINEAR_ORTHOTROPIC;
      else if(key_word[15] == 'P')
	 return MAT_NONLINEAR_PLASTIC_DISCRETE_BEAM;
      else if(key_word[6] == 'O')
	 return MAT_NONLOCAL;
      else if(key_word[6] == 'U')
	 return MAT_NULL;
   }
   else if(key_word[5] == 'O')
   {
      if(key_word[6] == 'G')
	 return MAT_OGDEN_RUBBER;
      else if(key_word[7] == 'I')
	 return MAT_ORIENTED_CRACK;
      else if(key_word[11] == 'E')
	 return MAT_ORTHO_ELASTIC_PLASTIC;
      else if(key_word[17] == 'E')
	 return MAT_ORTHOTROPIC_ELASTIC;
      else if(key_word[17] == 'S')
	 return MAT_ORTHOTROPIC_SMEARED_CRACK;
      else if(key_word[17] == 'T')
	 return MAT_ORTHOTROPIC_THERMAL;
      else if(key_word[17] == 'V')
	 return MAT_ORTHOTROPIC_VISCOELASTIC;
   }
   else if(key_word[5] == 'P')
   {
      if(key_word[8] == 'C')
	 return MAT_PIECEWISE_LINEAR_PLASTICITY;
      else if(key_word[7] == 'T')
	 return MAT_PITZER_CRUSHABLE_FOAM;
      else if(key_word[13] == 'G')
	 return MAT_PLASTIC_GREEN_NAGHDI_RATE;
      else if(key_word[36] == 'E')
	 return MAT_PLASTICITY_COMPRESSION_TENSION_EOS;
      else if(key_word[16] == 'C')
	 return MAT_PLASTICITY_COMPRESSION_TENSION;
      else if(key_word[16] == 'P')
	 return MAT_PLASTICITY_POLYMER;
      else if(key_word[34] == 'R')
	 return MAT_PLASTICITY_WITH_DAMAGE_ORTHO_RCDC;
      else if(key_word[28] == 'O')
	 return MAT_PLASTICITY_WITH_DAMAGE_ORTHO;
      else if(key_word[21] == 'D')
	 return MAT_PLASTICITY_WITH_DAMAGE;
      else if(key_word[13] == 'K')
	 return MAT_PLASTIC_KINEMATIC;
      else if(key_word[13] == 'N')
	 return MAT_PLASTIC_NONLINEAR_KINEMATIC;
      else if(key_word[7] == 'L')
	 return MAT_POLYMER;
      else if(key_word[7] == 'W')
	 return MAT_POWER_LAW_PLASTICITY;
      else if(key_word[6] == 'S')
	 return MAT_PSEUDO_TENSOR;
   }
   else if(key_word[5] == 'Q')
      return MAT_QUASILINEAR_VISCOELASTIC;
   else if(key_word[5] == 'R')
   {
      if(key_word[7] == 'M')
	 return MAT_RAMBERG_OSGOOD;
      else if(key_word[20] == 'C')
	 return MAT_RATE_SENSITIVE_COMPOSITE_FABRIC;
      else if(key_word[22] == 'L')
	 return MAT_RATE_SENSITIVE_POLYMER;
      else if(key_word[22] == 'W')
	 return MAT_RATE_SENSITIVE_POWERLAW_PLASTICITY;
      else if(key_word[8] == 'B')
	 return MAT_RC_BEAM;
      else if(key_word[8] == 'S')
	 return MAT_RC_SHEAR_WALL;
      else if(key_word[15] == 'A')
	 return MAT_RESULTANT_ANISOTROPIC;
      else if(key_word[15] == 'P')
	 return MAT_RESULTANT_PLASTICITY;
      else if(key_word[6] == 'I')
	 return MAT_RIGID;
   }
   else if(key_word[5] == 'S')
   {
      if(key_word[6] == 'A')
	 return MAT_SAMP_1;
      else if(key_word[6] == 'C')
	 return MAT_SCHWER_MURRAY_CAP_MODEL;
      else if(key_word[6] == 'E')
      {
	 if(key_word[7] == 'A')
	    return MAT_SEATBELT;
	 else if(key_word[13] == 'B')
	    return MAT_SEISMIC_BEAM;
	 else if(key_word[13] == 'I')
	    return MAT_SEISMIC_ISOLATOR;
      }
      else if(key_word[6] == 'H')
	 return MAT_SHAPE_MEMORY;
      else if(key_word[6] == 'I')
      {
         if(key_word[7] == 'D')
	    return MAT_SID_DAMPER_DISCRETE_BEAM;
	 else if(key_word[7] == 'M')
         {
	    if(key_word[29] == 'O')
	       return MAT_SIMPLIFIED_JOHNSON_COOK_ORTHOTROPIC_DAMAGE;
	    else if(key_word[27] == 'K')
	       return MAT_SIMPLIFIED_JOHNSON_COOK;
	    else if(key_word[28] == 'W')
	       return MAT_SIMPLIFIED_RUBBER_FOAM_WITH_FAILURE;
	    else if(key_word[23] == 'W')
	       return MAT_SIMPLIFIED_RUBBER_WITH_DAMAGE;
	    else if(key_word[26] == 'M')
	       return MAT_SIMPLIFIED_RUBBER_FOAM;
         }
      }
      else if(key_word[6] == 'O')
      {
	 if(key_word[7] == 'F')
         {
	    if(key_word[17] == 'V')
	       return MAT_SOFT_TISSUE_VISCO;
	    else if(key_word[10] == 'T')
	       return MAT_SOFT_TISSUE;
         }
	 else if(key_word[7] == 'I')
         {
	    if(key_word[19] == 'F')
	       return MAT_SOIL_AND_FOAM_FAILURE;
	    else if(key_word[17] == 'M')
	       return MAT_SOIL_AND_FOAM;
	    else if(key_word[10] == 'B')
	       return MAT_SOIL_BRICK;
	    else if(key_word[10] == 'C')
	       return MAT_SOIL_CONCRETE;
         }
      }
      else if(key_word[6] == 'P')
      {
	 if(key_word[7] == 'E')
	    return MAT_SPECIAL_ORTHOTROPIC;
	 else if(key_word[7] == 'O')
	 {
	    if(key_word[16] == 'I')
	       return MAT_SPOTWELD_DAIMLERCHRYSLER;
	    else if(key_word[17] == 'A')
	       return MAT_SPOTWELD_DAMAGE_FAILURE;
	    else
	       return MAT_SPOTWELD;
	 }
	 else if(key_word[7] == 'R')
	 {
	    if(key_word[17] == 'I')
	       return MAT_SPRING_ELASTIC;
	    else if(key_word[17] == 'O')
	       return MAT_SPRING_ELASTOPLASTIC;
	    else if(key_word[12] == 'G')
	       return MAT_SPRING_GENERAL_NONLINEAR;
	    else if(key_word[12] == 'I')
	       return MAT_SPRING_INELASTIC;
	    else if(key_word[13] == 'A')
	       return MAT_SPRING_MAXWELL;
	    else if(key_word[13] == 'U')
	       return MAT_SPRING_MUSCLE;
	    else if(key_word[13] == 'O')
	       return MAT_SPRING_NONLINEAR_ELASTIC;
	    else if(key_word[13] == 'Q')
	       return MAT_SPRING_SQUAT_SHEARWALL;
	    else if(key_word[13] == 'R')
	       return MAT_SPRING_TRILINEAR_DEGRADING;
	 }
      }
      else if(key_word[6] == 'T')
      {
	 if(key_word[8] == 'E')
	    return MAT_STEEL_CONCENTRIC_BRACE;
	 else if(key_word[15] == 'L')
	    return MAT_STEINBERG_LUND;
	 else if(key_word[13] == 'G')
	    return MAT_STEINBERG;
	 else if(key_word[7] == 'R')
	    return MAT_STRAIN_RATE_DEPENDENT_PLASTICITY;
      }
   }
   else if(key_word[5] == 'T')
   {
      if(key_word[6] == 'E')
	 return MAT_TEMPERATURE_DEPENDENT_ORTHOTROPIC;
      else if(key_word[13] == 'I')
      {
	 if(key_word[23] == 'P')
	    return MAT_THERMAL_ISOTROPIC_PHASE_CHANGE;
	 else if(key_word[27] == 'C')
	    return MAT_THERMAL_ISOTROPIC_TD_LC;
	 else if(key_word[24] == 'D')
	    return MAT_THERMAL_ISOTROPIC_TD;
	 else if(key_word[21] == 'C')
	    return MAT_THERMAL_ISOTROPIC;
      }
      else if(key_word[13] == 'O')
      {
	 if(key_word[25] == 'T')
	    return MAT_THERMAL_ORTHOTROPIC_TD;
	 else if(key_word[23] == 'C')
	    return MAT_THERMAL_ORTHOTROPIC;
      }
      else if(key_word[13] == 'U')
	 return MAT_THERMAL_USER_DEFINED;
      else if(key_word[13] == 'L')
	 return MAT_THERMO_ELASTO_VISCOPLASTIC_CREEP;
      else if(key_word[46] == 'E')
	 return MAT_TRANSVERSELY_ANISOTROPIC_ELASTIC_PLASTIC_ECHANGE;
      else if(key_word[44] == 'C')
	 return MAT_TRANSVERSELY_ANISOTROPIC_ELASTIC_PLASTIC;
      else if(key_word[18] == 'I')
	 return MAT_TRANSVERSELY_ISOTROPIC_CRUSHABLE_FOAM;
      else if(key_word[7] == 'I')
	 return MAT_TRIP;
   }
   else if(key_word[5] == 'U')
   {
      if(key_word[6] == 'N')
	 return MAT_UNIFIED_CREEP;
      else if(key_word[6] == 'S')
	 return MAT_USER_DEFINED_MATERIAL_MODELS;
   }
   else if(key_word[5] == 'V')
   {
      if(key_word[6] == 'A')
	 return MAT_VACUUM;
      else if(key_word[18] == 'H')
	 return MAT_VISCOELASTIC_HILL_FOAM;
      else if(key_word[18] == 'T')
	 return MAT_VISCOELASTIC_THERMAL;
      else if(key_word[16] == 'C')
	 return MAT_VISCOELASTIC;
      else if(key_word[10] == 'U')
	 return MAT_VISCOUS_FOAM;
   }
   else if(key_word[5] == 'W')
   {
      if(key_word[23] == 'R')
	 return MAT_WINFRITH_CONCRETE_REINFORCEMENT;
      else if(key_word[21] == 'E')
	 return MAT_WINFRITH_CONCRETE;
      else if(key_word[10] == 'F')
	 return MAT_WOOD_FIR;
      else if(key_word[10] == 'P')
	 return MAT_WOOD_PINE;
      else if(key_word[8] == 'D')
	 return MAT_WOOD;
      else if(key_word[13] == 'P')
	 return MAT_WTM_STM_PLC;
      else if(key_word[11] == 'M')
	 return MAT_WTM_STM;
   }

   return MAT_NEW_TYPE;
}

unsigned int MatImport::readMats()
{
   char         new_kw[LINE_LEN];
   unsigned int	i = 0, mat_id = 0, mat_type = 0, num_mats = 0, title_flag;
   long		loc = 0L;
   VStringIterator   s = dataLocPtr->keywordList.begin(),
		     e = dataLocPtr->keywordList.end(), itr, 
		     pitr = dataLocPtr->keywordList.begin();
   typeFuncIterator  btype_iter = typeFuncMap.begin(),
                     etype_iter = typeFuncMap.end(), type_iter;

   dataLine = new DataLine(filePtr);

   while(true)
   {
      itr = find_if(pitr, e, bind2nd(KeyWordCompare (), "*MAT_"));

      if( itr == e )
	 break;

      pitr = itr+1;
      i = (unsigned int)(itr - s);
      loc = dataLocPtr->slocList[i];

      rewind(filePtr);

      if( fseek(filePtr, loc, SEEK_SET) )
      {
	 cout << "ERROR in locating the Mat cards" << endl;
	 break;
      }

      dataLine->clearFlag(KW_READ_END);

      char *str = dataLine->readNextCard(); //get the keyword
      Generic::RemoveLeadingAndTrailingBlanks( str );
cout << "KW = " << str << endl;

      mat_type = getMatTypeFromKeyword( str, &mat_id );
cout << "Mat TYPE = " << mat_type << endl;

      if( mat_type == MAT_NEW_TYPE )
      {
         cout << "Mat TYPE NOT SUPPORTED" << endl;
         continue;
      }

      num_mats++;

      strcpy(new_kw, str);

      dataLine->clearFlag(KW_READ_END);
      type_iter = typeFuncMap.find(mat_type);

      title_flag = 0;
      if( strstr(new_kw, "_TITL") )
      {
         title_flag = 1;
	 mat_type += TITLE_CARD;
      }

      if( type_iter != etype_iter )
      {
          impObj = new ImportObject(str, mat_type);

          if( title_flag )
          {
	     Title title(dataLine, impObj);
	     title.readCard();
          }

          (type_iter->second)(dataLine, impObj);

	  sprintf(new_kw, "%s_%d", new_kw, num_mats);
	  matManPtr->add(new_kw, impObj);
      }
      else
         cout << "Mat TYPE NOT FOUND" << endl;
   }

   return num_mats;
}

