#ifndef _Mat_IMPORT_H_
#define _Mat_IMPORT_H_

#include <string>
#include <map>
#include "dataloc.h"
#include "matmanager.h"
#include "dataline.h"
#include "card.h"
#include "mattype.h"
#include "typemap.h"

/** Class to import the data from native LSDYNA file for *MAT keywords. All
  * the data is imported through this class and stored in the manager object.
  */
class MatImport
{
public:
   /** Constructor for creating this object
     * \param fp File pointer to the LSDYNA native file
     * \param data_loc Pointer to the list of keywords and their locations in
     * the file
     * \param mat_man Manager pointer to hold the imported data as a list of
     * ImportObject list
     */
   MatImport
   (
      FILE          *fp,
      DataLoc       *data_loc,
      MatManager    *mat_man
   );

   ~MatImport()
   {
      filePtr = NULL;
      matManPtr = NULL;
      dataLocPtr = NULL;
      delete dataLine;
   }

   /** Function for getting the keyword type from given keyword name from LSDYNA
     * native file. The type is stored in the database
     * \param key_word Name of the keyword from file
     * \param mat_id ID of the keyword if it is there
     * \return Type for *MAT group of keywords if found else MAT_NEW_TYPE
     */
   static MatType getMatTypeFromKeyword
	   (
	      const char  *key_word,
	      unsigned int *mat_id
	   );

   /** Reads the *MAT keywords from file
     * \return Returns 0 on failure else number of *MAT keywords
     */
   unsigned int readMats();

   /** To parse the file faster while reading the sixth char of *MAT keyword
     * is used to determine the type of material
     * \param key_word *MAT keyword for which the type is required
     * \return Material type for the *MAT keyword
     */
   static MatType getMatTypeFrom6thDigit
	   (
	      const char *key_word
	   );

   /** To parse the file faster while reading the seventh char of *MAT keyword
     * is used to determine the type of material
     * \param key_word *MAT keyword for which the type is required
     * \return Material type for the *MAT keyword
     */
   static MatType getMatTypeFrom7thDigit
	   (
	      const char *key_word
	   );

   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initAleTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initAnisotropicTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initBammanTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initBarlatTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initBlatzTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initCohesiveTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initCompoTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initCompositeTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initConcreteTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initDamperTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initDiscreteTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initDofTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initElasticTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initFoamTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initGeneralTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initGensprTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initGursonTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initHoneyTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initLowdenseTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initModifiedTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initModifyTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initMohrTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initOrthoTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initOthersTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initPlasticTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initPlasticityTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initSeatbeltTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initSeismicTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initSensitiveTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initSimpleTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initSoilTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initSpringTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initSpringdisTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initThermalTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initViscoelasticTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initViscoplasticTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords */
   void initWeldTypesAndFunctions();

private:
   FILE          *filePtr;
   /** Manager pointer for holding the imported data for all the keywords */
   MatManager    *matManPtr;
   /** Pointer to keywords and their locations in the file */
   DataLoc       *dataLocPtr;
   /** Pointer to access the file data line by line */
   DataLine      *dataLine;
   /** Object to store imported data from LSDYNA data file */
   ImportObject  *impObj;
   /** A map between the keyword type and pointer to function */
   map<unsigned int, ImportFunctionPtr>  typeFuncMap;
};

#endif

