#ifndef _MatModifiedJohnsonCook_h_
#define _MatModifiedJohnsonCook_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *MAT_MODIFIED_JOHNSON_COOK keyword
  * from LSDYNA native file */

class MatModifiedJohnsonCook : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   MatModifiedJohnsonCook(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~MatModifiedJohnsonCook()
   {
   }

public:
/** Function to import Card1 details for *MAT_MODIFIED_JOHNSON_COOK
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"MID","RO","E","PR","BETA","XS1","CP","ALPHA",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, MAT, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *MAT_MODIFIED_JOHNSON_COOK
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"E0DOT","Tr","Tm","T0","FLAG1","FLAG2",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      flag1 = 0;
      if( wordArray[4] )
         flag1 = atoi(wordArray[4]);
      flag2 = 0;
      if( wordArray[5] )
         flag2 = atoi(wordArray[5]);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3FLAG10 details for *MAT_MODIFIED_JOHNSON_COOK
  * keyword from file */
   void readCard3FLAG10()
   {
      const char *fields[] = {"A","B","N","C","m",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 5;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3FLAG10");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card4FLAG10 details for *MAT_MODIFIED_JOHNSON_COOK
  * keyword from file */
   void readCard4FLAG10()
   {
      const char *fields[] = {"Q1","C1","Q2","C2",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card4FLAG10");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3FLAG11 details for *MAT_MODIFIED_JOHNSON_COOK
  * keyword from file */
   void readCard3FLAG11()
   {
      const char *fields[] = {"SIGA","B","BETA0","BETA1",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3FLAG11");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card4FLAG11 details for *MAT_MODIFIED_JOHNSON_COOK
  * keyword from file */
   void readCard4FLAG11()
   {
      const char *fields[] = {"A","N","ALPHA0","ALPHA1",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card4FLAG11");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card5FLAG20 details for *MAT_MODIFIED_JOHNSON_COOK
  * keyword from file */
   void readCard5FLAG20()
   {
      const char *fields[] = {"DC","PD","D1","D2","D3","D4","D5",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card5FLAG20");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card5FLAG21 details for *MAT_MODIFIED_JOHNSON_COOK
  * keyword from file */
   void readCard5FLAG21()
   {
      const char *fields[] = {"DC","WC",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 2;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card5FLAG21");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card6 details for *MAT_MODIFIED_JOHNSON_COOK
  * keyword from file */
   void readCard6()
   {
      const char *fields[] = {"TC","TAUC",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 2;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card6");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *MAT_MODIFIED_JOHNSON_COOK
  * from LSDYNA native file */
   unsigned int importMatModifiedJohnsonCook()
   {
      readCard1();
      readCard2();
      if( flag1 == 0 )
      {
         readCard3FLAG10();
         readCard4FLAG10();
      }
      else if( flag1 == 1 )
      {
         readCard3FLAG11();
         readCard4FLAG11();
      }
      if( flag2 == 0 )
      {
         readCard5FLAG20();
      }
      else if( flag2 == 1 )
      {
         readCard5FLAG21();
      }
      readCard6();
      return 0;
   }
public:
   int flag1;
   int flag2;
};

#endif

