#ifndef _MatModifiedZerilliArmstrong_h_
#define _MatModifiedZerilliArmstrong_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *MAT_MODIFIED_ZERILLI_ARMSTRONG keyword
  * from LSDYNA native file */

class MatModifiedZerilliArmstrong : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   MatModifiedZerilliArmstrong(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~MatModifiedZerilliArmstrong()
   {
   }

public:
/** Function to import Card1 details for *MAT_MODIFIED_ZERILLI_ARMSTRONG
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"MID","RO","G","E0","N","TROOM","PC","SPALL",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, MAT, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *MAT_MODIFIED_ZERILLI_ARMSTRONG
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"C1","C2","C3","C4","C5","C6","EFAIL","VP",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3 details for *MAT_MODIFIED_ZERILLI_ARMSTRONG
  * keyword from file */
   void readCard3()
   {
      const char *fields[] = {"B1","B2","B3","G1","G2","G3","G4","BULK",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *MAT_MODIFIED_ZERILLI_ARMSTRONG
  * from LSDYNA native file */
   unsigned int importMatModifiedZerilliArmstrong()
   {
      readCard1();
      readCard2();
      readCard3();
      return 0;
   }
};

#endif

