#ifndef _MatTemperatureDependentOrthotropic_h_
#define _MatTemperatureDependentOrthotropic_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *MAT_TEMPERATURE_DEPENDENT_ORTHOTROPIC keyword
  * from LSDYNA native file */

class MatTemperatureDependentOrthotropic : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   MatTemperatureDependentOrthotropic(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~MatTemperatureDependentOrthotropic()
   {
   }

public:
/** Function to import Card1 details for *MAT_TEMPERATURE_DEPENDENT_ORTHOTROPIC
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"MID","RO","AOPT","REF","MACF",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, };
      numFields = 5;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, MAT, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *MAT_TEMPERATURE_DEPENDENT_ORTHOTROPIC
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"XP","YP","ZP","A1","A2","A3",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3 details for *MAT_TEMPERATURE_DEPENDENT_ORTHOTROPIC
  * keyword from file */
   void readCard3()
   {
      const char *fields[] = {"V1","V2","V3","D1","D2","D3","BETA",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card1Temp details for *MAT_TEMPERATURE_DEPENDENT_ORTHOTROPIC
  * keyword from file */
   void readCard1Temp()
   {
      const char *fields[] = {"EAi","EBi","ECi","PRBAi","PRCAi","PRCBi",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1Temp");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2Temp details for *MAT_TEMPERATURE_DEPENDENT_ORTHOTROPIC
  * keyword from file */
   void readCard2Temp()
   {
      const char *fields[] = {"AAi","ABi","ACi","GABi","GBCi","GCAi","Ti",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2Temp");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *MAT_TEMPERATURE_DEPENDENT_ORTHOTROPIC
  * from LSDYNA native file */
   unsigned int importMatTemperatureDependentOrthotropic()
   {
      readCard1();
      readCard2();
      readCard3();
      readCard1Temp();
      readCard2Temp();
      while(numFields)
      {
         readCard1Temp();
         readCard2Temp();
      }
      return 0;
   }
};

#endif

