#ifndef _MatUserDefinedMaterialModels_h_
#define _MatUserDefinedMaterialModels_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *MAT_USER_DEFINED_MATERIAL_MODELS keyword
  * from LSDYNA native file */

class MatUserDefinedMaterialModels : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   MatUserDefinedMaterialModels(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~MatUserDefinedMaterialModels()
   {
   }

public:
/** Function to import Card1 details for *MAT_USER_DEFINED_MATERIAL_MODELS
  * keyword from file */
   int readCard1()
   {
      const char *fields[] = {"MID","RO","MT","LMC","NHV","IORTHO","IBULK","IG",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return 0;
      lmc = 0;
      if( wordArray[3] )
         lmc = atoi(wordArray[3]);
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, MAT, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
      if( wordArray[5] )
         return atoi(wordArray[5]);
      else
         return 0;
   }

/** Function to import Card2 details for *MAT_USER_DEFINED_MATERIAL_MODELS
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"IVECT","IFAIL","ITHERM","IHYPER","IEOS",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 5;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card1IORTHO1 details for *MAT_USER_DEFINED_MATERIAL_MODELS
  * keyword from file */
   void readCard1IORTHO1()
   {
      const char *fields[] = {"AOPT","MACF","XP","YP","ZP","A1","A2","A3",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1IORTHO1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2IORTHO1 details for *MAT_USER_DEFINED_MATERIAL_MODELS
  * keyword from file */
   void readCard2IORTHO1()
   {
      const char *fields[] = {"V1","V2","V3","D1","D2","D3","BETA",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2IORTHO1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import CardLMC details for *MAT_USER_DEFINED_MATERIAL_MODELS
  * keyword from file */
   void readCardLMC()
   {
      const char *fields[] = {"P1","P2","P3","P4","P5","P6","P7","P8",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int i, end_loop;
      end_loop = ((lmc%8) ? (lmc/8)+1 : lmc/8);
      for(i = 0; i < end_loop; i++)
      {
         numFields = 8;
         wordArray = dataLine->readNextCardAsWords(numFields);
         if( !numFields && dataLine->isFlagOn(KW_READ_END) ) return;

         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
         {
            cardObj = new Card("CardLMC");
            cardObj->addFields(numFields, field_types, fields, wordArray);
            impObj->addCard(cardObj);
         }
      }
   }

/** Function to import all the cards of the keyword *MAT_USER_DEFINED_MATERIAL_MODELS
  * from LSDYNA native file */
   unsigned int importMatUserDefinedMaterialModels()
   {
      int iortho = 0;
      iortho = readCard1();
      readCard2();
      if( iortho == 1 )
      {
         readCard1IORTHO1();
         readCard2IORTHO1();
      }
      readCardLMC();
      return 0;
   }
public:
   int lmc;
};

#endif

