#ifndef _MatConcreteEc2_h_
#define _MatConcreteEc2_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *MAT_CONCRETE_EC2 keyword
  * from LSDYNA native file */

class MatConcreteEc2 : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   MatConcreteEc2(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~MatConcreteEc2()
   {
   }

public:
/** Function to import Card1 details for *MAT_CONCRETE_EC2
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"MID","RO","FC","FT","TYPEC","UNITC",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, MAT, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *MAT_CONCRETE_EC2
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"ESOFT","LCHAR","MU",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 3;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3 details for *MAT_CONCRETE_EC2
  * keyword from file */
   void readCard3()
   {
      const char *fields[] = {"YMREINF","PRREINF","SUREINF","TYPER","FRACRX","FRACY",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Blank details for *MAT_CONCRETE_EC2
  * keyword from file */
   void readBlank()
   {
      const char *fields[] = {"UNUSED",};
      unsigned int field_types[] = {DATA_UNUSED, };
      numFields = 1;
      unsigned int field_widths[] = {80, };
      strBuff = dataLine->readNextCard(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Blank");
         cardObj->addFields(numFields, field_types, field_widths, fields, strBuff);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *MAT_CONCRETE_EC2
  * from LSDYNA native file */
   unsigned int importMatConcreteEc2()
   {
      readCard1();
      readCard2();
      readCard3();
      readBlank();
      return 0;
   }
};

#endif

