#ifndef _MatSeismicBeam_h_
#define _MatSeismicBeam_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *MAT_SEISMIC_BEAM keyword
  * from LSDYNA native file */

class MatSeismicBeam : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   MatSeismicBeam(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~MatSeismicBeam()
   {
   }

public:
/** Function to import Card1 details for *MAT_SEISMIC_BEAM
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"MID","RO","E","PR","AOPT","FTYPE","DEGRAD","IFEMA",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      ftype = 0;
      if( wordArray[5] )
         ftype = atoi(wordArray[5]);
      ifema = 0;
      if( wordArray[7] )
         ifema = atoi(wordArray[7]);
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, MAT, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *MAT_SEISMIC_BEAM
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"LCPMS","SFS","LCPMT","SFT","LCAT","SFAT","LCAC","SFAC",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, 2, 4, 6, };
      unsigned int man_types[] = {DEFINE, DEFINE, DEFINE, DEFINE, };
      unsigned int kw_types[] = {CURVE, CURVE, CURVE, CURVE, };
      unsigned int num_indices = 4;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3FTYPE1 details for *MAT_SEISMIC_BEAM
  * keyword from file */
   void readCard3FTYPE1()
   {
      const char *fields[] = {"ALPHA","BETA","GAMMA","DELTA","A","B","FOFFS",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3FTYPE1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3FTYPE2 details for *MAT_SEISMIC_BEAM
  * keyword from file */
   void readCard3FTYPE2()
   {
      const char *fields[] = {"SIGY","D","W","TF","TW",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 5;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3FTYPE2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card4IFEMA1 details for *MAT_SEISMIC_BEAM
  * keyword from file */
   void readCard4IFEMA1()
   {
      const char *fields[] = {"PR1","PR2","PR3","PR4",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card4IFEMA1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card4IFEMA2 details for *MAT_SEISMIC_BEAM
  * keyword from file */
   void readCard4IFEMA2()
   {
      const char *fields[] = {"TS1","TS2","TS3","TS4","CS1","CS2","CS3","CS4",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card4IFEMA2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *MAT_SEISMIC_BEAM
  * from LSDYNA native file */
   unsigned int importMatSeismicBeam()
   {
      readCard1();
      readCard2();
      if( ftype == 1 )
      {
         readCard3FTYPE1();
      }
      else if( ftype == 2 )
      {
         readCard3FTYPE2();
      }
      if( ifema > 0 )
      {
         readCard4IFEMA1();
      }
      if( ifema == 2 )
      {
         readCard4IFEMA2();
      }
      return 0;
   }
public:
   int ftype;
   int ifema;
};

#endif

