#ifndef _MatSeismicIsolator_h_
#define _MatSeismicIsolator_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *MAT_SEISMIC_ISOLATOR keyword
  * from LSDYNA native file */

class MatSeismicIsolator : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   MatSeismicIsolator(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~MatSeismicIsolator()
   {
   }

public:
/** Function to import Card1 details for *MAT_SEISMIC_ISOLATOR
  * keyword from file */
   int readCard1()
   {
      const char *fields[] = {"MID","RO","A","GAMMA","BETA","DISPY","STIFFV","ITYPE",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return 0;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, MAT, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
      if( wordArray[7] )
         return atoi(wordArray[7]);
      else
         return 0;
   }

/** Function to import Card2 details for *MAT_SEISMIC_ISOLATOR
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"PRELOAD","DAMP","MX1","MX2","MY1","MY2",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3ITYPE02 details for *MAT_SEISMIC_ISOLATOR
  * keyword from file */
   void readCard3ITYPE02()
   {
      const char *fields[] = {"FMAX","DELF","AFRIC","RADX","RADY","RADB","STIFFL","STIFFTS",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3ITYPE02");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card4ITYPE12 details for *MAT_SEISMIC_ISOLATOR
  * keyword from file */
   void readCard4ITYPE12()
   {
      const char *fields[] = {"FORCEY","ALPHA","STIFFT","DFAIL","FMAXYC","FMAXXT","FMAXYT","YLOCK",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card4ITYPE12");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *MAT_SEISMIC_ISOLATOR
  * from LSDYNA native file */
   unsigned int importMatSeismicIsolator()
   {
      int itype = 0;
      itype = readCard1();
      readCard2();
      if( itype == 0 || itype == 2 )
      {
         readCard3ITYPE02();
      }
      if( itype == 1 || itype == 2 )
      {
         readCard4ITYPE12();
      }
      return 0;
   }
};

#endif

