#ifndef _MatRateSensitiveCompositeFabric_h_
#define _MatRateSensitiveCompositeFabric_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *MAT_RATE_SENSITIVE_COMPOSITE_FABRIC keyword
  * from LSDYNA native file */

class MatRateSensitiveCompositeFabric : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   MatRateSensitiveCompositeFabric(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~MatRateSensitiveCompositeFabric()
   {
   }

public:
/** Function to import Card1 details for *MAT_RATE_SENSITIVE_COMPOSITE_FABRIC
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"MID","RO","EA","EB","EC","PRBA","TAU1","GAMMA1",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, MAT, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *MAT_RATE_SENSITIVE_COMPOSITE_FABRIC
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"GAB","GBC","GCA","SLIMT1","SLIMC1","SLIMT2","SLIMC2","SLIMS",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3 details for *MAT_RATE_SENSITIVE_COMPOSITE_FABRIC
  * keyword from file */
   void readCard3()
   {
      const char *fields[] = {"AOPT","TSIZE","ERODS","SOFT","FS",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 5;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card4 details for *MAT_RATE_SENSITIVE_COMPOSITE_FABRIC
  * keyword from file */
   void readCard4()
   {
      const char *fields[] = {"XP","YP","ZP","A1","A2","A3",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card4");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card5 details for *MAT_RATE_SENSITIVE_COMPOSITE_FABRIC
  * keyword from file */
   void readCard5()
   {
      const char *fields[] = {"V1","V2","V3","D1","D2","D3","BETA",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card5");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card6 details for *MAT_RATE_SENSITIVE_COMPOSITE_FABRIC
  * keyword from file */
   void readCard6()
   {
      const char *fields[] = {"E11C","E11T","E22C","E22T","GMS",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 5;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card6");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card7 details for *MAT_RATE_SENSITIVE_COMPOSITE_FABRIC
  * keyword from file */
   void readCard7()
   {
      const char *fields[] = {"XC","XT","YC","YT","SC",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 5;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card7");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card8 details for *MAT_RATE_SENSITIVE_COMPOSITE_FABRIC
  * keyword from file */
   void readCard8()
   {
      const char *fields[] = {"K",};
      unsigned int field_types[] = {DATA_DOUBLE, };
      numFields = 1;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card8");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import CardLoop details for *MAT_RATE_SENSITIVE_COMPOSITE_FABRIC
  * keyword from file */
   void readCardLoop()
   {
      const char *fields[] = {"GI","BETAI",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 2;
      unsigned int i, end_loop;
      end_loop = 6;
      for(i = 0; i < end_loop; i++)
      {
         numFields = 2;
         wordArray = dataLine->readNextCardAsWords(numFields);
         if( !numFields && dataLine->isFlagOn(KW_READ_END) ) return;

         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
         {
            cardObj = new Card("CardLoop");
            cardObj->addFields(numFields, field_types, fields, wordArray);
            impObj->addCard(cardObj);
         }
      }
   }

/** Function to import all the cards of the keyword *MAT_RATE_SENSITIVE_COMPOSITE_FABRIC
  * from LSDYNA native file */
   unsigned int importMatRateSensitiveCompositeFabric()
   {
      readCard1();
      readCard2();
      readCard3();
      readCard4();
      readCard5();
      readCard6();
      readCard7();
      readCard8();
      readCardLoop();
      return 0;
   }
};

#endif

