#ifndef _MatHyperelasticRubber_h_
#define _MatHyperelasticRubber_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *MAT_HYPERELASTIC_RUBBER keyword
  * from LSDYNA native file */

class MatHyperelasticRubber : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   MatHyperelasticRubber(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~MatHyperelasticRubber()
   {
   }

public:
/** Function to import Card1 details for *MAT_HYPERELASTIC_RUBBER
  * keyword from file */
   int readCard1()
   {
      const char *fields[] = {"MID","RO","PR","N","NV","G","SIGF",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return 0;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, MAT, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
      if( wordArray[3] )
         return atoi(wordArray[3]);
      else
         return 0;
   }

/** Function to import Card2NGT0 details for *MAT_HYPERELASTIC_RUBBER
  * keyword from file */
   void readCard2NGT0()
   {
      const char *fields[] = {"SGL","SW","ST","LCID1","DATA","LCID2","BSTART","TRAMP",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {3, 5, };
      unsigned int man_types[] = {DEFINE, DEFINE, };
      unsigned int kw_types[] = {CURVE, CURVE, };
      unsigned int num_indices = 2;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2NGT0");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2NEQ0 details for *MAT_HYPERELASTIC_RUBBER
  * keyword from file */
   void readCard2NEQ0()
   {
      const char *fields[] = {"C10","C01","C11","C20","C02","C30",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2NEQ0");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import CardLoop details for *MAT_HYPERELASTIC_RUBBER
  * keyword from file */
   void readCardLoop()
   {
      const char *fields[] = {"GI","BETAI",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 2;
      unsigned int i, end_loop;
      end_loop = 6;
      for(i = 0; i < end_loop; i++)
      {
         numFields = 2;
         wordArray = dataLine->readNextCardAsWords(numFields);
         if( !numFields && dataLine->isFlagOn(KW_READ_END) ) return;

         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
         {
            cardObj = new Card("CardLoop");
            cardObj->addFields(numFields, field_types, fields, wordArray);
            impObj->addCard(cardObj);
         }
      }
   }

/** Function to import all the cards of the keyword *MAT_HYPERELASTIC_RUBBER
  * from LSDYNA native file */
   unsigned int importMatHyperelasticRubber()
   {
      int n = 0;
      n = readCard1();
      if( n > 0 )
      {
         readCard2NGT0();
      }
      if( n == 0 )
      {
         readCard2NEQ0();
      }
      readCardLoop();
      return 0;
   }
};

#endif

