#ifndef _MatSimplifiedRubberFoam_h_
#define _MatSimplifiedRubberFoam_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *MAT_SIMPLIFIED_RUBBER_FOAM keyword
  * from LSDYNA native file */

class MatSimplifiedRubberFoam : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   MatSimplifiedRubberFoam(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~MatSimplifiedRubberFoam()
   {
   }

public:
/** Function to import Card1 details for *MAT_SIMPLIFIED_RUBBER_FOAM
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"MID","RO","KM","MU","G","SIGF","REF","PRTEN",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, MAT, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *MAT_SIMPLIFIED_RUBBER_FOAM
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"SGL","SW","ST","LC/TBID","TENSION","RTYPE","AVGOPT","PR/BETA",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *MAT_SIMPLIFIED_RUBBER_FOAM
  * from LSDYNA native file */
   unsigned int importMatSimplifiedRubberFoam()
   {
      readCard1();
      readCard2();
      return 0;
   }
};

#endif

