#ifndef _MatThermalUserDefined_h_
#define _MatThermalUserDefined_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *MAT_THERMAL_USER_DEFINED keyword
  * from LSDYNA native file */

class MatThermalUserDefined : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   MatThermalUserDefined(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~MatThermalUserDefined()
   {
   }

public:
/** Function to import Card1 details for *MAT_THERMAL_USER_DEFINED
  * keyword from file */
   int readCard1()
   {
      const char *fields[] = {"MID","RO","MT","LMC","NVH","AOPT","IORTHO","IHVE",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return 0;
      lmc = 0;
      if( wordArray[3] )
         lmc = atoi(wordArray[3]);
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, MAT, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
      if( wordArray[6] )
         return atoi(wordArray[6]);
      else
         return 0;
   }

/** Function to import Card2IORTHO1 details for *MAT_THERMAL_USER_DEFINED
  * keyword from file */
   void readCard2IORTHO1()
   {
      const char *fields[] = {"XP","YP","ZP","A1","A2","A3",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2IORTHO1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3IORTHO1 details for *MAT_THERMAL_USER_DEFINED
  * keyword from file */
   void readCard3IORTHO1()
   {
      const char *fields[] = {"D1","D2","D3",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 3;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3IORTHO1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card4LMC details for *MAT_THERMAL_USER_DEFINED
  * keyword from file */
   void readCard4LMC()
   {
      const char *fields[] = {"P1","P2","P3","P4","P5","P6","P7","P8",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int i, end_loop;
      end_loop = ((lmc%8) ? (lmc/8)+1 : lmc/8);
      for(i = 0; i < end_loop; i++)
      {
         numFields = 8;
         wordArray = dataLine->readNextCardAsWords(numFields);
         if( !numFields && dataLine->isFlagOn(KW_READ_END) ) return;

         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
         {
            cardObj = new Card("Card4LMC");
            cardObj->addFields(numFields, field_types, fields, wordArray);
            impObj->addCard(cardObj);
         }
      }
   }

/** Function to import all the cards of the keyword *MAT_THERMAL_USER_DEFINED
  * from LSDYNA native file */
   unsigned int importMatThermalUserDefined()
   {
      int iortho = 0;
      iortho = readCard1();
      if( iortho == 1 )
      {
         readCard2IORTHO1();
         readCard3IORTHO1();
      }
      readCard4LMC();
      return 0;
   }
public:
   int lmc;
};

#endif

