#ifndef _MatSpringGeneralNonlinear_h_
#define _MatSpringGeneralNonlinear_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *MAT_SPRING_GENERAL_NONLINEAR keyword
  * from LSDYNA native file */

class MatSpringGeneralNonlinear : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   MatSpringGeneralNonlinear(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~MatSpringGeneralNonlinear()
   {
   }

public:
/** Function to import Card1 details for *MAT_SPRING_GENERAL_NONLINEAR
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"MID","LCDL","LCDU","BETA","TYI","CYI",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {1, 2, };
      unsigned int man_types[] = {DEFINE, DEFINE, };
      unsigned int kw_types[] = {CURVE, CURVE, };
      unsigned int num_indices = 2;
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, MAT, impObj);

      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *MAT_SPRING_GENERAL_NONLINEAR
  * from LSDYNA native file */
   unsigned int importMatSpringGeneralNonlinear()
   {
      readCard1();
      return 0;
   }
};

#endif

