#ifndef _MatSoftTissueVisco_h_
#define _MatSoftTissueVisco_h_

#include "manager.h"
#include "dispexport.h"
#include "matsofttissue.h"

/** This class is used for importing *MAT_SOFT_TISSUE_VISCO keyword
  * from LSDYNA native file */

class MatSoftTissueVisco : public MatSoftTissue
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   MatSoftTissueVisco(DataLine *data_line, ImportObject *imp_obj) : MatSoftTissue (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~MatSoftTissueVisco()
   {
   }

public:
/** Function to import Card5 details for *MAT_SOFT_TISSUE_VISCO
  * keyword from file */
   void readCard5()
   {
      const char *fields[] = {"S1","S2","S3","S4","S5","S6",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card5");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card6 details for *MAT_SOFT_TISSUE_VISCO
  * keyword from file */
   void readCard6()
   {
      const char *fields[] = {"T1","T2","T3","T4","T5","T6",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card6");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *MAT_SOFT_TISSUE_VISCO
  * from LSDYNA native file */
   unsigned int importMatSoftTissueVisco()
   {
      importMatSoftTissue();
      readCard5();
      readCard6();
      return 0;
   }
};

#endif

