#ifndef _MatQuasilinearViscoelastic_h_
#define _MatQuasilinearViscoelastic_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *MAT_QUASILINEAR_VISCOELASTIC keyword
  * from LSDYNA native file */

class MatQuasilinearViscoelastic : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   MatQuasilinearViscoelastic(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~MatQuasilinearViscoelastic()
   {
   }

public:
/** Function to import Card1 details for *MAT_QUASILINEAR_VISCOELASTIC
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"MID","RO","K","LC1","LC2","N","GSTART","M",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_INT, };
      unsigned int field_indices[] = {3, 4, };
      unsigned int man_types[] = {DEFINE, DEFINE, };
      unsigned int kw_types[] = {CURVE, CURVE, };
      unsigned int num_indices = 2;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      lc1 = 0;
      if( wordArray[3] )
         lc1 = atoi(wordArray[3]);
      lc2 = 0;
      if( wordArray[4] )
         lc2 = atoi(wordArray[4]);
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, MAT, impObj);

      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *MAT_QUASILINEAR_VISCOELASTIC
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"SO","E_MIN","E_MAX","GAMA1","GAMA2","K_FAIL","EH","FORM",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3LC10 details for *MAT_QUASILINEAR_VISCOELASTIC
  * keyword from file */
   void readCard3LC10()
   {
      const char *fields[] = {"G1","BETA1","G2","BETA2","G3","BETA3","G4","BETA4",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3LC10");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card4LC10 details for *MAT_QUASILINEAR_VISCOELASTIC
  * keyword from file */
   void readCard4LC10()
   {
      const char *fields[] = {"G5","BETA5","G6","BETA6","G7","BETA7","G8","BETA8",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card4LC10");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card5LC10 details for *MAT_QUASILINEAR_VISCOELASTIC
  * keyword from file */
   void readCard5LC10()
   {
      const char *fields[] = {"G9","BETA9","G10","BETA10","G11","BETA11","G12","BETA12",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card5LC10");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3LC20 details for *MAT_QUASILINEAR_VISCOELASTIC
  * keyword from file */
   void readCard3LC20()
   {
      const char *fields[] = {"C1","C2","C3","C4","C5","C6",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3LC20");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *MAT_QUASILINEAR_VISCOELASTIC
  * from LSDYNA native file */
   unsigned int importMatQuasilinearViscoelastic()
   {
      readCard1();
      readCard2();
      if( lc1 == 0 )
      {
         readCard3LC10();
         readCard4LC10();
         readCard5LC10();
      }
      if( lc2 == 0 )
      {
         readCard3LC20();
      }
      return 0;
   }
public:
   int lc1;
   int lc2;
};

#endif

