#ifndef _MatSpotweldDamageFailure_h_
#define _MatSpotweldDamageFailure_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *MAT_SPOTWELD_DAMAGE_FAILURE keyword
  * from LSDYNA native file */

class MatSpotweldDamageFailure : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   MatSpotweldDamageFailure(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~MatSpotweldDamageFailure()
   {
   }

public:
/** Function to import Card1 details for *MAT_SPOTWELD_DAMAGE_FAILURE
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"MID","RO","E","PR","SIGY","ET","DT","TFAIL",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, MAT, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *MAT_SPOTWELD_DAMAGE_FAILURE
  * keyword from file */
   int readCard2()
   {
      const char *fields[] = {"RS","OPT","FVAL","TRUE_T","UNUSED","BETA",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_UNUSED, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return 0;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
      if( wordArray[1] )
         return atoi(wordArray[1]);
      else
         return 0;
   }

/** Function to import Card3OPTM10 details for *MAT_SPOTWELD_DAMAGE_FAILURE
  * keyword from file */
   void readCard3OPTM10()
   {
      const char *fields[] = {"EFAIL","NRR","NRS","NRT","MRR","MSS","MTT","NF",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3OPTM10");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3OPT1 details for *MAT_SPOTWELD_DAMAGE_FAILURE
  * keyword from file */
   void readCard3OPT1()
   {
      const char *fields[] = {"EFAIL","SIGAX","SIGTAU","UNUSED","UNUSED","UNUSED","UNUSED","NF",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_UNUSED, DATA_UNUSED, DATA_UNUSED, DATA_UNUSED, DATA_INT, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3OPT1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3OPT2 details for *MAT_SPOTWELD_DAMAGE_FAILURE
  * keyword from file */
   void readCard3OPT2()
   {
      const char *fields[] = {"EFAIL","USERV1","USERV2","USERV3","USERV4","USERV5","USERV6","NF",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3OPT2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3OPT34 details for *MAT_SPOTWELD_DAMAGE_FAILURE
  * keyword from file */
   void readCard3OPT34()
   {
      const char *fields[] = {"EFAIL","ZD","ZT","ZALP1","ZALP2","ZALP3","ZRRAD","NF",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3OPT34");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3OPT5 details for *MAT_SPOTWELD_DAMAGE_FAILURE
  * keyword from file */
   void readCard3OPT5()
   {
      const char *fields[] = {"EFAIL","ZD","ZT","ZT2",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3OPT5");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3OPT679 details for *MAT_SPOTWELD_DAMAGE_FAILURE
  * keyword from file */
   void readCard3OPT679()
   {
      const char *fields[] = {"EFAIL","UNUSED","UNUSED","UNUSED","UNUSED","UNUSED","UNUSED","NF",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_UNUSED, DATA_UNUSED, DATA_UNUSED, DATA_UNUSED, DATA_UNUSED, DATA_UNUSED, DATA_INT, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3OPT679");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *MAT_SPOTWELD_DAMAGE_FAILURE
  * from LSDYNA native file */
   unsigned int importMatSpotweldDamageFailure()
   {
      int opt = 0;
      readCard1();
      opt = readCard2();
      if( opt == -2 || opt == -1 || opt == 0 )
      {
         readCard3OPTM10();
      }
      else if( opt == 1 )
      {
         readCard3OPT1();
      }
      else if( opt == 2 )
      {
         readCard3OPT2();
      }
      else if( opt == 3 || opt == 4 )
      {
         readCard3OPT34();
      }
      else if( opt == 5 )
      {
         readCard3OPT5();
      }
      else if( opt == 6 || opt == 7 || opt == 9 )
      {
         readCard3OPT679();
      }
      return 0;
   }
};

#endif

