#ifndef _NodeRigidSurface_h_
#define _NodeRigidSurface_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *NODE_RIGID_SURFACE keyword
  * from LSDYNA native file */

class NodeRigidSurface : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   NodeRigidSurface(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~NodeRigidSurface()
   {
   }

public:
/** Function to import Card1 details for *NODE_RIGID_SURFACE
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"NID","X","Y","Z",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 4;
      unsigned int field_widths[] = {8, 16, 16, 16, };
      strBuff = dataLine->readNextCard(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;

      wordArray = dataLine->splitIntoWords(numFields, field_widths);
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, NOD, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, field_widths, fields, strBuff);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *NODE_RIGID_SURFACE
  * from LSDYNA native file */
   unsigned int importNodeRigidSurface()
   {
      readCard1();
      return 0;
   }
};

#endif

