#include <iostream>
#include <algorithm>
#include "generic.h"
#include "nodtype.h"
#include "nodimport.h"
#include <stdlib.h>

using namespace std;

NodImport::NodImport
(
   FILE          *fp,
   DataLoc       *data_loc,
   NodManager    *nod_man
)
{
   filePtr = fp;
   nodManPtr = nod_man;
   dataLocPtr = data_loc;
   dataLine = NULL;

   initNodTypesAndFunctions();
}

NodType NodImport::getNodTypeFromKeyword
	(
	   const char  *key_word,
	   unsigned int *nod_id
	)
{
   *nod_id = 0;

   if( key_word[6] == 'R' )
      return NODE_RIGID_SURFACE;
   else if( key_word[13] == 'V' )
      return NODE_SCALAR_VALUE;
   else if( key_word[6] == 'S' )
      return NODE_SCALAR;
   else if( key_word[6] == 'T' )
      return NODE_TRANSFORM;
   else if( key_word[4] == 'E' )
      return NODE;

   return NOD_NEW_TYPE;
}

unsigned int NodImport::readNods()
{
   char         new_kw[LINE_LEN];
   unsigned int	i = 0, nod_id = 0, nod_type = 0, num_nods = 0;
   long		loc = 0L;
   VStringIterator   s = dataLocPtr->keywordList.begin(),
		     e = dataLocPtr->keywordList.end(), itr, 
		     pitr = dataLocPtr->keywordList.begin();
   typeFuncIterator  btype_iter = typeFuncMap.begin(),
                     etype_iter = typeFuncMap.end(), type_iter;

   dataLine = new DataLine(filePtr);

   while(true)
   {
      itr = find_if(pitr, e, bind2nd(KeyWordCompare (), "*NODE"));

      if( itr == e )
	 break;

      pitr = itr+1;
      i = (unsigned int)(itr - s);
      loc = dataLocPtr->slocList[i];

      rewind(filePtr);

      if( fseek(filePtr, loc, SEEK_SET) )
      {
	 cout << "ERROR in locating the Node cards" << endl;
	 break;
      }

      dataLine->clearFlag(KW_READ_END);

      char *str = dataLine->readNextCard(); //get the keyword
      Generic::RemoveLeadingAndTrailingBlanks( str );
cout << "KW = " << str << endl;

      nod_type = getNodTypeFromKeyword( str, &nod_id );
cout << "Node TYPE = " << nod_type << endl;

      if( nod_type == NOD_NEW_TYPE )
      {
         cout << "Node TYPE NOT SUPPORTED" << endl;
         continue;
      }

      num_nods++;

      strcpy(new_kw, str);

      dataLine->clearFlag(KW_READ_END);
      type_iter = typeFuncMap.find(nod_type);
      if( type_iter != etype_iter )
      {
          impObj = new ImportObject(str, nod_type);
          (type_iter->second)(dataLine, impObj);
          Card::clearFlag();
          while( !dataLine->isFlagOn(KW_READ_END) )
          {
             (type_iter->second)(dataLine, impObj);
          }
          sprintf(new_kw, "%s_%d", new_kw, num_nods);
          nodManPtr->add(new_kw, impObj);
      }
      else
         cout << "Node TYPE NOT FOUND" << endl;
   }

   return num_nods;
}

