#ifndef _Nod_IMPORT_H_
#define _Nod_IMPORT_H_

#include <string>
#include <map>
#include "dataloc.h"
#include "nodmanager.h"
#include "dataline.h"
#include "card.h"
#include "nodtype.h"
#include "typemap.h"

/** Class to import the data from native LSDYNA file for *NODE keywords. All
  * the data is imported through this class and stored in the manager object.
  */
class NodImport
{
public:
   /** Constructor for creating this object
     * \param fp File pointer to the LSDYNA native file
     * \param data_loc Pointer to the list of keywords and their locations in
     * the file
     * \param nod_man Manager pointer to hold the imported data as a list of
     * ImportObject list
     */
   NodImport
   (
      FILE          *fp,
      DataLoc       *data_loc,
      NodManager    *nod_man
   );

   ~NodImport()
   {
      filePtr = NULL;
      nodManPtr = NULL;
      dataLocPtr = NULL;
      delete dataLine;
   }

   /** Function for getting the keyword type from given keyword name from LSDYNA
     * native file. The type is stored in the database
     * \param key_word Name of the keyword from file
     * \param nod_id ID of the keyword if it is there
     * \return Type for *NODE group of keywords
     */
   static NodType getNodTypeFromKeyword
	   (
	      const char  *key_word,
	      unsigned int *nod_id
	   );

   /** Reads the *NODE keywords from file
     * \return Returns 0 on failure else number of *NODE keywords
     */
   unsigned int readNods();

   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *NODE keyword there is a function to call
     */
   void initNodTypesAndFunctions();

private:
   FILE          *filePtr;
   /** Manager pointer for holding the imported data for all the keywords */
   NodManager    *nodManPtr;
   /** Pointer to keywords and their locations in the file */
   DataLoc       *dataLocPtr;
   /** Pointer to access the file data line by line */
   DataLine      *dataLine;
   /** Object to store imported data from LSDYNA data file */
   ImportObject  *impObj;
   /** A map between the keyword type and pointer to function */
   map<unsigned int, ImportFunctionPtr>  typeFuncMap;
};

#endif

