#include <iostream>
#include <algorithm>
#include "generic.h"
#include "parametertype.h"
#include "parameterimport.h"
#include <stdlib.h>

using namespace std;

ParameterImport::ParameterImport
(
   FILE          *fp,
   DataLoc       *data_loc,
   ParameterManager    *parameter_man
)
{
   filePtr = fp;
   parameterManPtr = parameter_man;
   dataLocPtr = data_loc;
   dataLine = NULL;

   initParameterTypesAndFunctions();
}

ParameterType ParameterImport::getParameterTypeFromKeyword
	(
	   const char  *key_word,
	   unsigned int *parameter_id
	)
{
   *parameter_id = 0;

   if( strstr(key_word, "EXP") )
      return PARAMETER_EXPRESSION;
   else if( strstr(key_word, "MET") )
      return PARAMETER;

   return PARAMETER_NEW_TYPE;
}

unsigned int ParameterImport::readParameters()
{
   char         new_kw[LINE_LEN];
   unsigned int	i = 0, parameter_id = 0, parameter_type = 0, num_parameters = 0;
   long		loc = 0L;
   VStringIterator   s = dataLocPtr->keywordList.begin(),
		     e = dataLocPtr->keywordList.end(), itr, 
		     pitr = dataLocPtr->keywordList.begin();
   typeFuncIterator  btype_iter = typeFuncMap.begin(),
                     etype_iter = typeFuncMap.end(), type_iter;

   dataLine = new DataLine(filePtr);

   while(true)
   {
      itr = find_if(pitr, e, bind2nd(KeyWordCompare (), "*PARAM"));

      if( itr == e )
	 break;

      pitr = itr+1;
      i = (unsigned int)(itr - s);
      loc = dataLocPtr->slocList[i];

      rewind(filePtr);

      if( fseek(filePtr, loc, SEEK_SET) )
      {
	 cout << "ERROR in locating the Parameter cards" << endl;
	 break;
      }

      dataLine->clearFlag(KW_READ_END);

      char *str = dataLine->readNextCard(); //get the keyword
      Generic::RemoveLeadingAndTrailingBlanks( str );
cout << "KW = " << str << endl;

      parameter_type = getParameterTypeFromKeyword( str, &parameter_id );
cout << "Parameter TYPE = " << parameter_type << endl;

      if( parameter_type == PARAMETER_NEW_TYPE )
      {
         cout << "Parameter TYPE NOT SUPPORTED" << endl;
         continue;
      }

      num_parameters++;

      strcpy(new_kw, str);

      dataLine->clearFlag(KW_READ_END);
      type_iter = typeFuncMap.find(parameter_type);
      if( type_iter != etype_iter )
      {
          impObj = new ImportObject(str, parameter_type);
          (type_iter->second)(dataLine, impObj);
          if( parameter_id )
          {
             parameterManPtr->add(new_kw, impObj);
          }
          else
          {
             sprintf(new_kw, "%s_%d", new_kw, num_parameters);
             parameterManPtr->add(new_kw, impObj);
          }
      }
      else
         cout << "Parameter TYPE NOT FOUND" << endl;
   }

   return num_parameters;
}

