#ifndef _PartCards_h_
#define _PartCards_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *PART_CARDS keyword
  * from LSDYNA native file */

class PartCards : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   PartCards(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~PartCards()
   {
   }

public:
/** Function to import TitleCard details for *PART_CARDS
  * keyword from file */
   void readTitleCard()
   {
      const char *fields[] = {"HEADING",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, };
      numFields = 1;
      unsigned int field_widths[] = {80, };
      strBuff = dataLine->readNextCard(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("TitleCard");
         cardObj->addFields(numFields, field_types, field_widths, fields, strBuff);
         impObj->addCard(cardObj);
      }
   }

/** Function to import PartCard details for *PART_CARDS
  * keyword from file */
   void readPartCard()
   {
      const char *fields[] = {"PID","SECID","MID","EOSID","HGID","GRAV","ADPOPT","TMID",};
      unsigned int field_types[] = {DATA_INT, DATA_CHAR_ARRAY, DATA_CHAR_ARRAY, DATA_CHAR_ARRAY, DATA_CHAR_ARRAY, DATA_INT, DATA_INT, DATA_CHAR_ARRAY, };
      unsigned int field_indices[] = {1, 2, 3, 4, 7, };
      unsigned int man_types[] = {SECTION, MAT, EOS, HG, MAT, };
      unsigned int kw_types[] = {9999, 9999, 9999, 9999, THERMAL, };
      unsigned int num_indices = 5;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, PARTC, impObj);

      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("PartCard");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *PART_CARDS
  * from LSDYNA native file */
   unsigned int importPartCards()
   {
      readTitleCard();
      readPartCard();
      return 0;
   }
};

#endif

