#ifndef _PartComposite_h_
#define _PartComposite_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *PART_COMPOSITE keyword
  * from LSDYNA native file */

class PartComposite : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   PartComposite(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~PartComposite()
   {
   }

public:
/** Function to import TitleCard details for *PART_COMPOSITE
  * keyword from file */
   void readTitleCard()
   {
      const char *fields[] = {"HEADING",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, };
      numFields = 1;
      unsigned int field_widths[] = {80, };
      strBuff = dataLine->readNextCard(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("TitleCard");
         cardObj->addFields(numFields, field_types, field_widths, fields, strBuff);
         impObj->addCard(cardObj);
      }
   }

/** Function to import PartCard details for *PART_COMPOSITE
  * keyword from file */
   void readPartCard()
   {
      const char *fields[] = {"PID","ELFORM","SHRF","NLOC","MAREA","HGID","ADPOPT",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_CHAR_ARRAY, DATA_INT, };
      unsigned int field_indices[] = {5, };
      unsigned int man_types[] = {HG, };
      unsigned int kw_types[] = {9999, };
      unsigned int num_indices = 1;
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, PARTC, impObj);

      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("PartCard");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import ContactCard details for *PART_COMPOSITE
  * keyword from file */
   void readContactCard()
   {
      const char *fields[] = {"FS","FD","DC","VC","OPTT","SFT","SSF",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("ContactCard");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import MatCard details for *PART_COMPOSITE
  * keyword from file */
   void readMatCard()
   {
      const char *fields[] = {"MID1","THICK1","B1","UNUSED","MID2","THICK2","B2",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_UNUSED, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, 4, };
      unsigned int man_types[] = {MAT, MAT, };
      unsigned int kw_types[] = {9999, 9999, };
      unsigned int num_indices = 2;
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("MatCard");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *PART_COMPOSITE
  * from LSDYNA native file */
   unsigned int importPartComposite()
   {
      readTitleCard();
      readPartCard();
      if( strstr(impObj->getKeyword().data(), "_CONTACT") )
      {
         readContactCard();
      }
      readMatCard();
      while(numFields)
      {
         readMatCard();
      }
      return 0;
   }
};

#endif

