#ifndef _PartModes_h_
#define _PartModes_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *PART_MODES keyword
  * from LSDYNA native file */

class PartModes : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   PartModes(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~PartModes()
   {
   }

public:
/** Function to import PartCard details for *PART_MODES
  * keyword from file */
   int readPartCard()
   {
      const char *fields[] = {"PID","NMFB","FORM","ANSID","FORMAT","KMFLAG","NUPDF","SIGREC",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 3, };
      unsigned int man_types[] = {PARTC, PARTC, };
      unsigned int kw_types[] = {9999, 9999, };
      unsigned int num_indices = 2;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return 0;
      nmfb = 0;
      if( wordArray[1] )
         nmfb = atoi(wordArray[1]);
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("PartCard");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
      if( wordArray[5] )
         return atoi(wordArray[5]);
      else
         return 0;
   }

/** Function to import Card2 details for *PART_MODES
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"FILENAME",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, };
      numFields = 1;
      unsigned int field_widths[] = {80, };
      strBuff = dataLine->readNextCard(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, field_widths, fields, strBuff);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3 details for *PART_MODES
  * keyword from file */
   void readCard3()
   {
      const char *fields[] = {"MODE1","MODE2","MODE3","MODE4","MODE5","MODE6","MODE7","MODE8",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 8;
      unsigned int i, end_loop;
      end_loop = ((nmfb%8) ? (nmfb/8)+1 : nmfb/8);
      for(i = 0; i < end_loop; i++)
      {
         numFields = 8;
         wordArray = dataLine->readNextCardAsWords(numFields);
         if( !numFields && dataLine->isFlagOn(KW_READ_END) ) return;

         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
         {
            cardObj = new Card("Card3");
            cardObj->addFields(numFields, field_types, fields, wordArray);
            impObj->addCard(cardObj);
         }
      }
   }

/** Function to import Card4 details for *PART_MODES
  * keyword from file */
   void readCard4()
   {
      const char *fields[] = {"MSTART","MSTOP","DAMPF",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, };
      numFields = 3;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card4");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *PART_MODES
  * from LSDYNA native file */
   unsigned int importPartModes()
   {
      int kmflag = 0;
      kmflag = readPartCard();
      readCard2();
      if( kmflag == 1 )
      {
         readCard3();
      }
      readCard4();
      while(numFields)
      {
         readCard4();
      }
      return 0;
   }
public:
   int nmfb;
};

#endif

