#include <iostream>
#include <algorithm>
#include "generic.h"
#include "partctype.h"
#include "partcimport.h"

#include "partcards.h"
#include "partinertia.h"
#include "partreposition.h"
#include "partcontact.h"
#include "partprint.h"
#include "partattachmentnodes.h"
#include "filepath.h"

#include <stdlib.h>

using namespace std;

PartCImport::PartCImport
(
   FILE          *fp,
   DataLoc       *data_loc,
   PartCManager    *partc_man
)
{
   filePtr = fp;
   partcManPtr = partc_man;
   dataLocPtr = data_loc;
   dataLine = NULL;

   initPartCTypesAndFunctions();
}

PartCType PartCImport::getPartCTypeFromKeyword
	  (
	     const char  *key_word,
	     unsigned int *partc_type
	  )
{
   *partc_type = 0;

   if( strstr(key_word, "ADAP") )
   {
      *partc_type |= (1 << PART_ADAPTIVE_FAILURE);
      return PART_ADAPTIVE_FAILURE;
   }
   else if( strstr(key_word, "TE_CON") )
   {
      *partc_type |= (1 << PART_COMPOSITE_CONTACT);
      return PART_COMPOSITE_CONTACT;
   }
   else if( strstr(key_word, "SITE") )
   {
      *partc_type |= (1 << PART_COMPOSITE);
      return PART_COMPOSITE;
   }
   else if( strstr(key_word, "MODE") )
   {
      *partc_type |= (1 << PART_MODES);
      return PART_MODES;
   }
   else if( strstr(key_word, "MOVE") )
   {
      *partc_type |= (1 << PART_MOVE);
      return PART_MOVE;
   }
   else if( strstr(key_word, "SENS") )
   {
      *partc_type |= (1 << PART_SENSOR);
      return PART_SENSOR;
   }
   else
   {
      *partc_type |= (1 << PART);

      if( strstr(key_word, "_INERTIA") )
         *partc_type |= (1 << PART_INERTIA);
      else if( strstr(key_word, "_REPOSITION") )
         *partc_type |= (1 << PART_REPOSITION);

      if( strstr(key_word, "_CONTACT") )
         *partc_type |= (1 << PART_CONTACT);

      if( strstr(key_word, "_PRINT") )
         *partc_type |= (1 << PART_PRINT);

      if( strstr(key_word, "_ATTACH") )
         *partc_type |= (1 << PART_ATTACH);

      return PART;
   }
}

unsigned int PartCImport::readPartCs()
{
   char              new_kw[LINE_LEN];
   unsigned int	     i = 0, partc_type = 0, num_partcs = 0, partc_bin = 0;
   long		     loc = 0L;
   VStringIterator   s = dataLocPtr->keywordList.begin(),
		     e = dataLocPtr->keywordList.end(), itr, 
		     pitr = dataLocPtr->keywordList.begin();
   typeFuncIterator  btype_iter = typeFuncMap.begin(),
                     etype_iter = typeFuncMap.end(), type_iter;

   dataLine = new DataLine(filePtr);

   while(true)
   {
      itr = find_if(pitr, e, bind2nd(KeyWordCompare (), "*PART"));

      if( itr == e )
	 break;

      pitr = itr+1;
      i = (unsigned int)(itr - s);
      loc = dataLocPtr->slocList[i];

      rewind(filePtr);

      if( fseek(filePtr, loc, SEEK_SET) )
      {
	 cout << "ERROR in locating the Part cards" << endl;
	 break;
      }

      dataLine->clearFlag(KW_READ_END);

      char *str = dataLine->readNextCard(); //get the keyword
      Generic::RemoveLeadingAndTrailingBlanks( str );
cout << "KW = " << str << endl;

      partc_type = getPartCTypeFromKeyword( str, &partc_bin );
cout << "PartC TYPE = " << partc_type << endl;

      num_partcs++;

      strcpy(new_kw, str);

      dataLine->clearFlag(KW_READ_END);

      if( partc_bin & (1 << PART) )
      {
	 impObj = new ImportObject(str, partc_bin);

         PartCards  partc(dataLine, impObj);
         partc.importPartCards();

         if( partc_bin & (1 << PART_INERTIA) )
         {
            PartInertia    part_inertia(dataLine, impObj);
            part_inertia.importPartInertia();
         }
         else if( partc_bin & (1 << PART_REPOSITION) )
         {
            PartReposition   part_repos(dataLine, impObj);
            part_repos.importPartReposition();
         }

         if( partc_bin & (1 << PART_CONTACT) )
         {
            PartContact	  part_contact(dataLine, impObj);
            part_contact.importPartContact();
         }
         
         if( partc_bin & (1 << PART_PRINT) )
         {
            PartPrint	  part_print(dataLine, impObj);
            part_print.importPartPrint();
         }

         if( partc_bin & (1 << PART_ATTACH) )
         {
            PartAttachmentNodes	  part_attach(dataLine, impObj);
            part_attach.importPartAttachmentNodes();
         }

	 sprintf(new_kw, "%s_%d", new_kw, num_partcs);
	 partcManPtr->add(new_kw, impObj);
      }
      else
      {
	 type_iter = typeFuncMap.find(partc_type);
	 if( type_iter != etype_iter )
	 {
	    impObj = new ImportObject(str, partc_bin);
	    (type_iter->second)(dataLine, impObj);
	    sprintf(new_kw, "%s_%d", new_kw, num_partcs);
	    partcManPtr->add(new_kw, impObj);
	 }
	 else
	    cout << "Part TYPE NOT FOUND" << endl;
      }
   }

   return num_partcs;
}

