#ifndef _PerturbationShellThickness_h_
#define _PerturbationShellThickness_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *PERTURBATION_SHELL_THICKNESS keyword
  * from LSDYNA native file */

class PerturbationShellThickness : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   PerturbationShellThickness(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~PerturbationShellThickness()
   {
   }

public:
/** Function to import Card1 details for *PERTURBATION_SHELL_THICKNESS
  * keyword from file */
   int readCard1()
   {
      const char *fields[] = {"TYPE","EID","SCL",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, };
      unsigned int field_indices[] = {1, };
      unsigned int man_types[] = {ELEMENT, };
      unsigned int kw_types[] = {SHELL, };
      unsigned int num_indices = 1;
      numFields = 3;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return 0;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
      if( wordArray[0] )
         return atoi(wordArray[0]);
      else
         return 0;
   }

/** Function to import Type1Card details for *PERTURBATION_SHELL_THICKNESS
  * keyword from file */
   void readType1Card()
   {
      const char *fields[] = {"AMPL","XWL","XOFF","YWL","YOFF","ZWL","ZOFF",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 7;
      unsigned int i, end_loop;
      end_loop = 10000;
      for(i = 0; i < end_loop; i++)
      {
         numFields = 7;
         wordArray = dataLine->readNextCardAsWords(numFields);
         if( !numFields && dataLine->isFlagOn(KW_READ_END) ) return;

         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
         {
            cardObj = new Card("Type1Card");
            cardObj->addFields(numFields, field_types, fields, wordArray);
            impObj->addCard(cardObj);
         }
      }
   }

/** Function to import Type2Card details for *PERTURBATION_SHELL_THICKNESS
  * keyword from file */
   void readType2Card()
   {
      const char *fields[] = {"FADE",};
      unsigned int field_types[] = {DATA_DOUBLE, };
      numFields = 1;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Type2Card");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *PERTURBATION_SHELL_THICKNESS
  * from LSDYNA native file */
   unsigned int importPerturbationShellThickness()
   {
      int type = 0;
      type = readCard1();
      if( type == 1 )
      {
         readType1Card();
      }
      else if( type == 2 )
      {
         readType2Card();
      }
      return 0;
   }
};

#endif

