#include <iostream>
#include <algorithm>
#include "generic.h"
#include "perturbtype.h"
#include "perturbimport.h"
#include <stdlib.h>

using namespace std;

PerturbImport::PerturbImport
(
   FILE          *fp,
   DataLoc       *data_loc,
   PerturbManager    *perturb_man
)
{
   filePtr = fp;
   perturbManPtr = perturb_man;
   dataLocPtr = data_loc;
   dataLine = NULL;

   initPerturbTypesAndFunctions();
}

PerturbType PerturbImport::getPerturbTypeFromKeyword
	(
	   const char  *key_word,
	   unsigned int *perturb_id
	)
{
   *perturb_id = 0;

   if( strstr(key_word, "NOD") )
      return PERTURBATION_NODE;
   else if( strstr(key_word, "SHE") )
      return PERTURBATION_SHELL_THICKNESS;

   return PERTURB_NEW_TYPE;
}

unsigned int PerturbImport::readPerturbs()
{
   char         new_kw[LINE_LEN];
   unsigned int	i = 0, perturb_id = 0, perturb_type = 0, num_perturbs = 0;
   long		loc = 0L;
   VStringIterator   s = dataLocPtr->keywordList.begin(),
		     e = dataLocPtr->keywordList.end(), itr, 
		     pitr = dataLocPtr->keywordList.begin();
   typeFuncIterator  btype_iter = typeFuncMap.begin(),
                     etype_iter = typeFuncMap.end(), type_iter;

   dataLine = new DataLine(filePtr);

   while(true)
   {
      itr = find_if(pitr, e, bind2nd(KeyWordCompare (), "*PERT"));

      if( itr == e )
	 break;

      pitr = itr+1;
      i = (unsigned int)(itr - s);
      loc = dataLocPtr->slocList[i];

      rewind(filePtr);

      if( fseek(filePtr, loc, SEEK_SET) )
      {
	 cout << "ERROR in locating the Perturb cards" << endl;
	 break;
      }

      dataLine->clearFlag(KW_READ_END);

      char *str = dataLine->readNextCard(); //get the keyword
      Generic::RemoveLeadingAndTrailingBlanks( str );
cout << "KW = " << str << endl;

      perturb_type = getPerturbTypeFromKeyword( str, &perturb_id );
cout << "Perturb TYPE = " << perturb_type << endl;

      if( perturb_type == PERTURB_NEW_TYPE )
      {
         cout << "Perturb TYPE NOT SUPPORTED" << endl;
         continue;
      }

      num_perturbs++;

      strcpy(new_kw, str);

      dataLine->clearFlag(KW_READ_END);
      type_iter = typeFuncMap.find(perturb_type);
      if( type_iter != etype_iter )
      {
          impObj = new ImportObject(str, perturb_type);
          (type_iter->second)(dataLine, impObj);
          if( perturb_id )
          {
             perturbManPtr->add(new_kw, impObj);
          }
          else
          {
             sprintf(new_kw, "%s_%d", new_kw, num_perturbs);
             perturbManPtr->add(new_kw, impObj);
          }
      }
      else
         cout << "Perturb TYPE NOT FOUND" << endl;
   }

   return num_perturbs;
}

