#ifndef _Perturb_IMPORT_H_
#define _Perturb_IMPORT_H_

#include <string>
#include <map>
#include "dataloc.h"
#include "perturbmanager.h"
#include "dataline.h"
#include "card.h"
#include "perturbtype.h"
#include "typemap.h"

/** Class to import the data from native LSDYNA file for *PERTUBATION keywords. 
  * All the data is imported through this class and stored in the manager object.
  */
class PerturbImport
{
public:
   /** Constructor for creating this object
     * \param fp File pointer to the LSDYNA native file
     * \param data_loc Pointer to the list of keywords and their locations in
     * the file
     * \param perturb_man Manager pointer to hold the imported data as a list of
     * ImportObject list
     */
   PerturbImport
   (
      FILE          *fp,
      DataLoc       *data_loc,
      PerturbManager    *perturb_man
   );

   ~PerturbImport()
   {
      filePtr = NULL;
      perturbManPtr = NULL;
      dataLocPtr = NULL;
      delete dataLine;
   }

   /** Function for getting the keyword type from given keyword name from LSDYNA
     * native file. The type is stored in the database
     * \param key_word Name of the keyword from file
     * \param perturb_id ID of the keyword if it is there
     * \return Type for *PERTUBATION group of keywords
     */
   static PerturbType getPerturbTypeFromKeyword
	   (
	      const char  *key_word,
	      unsigned int *perturb_id
	   );

   /** Reads the *PERTURBATION keywords from file
     * \return Returns 0 on failure else number of *PERTURBATION keywords
     */
   unsigned int readPerturbs();

   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *PERTURBATION keyword there is a function to call
     */
   void initPerturbTypesAndFunctions();

private:
   FILE          *filePtr;
   /** Manager pointer for holding the imported data for all the keywords */
   PerturbManager    *perturbManPtr;
   /** Pointer to keywords and their locations in the file */
   DataLoc       *dataLocPtr;
   /** Pointer to access the file data line by line */
   DataLine      *dataLine;
   /** Object to store imported data from LSDYNA data file */
   ImportObject  *impObj;
   /** A map between the keyword type and pointer to function */
   map<unsigned int, ImportFunctionPtr>  typeFuncMap;
};

#endif

