#ifndef _RailTrack_h_
#define _RailTrack_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *RAIL_TRACK keyword
  * from LSDYNA native file */

class RailTrack : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   RailTrack(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~RailTrack()
   {
   }

public:
/** Function to import Card1 details for *RAIL_TRACK
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"ID","BSETID1","NORGN1","LCUR1","OSET1","SF1","GA1",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {1, 2, 3, };
      unsigned int man_types[] = {SET, NOD, DEFINE, };
      unsigned int kw_types[] = {BEAM, 9999, CURVE, };
      unsigned int num_indices = 3;
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, RAIL, impObj);

      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *RAIL_TRACK
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"UNUSED","BSETID2","NORGN2","LCUR2","OSET2","SF2","GA2",};
      unsigned int field_types[] = {DATA_UNUSED, DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {1, 2, 3, };
      unsigned int man_types[] = {SET, NOD, DEFINE, };
      unsigned int kw_types[] = {BEAM, 9999, CURVE, };
      unsigned int num_indices = 3;
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *RAIL_TRACK
  * from LSDYNA native file */
   unsigned int importRailTrack()
   {
      readCard1();
      readCard2();
      return 0;
   }
};

#endif

