#include <iostream>
#include <algorithm>
#include "generic.h"
#include "railtype.h"
#include "railimport.h"
#include <stdlib.h>

using namespace std;

RailImport::RailImport
(
   FILE          *fp,
   DataLoc       *data_loc,
   RailManager    *rail_man
)
{
   filePtr = fp;
   railManPtr = rail_man;
   dataLocPtr = data_loc;
   dataLine = NULL;

   initRailTypesAndFunctions();
}

RailType RailImport::getRailTypeFromKeyword
	(
	   const char  *key_word,
	   unsigned int *rail_id
	)
{
   *rail_id = 0;

   if( strstr(key_word, "ACK") )
      return RAIL_TRACK;
   else if( strstr(key_word, "AIN") )
      return RAIL_TRAIN;

   return RAIL_NEW_TYPE;
}

unsigned int RailImport::readRails()
{
   char         new_kw[LINE_LEN];
   unsigned int	i = 0, rail_id = 0, rail_type = 0, num_rails = 0;
   long		loc = 0L;
   VStringIterator   s = dataLocPtr->keywordList.begin(),
		     e = dataLocPtr->keywordList.end(), itr, 
		     pitr = dataLocPtr->keywordList.begin();
   typeFuncIterator  btype_iter = typeFuncMap.begin(),
                     etype_iter = typeFuncMap.end(), type_iter;

   dataLine = new DataLine(filePtr);

   while(true)
   {
      itr = find_if(pitr, e, bind2nd(KeyWordCompare (), "*RAIL"));

      if( itr == e )
	 break;

      pitr = itr+1;
      i = (unsigned int)(itr - s);
      loc = dataLocPtr->slocList[i];

      rewind(filePtr);

      if( fseek(filePtr, loc, SEEK_SET) )
      {
	 cout << "ERROR in locating the Rail cards" << endl;
	 break;
      }

      dataLine->clearFlag(KW_READ_END);

      char *str = dataLine->readNextCard(); //get the keyword
      Generic::RemoveLeadingAndTrailingBlanks( str );
cout << "KW = " << str << endl;

      rail_type = getRailTypeFromKeyword( str, &rail_id );
cout << "Rail TYPE = " << rail_type << endl;

      if( rail_type == RAIL_NEW_TYPE )
      {
         cout << "Rail TYPE NOT SUPPORTED" << endl;
         continue;
      }

      num_rails++;

      strcpy(new_kw, str);

      dataLine->clearFlag(KW_READ_END);
      type_iter = typeFuncMap.find(rail_type);
      if( type_iter != etype_iter )
      {
          impObj = new ImportObject(str, rail_type);
          (type_iter->second)(dataLine, impObj);
          if( rail_id )
          {
             railManPtr->add(new_kw, impObj);
          }
          else
          {
             sprintf(new_kw, "%s_%d", new_kw, num_rails);
             railManPtr->add(new_kw, impObj);
          }
      }
      else
         cout << "Rail TYPE NOT FOUND" << endl;
   }

   return num_rails;
}

