#ifndef _Rail_IMPORT_H_
#define _Rail_IMPORT_H_

#include <string>
#include <map>
#include "dataloc.h"
#include "railmanager.h"
#include "dataline.h"
#include "card.h"
#include "railtype.h"
#include "typemap.h"

/** Class to import the data from native LSDYNA file for *RAIL keywords. All
  * the data is imported through this class and stored in the manager object.
  */
class RailImport
{
public:
   /** Constructor for creating this object
     * \param fp File pointer to the LSDYNA native file
     * \param data_loc Pointer to the list of keywords and their locations in
     * the file
     * \param rail_man Manager pointer to hold the imported data as a list of
     * ImportObject list
     */
   RailImport
   (
      FILE          *fp,
      DataLoc       *data_loc,
      RailManager    *rail_man
   );

   ~RailImport()
   {
      filePtr = NULL;
      railManPtr = NULL;
      dataLocPtr = NULL;
      delete dataLine;
   }

   /** Function for getting the keyword type from given keyword name from LSDYNA
     * native file. The type is stored in the database
     * \param key_word Name of the keyword from file
     * \param rail_id ID if exists along with the keyword
     * \return Type for *RAIL group of keywords
     */
   static RailType getRailTypeFromKeyword
	   (
	      const char  *key_word,
	      unsigned int *rail_id
	   );

   /** Reads the *RAIL keywords from file
     * \return Returns 0 on failure else number of *RAIL keywords
     */
   unsigned int readRails();

   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *RAIL keyword there is a function to call
     */
   void initRailTypesAndFunctions();

private:
   FILE          *filePtr;
   /** Manager pointer for holding the imported data for all the keywords */
   RailManager    *railManPtr;
   /** Pointer to keywords and their locations in the file */
   DataLoc       *dataLocPtr;
   /** Pointer to access the file data line by line */
   DataLine      *dataLine;
   /** Object to store imported data from LSDYNA data file */
   ImportObject  *impObj;
   /** A map between the keyword type and pointer to function */
   map<unsigned int, ImportFunctionPtr>  typeFuncMap;
};

#endif

