#ifndef _RigidwallGeometric_h_
#define _RigidwallGeometric_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *RIGIDWALL_GEOMETRIC keyword
  * from LSDYNA native file */

class RigidwallGeometric : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   RigidwallGeometric(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~RigidwallGeometric()
   {
   }

public:
/** Function to import Card1 details for *RIGIDWALL_GEOMETRIC
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"NSID","NSIDEX","BOXID","BIRTH","DEATH",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, 1, 2, };
      unsigned int man_types[] = {SET, SET, DEFINE, };
      unsigned int kw_types[] = {NOD, NOD, BOX, };
      unsigned int num_indices = 3;
      numFields = 5;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *RIGIDWALL_GEOMETRIC
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"XT","YT","ZT","XH","YH","ZH","FRIC",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *RIGIDWALL_GEOMETRIC
  * from LSDYNA native file */
   unsigned int importRigidwallGeometric()
   {
      readCard1();
      readCard2();
      return 0;
   }
};

#endif

