#ifndef _RigidwallGeometricPrism_h_
#define _RigidwallGeometricPrism_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *RIGIDWALL_GEOMETRIC_PRISM keyword
  * from LSDYNA native file */

class RigidwallGeometricPrism : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   RigidwallGeometricPrism(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~RigidwallGeometricPrism()
   {
   }

public:
/** Function to import Card3 details for *RIGIDWALL_GEOMETRIC_PRISM
  * keyword from file */
   void readCard3()
   {
      const char *fields[] = {"XHEV","YHEV","ZHEV","LENL","LENM","LENP",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *RIGIDWALL_GEOMETRIC_PRISM
  * from LSDYNA native file */
   unsigned int importRigidwallGeometricPrism()
   {
      readCard3();
      return 0;
   }
};

#endif

