#ifndef _RigidwallId_h_
#define _RigidwallId_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *RIGIDWALL_ID keyword
  * from LSDYNA native file */

class RigidwallId : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   RigidwallId(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~RigidwallId()
   {
   }

public:
/** Function to import CardID details for *RIGIDWALL_ID
  * keyword from file */
   void readCardID()
   {
      const char *fields[] = {"RWID","HEADING",};
      unsigned int field_types[] = {DATA_INT, DATA_CHAR_ARRAY, };
      numFields = 2;
      unsigned int field_widths[] = {10, 70, };
      strBuff = dataLine->readNextCard(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;

      wordArray = dataLine->splitIntoWords(numFields, field_widths);
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, RIGIDWALL, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("CardID");
         cardObj->addFields(numFields, field_types, field_widths, fields, strBuff);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *RIGIDWALL_ID
  * from LSDYNA native file */
   unsigned int importRigidwallId()
   {
      readCardID();
      return 0;
   }
};

#endif

