#ifndef _RigidwallPlanarOrtho_h_
#define _RigidwallPlanarOrtho_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *RIGIDWALL_PLANAR_ORTHO keyword
  * from LSDYNA native file */

class RigidwallPlanarOrtho : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   RigidwallPlanarOrtho(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~RigidwallPlanarOrtho()
   {
   }

public:
/** Function to import CardA details for *RIGIDWALL_PLANAR_ORTHO
  * keyword from file */
   void readCardA()
   {
      const char *fields[] = {"SFRICA","SFRICB","DFRICA","DFRICB","DECAYA","DECAYB",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("CardA");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import CardB details for *RIGIDWALL_PLANAR_ORTHO
  * keyword from file */
   void readCardB()
   {
      const char *fields[] = {"NODE1","NODE2","D1","D2","D3",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, 1, };
      unsigned int man_types[] = {NOD, NOD, };
      unsigned int kw_types[] = {9999, 9999, };
      unsigned int num_indices = 2;
      numFields = 5;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("CardB");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *RIGIDWALL_PLANAR_ORTHO
  * from LSDYNA native file */
   unsigned int importRigidwallPlanarOrtho()
   {
      readCardA();
      readCardB();
      return 0;
   }
};

#endif

