#include <iostream>
#include <algorithm>
#include "generic.h"
#include "rigidwalltype.h"
#include "rigidwallimport.h"

#include "rigidwallid.h"
#include "rigidwallgeometric.h"
#include "rigidwallgeometricflat.h"
#include "rigidwallgeometricprism.h"
#include "rigidwallgeometriccylinder.h"
#include "rigidwallgeometricsphere.h"
#include "rigidwallgeometricmotion.h"

#include "rigidwallplanar.h"
#include "rigidwallplanarortho.h"
#include "rigidwallplanarfinite.h"
#include "rigidwallplanarmoving.h"
#include "rigidwallplanarforces.h"

#include <stdlib.h>

using namespace std;

RigidwallImport::RigidwallImport
(
   FILE          *fp,
   DataLoc       *data_loc,
   RigidwallManager    *rigidwall_man
)
{
   filePtr = fp;
   rigidwallManPtr = rigidwall_man;
   dataLocPtr = data_loc;
   dataLine = NULL;
}

RigidwallType RigidwallImport::getRigidwallTypeFromKeyword
	(
	   const char  *key_word,
	   unsigned int *rw_bin_type
	)
{
   *rw_bin_type = 0;

   if( strstr(key_word, "_ID") )
      *rw_bin_type |= (1 << RIGIDWALL_ID);

   if( strstr(key_word, "GEO") )
   {
      *rw_bin_type |= (1 << RIGIDWALL_GEOMETRIC);
       
      if( strstr(key_word, "FLAT") )
         *rw_bin_type |= (1 << RIGIDWALL_FLAT);
      else if( strstr(key_word, "PRIS") )
         *rw_bin_type |= (1 << RIGIDWALL_PRISM);
      else if( strstr(key_word, "CYL") )
         *rw_bin_type |= (1 << RIGIDWALL_CYLINDER);
      else if( strstr(key_word, "SPH") )
         *rw_bin_type |= (1 << RIGIDWALL_SPHERE);

      if( strstr(key_word, "MOT") )
         *rw_bin_type |= (1 << RIGIDWALL_MOTION);

      return RIGIDWALL_GEOMETRIC;
   }
   else if( strstr(key_word, "PLA") )
   {
      *rw_bin_type |= (1 << RIGIDWALL_PLANAR);

      if( strstr(key_word, "ORT") )
         *rw_bin_type |= (1 << RIGIDWALL_ORTHO);
      if( strstr(key_word, "FIN") )
         *rw_bin_type |= (1 << RIGIDWALL_FINITE);
      if( strstr(key_word, "MOV") )
         *rw_bin_type |= (1 << RIGIDWALL_MOVING);

      if( strstr(key_word, "FOR") )
         *rw_bin_type |= (1 << RIGIDWALL_FORCES);

      return RIGIDWALL_PLANAR;
   }

   return RIGIDWALL_NEW_TYPE;
}

unsigned int RigidwallImport::readRigidwalls()
{
   char         new_kw[LINE_LEN];
   unsigned int	i = 0, rw_bin_type = 0, rigidwall_type = 0, 
                num_rigidwalls = 0;
   long		loc = 0L;
   VStringIterator   s = dataLocPtr->keywordList.begin(),
		     e = dataLocPtr->keywordList.end(), itr, 
		     pitr = dataLocPtr->keywordList.begin();
   typeFuncIterator  btype_iter = typeFuncMap.begin(),
                     etype_iter = typeFuncMap.end(), type_iter;

   dataLine = new DataLine(filePtr);

   while(true)
   {
      itr = find_if(pitr, e, bind2nd(KeyWordCompare (), "*RIGIDW"));

      if( itr == e )
	 break;

      pitr = itr+1;
      i = (unsigned int)(itr - s);
      loc = dataLocPtr->slocList[i];

      rewind(filePtr);

      if( fseek(filePtr, loc, SEEK_SET) )
      {
	 cout << "ERROR in locating the Rigidwall cards" << endl;
	 break;
      }

      dataLine->clearFlag(KW_READ_END);

      char *str = dataLine->readNextCard(); //get the keyword
      Generic::RemoveLeadingAndTrailingBlanks( str );
cout << "KW = " << str << endl;

      rigidwall_type = getRigidwallTypeFromKeyword( str, &rw_bin_type );
cout << "Rigidwall TYPE = " << rigidwall_type << endl;

      if( rigidwall_type == RIGIDWALL_NEW_TYPE )
      {
         cout << "Rigidwall TYPE NOT SUPPORTED" << endl;
         continue;
      }

      num_rigidwalls++;

      strcpy(new_kw, str);

      dataLine->clearFlag(KW_READ_END);
      impObj = new ImportObject(str, rw_bin_type);

      switch(rigidwall_type)
      {
         case RIGIDWALL_GEOMETRIC:
            importGeometricType(rw_bin_type);
            break;
         case RIGIDWALL_PLANAR:
            importPlanarType(rw_bin_type);
            break;
      }

      sprintf(new_kw, "%s_%d", new_kw, num_rigidwalls);
      rigidwallManPtr->add(new_kw, impObj);
   }

   return num_rigidwalls;
}

unsigned int RigidwallImport::importGeometricType
             (
                unsigned int & rw_type
             )
{
   if( rw_type & (1 << RIGIDWALL_ID) )
   {
      RigidwallId  rw_id(dataLine, impObj);
      rw_id.importRigidwallId();
   }

   RigidwallGeometric    rw_geo(dataLine, impObj);
   rw_geo.importRigidwallGeometric();

   if( rw_type & (1 << RIGIDWALL_FLAT) )
   {
      RigidwallGeometricFlat  rwgeo_flat(dataLine, impObj);
      rwgeo_flat.importRigidwallGeometricFlat();
   }
   else if( rw_type & (1 << RIGIDWALL_PRISM) )
   {
      RigidwallGeometricPrism  rwgeo_prism(dataLine, impObj);
      rwgeo_prism.importRigidwallGeometricPrism();
   }
   else if( rw_type & (1 << RIGIDWALL_CYLINDER) )
   {
      RigidwallGeometricCylinder  rwgeo_cyl(dataLine, impObj);
      rwgeo_cyl.importRigidwallGeometricCylinder();
   }
   else if( rw_type & (1 << RIGIDWALL_SPHERE) )
   {
      RigidwallGeometricSphere  rwgeo_sph(dataLine, impObj);
      rwgeo_sph.importRigidwallGeometricSphere();
   }

   if( rw_type & (1 << RIGIDWALL_MOTION) )
   {
      RigidwallGeometricMotion  rwgeo_mot(dataLine, impObj);
      rwgeo_mot.importRigidwallGeometricMotion();
   }
    
   return 0;
}

unsigned int RigidwallImport::importPlanarType
             (
                unsigned int & rw_type
             )
{
   if( rw_type & (1 << RIGIDWALL_ID) )
   {
      RigidwallId  rw_id(dataLine, impObj);
      rw_id.importRigidwallId();
   }

   RigidwallPlanar    rw_plan(dataLine, impObj);
   rw_plan.importRigidwallPlanar();

   if( rw_type & (1 << RIGIDWALL_ORTHO) )
   {
      RigidwallPlanarOrtho  rwplan_ortho(dataLine, impObj);
      rwplan_ortho.importRigidwallPlanarOrtho();
   }

   if( rw_type & (1 << RIGIDWALL_FINITE) )
   {
      RigidwallPlanarFinite  rwplan_fin(dataLine, impObj);
      rwplan_fin.importRigidwallPlanarFinite();
   }

   if( rw_type & (1 << RIGIDWALL_MOVING) )
   {
      RigidwallPlanarMoving  rwplan_mov(dataLine, impObj);
      rwplan_mov.importRigidwallPlanarMoving();

      if( rw_type & (1 << RIGIDWALL_ORTHO) )
         cout << "Error: ORTHO and MOVING options are not allowed together" 
	      << endl;
   }

   if( rw_type & (1 << RIGIDWALL_FORCES) )
   {
      RigidwallPlanarForces  rwplan_for(dataLine, impObj);
      rwplan_for.importRigidwallPlanarForces();
   }

   return 0;
}

