#ifndef _Rigidwall_IMPORT_H_
#define _Rigidwall_IMPORT_H_

#include <string>
#include <map>
#include "dataloc.h"
#include "rigidwallmanager.h"
#include "dataline.h"
#include "card.h"
#include "rigidwalltype.h"
#include "typemap.h"

/** Class to import the data from native LSDYNA file for *RIGIDWALL keywords. All
  * the data is imported through this class and stored in the manager object.
  */
class RigidwallImport
{
public:
   /** Constructor for creating this object
     * \param fp File pointer to the LSDYNA native file
     * \param data_loc Pointer to the list of keywords and their locations in
     * the file
     * \param rigidwall_man Manager pointer to hold the imported data as a list of
     * ImportObject list
     */
   RigidwallImport
   (
      FILE          *fp,
      DataLoc       *data_loc,
      RigidwallManager    *rigidwall_man
   );

   ~RigidwallImport()
   {
      filePtr = NULL;
      rigidwallManPtr = NULL;
      dataLocPtr = NULL;
      delete dataLine;
   }

   /** Function for getting the keyword type from given keyword name from LSDYNA
     * native file. The type is stored in the database
     * \param key_word Name of the keyword from file
     * \param rigidwall_id ID of the keyword if it is there
     * \return Type for *RIGIDWALL group of keywords
     */
   static RigidwallType getRigidwallTypeFromKeyword
	   (
	      const char  *key_word,
	      unsigned int *rigidwall_id
	   );

   /** Reads the *RIGIDWALL_PLANAR keywords from file
     * \return Returns 0 on failure else number of *RIGIDWALL_PLANAR keywords
     */
   unsigned int importPlanarType
		(
                   unsigned int & rw_type
		);

   /** Reads the *RIGIDWALL_GEOMETRIC keywords from file
     * \return Returns 0 on failure else number of *RIGIDWALL_GEOMETRIC keywords
     */
   unsigned int importGeometricType
		(
                   unsigned int & rw_type
		);

   /** Reads the *RIGIDWALL keywords from file
     * \return Returns 0 on failure else number of *RIGIDWALL keywords
     */
   unsigned int readRigidwalls();

private:
   FILE          *filePtr;
   /** Manager pointer for holding the imported data for all the keywords */
   RigidwallManager    *rigidwallManPtr;
   /** Pointer to keywords and their locations in the file */
   DataLoc       *dataLocPtr;
   /** Pointer to access the file data line by line */
   DataLine      *dataLine;
   /** Object to store imported data from LSDYNA data file */
   ImportObject  *impObj;
   /** A map between the keyword type and pointer to function */
   map<unsigned int, ImportFunctionPtr>  typeFuncMap;
};

#endif

