#include <iostream>
#include <algorithm>
#include "generic.h"
#include "sectiontype.h"
#include "sectionimport.h"
#include "title.h"
#include <stdlib.h>

using namespace std;

SectionImport::SectionImport
(
   FILE          *fp,
   DataLoc       *data_loc,
   SectionManager    *section_man
)
{
   filePtr = fp;
   sectionManPtr = section_man;
   dataLocPtr = data_loc;
   dataLine = NULL;

   initShellTypesAndFunctions();
   initSolidTypesAndFunctions();
}

SectionType SectionImport::getSectionTypeFromKeyword
	(
	   const char  *key_word,
	   unsigned int *section_id
	)
{
   *section_id = 0;

   if( strstr(key_word, "BEA") )
      return SECTION_BEAM;
   else if( strstr(key_word, "CRE") )
      return SECTION_DISCRETE;
   else if( strstr(key_word, "MIX") )
      return SECTION_POINT_SOURCE_MIXTURE;
   else if( strstr(key_word, "SOU") )
      return SECTION_POINT_SOURCE;
   else if( strstr(key_word, "BEL") )
      return SECTION_SEATBELT;
   else if( strstr(key_word, "L_ALE") )
      return SECTION_SHELL_ALE;
   else if( strstr(key_word, "L_EFG") )
      return SECTION_SHELL_EFG;
   else if( strstr(key_word, "N_SHE") )
      return SECTION_SHELL;
   else if( strstr(key_word, "D_ALE") )
      return SECTION_SOLID_ALE;
   else if( strstr(key_word, "D_EFG") )
      return SECTION_SOLID_EFG;
   else if( strstr(key_word, "N_SOL") )
      return SECTION_SOLID;
   else if( strstr(key_word, "TEN") )
      return SECTION_SPH_TENSOR;
   else if( strstr(key_word, "USE") )
      return SECTION_SPH_USER;
   else if( strstr(key_word, "SPH") )
      return SECTION_SPH;
   else if( strstr(key_word, "TSHE") )
      return SECTION_TSHELL;

   return SECTION_NEW_TYPE;
}

unsigned int SectionImport::readSections()
{
   char         new_kw[LINE_LEN];
   unsigned int	i = 0, section_id = 0, section_type = 0, 
                num_sections = 0, title_flag = 0;
   long		loc = 0L;
   VStringIterator   s = dataLocPtr->keywordList.begin(),
		     e = dataLocPtr->keywordList.end(), itr, 
		     pitr = dataLocPtr->keywordList.begin();
   typeFuncIterator  btype_iter = typeFuncMap.begin(),
                     etype_iter = typeFuncMap.end(), type_iter;

   dataLine = new DataLine(filePtr);

   while(true)
   {
      itr = find_if(pitr, e, bind2nd(KeyWordCompare (), "*SECT"));

      if( itr == e )
	 break;

      pitr = itr+1;
      i = (unsigned int)(itr - s);
      loc = dataLocPtr->slocList[i];

      rewind(filePtr);

      if( fseek(filePtr, loc, SEEK_SET) )
      {
	 cout << "ERROR in locating the Section cards" << endl;
	 break;
      }

      dataLine->clearFlag(KW_READ_END);

      char *str = dataLine->readNextCard(); //get the keyword
      Generic::RemoveLeadingAndTrailingBlanks( str );
cout << "KW = " << str << endl;

      section_type = getSectionTypeFromKeyword( str, &section_id );
cout << "Section TYPE = " << section_type << endl;

      if( section_type == SECTION_NEW_TYPE )
      {
         cout << "Section TYPE NOT SUPPORTED" << endl;
         continue;
      }

      //num_sections++;

      strcpy(new_kw, str);
      type_iter = typeFuncMap.find(section_type);

      title_flag = 0;
      if( strstr(new_kw, "_TITL") )
      {
         title_flag = 1;
         section_type += TITLE_CARD;
      }

      dataLine->clearFlag(KW_READ_END);
      //type_iter = typeFuncMap.find(section_type);
      if( type_iter != etype_iter )
      {
	 impObj = new ImportObject(str, section_type);

         while( !dataLine->isFlagOn(KW_READ_END) )
         {
	    if( title_flag )
	    {
	       Title title(dataLine, impObj);
	       title.readCard();
	    }

	    (type_iter->second)(dataLine, impObj);
         }

         num_sections++;
	 sprintf(new_kw, "%s_%d", new_kw, num_sections);
	 sectionManPtr->add(new_kw, impObj);
      }
      else
         cout << "Section TYPE NOT FOUND" << endl;
   }

   return num_sections;
}

