#ifndef _Section_IMPORT_H_
#define _Section_IMPORT_H_

#include <string>
#include <map>
#include "dataloc.h"
#include "sectionmanager.h"
#include "dataline.h"
#include "card.h"
#include "sectiontype.h"
#include "typemap.h"

/** Class to import the data from native LSDYNA file for *SECTION keywords. All
  * the data is imported through this class and stored in the manager object.
  */
class SectionImport
{
public:
   /** Constructor for creating this object
     * \param fp File pointer to the LSDYNA native file
     * \param data_loc Pointer to the list of keywords and their locations in
     * the file
     * \param section_man Manager pointer to hold the imported data as a list of
     * ImportObject list
     */
   SectionImport
   (
      FILE          *fp,
      DataLoc       *data_loc,
      SectionManager    *section_man
   );

   ~SectionImport()
   {
      filePtr = NULL;
      sectionManPtr = NULL;
      dataLocPtr = NULL;
      delete dataLine;
   }

   /** Function for getting the keyword type from given keyword name from LSDYNA
     * native file. The type is stored in the database
     * \param key_word Name of the keyword from file
     * \param section_id ID if exists along with the keyword
     * \return Type for *SECTION group of keywords
     */
   static SectionType getSectionTypeFromKeyword
	   (
	      const char  *key_word,
	      unsigned int *section_id
	   );

   /** Reads the *SECTION keywords from file
     * \return Returns 0 on failure else number of *SECTION keywords
     */
   unsigned int readSections();

   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *SECTION keyword there is a function to call
     */
   void initShellTypesAndFunctions();
   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *SECTION keyword there is a function to call
     */
   void initSolidTypesAndFunctions();

private:
   FILE          *filePtr;
   /** Manager pointer for holding the imported data for all the keywords */
   SectionManager    *sectionManPtr;
   /** Pointer to keywords and their locations in the file */
   DataLoc       *dataLocPtr;
   /** Pointer to access the file data line by line */
   DataLine      *dataLine;
   /** Object to store imported data from LSDYNA data file */
   ImportObject  *impObj;
   /** A map between the keyword type and pointer to function */
   map<unsigned int, ImportFunctionPtr>  typeFuncMap;
};

#endif

