#ifndef _SectionPointSourceMixture_h_
#define _SectionPointSourceMixture_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *SECTION_POINT_SOURCE_MIXTURE keyword
  * from LSDYNA native file */

class SectionPointSourceMixture : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   SectionPointSourceMixture(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~SectionPointSourceMixture()
   {
   }

public:
/** Function to import Card1 details for *SECTION_POINT_SOURCE_MIXTURE
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"SECID","LCIDT","UNUSED","LCIDVEL","NIDLC001","NIDLC002","NIDLC003","IDIR",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_INT, DATA_UNUSED, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {1, 3, 4, 5, 6, };
      unsigned int man_types[] = {DEFINE, DEFINE, NOD, NOD, NOD, };
      unsigned int kw_types[] = {CURVE, CURVE, 9999, 9999, 9999, };
      unsigned int num_indices = 5;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, SECTION, impObj);

      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *SECTION_POINT_SOURCE_MIXTURE
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"LCMDOT1","LCMDOT2","LCMDOT3","LCMDOT4","LCMDOT5","LCMDOT6","LCMDOT7","LCMDOT8",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, 3, 4, 5, 6, 7, };
      unsigned int man_types[] = {DEFINE, DEFINE, DEFINE, DEFINE, DEFINE, DEFINE, DEFINE, DEFINE, };
      unsigned int kw_types[] = {CURVE, CURVE, CURVE, CURVE, CURVE, CURVE, CURVE, CURVE, };
      unsigned int num_indices = 8;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card3 details for *SECTION_POINT_SOURCE_MIXTURE
  * keyword from file */
   void readCard3()
   {
      const char *fields[] = {"NODEID","VECID","ORIFAREA",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, 1, };
      unsigned int man_types[] = {NOD, DEFINE, };
      unsigned int kw_types[] = {9999, VECTOR, };
      unsigned int num_indices = 2;
      numFields = 3;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card3");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *SECTION_POINT_SOURCE_MIXTURE
  * from LSDYNA native file */
   unsigned int importSectionPointSourceMixture()
   {
      readCard1();
      readCard2();
      readCard3();
      return 0;
   }
};

#endif

