#ifndef _SectionShell_h_
#define _SectionShell_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *SECTION_SHELL keyword
  * from LSDYNA native file */

class SectionShell : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   SectionShell(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~SectionShell()
   {
   }

public:
/** Function to import Card1 details for *SECTION_SHELL
  * keyword from file */
   int readCard1()
   {
      const char *fields[] = {"SECID","ELFORM","SHRF","NIP","PROPT","QR/IRID","ICOMP","SETYP",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_INT, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return 0;
      elform = 0;
      if( wordArray[1] )
         elform = atoi(wordArray[1]);
      nip = 0;
      if( wordArray[3] )
         nip = atoi(wordArray[3]);
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, SECTION, impObj);

      if( Card::isFlagOn(SAVE_REFERENCES) )
         sectionIntegrationFind(wordArray, numFields, 5, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
      if( wordArray[6] )
         return atoi(wordArray[6]);
      else
         return 0;
   }

/** Function to import Card2 details for *SECTION_SHELL
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"T1","T2","T3","T4","NLOC","MAREA","IDOF","EDGSET",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import CardICOMP details for *SECTION_SHELL
  * keyword from file */
   void readCardICOMP()
   {
      const char *fields[] = {"B1","B2","B3","B4","B5","B6","B7","B8",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int i, end_loop;
      end_loop = ((nip%8) ? (nip/8)+1 : nip/8);
      for(i = 0; i < end_loop; i++)
      {
         numFields = 8;
         wordArray = dataLine->readNextCardAsWords(numFields);
         if( !numFields && dataLine->isFlagOn(KW_READ_END) ) return;

         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
         {
            cardObj = new Card("CardICOMP");
            cardObj->addFields(numFields, field_types, fields, wordArray);
            impObj->addCard(cardObj);
         }
      }
   }

/** Function to import CardALE details for *SECTION_SHELL
  * keyword from file */
   void readCardALE()
   {
      const char *fields[] = {"AFAC","BFAC","CFAC","DFAC","EFAC","START","END","AAFAC",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("CardALE");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import CardEFG details for *SECTION_SHELL
  * keyword from file */
   void readCardEFG()
   {
      const char *fields[] = {"DX","DY","ISPLINE","IDILA",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, };
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("CardEFG");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import CardELFORM details for *SECTION_SHELL
  * keyword from file */
   void readCardELFORM()
   {
      const char *fields[] = {"NIPP","NXDOF","IUNF","IHGF","ITAJ","LMC","NHSV","ILOC",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      nipp = 0;
      if( wordArray[0] )
         nipp = atoi(wordArray[0]);
      lmc = 0;
      if( wordArray[5] )
         lmc = atoi(wordArray[5]);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("CardELFORM");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import CardNIPP details for *SECTION_SHELL
  * keyword from file */
   void readCardNIPP()
   {
      const char *fields[] = {"XI","ETA","WGT",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 3;
      unsigned int i, end_loop;
      end_loop = nipp;
      for(i = 0; i < end_loop; i++)
      {
         numFields = 3;
         wordArray = dataLine->readNextCardAsWords(numFields);
         if( !numFields && dataLine->isFlagOn(KW_READ_END) ) return;

         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
         {
            cardObj = new Card("CardNIPP");
            cardObj->addFields(numFields, field_types, fields, wordArray);
            impObj->addCard(cardObj);
         }
      }
   }

/** Function to import CardLMC details for *SECTION_SHELL
  * keyword from file */
   void readCardLMC()
   {
      const char *fields[] = {"P1","P2","P3","P4","P5","P6","P7","P8",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int i, end_loop;
      end_loop = ((lmc%8) ? (lmc/8)+1 : lmc/8);
      for(i = 0; i < end_loop; i++)
      {
         numFields = 8;
         wordArray = dataLine->readNextCardAsWords(numFields);
         if( !numFields && dataLine->isFlagOn(KW_READ_END) ) return;

         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
         {
            cardObj = new Card("CardLMC");
            cardObj->addFields(numFields, field_types, fields, wordArray);
            impObj->addCard(cardObj);
         }
      }
   }

/** Function to import all the cards of the keyword *SECTION_SHELL
  * from LSDYNA native file */
   unsigned int importSectionShell()
   {
      int icomp = 0;
      icomp = readCard1();
      readCard2();
      if( icomp == 1 )
      {
         readCardICOMP();
      }
      const char *kw = impObj->getKeyword().data();
      if( strstr(kw, "ALE") )
      {
         readCardALE();
      }
      if( strstr(kw, "EFG") )
      {
         readCardEFG();
      }
      if( elform == 101 || elform == 102 || elform == 103 || elform == 104 || elform == 105 )
      {
         readCardELFORM();
         readCardNIPP();
         readCardLMC();
      }
      return 0;
   }
public:
   int elform;
   int nip;
   int nipp;
   int lmc;
};

#endif

