#ifndef _SectionTshell_h_
#define _SectionTshell_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *SECTION_TSHELL keyword
  * from LSDYNA native file */

class SectionTshell : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   SectionTshell(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~SectionTshell()
   {
   }

public:
/** Function to import Card1 details for *SECTION_TSHELL
  * keyword from file */
   int readCard1()
   {
      const char *fields[] = {"SECID","ELFORM","SHRF","NIP","PROPT","QR","ICOMP",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_INT, DATA_DOUBLE, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, };
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return 0;
      nip = 0;
      if( wordArray[3] )
         nip = atoi(wordArray[3]);
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, SECTION, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
      if( wordArray[6] )
         return atoi(wordArray[6]);
      else
         return 0;
   }

/** Function to import CardNIP details for *SECTION_TSHELL
  * keyword from file */
   void readCardNIP()
   {
      const char *fields[] = {"B1","B2","B3","B4","B5","B6","B7","B8",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int i, end_loop;
      end_loop = ((nip%8) ? (nip/8)+1 : nip/8);
      for(i = 0; i < end_loop; i++)
      {
         numFields = 8;
         wordArray = dataLine->readNextCardAsWords(numFields);
         if( !numFields && dataLine->isFlagOn(KW_READ_END) ) return;

         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
         {
            cardObj = new Card("CardNIP");
            cardObj->addFields(numFields, field_types, fields, wordArray);
            impObj->addCard(cardObj);
         }
      }
   }

/** Function to import all the cards of the keyword *SECTION_TSHELL
  * from LSDYNA native file */
   unsigned int importSectionTshell()
   {
      int icomp = 0;
      icomp = readCard1();
      if( icomp == 1 )
      {
         readCardNIP();
      }
      return 0;
   }
public:
   int nip;
};

#endif

