#ifndef _SectionSolid_h_
#define _SectionSolid_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *SECTION_SOLID keyword
  * from LSDYNA native file */

class SectionSolid : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   SectionSolid(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~SectionSolid()
   {
   }

public:
/** Function to import Card1 details for *SECTION_SOLID
  * keyword from file */
   int readCard1()
   {
      const char *fields[] = {"SECID","ELFORM","AET",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_INT, DATA_INT, };
      numFields = 3;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return 0;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, SECTION, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
      if( wordArray[1] )
         return atoi(wordArray[1]);
      else
         return 0;
   }

/** Function to import CardALE details for *SECTION_SOLID
  * keyword from file */
   void readCardALE()
   {
      const char *fields[] = {"AFAC","BFAC","CFAC","DFAC","START","END","AAFAC",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("CardALE");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import CardEFG details for *SECTION_SOLID
  * keyword from file */
   void readCardEFG()
   {
      const char *fields[] = {"DX","DY","DZ","ISPLINE","IDILA","IEBT","IDIM","TOLDEF",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("CardEFG");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import CardELFORM details for *SECTION_SOLID
  * keyword from file */
   void readCardELFORM()
   {
      const char *fields[] = {"NIP","NXDOF","IHGF","ITAJ","LMC","NHSV",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      nip = 0;
      if( wordArray[0] )
         nip = atoi(wordArray[0]);
      lmc = 0;
      if( wordArray[4] )
         lmc = atoi(wordArray[4]);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("CardELFORM");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import CardNIP details for *SECTION_SOLID
  * keyword from file */
   void readCardNIP()
   {
      const char *fields[] = {"XI","ETA","ZETA","WGT",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 4;
      unsigned int i, end_loop;
      end_loop = nip;
      for(i = 0; i < end_loop; i++)
      {
         numFields = 4;
         wordArray = dataLine->readNextCardAsWords(numFields);
         if( !numFields && dataLine->isFlagOn(KW_READ_END) ) return;

         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
         {
            cardObj = new Card("CardNIP");
            cardObj->addFields(numFields, field_types, fields, wordArray);
            impObj->addCard(cardObj);
         }
      }
   }

/** Function to import CardLMC details for *SECTION_SOLID
  * keyword from file */
   void readCardLMC()
   {
      const char *fields[] = {"P1","P2","P3","P4","P5","P6","P7","P8",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      unsigned int i, end_loop;
      end_loop = ((lmc%8) ? (lmc/8)+1 : lmc/8);
      for(i = 0; i < end_loop; i++)
      {
         numFields = 8;
         wordArray = dataLine->readNextCardAsWords(numFields);
         if( !numFields && dataLine->isFlagOn(KW_READ_END) ) return;

         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
         {
            cardObj = new Card("CardLMC");
            cardObj->addFields(numFields, field_types, fields, wordArray);
            impObj->addCard(cardObj);
         }
      }
   }

/** Function to import all the cards of the keyword *SECTION_SOLID
  * from LSDYNA native file */
   unsigned int importSectionSolid()
   {
      int elform = 0;
      elform = readCard1();
      const char *kw = impObj->getKeyword().data();
      if( strstr(kw, "ALE") )
      {
         readCardALE();
      }
      if( strstr(kw, "EFG") )
      {
         readCardEFG();
      }
      if( elform == 101 || elform == 102 || elform == 103 || elform == 104 || elform == 105 )
      {
         readCardELFORM();
         readCardNIP();
         readCardLMC();
      }
      return 0;
   }
public:
   int nip;
   int lmc;
};

#endif

