#ifndef _SectionSph_h_
#define _SectionSph_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *SECTION_SPH keyword
  * from LSDYNA native file */

class SectionSph : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   SectionSph(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~SectionSph()
   {
   }

public:
/** Function to import Card1 details for *SECTION_SPH
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"SECID","CSLH","HMIN","HMAX","SPHINI","DEATH","START",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 7;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, SECTION, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import CardTENSOR details for *SECTION_SPH
  * keyword from file */
   void readCardTENSOR()
   {
      const char *fields[] = {"HXCSLH","HYCSLH","HZCSLH","HXINI","HYINI","HZINI",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("CardTENSOR");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *SECTION_SPH
  * from LSDYNA native file */
   unsigned int importSectionSph()
   {
      readCard1();
      if( strstr(impObj->getKeyword().data(), "TENS") )
      {
         readCardTENSOR();
      }
      return 0;
   }
};

#endif

