#ifndef _SensorControl_h_
#define _SensorControl_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *SENSOR_CONTROL keyword
  * from LSDYNA native file */

class SensorControl : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   SensorControl(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~SensorControl()
   {
   }

public:
/** Function to import Card1 details for *SENSOR_CONTROL
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"CNTLID","TYPE","TYPEID",};
      unsigned int field_types[] = {DATA_INT, DATA_CHAR_ARRAY, DATA_INT, };
      numFields = 3;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, SENSOR, impObj);

      if( Card::isFlagOn(SAVE_REFERENCES) )
         sensorControlFind(wordArray, numFields, 1, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *SENSOR_CONTROL
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"INITSTT","SWIT1","SWIT2","SWIT3","SWIT4","SWIT5","SWIT6","SWIT7",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {1, 2, 3, 4, 5, 6, 7, };
      unsigned int man_types[] = {SENSOR, SENSOR, SENSOR, SENSOR, SENSOR, SENSOR, SENSOR, };
      unsigned int kw_types[] = {9999, 9999, 9999, 9999, 9999, 9999, 9999, };
      unsigned int num_indices = 7;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *SENSOR_CONTROL
  * from LSDYNA native file */
   unsigned int importSensorControl()
   {
      readCard1();
      readCard2();
      return 0;
   }
};

#endif

