#ifndef _SensorDefineElement_h_
#define _SensorDefineElement_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *SENSOR_DEFINE_ELEMENT keyword
  * from LSDYNA native file */

class SensorDefineElement : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   SensorDefineElement(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~SensorDefineElement()
   {
   }

public:
/** Function to import Card details for *SENSOR_DEFINE_ELEMENT
  * keyword from file */
   void readCard()
   {
      const char *fields[] = {"SENSID","ETYPE","ELEMID","COMP","CTYPE","LAYER",};
      unsigned int field_types[] = {DATA_INT, DATA_CHAR_ARRAY, DATA_INT, DATA_CHAR_ARRAY, DATA_CHAR_ARRAY, DATA_CHAR_ARRAY, };
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, SENSOR, impObj);

      if( Card::isFlagOn(SAVE_REFERENCES) )
         sensorElementFind(wordArray, numFields, 1, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *SENSOR_DEFINE_ELEMENT
  * from LSDYNA native file */
   unsigned int importSensorDefineElement()
   {
      readCard();
      return 0;
   }
};

#endif

