#ifndef _SensorDefineNode_h_
#define _SensorDefineNode_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *SENSOR_DEFINE_NODE keyword
  * from LSDYNA native file */

class SensorDefineNode : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   SensorDefineNode(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~SensorDefineNode()
   {
   }

public:
/** Function to import Card details for *SENSOR_DEFINE_NODE
  * keyword from file */
   void readCard()
   {
      const char *fields[] = {"SENSID","NODE1","NODE2","VID","CRD","CTYPE",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_CHAR_ARRAY, DATA_INT, DATA_CHAR_ARRAY, };
      unsigned int field_indices[] = {1, 2, 3, 4, };
      unsigned int man_types[] = {NOD, NOD, DEFINE, DEFINE, };
      unsigned int kw_types[] = {9999, 9999, VECTOR, COORDINATE, };
      unsigned int num_indices = 4;
      numFields = 6;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, SENSOR, impObj);

      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *SENSOR_DEFINE_NODE
  * from LSDYNA native file */
   unsigned int importSensorDefineNode()
   {
      readCard();
      return 0;
   }
};

#endif

