#ifndef _SensorSwitchCalcLogic_h_
#define _SensorSwitchCalcLogic_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *SENSOR_SWITCH_CALC_LOGIC keyword
  * from LSDYNA native file */

class SensorSwitchCalcLogic : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   SensorSwitchCalcLogic(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~SensorSwitchCalcLogic()
   {
   }

public:
/** Function to import Card details for *SENSOR_SWITCH_CALC_LOGIC
  * keyword from file */
   void readCard()
   {
      const char *fields[] = {"SWITID","SWIT1","SWIT2","SWIT3","SWIT4","SWIT5","SWIT6","SWIT7",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {1, 2, 3, 4, 5, 6, 7, };
      unsigned int man_types[] = {SENSOR, SENSOR, SENSOR, SENSOR, SENSOR, SENSOR, SENSOR, };
      unsigned int kw_types[] = {9999, 9999, 9999, 9999, 9999, 9999, 9999, };
      unsigned int num_indices = 7;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, SENSOR, impObj);

      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *SENSOR_SWITCH_CALC_LOGIC
  * from LSDYNA native file */
   unsigned int importSensorSwitchCalcLogic()
   {
      readCard();
      return 0;
   }
};

#endif

