#include <iostream>
#include <algorithm>
#include "generic.h"
#include "sensortype.h"
#include "sensorimport.h"
#include <stdlib.h>

using namespace std;

SensorImport::SensorImport
(
   FILE          *fp,
   DataLoc       *data_loc,
   SensorManager    *sensor_man
)
{
   filePtr = fp;
   sensorManPtr = sensor_man;
   dataLocPtr = data_loc;
   dataLine = NULL;

   initSensorTypesAndFunctions();
}

SensorType SensorImport::getSensorTypeFromKeyword
	(
	   const char  *key_word,
	   unsigned int *sensor_id
	)
{
   *sensor_id = 0;

   if( strstr(key_word, "TRO") )
      return SENSOR_CONTROL;
   else if( strstr(key_word, "MATH") )
      return SENSOR_DEFINE_CALC_MATH;
   else if( strstr(key_word, "ELE") )
      return SENSOR_DEFINE_ELEMENT;
   else if( strstr(key_word, "FOR") )
      return SENSOR_DEFINE_FORCE;
   else if( strstr(key_word, "NOD") )
      return SENSOR_DEFINE_NODE;
   else if( strstr(key_word, "LOG") )
      return SENSOR_SWITCH_CALC_LOGIC;
   else if( strstr(key_word, "SWI") )
      return SENSOR_SWITCH;

   return SENSOR_NEW_TYPE;
}

unsigned int SensorImport::readSensors()
{
   char         new_kw[LINE_LEN];
   unsigned int	i = 0, sensor_id = 0, sensor_type = 0, num_sensors = 0;
   long		loc = 0L;
   VStringIterator   s = dataLocPtr->keywordList.begin(),
		     e = dataLocPtr->keywordList.end(), itr, 
		     pitr = dataLocPtr->keywordList.begin();
   typeFuncIterator  btype_iter = typeFuncMap.begin(),
                     etype_iter = typeFuncMap.end(), type_iter;

   dataLine = new DataLine(filePtr);

   while(true)
   {
      itr = find_if(pitr, e, bind2nd(KeyWordCompare (), "*SENSOR"));

      if( itr == e )
	 break;

      pitr = itr+1;
      i = (unsigned int)(itr - s);
      loc = dataLocPtr->slocList[i];

      rewind(filePtr);

      if( fseek(filePtr, loc, SEEK_SET) )
      {
	 cout << "ERROR in locating the Sensor cards" << endl;
	 break;
      }

      dataLine->clearFlag(KW_READ_END);

      char *str = dataLine->readNextCard(); //get the keyword
      Generic::RemoveLeadingAndTrailingBlanks( str );
cout << "KW = " << str << endl;

      sensor_type = getSensorTypeFromKeyword( str, &sensor_id );
cout << "Sensor TYPE = " << sensor_type << endl;

      if( sensor_type == SENSOR_NEW_TYPE )
      {
         cout << "Sensor TYPE NOT SUPPORTED" << endl;
         continue;
      }

      num_sensors++;

      strcpy(new_kw, str);

      dataLine->clearFlag(KW_READ_END);
      type_iter = typeFuncMap.find(sensor_type);
      if( type_iter != etype_iter )
      {
          impObj = new ImportObject(str, sensor_type);
          (type_iter->second)(dataLine, impObj);
          if( sensor_id )
          {
             sensorManPtr->add(new_kw, impObj);
          }
          else
          {
             sprintf(new_kw, "%s_%d", new_kw, num_sensors);
             sensorManPtr->add(new_kw, impObj);
          }
      }
      else
         cout << "Sensor TYPE NOT FOUND" << endl;
   }

   return num_sensors;
}

