#ifndef _Sensor_IMPORT_H_
#define _Sensor_IMPORT_H_

#include <string>
#include <map>
#include "dataloc.h"
#include "sensormanager.h"
#include "dataline.h"
#include "card.h"
#include "sensortype.h"
#include "typemap.h"

/** Class to import the data from native LSDYNA file for *SENSOR keywords. All
  * the data is imported through this class and stored in the manager object.
  */
class SensorImport
{
public:
   /** Constructor for creating this object
     * \param fp File pointer to the LSDYNA native file
     * \param data_loc Pointer to the list of keywords and their locations in
     * the file
     * \param sensor_man Manager pointer to hold the imported data as a list of
     * ImportObject list
     */
   SensorImport
   (
      FILE          *fp,
      DataLoc       *data_loc,
      SensorManager    *sensor_man
   );

   ~SensorImport()
   {
      filePtr = NULL;
      sensorManPtr = NULL;
      dataLocPtr = NULL;
      delete dataLine;
   }

   /** Function for getting the keyword type from given keyword name from LSDYNA
     * native file. The type is stored in the database
     * \param key_word Name of the keyword from file
     * \param sensor_id ID of the keyword if it is there
     * \return Type for *SENSOR group of keywords
     */
   static SensorType getSensorTypeFromKeyword
	   (
	      const char  *key_word,
	      unsigned int *sensor_id
	   );

   /** Reads the *SENSOR keywords from file
     * \return Returns 0 on failure else number of *SENSOR keywords
     */
   unsigned int readSensors();

   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *SENSOR keyword there is a function to call
     */
   void initSensorTypesAndFunctions();

private:
   FILE          *filePtr;
   /** Manager pointer for holding the imported data for all the keywords */
   SensorManager *sensorManPtr;
   /** Pointer to keywords and their locations in the file */
   DataLoc       *dataLocPtr;
   /** Pointer to access the file data line by line */
   DataLine      *dataLine;
   /** Object to store imported data from LSDYNA data file */
   ImportObject  *impObj;
   /** A map between the keyword type and pointer to function */
   map<unsigned int, ImportFunctionPtr>  typeFuncMap;
};

#endif

