#ifndef _SetNodeGeneral_h_
#define _SetNodeGeneral_h_

#include "manager.h"
#include "dispexport.h"
#include "setidattribute.h"

/** This class is used for importing *SET_NODE_GENERAL keyword
  * from LSDYNA native file */

class SetNodeGeneral : public SetIdAttribute
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   SetNodeGeneral(DataLine *data_line, ImportObject *imp_obj) : SetIdAttribute (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~SetNodeGeneral()
   {
   }

public:
/** Function to import CardLoop details for *SET_NODE_GENERAL
  * keyword from file */
   void readCardLoop()
   {
      const char *fields[] = {"OPTION","E1","E2","E3","E4","E5","E6","E7",};
      unsigned int field_types[] = {DATA_CHAR_ARRAY, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         setGenFind(wordArray, numFields, 1, impObj);
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("CardLoop");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *SET_NODE_GENERAL
  * from LSDYNA native file */
   unsigned int importSetNodeGeneral()
   {
      importSetIdAttribute();
      readCardLoop();
      while(numFields)
      {
         readCardLoop();
      }
      return 0;
   }
};

#endif

