#ifndef _SetPartAdd_h_
#define _SetPartAdd_h_

#include "manager.h"
#include "dispexport.h"
#include "setidcard.h"

/** This class is used for importing *SET_PART_ADD keyword
  * from LSDYNA native file */

class SetPartAdd : public SetIdCard
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   SetPartAdd(DataLine *data_line, ImportObject *imp_obj) : SetIdCard (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~SetPartAdd()
   {
   }

public:
/** Function to import CardLoop details for *SET_PART_ADD
  * keyword from file */
   void readCardLoop()
   {
      const char *fields[] = {"PSID1","PSID2","PSID3","PSID4","PSID5","PSID6","PSID7","PSID8",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, 3, 4, 5, 6, 7, };
      unsigned int man_types[] = {SET, SET, SET, SET, SET, SET, SET, SET, };
      unsigned int kw_types[] = {PARTC, PARTC, PARTC, PARTC, PARTC, PARTC, PARTC, PARTC, };
      unsigned int num_indices = 8;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("CardLoop");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *SET_PART_ADD
  * from LSDYNA native file */
   unsigned int importSetPartAdd()
   {
      importSetIdCard();
      readCardLoop();
      while(numFields)
      {
         readCardLoop();
      }
      return 0;
   }
};

#endif

