#ifndef _SetShell_h_
#define _SetShell_h_

#include "manager.h"
#include "dispexport.h"
#include "setidattribute.h"

/** This class is used for importing *SET_SHELL keyword
  * from LSDYNA native file */

class SetShell : public SetIdAttribute
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   SetShell(DataLine *data_line, ImportObject *imp_obj) : SetIdAttribute (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~SetShell()
   {
   }

public:
/** Function to import CardLoop details for *SET_SHELL
  * keyword from file */
   void readCardLoop()
   {
      const char *fields[] = {"EID1","EID2","EID3","EID4","EID5","EID6","EID7","EID8",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, 3, 4, 5, 6, 7, };
      unsigned int man_types[] = {ELEMENT, ELEMENT, ELEMENT, ELEMENT, ELEMENT, ELEMENT, ELEMENT, ELEMENT, };
      unsigned int kw_types[] = {SHELL, SHELL, SHELL, SHELL, SHELL, SHELL, SHELL, SHELL, };
      unsigned int num_indices = 8;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("CardLoop");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *SET_SHELL
  * from LSDYNA native file */
   unsigned int importSetShell()
   {
      importSetIdAttribute();
      readCardLoop();
      while(numFields)
      {
         readCardLoop();
      }
      return 0;
   }
};

#endif

