#ifndef _SetShellColumn_h_
#define _SetShellColumn_h_

#include "manager.h"
#include "dispexport.h"
#include "setidattribute.h"

/** This class is used for importing *SET_SHELL_COLUMN keyword
  * from LSDYNA native file */

class SetShellColumn : public SetIdAttribute
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   SetShellColumn(DataLine *data_line, ImportObject *imp_obj) : SetIdAttribute (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~SetShellColumn()
   {
   }

public:
/** Function to import CardLoop details for *SET_SHELL_COLUMN
  * keyword from file */
   void readCardLoop()
   {
      const char *fields[] = {"EID","A1","A2","A3","A4",};
      unsigned int field_types[] = {DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, };
      unsigned int man_types[] = {ELEMENT, };
      unsigned int kw_types[] = {SHELL, };
      unsigned int num_indices = 1;
      numFields = 5;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("CardLoop");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *SET_SHELL_COLUMN
  * from LSDYNA native file */
   unsigned int importSetShellColumn()
   {
      importSetIdAttribute();
      readCardLoop();
      while(numFields)
      {
         readCardLoop();
      }
      return 0;
   }
};

#endif

