#include <iostream>
#include <algorithm>
#include "generic.h"
#include "settype.h"
#include "setimport.h"
#include "title.h"
#include <stdlib.h>

using namespace std;

SetImport::SetImport
(
   FILE          *fp,
   DataLoc       *data_loc,
   SetManager    *set_man
)
{
   filePtr = fp;
   setManPtr = set_man;
   dataLocPtr = data_loc;
   dataLine = NULL;

   initNodeTypesAndFunctions();
   initSimpleTypesAndFunctions();
   initPartTypesAndFunctions();
}

SetType SetImport::getSetTypeFromKeyword
	(
	   const char  *key_word,
	   unsigned int *set_id
	)
{
   *set_id = 0;

   if( strstr(key_word, "NOD") )
   {
      if( strstr(key_word, "ADV") )
	 return SET_NODE_ADD_ADVANCED;
      else if( strstr(key_word, "ADD") )
	 return SET_NODE_ADD;
      else if( strstr(key_word, "COL") )
	 return SET_NODE_COLUMN;
      else if( strstr(key_word, "RAL") )
	 return SET_NODE_GENERAL;
      else if( strstr(key_word, "RAT") )
	 return SET_NODE_LIST_GENERATE;
      else if( strstr(key_word, "LIS") )
	 return SET_NODE_LIST;
      else
	 return SET_NODE;
   }
   else if( strstr(key_word, "GRO") )
      return SET_MULTI_MATERIAL_GROUP_LIST;
   else if( strstr(key_word, "PAR") )
   {
      if( strstr(key_word, "ADD") )
	 return SET_PART_ADD;
      else if( strstr(key_word, "COL") )
	 return SET_PART_COLUMN;
      else if( strstr(key_word, "RAT") )
	 return SET_PART_LIST_GENERATE;
      else if( strstr(key_word, "LIS") )
	 return SET_PART_LIST;
      else
	 return SET_PART;
   }
   else if( strstr(key_word, "_SH") )
   {
      if( strstr(key_word, "ADD") )
	 return SET_SHELL_ADD;
      else if( strstr(key_word, "COL") )
	 return SET_SHELL_COLUMN;
      else if( strstr(key_word, "RAL") )
	 return SET_SHELL_GENERAL;
      else if( strstr(key_word, "RAT") )
	 return SET_SHELL_LIST_GENERATE;
      else if( strstr(key_word, "LIS") )
	 return SET_SHELL_LIST;
      else
	 return SET_SHELL;
   }
   else if( strstr(key_word, "_TS") )
   {
      if( strstr(key_word, "RAL") )
	 return SET_TSHELL_GENERAL;
      else if( strstr(key_word, "RAT") )
	 return SET_TSHELL_GENERATE;
      else
	 return SET_TSHELL;
   }
   else if( strstr(key_word, "BEA") )
   {
      if( strstr(key_word, "ADD") )
	 return SET_BEAM_ADD;
      else if( strstr(key_word, "RAL") )
	 return SET_BEAM_GENERAL;
      else if( strstr(key_word, "RAT") )
	 return SET_BEAM_GENERATE;
      else
	 return SET_BEAM;
   }
   else if( strstr(key_word, "DIS") )
   {
      if( strstr(key_word, "ADD") )
	 return SET_DISCRETE_ADD;
      else if( strstr(key_word, "RAL") )
	 return SET_DISCRETE_GENERAL;
      else if( strstr(key_word, "RAT") )
	 return SET_DISCRETE_GENERATE;
      else
	 return SET_DISCRETE;
   }
   else if( strstr(key_word, "SEG") )
   {
      if( strstr(key_word, "2D") )
	 return SET_2D_SEGMENT;
      else if( strstr(key_word, "GEN") )
	 return SET_SEGMENT_GENERAL;
      else
	 return SET_SEGMENT;
   }
   else if( strstr(key_word, "SOL") )
   {
      if( strstr(key_word, "ADD") )
	 return SET_SOLID_ADD;
      else if( strstr(key_word, "RAL") )
	 return SET_SOLID_GENERAL;
      else if( strstr(key_word, "RAT") )
	 return SET_SOLID_GENERATE;
      else
	 return SET_SOLID;
   }

   return SET_NEW_TYPE;
}

unsigned int SetImport::readSets()
{
   time_t       t1, t2;
   char         new_kw[LINE_LEN];
   unsigned int	i = 0, set_id = 0, set_type = 0, num_sets = 0;
   long		loc = 0L;
   VStringIterator   s = dataLocPtr->keywordList.begin(),
		     e = dataLocPtr->keywordList.end(), itr, 
		     pitr = dataLocPtr->keywordList.begin();
   typeFuncIterator  btype_iter = typeFuncMap.begin(),
                     etype_iter = typeFuncMap.end(), type_iter;

   dataLine = new DataLine(filePtr);

   while(true)
   {
      itr = find_if(pitr, e, bind2nd(KeyWordCompare (), "*SET"));

      time(&t1);

      if( itr == e )
	 break;

      pitr = itr+1;
      i = (unsigned int)(itr - s);
      loc = dataLocPtr->slocList[i];

      rewind(filePtr);

      if( fseek(filePtr, loc, SEEK_SET) )
      {
	 cout << "ERROR in locating the Set cards" << endl;
	 break;
      }

      dataLine->clearFlag(KW_READ_END);

      char *str = dataLine->readNextCard(); //get the keyword
      Generic::RemoveLeadingAndTrailingBlanks( str );
cout << "KW = " << str << endl;

      set_type = getSetTypeFromKeyword( str, &set_id );
cout << "Set TYPE = " << set_type << endl;

      if( set_type == SET_NEW_TYPE )
      {
         cout << "Set TYPE NOT SUPPORTED" << endl;
         continue;
      }

      num_sets++;

      strcpy(new_kw, str);
      dataLine->clearFlag(KW_READ_END);
      type_iter = typeFuncMap.find(set_type);

      unsigned int title_flag = 0;
      if( strstr(new_kw, "_TITL") )
      {
         set_type += TITLE_CARD;
         title_flag = 1;
      }

      if( type_iter != etype_iter )
      {
          impObj = new ImportObject(str, set_type);
	  if( title_flag )
	  {
	     Title title(dataLine, impObj);
	     title.readCard();
	  }
          
          (type_iter->second)(dataLine, impObj);
          sprintf(new_kw, "%s_%d", new_kw, num_sets);
          setManPtr->add(new_kw, impObj);
      }
      else
         cout << "Set TYPE NOT FOUND" << endl;
      time(&t2);

cout << "TIME FOR SET=" << num_sets << " = " << difftime(t2, t1) << endl;
   }

   return num_sets;
}

