#ifndef _SetGenerate_h_
#define _SetGenerate_h_

#include "manager.h"
#include "dispexport.h"
#include "setidcard.h"

/** This class is used for importing *SET_BEAM_GENERATE keyword
  * from LSDYNA native file */

class SetGenerate : public SetIdCard
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   SetGenerate(DataLine *data_line, ImportObject *imp_obj) : SetIdCard (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~SetGenerate()
   {
   }

public:
/** Function to import CardLoop details for *SET_BEAM_GENERATE
  * keyword from file */
   void readCardLoop()
   {
      const char *fields[] = {"B1BEG","B1END","B2BEG","B2END","B3BEG","B3END","B4BEG","B4END",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, 3, 4, 5, 6, 7, };
      unsigned int man_types[] = {ELEMENT, ELEMENT, ELEMENT, ELEMENT, ELEMENT, ELEMENT, ELEMENT, ELEMENT, };
      unsigned int kw_types[] = {BEAM, BEAM, BEAM, BEAM, BEAM, BEAM, BEAM, BEAM, };
      unsigned int num_indices = 8;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("CardLoop");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *SET_BEAM_GENERATE
  * from LSDYNA native file */
   unsigned int importSetGenerate()
   {
      importSetIdCard();
      readCardLoop();
      while(numFields)
      {
         readCardLoop();
      }
      return 0;
   }
};

#endif

