#ifndef _SetMultiMaterialGroupList_h_
#define _SetMultiMaterialGroupList_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *SET_MULTI_MATERIAL_GROUP_LIST keyword
  * from LSDYNA native file */

class SetMultiMaterialGroupList : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   SetMultiMaterialGroupList(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~SetMultiMaterialGroupList()
   {
   }

public:
/** Function to import Card1 details for *SET_MULTI_MATERIAL_GROUP_LIST
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"AMSID",};
      unsigned int field_types[] = {DATA_INT, };
      numFields = 1;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_IDS) )
         addIDToFile(wordArray, 0, SET, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import Card2 details for *SET_MULTI_MATERIAL_GROUP_LIST
  * keyword from file */
   void readCard2()
   {
      const char *fields[] = {"AMGID1","AMGID2","AMGID3","AMGID4","AMGID5","AMGID6","AMGID7","AMGID8",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      unsigned int field_indices[] = {0, 1, 2, 3, 4, 5, 6, 7, };
      unsigned int man_types[] = {ALE, ALE, ALE, ALE, ALE, ALE, ALE, ALE, };
      unsigned int kw_types[] = {MMG, MMG, MMG, MMG, MMG, MMG, MMG, MMG, };
      unsigned int num_indices = 8;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card2");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *SET_MULTI_MATERIAL_GROUP_LIST
  * from LSDYNA native file */
   unsigned int importSetMultiMaterialGroupList()
   {
      readCard1();
      readCard2();
      return 0;
   }
};

#endif

