#ifndef _SetSegment_h_
#define _SetSegment_h_

#include "manager.h"
#include "dispexport.h"
#include "setidattribute.h"

/** This class is used for importing *SET_SEGMENT keyword
  * from LSDYNA native file */

class SetSegment : public SetIdAttribute
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   SetSegment(DataLine *data_line, ImportObject *imp_obj) : SetIdAttribute (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~SetSegment()
   {
   }

public:
/** Function to import CardLoop details for *SET_SEGMENT
  * keyword from file */
   void readCardLoop()
   {
      const char *fields[] = {"N1","N2","N3","N4","A1","A2","A3","A4",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      unsigned int field_indices[] = {0, 1, 2, 3, };
      unsigned int man_types[] = {NOD, NOD, NOD, NOD, };
      unsigned int kw_types[] = {9999, 9999, 9999, 9999, };
      unsigned int num_indices = 4;
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_REFERENCES) )
         addIDToRefFile(wordArray, num_indices, field_indices, man_types, kw_types, impObj);

      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("CardLoop");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *SET_SEGMENT
  * from LSDYNA native file */
   unsigned int importSetSegment()
   {
      importSetIdAttribute();
      readCardLoop();
      while(numFields)
      {
         readCardLoop();
      }
      return 0;
   }
};

#endif

