#include <iostream>
#include <algorithm>
#include "generic.h"
#include "termtype.h"
#include "termimport.h"
#include <stdlib.h>

using namespace std;

TermImport::TermImport
(
   FILE          *fp,
   DataLoc       *data_loc,
   TermManager    *term_man
)
{
   filePtr = fp;
   termManPtr = term_man;
   dataLocPtr = data_loc;
   dataLine = NULL;

   initTermTypesAndFunctions();
}

TermType TermImport::getTermTypeFromKeyword
	(
	   const char  *key_word,
	   unsigned int *term_id
	)
{
   *term_id = 0;

   if( strstr(key_word, "BOD") )
      return TERMINATION_BODY;
   else if( strstr(key_word, "CON") )
      return TERMINATION_CONTACT;
   else if( strstr(key_word, "CUR") )
      return TERMINATION_CURVE;
   else if( strstr(key_word, "SET") )
      return TERMINATION_DELETED_SHELLS_SET;
   else if( strstr(key_word, "DEL") )
      return TERMINATION_DELETED_SHELLS;
   else if( strstr(key_word, "NOD") )
      return TERMINATION_NODE;

   return TERM_NEW_TYPE;
}

unsigned int TermImport::readTerms()
{
   char         new_kw[LINE_LEN];
   unsigned int	i = 0, term_id = 0, term_type = 0, num_terms = 0;
   long		loc = 0L;
   VStringIterator   s = dataLocPtr->keywordList.begin(),
		     e = dataLocPtr->keywordList.end(), itr, 
		     pitr = dataLocPtr->keywordList.begin();
   typeFuncIterator  btype_iter = typeFuncMap.begin(),
                     etype_iter = typeFuncMap.end(), type_iter;

   dataLine = new DataLine(filePtr);

   while(true)
   {
      itr = find_if(pitr, e, bind2nd(KeyWordCompare (), "*TERM"));

      if( itr == e )
	 break;

      pitr = itr+1;
      i = (unsigned int)(itr - s);
      loc = dataLocPtr->slocList[i];

      rewind(filePtr);

      if( fseek(filePtr, loc, SEEK_SET) )
      {
	 cout << "ERROR in locating the Termination cards" << endl;
	 break;
      }

      dataLine->clearFlag(KW_READ_END);

      char *str = dataLine->readNextCard(); //get the keyword
      Generic::RemoveLeadingAndTrailingBlanks( str );
cout << "KW = " << str << endl;

      term_type = getTermTypeFromKeyword( str, &term_id );
cout << "Termination TYPE = " << term_type << endl;

      if( term_type == TERM_NEW_TYPE )
      {
         cout << "Termination TYPE NOT SUPPORTED" << endl;
         continue;
      }

      num_terms++;

      strcpy(new_kw, str);

      dataLine->clearFlag(KW_READ_END);
      type_iter = typeFuncMap.find(term_type);
      if( type_iter != etype_iter )
      {
          impObj = new ImportObject(str, term_type);
          (type_iter->second)(dataLine, impObj);
          if( term_id )
          {
             termManPtr->add(new_kw, impObj);
          }
          else
          {
             sprintf(new_kw, "%s_%d", new_kw, num_terms);
             termManPtr->add(new_kw, impObj);
          }
      }
      else
         cout << "Termination TYPE NOT FOUND" << endl;
   }

   return num_terms;
}

