#ifndef _Term_IMPORT_H_
#define _Term_IMPORT_H_

#include <string>
#include <map>
#include "dataloc.h"
#include "termmanager.h"
#include "dataline.h"
#include "card.h"
#include "termtype.h"
#include "typemap.h"

/** Class to import the data from native LSDYNA file for *TERMINATION keywords. 
  * All the data is imported through this class and stored in the manager object.
  */
class TermImport
{
public:
   /** Constructor for creating this object
     * \param fp File pointer to the LSDYNA native file
     * \param data_loc Pointer to the list of keywords and their locations in
     * the file
     * \param term_man Manager pointer to hold the imported data as a list of
     * ImportObject list
     */
   TermImport
   (
      FILE          *fp,
      DataLoc       *data_loc,
      TermManager    *term_man
   );

   ~TermImport()
   {
      filePtr = NULL;
      termManPtr = NULL;
      dataLocPtr = NULL;
      delete dataLine;
   }

   /** Function for getting the keyword type from given keyword name from LSDYNA
     * native file. The type is stored in the database
     * \param key_word Name of the keyword from file
     * \param term_id ID of the keyword if it is there
     * \return Type for *TERMINATION group of keywords
     */
   static TermType getTermTypeFromKeyword
	   (
	      const char  *key_word,
	      unsigned int *term_id
	   );

   /** Reads the *TERMINATION keywords from file
     * \return Returns the number of terms imported else 0
     */
   unsigned int readTerms();

   /** Creates keyword type and pointer to function initializations. This
     * function is a generated code from the XML files for keywords
     * For each type of *TERMINATION keyword there is a function to call
     */
   void initTermTypesAndFunctions();

private:
   FILE          *filePtr;
   /** Manager pointer for holding the imported data for all the keywords */
   TermManager    *termManPtr;
   /** Pointer to keywords and their locations in the file */
   DataLoc       *dataLocPtr;
   /** Pointer to access the file data line by line */
   DataLine      *dataLine;
   /** Object to store imported data from LSDYNA data file */
   ImportObject  *impObj;
   /** A map between the keyword type and pointer to function */
   map<unsigned int, ImportFunctionPtr>  typeFuncMap;
};

#endif

