#ifndef _UserInterfaceControl_h_
#define _UserInterfaceControl_h_

#include "manager.h"
#include "dispexport.h"
#include "importbase.h"

/** This class is used for importing *USER_INTERFACE_CONTROL keyword
  * from LSDYNA native file */

class UserInterfaceControl : public ImportBase
{
public:
/** Class constructor for creating the objects.
  * \param data_line DataLine object pointer to access file data
  * \param imp_obj ImportObject pointer to save data
  */
   UserInterfaceControl(DataLine *data_line, ImportObject *imp_obj) : ImportBase (data_line, imp_obj)
   {
   }

/** Class destructor for releasing the memory.
  */
   virtual ~UserInterfaceControl()
   {
   }

public:
/** Function to import Card1 details for *USER_INTERFACE_CONTROL
  * keyword from file */
   void readCard1()
   {
      const char *fields[] = {"IFID","NOC","NOCI","NHSV",};
      unsigned int field_types[] = {DATA_INT, DATA_INT, DATA_INT, DATA_INT, };
      numFields = 4;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("Card1");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import CardNOCI details for *USER_INTERFACE_CONTROL
  * keyword from file */
   void readCardNOCI()
   {
      const char *fields[] = {"UC1","UC2","UC3","UC4","UC5","UC6","UC7","UC8",};
      unsigned int field_types[] = {DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, DATA_DOUBLE, };
      numFields = 8;
      wordArray = dataLine->readNextCardAsWords(numFields);
      if( !numFields && dataLine->isFlagOn(KW_READ_END) )
         return;
      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )
      {
         cardObj = new Card("CardNOCI");
         cardObj->addFields(numFields, field_types, fields, wordArray);
         impObj->addCard(cardObj);
      }
   }

/** Function to import all the cards of the keyword *USER_INTERFACE_CONTROL
  * from LSDYNA native file */
   unsigned int importUserInterfaceControl()
   {
      readCard1();
      readCardNOCI();
      while(numFields)
      {
         readCardNOCI();
      }
      return 0;
   }
};

#endif

