#include <iostream>
#include <algorithm>
#include "generic.h"
#include "usertype.h"
#include "userimport.h"
#include <stdlib.h>

using namespace std;

UserImport::UserImport
(
   FILE          *fp,
   DataLoc       *data_loc,
   UserManager    *user_man
)
{
   filePtr = fp;
   userManPtr = user_man;
   dataLocPtr = data_loc;
   dataLine = NULL;

   initUserTypesAndFunctions();
}

UserType UserImport::getUserTypeFromKeyword
	(
	   const char  *key_word,
	   unsigned int *user_id
	)
{
   *user_id = 0;

   if( strstr(key_word, "CON") )
      return USER_INTERFACE_CONTROL;
   else if( strstr(key_word, "FRI") )
      return USER_INTERFACE_FRICTION;
   else if( strstr(key_word, "LOA") )
      return USER_LOADING;

   return USER_NEW_TYPE;
}

unsigned int UserImport::readUsers()
{
   char         new_kw[LINE_LEN];
   unsigned int	i = 0, user_id = 0, user_type = 0, num_users = 0;
   long		loc = 0L;
   VStringIterator   s = dataLocPtr->keywordList.begin(),
		     e = dataLocPtr->keywordList.end(), itr, 
		     pitr = dataLocPtr->keywordList.begin();
   typeFuncIterator  btype_iter = typeFuncMap.begin(),
                     etype_iter = typeFuncMap.end(), type_iter;

   dataLine = new DataLine(filePtr);

   while(true)
   {
      itr = find_if(pitr, e, bind2nd(KeyWordCompare (), "*USER"));

      if( itr == e )
	 break;

      pitr = itr+1;
      i = (unsigned int)(itr - s);
      loc = dataLocPtr->slocList[i];

      rewind(filePtr);

      if( fseek(filePtr, loc, SEEK_SET) )
      {
	 cout << "ERROR in locating the User cards" << endl;
	 break;
      }

      dataLine->clearFlag(KW_READ_END);

      char *str = dataLine->readNextCard(); //get the keyword
      Generic::RemoveLeadingAndTrailingBlanks( str );
cout << "KW = " << str << endl;

      user_type = getUserTypeFromKeyword( str, &user_id );
cout << "User TYPE = " << user_type << endl;

      if( user_type == USER_NEW_TYPE )
      {
         cout << "User TYPE NOT SUPPORTED" << endl;
         continue;
      }

      num_users++;

      strcpy(new_kw, str);

      dataLine->clearFlag(KW_READ_END);
      type_iter = typeFuncMap.find(user_type);
      if( type_iter != etype_iter )
      {
          impObj = new ImportObject(str, user_type);
          (type_iter->second)(dataLine, impObj);
          if( user_id )
          {
             userManPtr->add(new_kw, impObj);
          }
          else
          {
             sprintf(new_kw, "%s_%d", new_kw, num_users);
             userManPtr->add(new_kw, impObj);
          }
      }
      else
         cout << "User TYPE NOT FOUND" << endl;
   }

   return num_users;
}

