// iotest.cpp : Defines the entry point for the console application.
//

#include <iostream>
#include <fstream>
#include <time.h>
#include <gentime.h>
#include <algorithm>
#include <map>
#include <libgen.h>
#include "string.h"
#include "dataloc.h"
#include "iotest.h"
#include "manager_inc.h"
#include "import_inc.h"
#include "feputdb.h"
#include "fegetdb.h"
#include "myconnection.h"
#include "iotest.h"

using namespace std;

unsigned int Card::contFlag = 0;
map<string, string> MyConnection::nvMap;

int main(int argc, char* argv[])
{
   if( argc < 2 )
   {
      cout << "Usage: iotest input_filename" << endl;
      return 1;
   }

   vector<string> file_list;
   vector<DataLoc *> dataloc_list;

   Card::setFlag(SAVE_CARDS_FIELDS);
   if( getIncludeFiles(argv[1], file_list, dataloc_list) )
      return 1;

cout << "NUM FILES = " << file_list.size() << endl;

   time_t			t1, t2, t3, t4;
   char       *file_name = NULL;
   FILE       *fp;
   char       copy_file1[256], copy_file2[256];
   strcpy(copy_file1, argv[1]); //these two are required as the dirname and basename
   strcpy(copy_file2, argv[1]); // modifies the paased parameter

   char *exe_dir = dirname(argv[0]);
   char *file_dir = dirname(copy_file1);
   char *file_base = basename(copy_file2);
   string nodes, elms, sets, file_path, copy_file;

cout << "FILE DIR=" << file_dir << endl;
cout << "EXE DIR=" << exe_dir << endl;
cout << "FILE BASE=" << file_base << endl;
   
   GoldenConn *sql_conn = MyConnection::get();

   if( !sql_conn )
      return 1;

   time(&t1);

   for(unsigned int i = 0; i < file_list.size(); i++)
   {
      time(&t2);
      copy_file = file_list[i].data();
      file_name = (char *)copy_file.data();

cout << "file name=" << file_name << endl;

      nodes = exe_dir;
      nodes += "/nodes ";
      nodes += file_name;
      system(nodes.data());

      elms = exe_dir;
      elms += "/elms ";
      elms += file_name;
      system(elms.data());

      sets = exe_dir;
      sets += "/sets ";
      sets += file_name;
      system(sets.data());

      fp = fopen(file_name, "rb");

      if( !fp )
      {
         cout << "UNABLE to open file=" << file_name << endl;
         continue;
      }

      importIncludeCards(fp, dataloc_list[i], file_name);
      importDynaFile(fp, dataloc_list[i], file_name);
      time(&t3);
      cout << "TIME TAKEN FOR FILE READING = "
	   << difftime(t3, t2) << endl;

cout << "FILE NAME = " << file_name << endl;
      file_base = basename(file_name);
cout << "FILE BASE=" << file_base << endl;

      char *dot = strrchr(file_base, '.');
      if( dot )
	 *dot = '\0';

      file_name = file_base;
      
cout << "FILE NAME = " << file_name << endl;
cout << "FILE NAME = " << file_list[i] << endl;

      time(&t2);
      insertDataIntoDB(file_name, sql_conn);
      time(&t3);
cout << "TIME TAKEN TO INSERT INTO DB = " << difftime(t3, t2) << endl;

      time(&t2);
      resetAllManagers();
      time(&t3);
cout << "TIME TAKEN TO DESTROY = " << difftime(t3, t2) << endl;
      fclose(fp);
      delete dataloc_list[i];

      time(&t2);

cout << "TOTAL TIME TAKEN FOR FILE READING = "
	      << difftime(t2, t1) << endl;

/*
      getDataFromDB(file_name, sql_conn);

      string out_file = file_list[i];
      out_file += ".new";

cout << "OUT FILE=" << out_file << endl;

      exportAllEntities(out_file.data());
*/

      resetAllManagers();
   }

   delete sql_conn;

   return 0;
}

int insertDataIntoDB(char *file_name, GoldenConn *gold_conn)
{
   string model_name = file_name;
   FePutDB put_db(model_name.data(), gold_conn);

/*
   unsigned long start_millis = GenTime::getCurrentMillis();
   put_db.insertNodesIntoDB();
   unsigned long end_millis = GenTime::getCurrentMillis();
cout << "TIME TAKEN TO INSERT NODES INTO DB "
	<< (end_millis - start_millis) << endl;
   start_millis = GenTime::getCurrentMillis();

   put_db.insertElementsIntoDB();
   ElementManager::reset();
   end_millis = GenTime::getCurrentMillis();
cout << "TIME TAKEN TO INSERT ELEMENTS INTO DB "
	<< (end_millis - start_millis) << endl;
*/
   put_db.insertAirbagsIntoDB();
   put_db.insertAlesIntoDB();
   put_db.insertBoundarysIntoDB();
   put_db.insertComponentsIntoDB();
   put_db.insertConstraintsIntoDB();
   put_db.insertContactsIntoDB();
   put_db.insertControlsIntoDB();
   put_db.insertDampingsIntoDB();
   put_db.insertDatabasesIntoDB();
   put_db.insertDefinesIntoDB();
   put_db.insertDeformsIntoDB();
   put_db.insertEfsIntoDB();
   put_db.insertEossIntoDB();
   put_db.insertHgsIntoDB();
   put_db.insertIncludesIntoDB();
   put_db.insertInitialsIntoDB();
   put_db.insertIntegrationsIntoDB();
   put_db.insertInterfacesIntoDB();
   put_db.insertLoadsIntoDB();
   put_db.insertMatsIntoDB();
   put_db.insertParametersIntoDB();
   put_db.insertPartCsIntoDB();
   put_db.insertPerturbsIntoDB();
   put_db.insertRailsIntoDB();
   put_db.insertRigidwallsIntoDB();
   put_db.insertSectionsIntoDB();
/*
   put_db.insertSetsIntoDB();
   SetManager::reset();
*/
   put_db.insertSensorsIntoDB();
   put_db.insertTermsIntoDB();
   put_db.insertUsersIntoDB();
/**/

   return 0;
}

int getDataFromDB(char *file_name, GoldenConn *gold_conn)
{
   string model_name = file_name;
   unsigned long start_millis = GenTime::getCurrentMillis();
   FeGetDB get_db(model_name.data(), gold_conn);

   cout << "NUM INCS = " << get_db.getIncludesFromDB() << endl;

   cout << "NUM NODES = " << get_db.getNodesFromDB() << endl;
   unsigned long end_millis = GenTime::getCurrentMillis();
cout << "TIME TAKEN TO GET NODES FROM DB "
	<< (end_millis - start_millis) << endl;
   cout << "NUM DEFS = " << get_db.getDefinesFromDB() << endl;
   cout << "NUM SECS = " << get_db.getSectionsFromDB() << endl;
   cout << "NUM MATS = " << get_db.getMatsFromDB() << endl;
   cout << "NUM EOSS = " << get_db.getEossFromDB() << endl;
   cout << "NUM HGS = " << get_db.getHgsFromDB() << endl;
   cout << "NUM PARTS = " << get_db.getPartCsFromDB() << endl;
   cout << "NUM SETS = " << get_db.getSetsFromDB() << endl;

   start_millis = GenTime::getCurrentMillis();
   cout << "NUM ELMS = " << get_db.getElementsFromDB() << endl;
   end_millis = GenTime::getCurrentMillis();
cout << "TIME TAKEN TO GET ELEMENTS FROM DB "
	<< (end_millis - start_millis) << endl << endl;

   cout << "NUM ABS = " << get_db.getAirbagsFromDB() << endl;
   cout << "NUM ALES = " << get_db.getAlesFromDB() << endl;
   cout << "NUM BDRYS = " << get_db.getBoundarysFromDB() << endl;
   cout << "NUM CMPS = " << get_db.getComponentsFromDB() << endl;
   cout << "NUM CONSTS = " << get_db.getConstsFromDB() << endl;
   cout << "NUM CONTACTS = " << get_db.getContactsFromDB() << endl;
   cout << "NUM CTRLS = " << get_db.getControlsFromDB() << endl;
   cout << "NUM DAMPS = " << get_db.getDampingsFromDB() << endl;
   cout << "NUM DBS = " << get_db.getDatabasesFromDB() << endl;
   cout << "NUM DEFRMS = " << get_db.getDeformsFromDB() << endl;
   cout << "NUM EFS = " << get_db.getEfsFromDB() << endl;
   cout << "NUM INITS = " << get_db.getInitialsFromDB() << endl;
   cout << "NUM INTGS = " << get_db.getIntegrationsFromDB() << endl;
   cout << "NUM INTERS = " << get_db.getInterfacesFromDB() << endl;
   cout << "NUM LOADS = " << get_db.getLoadsFromDB() << endl;
   cout << "NUM PARAMS = " << get_db.getParametersFromDB() << endl;
   cout << "NUM PERTS = " << get_db.getPerturbsFromDB() << endl;

   cout << "NUM RAILS = " << get_db.getRailsFromDB() << endl;
   cout << "NUM RWS = " << get_db.getRigidwallsFromDB() << endl;
   cout << "NUM SENS = " << get_db.getSensorsFromDB() << endl;
   cout << "NUM TERMS = " << get_db.getTermsFromDB() << endl;
   cout << "NUM USERS = " << get_db.getUsersFromDB() << endl;
   
   return 0;
}

int importDynaFile(FILE *fp, DataLoc *data_loc, char *file_name)
{
   //importNodCards(fp, data_loc, file_name);
   importDefineCards(fp, data_loc, file_name);
   importSectionCards(fp, data_loc, file_name);
   importMatCards(fp, data_loc, file_name);
   importEosCards(fp, data_loc, file_name);
   importHgCards(fp, data_loc, file_name);
   importPartCCards(fp, data_loc, file_name);

   //importElementCards(fp, data_loc, file_name);
   //importSetCards(fp, data_loc, file_name);

   importAirbags(fp, data_loc, file_name);
   importALECards(fp, data_loc, file_name);
   importBdryCards(fp, data_loc, file_name);
   importCompCards(fp, data_loc, file_name);
   importConstCards(fp, data_loc, file_name);
   importContactCards(fp, data_loc, file_name);
   importControlCards(fp, data_loc, file_name);
   importDampingCards(fp, data_loc, file_name);
   importDatabaseCards(fp, data_loc, file_name);
   importDeformCards(fp, data_loc, file_name);
   importEFCards(fp, data_loc, file_name);
   importInitialCards(fp, data_loc, file_name);
   importIntegrationCards(fp, data_loc, file_name);
   importInterfaceCards(fp, data_loc, file_name);
   importLoadCards(fp, data_loc, file_name);
   importParameterCards(fp, data_loc, file_name);
   importPerturbCards(fp, data_loc, file_name);
   importRailCards(fp, data_loc, file_name);
   importRigidwallCards(fp, data_loc, file_name);
   importSensorCards(fp, data_loc, file_name);
   importTermCards(fp, data_loc, file_name);
   importUserCards(fp, data_loc, file_name);

   return 0;
}

int importAirbags(FILE *fp, DataLoc *data_loc, char *file_name)
{
   time_t  t1, t2;

   time(&t1);
   unsigned long ab_millis = GenTime::getCurrentMillis();
   AirbagManager *abman = AirbagManager::create();
   ABImport      abimport(fp, data_loc, abman);

   unsigned int num_airbags = abimport.readAirbags();

   cout << "NUM AIRBAGS = " << num_airbags << endl;
   cout << "NUM AIRBAGS FROM MANAGER = " << abman->length() << endl;

   time(&t2);
   unsigned long end_millis = GenTime::getCurrentMillis();
   cout << "TIME TAKEN TO READ AIRBAGS = "
	<< difftime(t2, t1) << endl;
   cout << "TIME TAKEN FOR AIRBAGS in millis = "
	<< (end_millis - ab_millis) << endl;

/*
   string str;
   abman->tostring(str);
   //cout << str << endl;

   if( num_airbags )
   {
      string out_file = file_name;
      out_file += ".ab";

      ofstream out_stream(out_file.data());

      if( out_stream.is_open() )
      {
	 out_stream << str;
	 out_stream.close();
      }
   }

   //delete abman;

*/
   return num_airbags;
}

int importALECards(FILE *fp, DataLoc *data_loc, char *file_name)
{
   time_t  t1, t2;

   time(&t1);
   unsigned long ab_millis = GenTime::getCurrentMillis();
   ALEManager    *aleman = ALEManager::create();
   ALEImport      aleimport(fp, data_loc, aleman);

   unsigned int num_ales = aleimport.readALEs();

   cout << "NUM ALEs = " << num_ales << endl;
   cout << "NUM ALEs FROM MANAGER = " << aleman->length() << endl;

   time(&t2);
   unsigned long end_millis = GenTime::getCurrentMillis();
   cout << "TIME TAKEN TO READ ALEs = "
	<< difftime(t2, t1) << endl;
   cout << "TIME TAKEN FOR ALEs in millis = "
	<< (end_millis - ab_millis) << endl;

/*
   string str;
   aleman->tostring(str);
   //cout << str << endl;

   if( num_ales )
   {
      string out_file = file_name;
      out_file += ".ale";

      ofstream out_stream(out_file.data());

      if( out_stream.is_open() )
      {
	 out_stream << str;
	 out_stream.close();
      }
   }

   //delete aleman;

*/
   return num_ales;
}

int importBdryCards(FILE *fp, DataLoc *data_loc, char *file_name)
{
   time_t  t1, t2;

   time(&t1);
   unsigned long  ab_millis = GenTime::getCurrentMillis();
   BdryManager    *bdryman = BdryManager::create();
   BdryImport      bdryimport(fp, data_loc, bdryman);

   unsigned int num_bdrys = bdryimport.readBdrys();

   cout << "NUM Bdrys = " << num_bdrys << endl;
   cout << "NUM Bdrys FROM MANAGER = " << bdryman->length() << endl;

   time(&t2);
   unsigned long end_millis = GenTime::getCurrentMillis();
   cout << "TIME TAKEN TO READ Bdrys = "
	<< difftime(t2, t1) << endl;
   cout << "TIME TAKEN FOR Bdrys in millis = "
	<< (end_millis - ab_millis) << endl;

/*
   string str;
   bdryman->tostring(str);
   //cout << str << endl;

   if( num_bdrys )
   {
      string out_file = file_name;
      out_file += ".bdry";

      ofstream out_stream(out_file.data());

      if( out_stream.is_open() )
      {
	 out_stream << str;
	 out_stream.close();
      }
   }

   //delete bdryman;

*/
   return num_bdrys;
}

int importCompCards(FILE *fp, DataLoc *data_loc, char *file_name)
{
   time_t  t1, t2;

   time(&t1);
   unsigned long  ab_millis = GenTime::getCurrentMillis();
   CompManager    *compman = CompManager::create();
   CompImport      compimport(fp, data_loc, compman);

   unsigned int num_comps = compimport.readComps();

   cout << "NUM Comps = " << num_comps << endl;
   cout << "NUM Comps FROM MANAGER = " << compman->length() << endl;

   time(&t2);
   unsigned long end_millis = GenTime::getCurrentMillis();
   cout << "TIME TAKEN TO READ Comps = "
	<< difftime(t2, t1) << endl;
   cout << "TIME TAKEN FOR Comps in millis = "
	<< (end_millis - ab_millis) << endl;

/*
   string str;
   compman->tostring(str);
   //cout << str << endl;

   if( num_comps )
   {
      string out_file = file_name;
      out_file += ".comp";

      ofstream out_stream(out_file.data());

      if( out_stream.is_open() )
      {
	 out_stream << str;
	 out_stream.close();
      }
   }

   //delete compman;

*/
   return num_comps;
}

int importConstCards(FILE *fp, DataLoc *data_loc, char *file_name)
{
   time_t  t1, t2;

   time(&t1);
   unsigned long  ab_millis = GenTime::getCurrentMillis();
   ConstManager    *constman = ConstManager::create();
   ConstImport      constimport(fp, data_loc, constman);

   unsigned int num_consts = constimport.readConsts();

   cout << "NUM Consts = " << num_consts << endl;
   cout << "NUM Consts FROM MANAGER = " << constman->length() << endl;

   time(&t2);
   unsigned long end_millis = GenTime::getCurrentMillis();
   cout << "TIME TAKEN TO READ Consts = "
	<< difftime(t2, t1) << endl;
   cout << "TIME TAKEN FOR Consts in millis = "
	<< (end_millis - ab_millis) << endl;

/*
   string str;
   constman->tostring(str);
   //cout << str << endl;

   if( num_consts )
   {
      string out_file = file_name;
      out_file += ".const";

      ofstream out_stream(out_file.data());

      if( out_stream.is_open() )
      {
	 out_stream << str;
	 out_stream.close();
      }
   }

   //delete constman;

*/
   return num_consts;
}

int importContactCards(FILE *fp, DataLoc *data_loc, char *file_name)
{
   time_t  t1, t2;

   time(&t1);
   unsigned long  ab_millis = GenTime::getCurrentMillis();
   ContactManager    *contactman = ContactManager::create();
   ContactImport      contactimport(fp, data_loc, contactman);

   unsigned int num_contacts = contactimport.readContacts();

   cout << "NUM Contacts = " << num_contacts << endl;
   cout << "NUM Contacts FROM MANAGER = " << contactman->length() << endl;

   time(&t2);
   unsigned long end_millis = GenTime::getCurrentMillis();
   cout << "TIME TAKEN TO READ Contacts = "
	<< difftime(t2, t1) << endl;
   cout << "TIME TAKEN FOR Contacts in millis = "
	<< (end_millis - ab_millis) << endl;

/*
   string str;
   contactman->tostring(str);
   //cout << str << endl;

   if( num_contacts )
   {
      string out_file = file_name;
      out_file += ".contact";

      ofstream out_stream(out_file.data());

      if( out_stream.is_open() )
      {
	 out_stream << str;
	 out_stream.close();
      }
   }

   //delete contactman;

*/
   return num_contacts;
}

int importControlCards(FILE *fp, DataLoc *data_loc, char *file_name)
{
   time_t  t1, t2;

   time(&t1);
   unsigned long  ab_millis = GenTime::getCurrentMillis();
   ControlManager    *controlman = ControlManager::create();
   ControlImport      controlimport(fp, data_loc, controlman);

   unsigned int num_controls = controlimport.readControls();

   cout << "NUM Controls = " << num_controls << endl;
   cout << "NUM Controls FROM MANAGER = " << controlman->length() << endl;

   time(&t2);
   unsigned long end_millis = GenTime::getCurrentMillis();
   cout << "TIME TAKEN TO READ Controls = "
	<< difftime(t2, t1) << endl;
   cout << "TIME TAKEN FOR Controls in millis = "
	<< (end_millis - ab_millis) << endl;

/*
   string str;
   controlman->tostring(str);
   //cout << str << endl;

   if( num_controls )
   {
      string out_file = file_name;
      out_file += ".control";

      ofstream out_stream(out_file.data());

      if( out_stream.is_open() )
      {
	 out_stream << str;
	 out_stream.close();
      }
   }

   //delete controlman;

*/
   return num_controls;
}

int importDampingCards(FILE *fp, DataLoc *data_loc, char *file_name)
{
   time_t  t1, t2;

   time(&t1);
   unsigned long  ab_millis = GenTime::getCurrentMillis();
   DampingManager    *dampingman = DampingManager::create();
   DampingImport      dampingimport(fp, data_loc, dampingman);

   unsigned int num_dampings = dampingimport.readDampings();

   cout << "NUM Dampings = " << num_dampings << endl;
   cout << "NUM Dampings FROM MANAGER = " << dampingman->length() << endl;

   time(&t2);
   unsigned long end_millis = GenTime::getCurrentMillis();
   cout << "TIME TAKEN TO READ Dampings = "
	<< difftime(t2, t1) << endl;
   cout << "TIME TAKEN FOR Dampings in millis = "
	<< (end_millis - ab_millis) << endl;

/*
   string str;
   dampingman->tostring(str);
   //cout << str << endl;

   if( num_dampings )
   {
      string out_file = file_name;
      out_file += ".damp";

      ofstream out_stream(out_file.data());

      if( out_stream.is_open() )
      {
	 out_stream << str;
	 out_stream.close();
      }
   }

   //delete dampingman;

*/
   return num_dampings;
}

int importDatabaseCards(FILE *fp, DataLoc *data_loc, char *file_name)
{
   time_t  t1, t2;

   time(&t1);
   unsigned long  ab_millis = GenTime::getCurrentMillis();
   DatabaseManager    *databaseman = DatabaseManager::create();
   DatabaseImport      databaseimport(fp, data_loc, databaseman);

   unsigned int num_databases = databaseimport.readDatabases();

   cout << "NUM Databases = " << num_databases << endl;
   cout << "NUM Databases FROM MANAGER = " << databaseman->length() << endl;

   time(&t2);
   unsigned long end_millis = GenTime::getCurrentMillis();
   cout << "TIME TAKEN TO READ Databases = "
	<< difftime(t2, t1) << endl;
   cout << "TIME TAKEN FOR Databases in millis = "
	<< (end_millis - ab_millis) << endl;

/*
   string str;
   databaseman->tostring(str);
   //cout << str << endl;

   if( num_databases )
   {
      string out_file = file_name;
      out_file += ".datab";

      ofstream out_stream(out_file.data());

      if( out_stream.is_open() )
      {
	 out_stream << str;
	 out_stream.close();
      }
   }
*/

   //delete databaseman;

   return num_databases;
}

int importDefineCards(FILE *fp, DataLoc *data_loc, char *file_name)
{
   time_t  t1, t2;

   time(&t1);
   unsigned long     ab_millis = GenTime::getCurrentMillis();
   DefineManager     *defineman = DefineManager::create();
   DefineImport      defineimport(fp, data_loc, defineman);

   unsigned int num_defines = defineimport.readDefines();

   cout << "NUM Defines = " << num_defines << endl;
   cout << "NUM Defines FROM MANAGER = " << defineman->length() << endl;

   time(&t2);
   unsigned long end_millis = GenTime::getCurrentMillis();
   cout << "TIME TAKEN TO READ Defines = "
	<< difftime(t2, t1) << endl;
   cout << "TIME TAKEN FOR Defines in millis = "
	<< (end_millis - ab_millis) << endl;
/*
   string str;
   defineman->tostring(str);
   //cout << str << endl;

   if( num_defines )
   {
      string out_file = file_name;
      out_file += ".define";

      ofstream out_stream(out_file.data());

      if( out_stream.is_open() )
      {
	 out_stream << str;
	 out_stream.close();
      }
   }

   //delete defineman;
*/
   return num_defines;
}

int importDeformCards(FILE *fp, DataLoc *data_loc, char *file_name)
{
   time_t  t1, t2;

   time(&t1);
   unsigned long     ab_millis = GenTime::getCurrentMillis();
   DeformManager     *deformman = DeformManager::create();
   DeformImport      deformimport(fp, data_loc, deformman);

   unsigned int num_deforms = deformimport.readDeforms();

   cout << "NUM Deforms = " << num_deforms << endl;
   cout << "NUM Deforms FROM MANAGER = " << deformman->length() << endl;

   time(&t2);
   unsigned long end_millis = GenTime::getCurrentMillis();
   cout << "TIME TAKEN TO READ Deforms = "
	<< difftime(t2, t1) << endl;
   cout << "TIME TAKEN FOR Deforms in millis = "
	<< (end_millis - ab_millis) << endl;
/*
   string str;
   deformman->tostring(str);
   //cout << str << endl;

   if( num_deforms )
   {
      string out_file = file_name;
      out_file += ".deform";

      ofstream out_stream(out_file.data());

      if( out_stream.is_open() )
      {
	 out_stream << str;
	 out_stream.close();
      }
   }

   //delete deformman;
*/
   return num_deforms;
}

int importEFCards(FILE *fp, DataLoc *data_loc, char *file_name)
{
   time_t  t1, t2;

   time(&t1);
   unsigned long     ab_millis = GenTime::getCurrentMillis();
   EFManager     *efman = EFManager::create();
   EFImport      efimport(fp, data_loc, efman);

   unsigned int num_efs = efimport.readEFs();

   cout << "NUM EFs = " << num_efs << endl;
   cout << "NUM EFs FROM MANAGER = " << efman->length() << endl;

   time(&t2);
   unsigned long end_millis = GenTime::getCurrentMillis();
   cout << "TIME TAKEN TO READ EFs = "
	<< difftime(t2, t1) << endl;
   cout << "TIME TAKEN FOR EFs in millis = "
	<< (end_millis - ab_millis) << endl;
/*
   string str;
   efman->tostring(str);
   //cout << str << endl;

   if( num_efs )
   {
      string out_file = file_name;
      out_file += ".ef";

      ofstream out_stream(out_file.data());

      if( out_stream.is_open() )
      {
	 out_stream << str;
	 out_stream.close();
      }
   }

   //delete efman;
*/
   return num_efs;
}

int importEosCards(FILE *fp, DataLoc *data_loc, char *file_name)
{
   time_t  t1, t2;

   time(&t1);
   unsigned long     ab_millis = GenTime::getCurrentMillis();
   EosManager     *eosman = EosManager::create();
   EosImport      eosimport(fp, data_loc, eosman);

   unsigned int num_eoss = eosimport.readEoss();

   cout << "NUM Eoss = " << num_eoss << endl;
   cout << "NUM Eoss FROM MANAGER = " << eosman->length() << endl;

   time(&t2);
   unsigned long end_millis = GenTime::getCurrentMillis();
   cout << "TIME TAKEN TO READ Eoss = "
	<< difftime(t2, t1) << endl;
   cout << "TIME TAKEN FOR Eoss in millis = "
	<< (end_millis - ab_millis) << endl;
/*
   string str;
   eosman->tostring(str);
   //cout << str << endl;

   if( num_eoss )
   {
      string out_file = file_name;
      out_file += ".eos";

      ofstream out_stream(out_file.data());

      if( out_stream.is_open() )
      {
	 out_stream << str;
	 out_stream.close();
      }
   }

   //delete eosman;
*/
   return num_eoss;
}

int importHgCards(FILE *fp, DataLoc *data_loc, char *file_name)
{
   time_t  t1, t2;

   time(&t1);
   unsigned long     ab_millis = GenTime::getCurrentMillis();
   HgManager     *hgman = HgManager::create();
   HgImport      hgimport(fp, data_loc, hgman);

   unsigned int num_hgs = hgimport.readHgs();

   cout << "NUM Hgs = " << num_hgs << endl;
   cout << "NUM Hgs FROM MANAGER = " << hgman->length() << endl;

   time(&t2);
   unsigned long end_millis = GenTime::getCurrentMillis();
   cout << "TIME TAKEN TO READ Hgs = "
	<< difftime(t2, t1) << endl;
   cout << "TIME TAKEN FOR Hgs in millis = "
	<< (end_millis - ab_millis) << endl;
/*
   string str;
   hgman->tostring(str);
   //cout << str << endl;

   if( num_hgs )
   {
      string out_file = file_name;
      out_file += ".hg";

      ofstream out_stream(out_file.data());

      if( out_stream.is_open() )
      {
	 out_stream << str;
	 out_stream.close();
      }
   }

   //delete hgman;
*/
   return num_hgs;
}

int importIncludeCards(FILE *fp, DataLoc *data_loc, char *file_name)
{
   time_t  t1, t2;

   time(&t1);
   unsigned long     ab_millis = GenTime::getCurrentMillis();
   IncludeManager     *includeman = IncludeManager::create();
   IncludeImport      includeimport(fp, data_loc, includeman);

   unsigned int num_includes = includeimport.readIncludes();

   cout << "NUM Includes = " << num_includes << endl;
   cout << "NUM Includes FROM MANAGER = " << includeman->length() << endl;

   time(&t2);
   unsigned long end_millis = GenTime::getCurrentMillis();
   cout << "TIME TAKEN TO READ Includes = "
	<< difftime(t2, t1) << endl;
   cout << "TIME TAKEN FOR Includes in millis = "
	<< (end_millis - ab_millis) << endl;
/*
   string str;
   includeman->tostring(str);
   //cout << str << endl;

   if( num_includes )
   {
      string out_file = file_name;
      out_file += ".inc";

      ofstream out_stream(out_file.data());

      if( out_stream.is_open() )
      {
	 out_stream << str;
	 out_stream.close();
      }
   }

   //delete includeman;
*/
   return num_includes;
}

int importInitialCards(FILE *fp, DataLoc *data_loc, char *file_name)
{
   time_t  t1, t2;

   time(&t1);
   unsigned long     ab_millis = GenTime::getCurrentMillis();
   InitialManager     *initialman = InitialManager::create();
   InitialImport      initialimport(fp, data_loc, initialman);

   unsigned int num_initials = initialimport.readInitials();

   cout << "NUM Initials = " << num_initials << endl;
   cout << "NUM Initials FROM MANAGER = " << initialman->length() << endl;

   time(&t2);
   unsigned long end_millis = GenTime::getCurrentMillis();
   cout << "TIME TAKEN TO READ Initials = "
	<< difftime(t2, t1) << endl;
   cout << "TIME TAKEN FOR Initials in millis = "
	<< (end_millis - ab_millis) << endl;
/*
   string str;
   initialman->tostring(str);
   //cout << str << endl;

   if( num_initials )
   {
      string out_file = file_name;
      out_file += ".init";

      ofstream out_stream(out_file.data());

      if( out_stream.is_open() )
      {
	 out_stream << str;
	 out_stream.close();
      }
   }

   //delete initialman;
*/
   return num_initials;
}

int importIntegrationCards(FILE *fp, DataLoc *data_loc, char *file_name)
{
   time_t  t1, t2;

   time(&t1);
   unsigned long      ab_millis = GenTime::getCurrentMillis();
   IntegrationManager *integrationman = 
			  IntegrationManager::create();
   IntegrationImport  integrationimport(fp, data_loc, integrationman);

   unsigned int num_integrations = integrationimport.readIntegrations();

   cout << "NUM Integrations = " << num_integrations << endl;
   cout << "NUM Integrations FROM MANAGER = " << integrationman->length() << endl;

   time(&t2);
   unsigned long end_millis = GenTime::getCurrentMillis();
   cout << "TIME TAKEN TO READ Integrations = "
	<< difftime(t2, t1) << endl;
   cout << "TIME TAKEN FOR Integrations in millis = "
	<< (end_millis - ab_millis) << endl;
/*
   string str;
   integrationman->tostring(str);
   //cout << str << endl;

   if( num_integrations )
   {
      string out_file = file_name;
      out_file += ".integ";

      ofstream out_stream(out_file.data());

      if( out_stream.is_open() )
      {
	 out_stream << str;
	 out_stream.close();
      }
   }

   //delete integrationman;
*/
   return num_integrations;
}

int importInterfaceCards(FILE *fp, DataLoc *data_loc, char *file_name)
{
   time_t  t1, t2;

   time(&t1);
   unsigned long    ab_millis = GenTime::getCurrentMillis();
   InterfaceManager *interfaceman = InterfaceManager::create();
   InterfaceImport  interfaceimport(fp, data_loc, interfaceman);

   unsigned int num_interfaces = interfaceimport.readInterfaces();

   cout << "NUM Interfaces = " << num_interfaces << endl;
   cout << "NUM Interfaces FROM MANAGER = " << interfaceman->length() << endl;

   time(&t2);
   unsigned long end_millis = GenTime::getCurrentMillis();
   cout << "TIME TAKEN TO READ Interfaces = "
	<< difftime(t2, t1) << endl;
   cout << "TIME TAKEN FOR Interfaces in millis = "
	<< (end_millis - ab_millis) << endl;
/*
   string str;
   interfaceman->tostring(str);
   //cout << str << endl;

   if( num_interfaces )
   {
      string out_file = file_name;
      out_file += ".interf";

      ofstream out_stream(out_file.data());

      if( out_stream.is_open() )
      {
	 out_stream << str;
	 out_stream.close();
      }
   }

   //delete interfaceman;
*/
   return num_interfaces;
}

int importLoadCards(FILE *fp, DataLoc *data_loc, char *file_name)
{
   time_t  t1, t2;

   time(&t1);
   unsigned long    ab_millis = GenTime::getCurrentMillis();
   LoadManager *loadman = LoadManager::create();
   LoadImport  loadimport(fp, data_loc, loadman);

   unsigned int num_loads = loadimport.readLoads();

   cout << "NUM Loads = " << num_loads << endl;
   cout << "NUM Loads FROM MANAGER = " << loadman->length() << endl;

   time(&t2);
   unsigned long end_millis = GenTime::getCurrentMillis();
   cout << "TIME TAKEN TO READ Loads = "
	<< difftime(t2, t1) << endl;
   cout << "TIME TAKEN FOR Loads in millis = "
	<< (end_millis - ab_millis) << endl;
/*
   string str;
   loadman->tostring(str);
   //cout << str << endl;

   if( num_loads )
   {
      string out_file = file_name;
      out_file += ".load";

      ofstream out_stream(out_file.data());

      if( out_stream.is_open() )
      {
	 out_stream << str;
	 out_stream.close();
      }
   }

   //delete loadman;
*/
   return num_loads;
}

int importNodCards(FILE *fp, DataLoc *data_loc, char *file_name)
{
   time_t  t1, t2;

   time(&t1);
   unsigned long    ab_millis = GenTime::getCurrentMillis();
   NodManager *nodman = NodManager::create();
   NodImport  nodimport(fp, data_loc, nodman);

   unsigned int num_nods = nodimport.readNods();

   cout << "NUM Nods = " << num_nods << endl;
   cout << "NUM Nods FROM MANAGER = " << nodman->length() << endl;

   time(&t2);
   unsigned long end_millis = GenTime::getCurrentMillis();
   cout << "TIME TAKEN TO READ Nods = "
	<< difftime(t2, t1) << endl;
   cout << "TIME TAKEN FOR Nods in millis = "
	<< (end_millis - ab_millis) << endl;
/*
   string str;
   nodman->tostring(str);
   //cout << str << endl;

   if( num_nods )
   {
      string out_file = file_name;
      out_file += ".nod";

      ofstream out_stream(out_file.data());

      if( out_stream.is_open() )
      {
	 out_stream << str;
	 out_stream.close();
      }
   }

   //delete nodman;
*/
   return num_nods;
}

int importParameterCards(FILE *fp, DataLoc *data_loc, char *file_name)
{
   time_t  t1, t2;

   time(&t1);
   unsigned long    ab_millis = GenTime::getCurrentMillis();
   ParameterManager *parameterman = ParameterManager::create();
   ParameterImport  parameterimport(fp, data_loc, parameterman);

   unsigned int num_parameters = parameterimport.readParameters();

   cout << "NUM Parameters = " << num_parameters << endl;
   cout << "NUM Parameters FROM MANAGER = " << parameterman->length() << endl;

   time(&t2);
   unsigned long end_millis = GenTime::getCurrentMillis();
   cout << "TIME TAKEN TO READ Parameters = "
	<< difftime(t2, t1) << endl;
   cout << "TIME TAKEN FOR Parameters in millis = "
	<< (end_millis - ab_millis) << endl;
/*
   string str;
   parameterman->tostring(str);
   //cout << str << endl;

   if( num_parameters )
   {
      string out_file = file_name;
      out_file += ".param";

      ofstream out_stream(out_file.data());

      if( out_stream.is_open() )
      {
	 out_stream << str;
	 out_stream.close();
      }
   }

   //delete parameterman;
*/
   return num_parameters;
}

int importPartCCards(FILE *fp, DataLoc *data_loc, char *file_name)
{
   time_t  t1, t2;

   time(&t1);
   unsigned long    ab_millis = GenTime::getCurrentMillis();
   PartCManager     *partcman = PartCManager::create();
   PartCImport      partcimport(fp, data_loc, partcman);

   unsigned int num_partcs = partcimport.readPartCs();

   cout << "NUM PartCs = " << num_partcs << endl;
   cout << "NUM PartCs FROM MANAGER = " << partcman->length() << endl;

   time(&t2);
   unsigned long end_millis = GenTime::getCurrentMillis();
   cout << "TIME TAKEN TO READ PartCs = "
	<< difftime(t2, t1) << endl;
   cout << "TIME TAKEN FOR PartCs in millis = "
	<< (end_millis - ab_millis) << endl;
/*
   string str;
   partcman->tostring(str);
   //cout << str << endl;

   if( num_partcs )
   {
      string out_file = file_name;
      out_file += ".part";

      ofstream out_stream(out_file.data());

      if( out_stream.is_open() )
      {
	 out_stream << str;
	 out_stream.close();
      }
   }

   //delete partcman;
*/
   return num_partcs;
}

int importPerturbCards(FILE *fp, DataLoc *data_loc, char *file_name)
{
   time_t  t1, t2;

   time(&t1);
   unsigned long    ab_millis = GenTime::getCurrentMillis();
   PerturbManager     *perturbman = PerturbManager::create();
   PerturbImport      perturbimport(fp, data_loc, perturbman);

   unsigned int num_perturbs = perturbimport.readPerturbs();

   cout << "NUM Perturbs = " << num_perturbs << endl;
   cout << "NUM Perturbs FROM MANAGER = " << perturbman->length() << endl;

   time(&t2);
   unsigned long end_millis = GenTime::getCurrentMillis();
   cout << "TIME TAKEN TO READ Perturbs = "
	<< difftime(t2, t1) << endl;
   cout << "TIME TAKEN FOR Perturbs in millis = "
	<< (end_millis - ab_millis) << endl;
/*
   string str;
   perturbman->tostring(str);
   //cout << str << endl;

   if( num_perturbs )
   {
      string out_file = file_name;
      out_file += ".pert";

      ofstream out_stream(out_file.data());

      if( out_stream.is_open() )
      {
	 out_stream << str;
	 out_stream.close();
      }
   }

   //delete perturbman;
*/
   return num_perturbs;
}

int importRailCards(FILE *fp, DataLoc *data_loc, char *file_name)
{
   time_t  t1, t2;

   time(&t1);
   unsigned long    ab_millis = GenTime::getCurrentMillis();
   RailManager     *railman = RailManager::create();
   RailImport      railimport(fp, data_loc, railman);

   unsigned int num_rails = railimport.readRails();

   cout << "NUM Rails = " << num_rails << endl;
   cout << "NUM Rails FROM MANAGER = " << railman->length() << endl;

   time(&t2);
   unsigned long end_millis = GenTime::getCurrentMillis();
   cout << "TIME TAKEN TO READ Rails = "
	<< difftime(t2, t1) << endl;
   cout << "TIME TAKEN FOR Rails in millis = "
	<< (end_millis - ab_millis) << endl;
/*
   string str;
   railman->tostring(str);
   //cout << str << endl;

   if( num_rails )
   {
      string out_file = file_name;
      out_file += ".rail";

      ofstream out_stream(out_file.data());

      if( out_stream.is_open() )
      {
	 out_stream << str;
	 out_stream.close();
      }
   }

   //delete railman;
*/
   return num_rails;
}

int importRigidwallCards(FILE *fp, DataLoc *data_loc, char *file_name)
{
   time_t  t1, t2;

   time(&t1);
   unsigned long    ab_millis = GenTime::getCurrentMillis();
   RigidwallManager *rigidwallman = RigidwallManager::create();
   RigidwallImport  rigidwallimport(fp, data_loc, rigidwallman);

   unsigned int num_rigidwalls = rigidwallimport.readRigidwalls();

   cout << "NUM Rigidwalls = " << num_rigidwalls << endl;
   cout << "NUM Rigidwalls FROM MANAGER = " << rigidwallman->length() << endl;

   time(&t2);
   unsigned long end_millis = GenTime::getCurrentMillis();
   cout << "TIME TAKEN TO READ Rigidwalls = "
	<< difftime(t2, t1) << endl;
   cout << "TIME TAKEN FOR Rigidwalls in millis = "
	<< (end_millis - ab_millis) << endl;
/*
   string str;
   rigidwallman->tostring(str);
   //cout << str << endl;

   if( num_rigidwalls )
   {
      string out_file = file_name;
      out_file += ".rw";

      ofstream out_stream(out_file.data());

      if( out_stream.is_open() )
      {
	 out_stream << str;
	 out_stream.close();
      }
   }

   //delete rigidwallman;
*/
   return num_rigidwalls;
}

int importSectionCards(FILE *fp, DataLoc *data_loc, char *file_name)
{
   time_t  t1, t2;

   time(&t1);
   unsigned long    ab_millis = GenTime::getCurrentMillis();
   SectionManager *sectionman = SectionManager::create();
   SectionImport  sectionimport(fp, data_loc, sectionman);

   unsigned int num_sections = sectionimport.readSections();

   cout << "NUM Sections = " << num_sections << endl;
   cout << "NUM Sections FROM MANAGER = " << sectionman->length() << endl;

   time(&t2);
   unsigned long end_millis = GenTime::getCurrentMillis();
   cout << "TIME TAKEN TO READ Sections = "
	<< difftime(t2, t1) << endl;
   cout << "TIME TAKEN FOR Sections in millis = "
	<< (end_millis - ab_millis) << endl;
/*
   string str;
   sectionman->tostring(str);
   //cout << str << endl;

   if( num_sections )
   {
      string out_file = file_name;
      out_file += ".sec";

      ofstream out_stream(out_file.data());

      if( out_stream.is_open() )
      {
	 out_stream << str;
	 out_stream.close();
      }
   }

   //delete sectionman;
*/
   return num_sections;
}

int importSensorCards(FILE *fp, DataLoc *data_loc, char *file_name)
{
   time_t  t1, t2;

   time(&t1);
   unsigned long    ab_millis = GenTime::getCurrentMillis();
   SensorManager *sensorman = SensorManager::create();
   SensorImport  sensorimport(fp, data_loc, sensorman);

   unsigned int num_sensors = sensorimport.readSensors();

   cout << "NUM Sensors = " << num_sensors << endl;
   cout << "NUM Sensors FROM MANAGER = " << sensorman->length() << endl;

   time(&t2);
   unsigned long end_millis = GenTime::getCurrentMillis();
   cout << "TIME TAKEN TO READ Sensors = "
	<< difftime(t2, t1) << endl;
   cout << "TIME TAKEN FOR Sensors in millis = "
	<< (end_millis - ab_millis) << endl;
/*
   string str;
   sensorman->tostring(str);
   //cout << str << endl;

   if( num_sensors )
   {
      string out_file = file_name;
      out_file += ".sensor";

      ofstream out_stream(out_file.data());

      if( out_stream.is_open() )
      {
	 out_stream << str;
	 out_stream.close();
      }
   }

   //delete sensorman;
*/
   return num_sensors;
}

int importSetCards(FILE *fp, DataLoc *data_loc, char *file_name)
{
   time_t  t1, t2;

   time(&t1);
   unsigned long    ab_millis = GenTime::getCurrentMillis();
   SetManager *setman = SetManager::create();
   SetImport  setimport(fp, data_loc, setman);

   unsigned int num_sets = setimport.readSets();

   cout << "NUM Sets = " << num_sets << endl;
   cout << "NUM Sets FROM MANAGER = " << setman->length() << endl;

   time(&t2);
   unsigned long end_millis = GenTime::getCurrentMillis();
   cout << "TIME TAKEN TO READ Sets = "
	<< difftime(t2, t1) << endl;
   cout << "TIME TAKEN FOR Sets in millis = "
	<< (end_millis - ab_millis) << endl;
/*
   string str;
   setman->tostring(str);
   //cout << str << endl;

   if( num_sets )
   {
      string out_file = file_name;
      out_file += ".set";

      ofstream out_stream(out_file.data());

      if( out_stream.is_open() )
      {
	 out_stream << str;
	 out_stream.close();
      }
   }

   //delete setman;
*/
   return num_sets;
}

int importTermCards(FILE *fp, DataLoc *data_loc, char *file_name)
{
   time_t  t1, t2;

   time(&t1);
   unsigned long    ab_millis = GenTime::getCurrentMillis();
   TermManager *termman = TermManager::create();
   TermImport  termimport(fp, data_loc, termman);

   unsigned int num_terms = termimport.readTerms();

   cout << "NUM Terms = " << num_terms << endl;
   cout << "NUM Terms FROM MANAGER = " << termman->length() << endl;

   time(&t2);
   unsigned long end_millis = GenTime::getCurrentMillis();
   cout << "TIME TAKEN TO READ Terms = "
	<< difftime(t2, t1) << endl;
   cout << "TIME TAKEN FOR Terms in millis = "
	<< (end_millis - ab_millis) << endl;
/*
   string str;
   termman->tostring(str);
   //cout << str << endl;

   if( num_terms )
   {
      string out_file = file_name;
      out_file += ".term";

      ofstream out_stream(out_file.data());

      if( out_stream.is_open() )
      {
	 out_stream << str;
	 out_stream.close();
      }
   }

   //delete termman;
*/
   return num_terms;
}

int importUserCards(FILE *fp, DataLoc *data_loc, char *file_name)
{
   time_t  t1, t2;

   time(&t1);
   unsigned long    ab_millis = GenTime::getCurrentMillis();
   UserManager *userman = UserManager::create();
   UserImport  userimport(fp, data_loc, userman);

   unsigned int num_users = userimport.readUsers();

   cout << "NUM Users = " << num_users << endl;
   cout << "NUM Users FROM MANAGER = " << userman->length() << endl;

   time(&t2);
   unsigned long end_millis = GenTime::getCurrentMillis();
   cout << "TIME TAKEN TO READ Users = "
	<< difftime(t2, t1) << endl;
   cout << "TIME TAKEN FOR Users in millis = "
	<< (end_millis - ab_millis) << endl;

/*
   string str;
   userman->tostring(str);
   //cout << str << endl;

   if( num_users )
   {
      string out_file = file_name;
      out_file += ".user";

      ofstream out_stream(out_file.data());

      if( out_stream.is_open() )
      {
	 out_stream << str;
	 out_stream.close();
      }
   }

   //delete userman;
*/
   return num_users;
}

int importElementCards(FILE *fp, DataLoc *data_loc, char *file_name)
{
   time_t  t1, t2;

   time(&t1);
   unsigned long    ab_millis = GenTime::getCurrentMillis();
   ElementManager *elementman = ElementManager::create();
   ElementImport  elementimport(fp, data_loc, elementman);

   unsigned int num_elements = elementimport.readElements();

   cout << "NUM Elements = " << num_elements << endl;
   cout << "NUM Elements FROM MANAGER = " << elementman->length() << endl;

   time(&t2);
   unsigned long end_millis = GenTime::getCurrentMillis();
   cout << "TIME TAKEN TO READ Elements = "
	<< difftime(t2, t1) << endl;
   cout << "TIME TAKEN FOR Elements in millis = "
	<< (end_millis - ab_millis) << endl;

/*
   string str;
   elementman->tostring(str);
   //cout << str << endl;

   if( num_elements )
   {
      string out_file = file_name;
      out_file += ".elm";

      ofstream out_stream(out_file.data());

      if( out_stream.is_open() )
      {
	 out_stream << str;
	 out_stream.close();
      }
   }

   //delete elementman;
*/

   return num_elements;
}

int importMatCards(FILE *fp, DataLoc *data_loc, char *file_name)
{
   time_t  t1, t2;

   time(&t1);
   unsigned long ab_millis = GenTime::getCurrentMillis();
   MatManager *matman = MatManager::create();
   MatImport matimport(fp, data_loc, matman);

   unsigned int num_mats = matimport.readMats();

   cout << "NUM Mats = " << num_mats << endl;
   cout << "NUM Mats FROM MANAGER = " << matman->length() << endl;

   time(&t2);
   unsigned long end_millis = GenTime::getCurrentMillis();
   cout << "TIME TAKEN TO READ Mats = "
	<< difftime(t2, t1) << endl;
   cout << "TIME TAKEN FOR Mats in millis = "
	<< (end_millis - ab_millis) << endl;

/*
   string str;
   matman->tostring(str);
   //cout << str << endl;

   if( num_mats )
   {
      string out_file = file_name;
      out_file += ".mat";

      ofstream out_stream(out_file.data());

      if( out_stream.is_open() )
      {
	 out_stream << str;
	 out_stream.close();
      }
   }

   //delete matman;
*/

   return num_mats;
}

/*
int exportAllEntities(DataLoc *data_loc, const char *out_file)
{
   VStringIterator   s = data_loc->keywordList.begin(),
		     e = data_loc->keywordList.end(), itr, 
		     pitr = data_loc->keywordList.begin();
   const char        *str;
   Manager           *man_ptr = NULL;
   string            kw_str;

   //out_stream.rdbuf()->pubsetbuf(0, 4096);

   for( itr = s; itr < e; itr++ )
   {
      str = (*itr).data();
      switch(str[1])
      {
         case 'A':
            switch(str[2])
            {
               case 'I':
                  man_ptr = AirbagManager::create();
                  break;
               case 'L':
                  man_ptr = ALEManager::create();
                  break;
            }
            break;
         case 'B':
            man_ptr = BdryManager::create();
            break;
         case 'C':
            switch(str[5])
            {
               case 'O':
                  man_ptr = CompManager::create();
                  break;
               case 'T':
                  man_ptr = ConstManager::create();
                  break;
               case 'A':
                  man_ptr = ContactManager::create();
                  break;
               case 'R':
                  man_ptr = ControlManager::create();
                  break;
            }
            break;
         case 'D':
            switch(str[5])
            {
               case 'I':
                  man_ptr = DampingManager::create();
                  break;
               case 'B':
                  man_ptr = DatabaseManager::create();
                  break;
               case 'N':
                  man_ptr = DefineManager::create();
                  break;
               case 'R':
                  man_ptr = DeformManager::create();
                  break;
            }
            break;
         case 'E':
            switch(str[2])
            {
               case 'F':
                  man_ptr = EFManager::create();
                  break;
               case 'L':
		  man_ptr = ElementManager::create();
		  break;
               case 'O':
                  man_ptr = EosManager::create();
                  break;
            }
            break;
         case 'H':
            man_ptr = HgManager::create();
            break;
         case 'I':
            switch(str[5])
            {
               case 'U':
                  man_ptr = IncludeManager::create();
                  break;
               case 'I':
                  man_ptr = InitialManager::create();
                  break;
               case 'G':
                  man_ptr = IntegrationManager::create();
                  break;
               case 'R':
                  man_ptr = InterfaceManager::create();
                  break;
            }
            break;
         case 'L':
            man_ptr = LoadManager::create();
            break;
         case 'M':
            man_ptr = MatManager::create();
            break;
         case 'N':
	    man_ptr = NodManager::create();
            break;
         case 'P':
            switch(str[4])
            {
               case 'A':
                  man_ptr = ParameterManager::create();
                  break;
               case 'T':
                  man_ptr = PartCManager::create();
                  break;
            }
            switch(str[2])
            {
               case 'P':
                  man_ptr = PerturbManager::create();
                  break;
            }
            break;
         case 'R':
            switch(str[2])
            {
               case 'A':
                  man_ptr = RailManager::create();
                  break;
               case 'I':
                  man_ptr = RigidwallManager::create();
                  break;
            }
            break;
         case 'S':
            switch(str[3])
            {
               case 'C':
                  man_ptr = SectionManager::create();
                  break;
               case 'N':
                  man_ptr = SensorManager::create();
                  break;
               case 'T':
                  man_ptr = SetManager::create();
                  break;
            }
            break;
         case 'T':
            if( str[2] == 'E' )
               man_ptr = TermManager::create();
            break;
         case 'U':
            man_ptr = UserManager::create();
            break;
      }

      if( man_ptr )
      {
         man_ptr->next_string(kw_str);
      }
      else
      {
cout << "KEY WORD UNSUPPORTED = " << str << endl;
      }
      man_ptr = NULL;
   }

   ofstream out_stream(out_file);
   if( !out_stream.is_open() )
   {
      cout << "UNABLE TO OPEN export file <" << out_file << ">" << endl;
      return 1;
   }
   out_stream << kw_str;
   out_stream.close();
   kw_str.clear();

   return 0;
}
*/

int exportAllEntities(const char *out_file)
{
   const char        *str;
   Manager           *man_ptr = NULL;
   string            kw_str;

   //out_stream.rdbuf()->pubsetbuf(0, 4096);
   ofstream out_stream(out_file);
   if( !out_stream.is_open() )
   {
      cout << "UNABLE TO OPEN export file <" << out_file << ">" << endl;
      return 1;
   }

   for(int i = 0; i < 32; i++) 
   {
      switch(i)
      {
	 case 0:
	    man_ptr = ControlManager::create();
	    break;
	 case 1:
	    man_ptr = DatabaseManager::create();
	    break;
         case 2:
            man_ptr = MatManager::create();
            break;
	 case 3:
	    man_ptr = SectionManager::create();
	    break;
	 case 4:
	    man_ptr = EosManager::create();
	    break;
         case 5:
            man_ptr = HgManager::create();
            break;
	 case 6:
	    man_ptr = PartCManager::create();
	    break;
         case 7:
	    man_ptr = NodManager::create();
            break;
	 case 8:
	    man_ptr = ElementManager::create();
	    break;
	 case 9:
	    man_ptr = DefineManager::create();
	    break;
	 case 10:
	    man_ptr = ConstManager::create();
	    break;
	 case 11:
	    man_ptr = ContactManager::create();
	    break;
	 case 12:
	    man_ptr = AirbagManager::create();
	    break;
	 case 13:
	    man_ptr = ALEManager::create();
	    break;
         case 14:
            man_ptr = BdryManager::create();
            break;
	 case 15:
	    man_ptr = CompManager::create();
	    break;
	 case 16:
	    man_ptr = DampingManager::create();
	    break;
	 case 17:
	    man_ptr = DeformManager::create();
	    break;
	 case 18:
	    man_ptr = EFManager::create();
	    break;
	 case 19:
	    man_ptr = IncludeManager::create();
	    break;
	 case 20:
	    man_ptr = InitialManager::create();
	    break;
	 case 21:
	    man_ptr = IntegrationManager::create();
	    break;
	 case 22:
	    man_ptr = InterfaceManager::create();
	    break;
         case 23:
            man_ptr = LoadManager::create();
            break;
	 case 24:
	    man_ptr = ParameterManager::create();
	    break;
	 case 25:
	    man_ptr = PerturbManager::create();
	    break;
	 case 26:
	    man_ptr = RailManager::create();
	    break;
	 case 27:
	    man_ptr = RigidwallManager::create();
	    break;
	 case 28:
	    man_ptr = SensorManager::create();
	    break;
	 case 29:
	    man_ptr = SetManager::create();
	    break;
         case 30:
            man_ptr = UserManager::create();
            break;
         case 31:
            man_ptr = TermManager::create();
            break;
      }

      man_ptr->tostring(kw_str);
      out_stream << kw_str;
      kw_str.clear();
   }

   out_stream.close();

   return 0;
}

void resetAllManagers()
{
   AirbagManager::reset();
//cout << "AFTER 1" << endl;
   ALEManager::reset();
//cout << "AFTER 2" << endl;
   BdryManager::reset();
//cout << "AFTER 3" << endl;
   CompManager::reset();
//cout << "AFTER 4" << endl;
   ConstManager::reset();
//cout << "AFTER 5" << endl;
   ContactManager::reset();
//cout << "AFTER 6" << endl;
   ControlManager::reset();
//cout << "AFTER 7" << endl;
   DampingManager::reset();
//cout << "AFTER 8" << endl;
   DatabaseManager::reset();
//cout << "AFTER 9" << endl;
   DefineManager::reset();
//cout << "AFTER 10" << endl;
   DeformManager::reset();
//cout << "AFTER 11" << endl;
   EFManager::reset();
//cout << "AFTER 12" << endl;
   EosManager::reset();
//cout << "AFTER 13" << endl;
   HgManager::reset();
//cout << "AFTER 14" << endl;
   IncludeManager::reset();
//cout << "AFTER 15" << endl;
   InitialManager::reset();
//cout << "AFTER 16" << endl;
   IntegrationManager::reset();
//cout << "AFTER 17" << endl;
   InterfaceManager::reset();
//cout << "AFTER 18" << endl;
   LoadManager::reset();
//cout << "AFTER 19" << endl;
   NodManager::reset();
//cout << "AFTER 20" << endl;
   ParameterManager::reset();
//cout << "AFTER 21" << endl;
   PartCManager::reset();
   PerturbManager::reset();
//cout << "AFTER 22" << endl;
   RailManager::reset();
//cout << "AFTER 23" << endl;
   RigidwallManager::reset();
//cout << "AFTER 24" << endl;
   SectionManager::reset();
//cout << "AFTER 25" << endl;
   SensorManager::reset();
//cout << "AFTER 26" << endl;
   SetManager::reset();
//cout << "AFTER 27" << endl;
   TermManager::reset();
//cout << "AFTER 28" << endl;
   UserManager::reset();
//cout << "AFTER 29" << endl;
   ElementManager::reset();
//cout << "AFTER 30" << endl;
   MatManager::reset();
//cout << "AFTER 31" << endl;
}

int getIncludeFiles(const char *main_file, vector<string> & file_list,
			vector<DataLoc *> & dataloc_list)
{
   char *str;
   unsigned int   i;
   long		  loc = 0L;
   vector<string> localfile_list;
   time_t t1, t2;

   time(&t1);
   FILE *main_fp = fopen(main_file, "rb");

   if( !main_fp )
   {
      cout << "UNABLE TO OPEN FILE <" << main_file << ">" << endl;
      return 1;
   }

   DataLoc *data_loc = new DataLoc(main_fp);
   time(&t2);

cout << "time taken to find keywords=" << difftime(t2, t1) << endl;

   VStringIterator b = data_loc->keywordList.begin(), 
                   e = data_loc->keywordList.end(), itr, pitr = b;

   DataLine data_line(main_fp);
   string local_file = main_file, inc_file;
   char *file_dir = dirname((char *)local_file.data());

   while(true)
   {
      //itr = find(pitr, e, "*INCLUDE");
      itr = find_if(pitr, e, bind2nd(KeyWordCompare (), "*INC"));

      if( itr == e )
	 break;

      pitr = itr+1;
      i = (unsigned int)(itr - b);
      loc = data_loc->slocList[i];

      rewind(main_fp);

      if( fseek(main_fp, loc, SEEK_SET) )
      {
	 cout << "ERROR in locating the INCLUDE cards" << endl;
	 break;
      }

      str = data_line.readNextCard(); //get the keyword
      Generic::RemoveLeadingAndTrailingBlanks( str );

      data_line.clearFlag(KW_READ_END);
      i = 1;
      str = data_line.readNextCard(i); //get the file name
      Generic::RemoveLeadingAndTrailingBlanks( str );

      if( str[0] != '\0' )
      {
         inc_file = file_dir;
         inc_file += "/";
         inc_file += str;
         localfile_list.push_back(inc_file);
cout << "INCLUDE FILE NAME = " << inc_file << endl;
      }
   }

   file_list.push_back(main_file);
   dataloc_list.push_back(data_loc);
   fclose(main_fp);

   for(i = 0; i < localfile_list.size(); i++)
      getIncludeFiles(localfile_list[i].data(), file_list, dataloc_list);

   return 0;
}

