#ifndef _Bdry_MANAGER_H_
#define _Bdry_MANAGER_H_

#include "manager.h"
#include "bdrytype.h"

using namespace std;

/** Manager class to hold all the keywords starting with *BOUNDARY. All the 
  * keywords are stored as list of ImportObject. This class holds its own 
  * instance here.
  */
class BdryManager : public Manager
{
private:
   /** Default constructor for creating this object */
   BdryManager() : Manager()
   {
   }

public:
   /** Static function to create this object. Object is created if already not 
     * there. only one instance exists at any point of time.
     */
   static BdryManager *create()
   {
      if( !managerPtr )
         managerPtr = new BdryManager();

      return managerPtr;
   }

   /** Destroys the stored instance of this object and initializes to NULL. */
   static void reset()
   {
      if( managerPtr )
         delete managerPtr;

      managerPtr = NULL;
   }

   ~BdryManager()
   {
      managerPtr = NULL;
   }

   /** Adds a given object ID to this object with a given type
     * \param id ID of object to add
     * \param mtype Type of object to store id
     */
   void addID(char *id, unsigned int mtype)
   {
#ifdef DEBUG
cout << "ADDING BOUNDARY ID = " << id << endl;
#endif
      switch(mtype)
      {
         case BOUNDARY_PRESCRIBED_MOTION_NODE:
         case BOUNDARY_PRESCRIBED_MOTION_NODE_ID:
         case BOUNDARY_PRESCRIBED_MOTION_RIGID:
         case BOUNDARY_PRESCRIBED_MOTION_RIGID_ID:
         case BOUNDARY_PRESCRIBED_MOTION_RIGID_LOCAL:
         case BOUNDARY_PRESCRIBED_MOTION_RIGID_LOCAL_ID:
         case BOUNDARY_PRESCRIBED_MOTION_SET:
         case BOUNDARY_PRESCRIBED_MOTION_SET_ID:
            motionIDTypeMap.insert(StringUIntPair(id, mtype));
            break;
         case BOUNDARY_SPC_NODE:
         case BOUNDARY_SPC_NODE_ID:
         case BOUNDARY_SPC_SET:
         case BOUNDARY_SPC_SET_ID:
            spcIDTypeMap.insert(StringUIntPair(id, mtype));
            break;
         default:
            otherIDTypeMap.insert(StringUIntPair(id, mtype));
      }
   }

   /** Function to find an object ID of given type
     * \param bdry_map Map of IDs and Types
     * \param id ID of object
     * \param mtype Not used
     */
   int findIDBasedOnType
       (
          multimap<string, unsigned int> & bdry_map,
          char *id, 
          unsigned int & 
       )
   {
      unsigned int num_ids = bdry_map.count(id);

#ifdef DEBUG
cout << "FINDID BOUNDARY = " << id << endl;
cout << "NUMIDS BOUNDARY = " << num_ids << endl;
#endif
      switch(num_ids)
      {
         case 1:
            {
	       StringUIntIterator iter = bdry_map.find(id);
	       return (int)iter->second;
            }
         case 0:
	    cout << "BOUNDARY ID <" << id << "> NOT FOUND" << endl;
	    return -1;
      }

      if( num_ids > 1 )
      {
	 StringUIntIterator low = bdry_map.lower_bound(id), iter,
	                up = bdry_map.upper_bound(id), e = bdry_map.end();
         unsigned int cur_type, prev_type, num_clash = 1;
	  
         iter = low;
         prev_type = iter->second;
         iter++;
	 for(;iter != up; iter++)
	 {
            cur_type = iter->second;
	    if( cur_type == prev_type )
               num_clash++;
            prev_type = cur_type;
	 }

         if( num_clash > 1 )
         {
            cout << "ID is same for " << num_clash << " boundarys. ID = <" 
                 << id << ">" << endl;
         }

         return prev_type;
      }

      return -1;
   }

   /** Function to find an object ID of given type
     * \param id ID of object
     * \param mtype Type of object to find
     */
   int findID(char *id, unsigned int mtype)
   {
      switch(mtype)
      {
         case SPC:
            return findIDBasedOnType(spcIDTypeMap, id, mtype);
         case MOTION:
            return findIDBasedOnType(motionIDTypeMap, id, mtype);
         default:
            return findIDBasedOnType(otherIDTypeMap, id, mtype);
      }

      return -1;
   }

private:
   /** An instance of this object */
   static BdryManager *managerPtr;
   /** A map holding the ID and type */
   multimap<string, unsigned int> otherIDTypeMap;
   /** A map holding the MOTION ID and type */
   multimap<string, unsigned int> motionIDTypeMap;
   /** A map holding the SPC ID and type */
   multimap<string, unsigned int> spcIDTypeMap;
};

#endif

