#ifndef _Const_MANAGER_H_
#define _Const_MANAGER_H_

#include "manager.h"
#include "consttype.h"

using namespace std;

/** Manager class to hold all the keywords starting with *CONSTRAINED. All the 
  * keywords are stored as list of ImportObject. This class holds its own 
  * instance here.
  */
class ConstManager : public Manager
{
private:
   /** Default constructor for creating this object */
   ConstManager() : Manager()
   {
   }

public:
   /** Static function to create this object. Object is created if already not 
     * there. only one instance exists at any point of time.
     */
   static ConstManager *create()
   {
      if( !managerPtr )
         managerPtr = new ConstManager();

      return managerPtr;
   }

   /** Destroys the stored instance of this object and initializes to NULL. */
   static void reset()
   {
      if( managerPtr )
         delete managerPtr;

      managerPtr = NULL;
   }

   ~ConstManager()
   {
      managerPtr = NULL;
   }

   /** Adds a given object ID to this object with a given type
     * \param id ID of object to add
     * \param mtype Type of object to store id
     */
   void addID(char *id, unsigned int mtype)
   {
#ifdef DEBUG
cout << "ADDING CONSTRAINT ID = " << id << endl;
#endif
      switch(mtype)
      {
         case CONSTRAINED_JOINT_CYLINDRICAL_ID_FAILURE:
         case CONSTRAINED_JOINT_CYLINDRICAL_ID_FAILURE_LOCAL:
         case CONSTRAINED_JOINT_CYLINDRICAL_ID_LOCAL:
         case CONSTRAINED_JOINT_CYLINDRICAL_ID_LOCAL_FAILURE:
         case CONSTRAINED_JOINT_CYLINDRICAL_FAILURE:
         case CONSTRAINED_JOINT_CYLINDRICAL_FAILURE_ID:
         case CONSTRAINED_JOINT_CYLINDRICAL_FAILURE_ID_LOCAL:
         case CONSTRAINED_JOINT_CYLINDRICAL_FAILURE_LOCAL:
         case CONSTRAINED_JOINT_CYLINDRICAL_FAILURE_LOCAL_ID:
         case CONSTRAINED_JOINT_CYLINDRICAL:
         case CONSTRAINED_JOINT_CYLINDRICAL_ID:
         case CONSTRAINED_JOINT_CYLINDRICAL_LOCAL:
         case CONSTRAINED_JOINT_CYLINDRICAL_LOCAL_ID:
         case CONSTRAINED_JOINT_CYLINDRICAL_LOCAL_ID_FAILURE:
         case CONSTRAINED_JOINT_CYLINDRICAL_LOCAL_FAILURE:
         case CONSTRAINED_JOINT_CYLINDRICAL_LOCAL_FAILURE_ID:
         case CONSTRAINED_JOINT_GEARS:
         case CONSTRAINED_JOINT_GEARS_ID:
         case CONSTRAINED_JOINT_GEARS_ID_FAILURE:
         case CONSTRAINED_JOINT_GEARS_ID_FAILURE_LOCAL:
         case CONSTRAINED_JOINT_GEARS_ID_LOCAL:
         case CONSTRAINED_JOINT_GEARS_ID_LOCAL_FAILURE:
         case CONSTRAINED_JOINT_GEARS_FAILURE:
         case CONSTRAINED_JOINT_GEARS_FAILURE_ID:
         case CONSTRAINED_JOINT_GEARS_FAILURE_ID_LOCAL:
         case CONSTRAINED_JOINT_GEARS_FAILURE_LOCAL:
         case CONSTRAINED_JOINT_GEARS_FAILURE_LOCAL_ID:
         case CONSTRAINED_JOINT_GEARS_LOCAL:
         case CONSTRAINED_JOINT_GEARS_LOCAL_ID:
         case CONSTRAINED_JOINT_GEARS_LOCAL_ID_FAILURE:
         case CONSTRAINED_JOINT_GEARS_LOCAL_FAILURE:
         case CONSTRAINED_JOINT_GEARS_LOCAL_FAILURE_ID:
         case CONSTRAINED_JOINT_LOCKING:
         case CONSTRAINED_JOINT_LOCKING_ID:
         case CONSTRAINED_JOINT_LOCKING_ID_FAILURE:
         case CONSTRAINED_JOINT_LOCKING_ID_FAILURE_LOCAL:
         case CONSTRAINED_JOINT_LOCKING_ID_LOCAL:
         case CONSTRAINED_JOINT_LOCKING_ID_LOCAL_FAILURE:
         case CONSTRAINED_JOINT_LOCKING_FAILURE:
         case CONSTRAINED_JOINT_LOCKING_FAILURE_ID:
         case CONSTRAINED_JOINT_LOCKING_FAILURE_ID_LOCAL:
         case CONSTRAINED_JOINT_LOCKING_FAILURE_LOCAL:
         case CONSTRAINED_JOINT_LOCKING_FAILURE_LOCAL_ID:
         case CONSTRAINED_JOINT_LOCKING_LOCAL:
         case CONSTRAINED_JOINT_LOCKING_LOCAL_ID:
         case CONSTRAINED_JOINT_LOCKING_LOCAL_ID_FAILURE:
         case CONSTRAINED_JOINT_LOCKING_LOCAL_FAILURE:
         case CONSTRAINED_JOINT_LOCKING_LOCAL_FAILURE_ID:
         case CONSTRAINED_JOINT_PLANAR_ID_FAILURE:
         case CONSTRAINED_JOINT_PLANAR_ID_FAILURE_LOCAL:
         case CONSTRAINED_JOINT_PLANAR_ID_LOCAL:
         case CONSTRAINED_JOINT_PLANAR_ID_LOCAL_FAILURE:
         case CONSTRAINED_JOINT_PLANAR:
         case CONSTRAINED_JOINT_PLANAR_ID:
         case CONSTRAINED_JOINT_PLANAR_FAILURE:
         case CONSTRAINED_JOINT_PLANAR_FAILURE_ID:
         case CONSTRAINED_JOINT_PLANAR_FAILURE_ID_LOCAL:
         case CONSTRAINED_JOINT_PLANAR_FAILURE_LOCAL:
         case CONSTRAINED_JOINT_PLANAR_FAILURE_LOCAL_ID:
         case CONSTRAINED_JOINT_PLANAR_LOCAL:
         case CONSTRAINED_JOINT_PLANAR_LOCAL_ID:
         case CONSTRAINED_JOINT_PLANAR_LOCAL_ID_FAILURE:
         case CONSTRAINED_JOINT_PLANAR_LOCAL_FAILURE:
         case CONSTRAINED_JOINT_PLANAR_LOCAL_FAILURE_ID:
         case CONSTRAINED_JOINT_PULLEY:
         case CONSTRAINED_JOINT_PULLEY_ID:
         case CONSTRAINED_JOINT_PULLEY_ID_FAILURE:
         case CONSTRAINED_JOINT_PULLEY_ID_FAILURE_LOCAL:
         case CONSTRAINED_JOINT_PULLEY_ID_LOCAL:
         case CONSTRAINED_JOINT_PULLEY_ID_LOCAL_FAILURE:
         case CONSTRAINED_JOINT_PULLEY_FAILURE:
         case CONSTRAINED_JOINT_PULLEY_FAILURE_ID:
         case CONSTRAINED_JOINT_PULLEY_FAILURE_ID_LOCAL:
         case CONSTRAINED_JOINT_PULLEY_FAILURE_LOCAL:
         case CONSTRAINED_JOINT_PULLEY_FAILURE_LOCAL_ID:
         case CONSTRAINED_JOINT_PULLEY_LOCAL:
         case CONSTRAINED_JOINT_PULLEY_LOCAL_ID:
         case CONSTRAINED_JOINT_PULLEY_LOCAL_ID_FAILURE:
         case CONSTRAINED_JOINT_PULLEY_LOCAL_FAILURE:
         case CONSTRAINED_JOINT_PULLEY_LOCAL_FAILURE_ID:
         case CONSTRAINED_JOINT_RACK_AND_PINION:
         case CONSTRAINED_JOINT_RACK_AND_PINION_ID:
         case CONSTRAINED_JOINT_RACK_AND_PINION_ID_FAILURE:
         case CONSTRAINED_JOINT_RACK_AND_PINION_ID_FAILURE_LOCAL:
         case CONSTRAINED_JOINT_RACK_AND_PINION_ID_LOCAL:
         case CONSTRAINED_JOINT_RACK_AND_PINION_ID_LOCAL_FAILURE:
         case CONSTRAINED_JOINT_RACK_AND_PINION_FAILURE:
         case CONSTRAINED_JOINT_RACK_AND_PINION_FAILURE_ID:
         case CONSTRAINED_JOINT_RACK_AND_PINION_FAILURE_ID_LOCAL:
         case CONSTRAINED_JOINT_RACK_AND_PINION_FAILURE_LOCAL:
         case CONSTRAINED_JOINT_RACK_AND_PINION_FAILURE_LOCAL_ID:
         case CONSTRAINED_JOINT_RACK_AND_PINION_LOCAL:
         case CONSTRAINED_JOINT_RACK_AND_PINION_LOCAL_ID:
         case CONSTRAINED_JOINT_RACK_AND_PINION_LOCAL_ID_FAILURE:
         case CONSTRAINED_JOINT_RACK_AND_PINION_LOCAL_FAILURE:
         case CONSTRAINED_JOINT_RACK_AND_PINION_LOCAL_FAILURE_ID:
         case CONSTRAINED_JOINT_REVOLUTE_ID_FAILURE:
         case CONSTRAINED_JOINT_REVOLUTE_ID_FAILURE_LOCAL:
         case CONSTRAINED_JOINT_REVOLUTE_ID_LOCAL:
         case CONSTRAINED_JOINT_REVOLUTE_ID_LOCAL_FAILURE:
         case CONSTRAINED_JOINT_REVOLUTE_FAILURE:
         case CONSTRAINED_JOINT_REVOLUTE_FAILURE_ID:
         case CONSTRAINED_JOINT_REVOLUTE_FAILURE_ID_LOCAL:
         case CONSTRAINED_JOINT_REVOLUTE_FAILURE_LOCAL:
         case CONSTRAINED_JOINT_REVOLUTE_FAILURE_LOCAL_ID:
         case CONSTRAINED_JOINT_REVOLUTE_LOCAL:
         case CONSTRAINED_JOINT_REVOLUTE_LOCAL_ID:
         case CONSTRAINED_JOINT_REVOLUTE_LOCAL_ID_FAILURE:
         case CONSTRAINED_JOINT_REVOLUTE_LOCAL_FAILURE:
         case CONSTRAINED_JOINT_REVOLUTE_LOCAL_FAILURE_ID:
         case CONSTRAINED_JOINT_REVOLUTE:
         case CONSTRAINED_JOINT_REVOLUTE_ID:
         case CONSTRAINED_JOINT_ROTATIONAL_MOTOR:
         case CONSTRAINED_JOINT_ROTATIONAL_MOTOR_ID:
         case CONSTRAINED_JOINT_ROTATIONAL_MOTOR_ID_FAILURE:
         case CONSTRAINED_JOINT_ROTATIONAL_MOTOR_ID_FAILURE_LOCAL:
         case CONSTRAINED_JOINT_ROTATIONAL_MOTOR_ID_LOCAL:
         case CONSTRAINED_JOINT_ROTATIONAL_MOTOR_ID_LOCAL_FAILURE:
         case CONSTRAINED_JOINT_ROTATIONAL_MOTOR_FAILURE:
         case CONSTRAINED_JOINT_ROTATIONAL_MOTOR_FAILURE_ID:
         case CONSTRAINED_JOINT_ROTATIONAL_MOTOR_FAILURE_ID_LOCAL:
         case CONSTRAINED_JOINT_ROTATIONAL_MOTOR_FAILURE_LOCAL:
         case CONSTRAINED_JOINT_ROTATIONAL_MOTOR_FAILURE_LOCAL_ID:
         case CONSTRAINED_JOINT_ROTATIONAL_MOTOR_LOCAL:
         case CONSTRAINED_JOINT_ROTATIONAL_MOTOR_LOCAL_ID:
         case CONSTRAINED_JOINT_ROTATIONAL_MOTOR_LOCAL_ID_FAILURE:
         case CONSTRAINED_JOINT_ROTATIONAL_MOTOR_LOCAL_FAILURE:
         case CONSTRAINED_JOINT_ROTATIONAL_MOTOR_LOCAL_FAILURE_ID:
         case CONSTRAINED_JOINT_SCREW:
         case CONSTRAINED_JOINT_SCREW_ID:
         case CONSTRAINED_JOINT_SCREW_ID_FAILURE:
         case CONSTRAINED_JOINT_SCREW_ID_FAILURE_LOCAL:
         case CONSTRAINED_JOINT_SCREW_ID_LOCAL:
         case CONSTRAINED_JOINT_SCREW_ID_LOCAL_FAILURE:
         case CONSTRAINED_JOINT_SCREW_FAILURE:
         case CONSTRAINED_JOINT_SCREW_FAILURE_ID:
         case CONSTRAINED_JOINT_SCREW_FAILURE_ID_LOCAL:
         case CONSTRAINED_JOINT_SCREW_FAILURE_LOCAL:
         case CONSTRAINED_JOINT_SCREW_FAILURE_LOCAL_ID:
         case CONSTRAINED_JOINT_SCREW_LOCAL:
         case CONSTRAINED_JOINT_SCREW_LOCAL_ID:
         case CONSTRAINED_JOINT_SCREW_LOCAL_ID_FAILURE:
         case CONSTRAINED_JOINT_SCREW_LOCAL_FAILURE:
         case CONSTRAINED_JOINT_SCREW_LOCAL_FAILURE_ID:
         case CONSTRAINED_JOINT_SPHERICAL_ID_FAILURE:
         case CONSTRAINED_JOINT_SPHERICAL_ID_FAILURE_LOCAL:
         case CONSTRAINED_JOINT_SPHERICAL_ID_LOCAL:
         case CONSTRAINED_JOINT_SPHERICAL_ID_LOCAL_FAILURE:
         case CONSTRAINED_JOINT_SPHERICAL_FAILURE:
         case CONSTRAINED_JOINT_SPHERICAL_FAILURE_ID:
         case CONSTRAINED_JOINT_SPHERICAL_FAILURE_ID_LOCAL:
         case CONSTRAINED_JOINT_SPHERICAL_FAILURE_LOCAL:
         case CONSTRAINED_JOINT_SPHERICAL_FAILURE_LOCAL_ID:
         case CONSTRAINED_JOINT_SPHERICAL:
         case CONSTRAINED_JOINT_SPHERICAL_ID:
         case CONSTRAINED_JOINT_SPHERICAL_LOCAL:
         case CONSTRAINED_JOINT_SPHERICAL_LOCAL_ID:
         case CONSTRAINED_JOINT_SPHERICAL_LOCAL_ID_FAILURE:
         case CONSTRAINED_JOINT_SPHERICAL_LOCAL_FAILURE:
         case CONSTRAINED_JOINT_SPHERICAL_LOCAL_FAILURE_ID:
         case CONSTRAINED_JOINT_TRANSLATIONAL:
         case CONSTRAINED_JOINT_TRANSLATIONAL_ID:
         case CONSTRAINED_JOINT_TRANSLATIONAL_ID_FAILURE:
         case CONSTRAINED_JOINT_TRANSLATIONAL_ID_FAILURE_LOCAL:
         case CONSTRAINED_JOINT_TRANSLATIONAL_ID_LOCAL:
         case CONSTRAINED_JOINT_TRANSLATIONAL_ID_LOCAL_FAILURE:
         case CONSTRAINED_JOINT_TRANSLATIONAL_FAILURE:
         case CONSTRAINED_JOINT_TRANSLATIONAL_FAILURE_ID:
         case CONSTRAINED_JOINT_TRANSLATIONAL_FAILURE_ID_LOCAL:
         case CONSTRAINED_JOINT_TRANSLATIONAL_FAILURE_LOCAL:
         case CONSTRAINED_JOINT_TRANSLATIONAL_FAILURE_LOCAL_ID:
         case CONSTRAINED_JOINT_TRANSLATIONAL_LOCAL:
         case CONSTRAINED_JOINT_TRANSLATIONAL_LOCAL_ID:
         case CONSTRAINED_JOINT_TRANSLATIONAL_LOCAL_ID_FAILURE:
         case CONSTRAINED_JOINT_TRANSLATIONAL_LOCAL_FAILURE:
         case CONSTRAINED_JOINT_TRANSLATIONAL_LOCAL_FAILURE_ID:
         case CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR:
         case CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_ID:
         case CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_ID_FAILURE:
         case CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_ID_FAILURE_LOCAL:
         case CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_ID_LOCAL:
         case CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_ID_LOCAL_FAILURE:
         case CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_FAILURE:
         case CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_FAILURE_ID:
         case CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_FAILURE_ID_LOCAL:
         case CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_FAILURE_LOCAL:
         case CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_FAILURE_LOCAL_ID:
         case CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_LOCAL:
         case CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_LOCAL_ID:
         case CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_LOCAL_ID_FAILURE:
         case CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_LOCAL_FAILURE:
         case CONSTRAINED_JOINT_TRANSLATIONAL_MOTOR_LOCAL_FAILURE_ID:
         case CONSTRAINED_JOINT_UNIVERSAL_ID_FAILURE:
         case CONSTRAINED_JOINT_UNIVERSAL_ID_FAILURE_LOCAL:
         case CONSTRAINED_JOINT_UNIVERSAL_ID_LOCAL:
         case CONSTRAINED_JOINT_UNIVERSAL_ID_LOCAL_FAILURE:
         case CONSTRAINED_JOINT_UNIVERSAL_FAILURE:
         case CONSTRAINED_JOINT_UNIVERSAL_FAILURE_ID:
         case CONSTRAINED_JOINT_UNIVERSAL_FAILURE_ID_LOCAL:
         case CONSTRAINED_JOINT_UNIVERSAL_FAILURE_LOCAL:
         case CONSTRAINED_JOINT_UNIVERSAL_FAILURE_LOCAL_ID:
         case CONSTRAINED_JOINT_UNIVERSAL_LOCAL:
         case CONSTRAINED_JOINT_UNIVERSAL_LOCAL_ID:
         case CONSTRAINED_JOINT_UNIVERSAL_LOCAL_ID_FAILURE:
         case CONSTRAINED_JOINT_UNIVERSAL_LOCAL_FAILURE:
         case CONSTRAINED_JOINT_UNIVERSAL_LOCAL_FAILURE_ID:
         case CONSTRAINED_JOINT_UNIVERSAL:
         case CONSTRAINED_JOINT_UNIVERSAL_ID:
         case CONSTRAINED_JOINT_CONSTANT_VELOCITY:
         case CONSTRAINED_JOINT_CONSTANT_VELOCITY_ID:
         case CONSTRAINED_JOINT_CONSTANT_VELOCITY_ID_FAILURE:
         case CONSTRAINED_JOINT_CONSTANT_VELOCITY_ID_FAILURE_LOCAL:
         case CONSTRAINED_JOINT_CONSTANT_VELOCITY_ID_LOCAL:
         case CONSTRAINED_JOINT_CONSTANT_VELOCITY_ID_LOCAL_FAILURE:
         case CONSTRAINED_JOINT_CONSTANT_VELOCITY_FAILURE:
         case CONSTRAINED_JOINT_CONSTANT_VELOCITY_FAILURE_ID:
         case CONSTRAINED_JOINT_CONSTANT_VELOCITY_FAILURE_ID_LOCAL:
         case CONSTRAINED_JOINT_CONSTANT_VELOCITY_FAILURE_LOCAL:
         case CONSTRAINED_JOINT_CONSTANT_VELOCITY_FAILURE_LOCAL_ID:
         case CONSTRAINED_JOINT_CONSTANT_VELOCITY_LOCAL:
         case CONSTRAINED_JOINT_CONSTANT_VELOCITY_LOCAL_ID:
         case CONSTRAINED_JOINT_CONSTANT_VELOCITY_LOCAL_ID_FAILURE:
         case CONSTRAINED_JOINT_CONSTANT_VELOCITY_LOCAL_FAILURE:
         case CONSTRAINED_JOINT_CONSTANT_VELOCITY_LOCAL_FAILURE_ID:
            {
               jointIDTypeMap.insert(StringUIntPair(id, mtype));
            }
            break;
         case CONSTRAINED_JOINT_STIFFNESS_FLEXION_TORSION:
         case CONSTRAINED_JOINT_STIFFNESS_GENERALIZED:
         case CONSTRAINED_JOINT_STIFFNESS_TRANSLATIONAL:
            {
               stiffIDTypeMap.insert(StringUIntPair(id, mtype));
            }
            break;
         case CONSTRAINED_POINTS:
            {
               pointsIDTypeMap.insert(StringUIntPair(id, mtype));
            }
            break;
         default:
            otherIDTypeMap.insert(StringUIntPair(id, mtype));
      }
   }

   /** Function to find an object ID of given type
     * \param const_map List of IDs and Types
     * \param id ID of object
     * \param mtype Not used
     */
   int findIDBasedOnType
       (
          multimap<string, unsigned int> & const_map,
          char *id, 
          unsigned int & 
       )
   {
      unsigned int num_ids = const_map.count(id);

#ifdef DEBUG
cout << "FINDID CONSTRAINT = " << id << endl;
cout << "NUMIDS CONSTRAINT = " << num_ids << endl;
#endif
      switch(num_ids)
      {
         case 1:
            {
	       StringUIntIterator iter = const_map.find(id);
	       return (int)iter->second;
            }
         case 0:
	    cout << "CONSTRAINT ID <" << id << "> NOT FOUND" << endl;
	    return -1;
      }

      if( num_ids > 1 )
      {
	 StringUIntIterator low = const_map.lower_bound(id), iter,
	                up = const_map.upper_bound(id), e = const_map.end();
         unsigned int cur_type, prev_type, num_clash = 1;
	  
         iter = low;
         prev_type = iter->second;
         iter++;
	 for(;iter != up; iter++)
	 {
            cur_type = iter->second;
	    if( cur_type == prev_type )
               num_clash++;
            prev_type = cur_type;
	 }

         if( num_clash > 1 )
         {
            cout << "ID is same for " << num_clash << " constraints. ID = <" 
                 << id << ">" << endl;
         }

         return 0;
      }

      return -1;
   }

   /** Function to find an object ID of given type
     * \param id ID of object
     * \param mtype Type of object to find
     */
   int findID(char *id, unsigned int mtype)
   {
      switch(mtype)
      {
         case JOINT:
            return findIDBasedOnType(jointIDTypeMap, id, mtype);
         case STIFFNESS:
            return findIDBasedOnType(stiffIDTypeMap, id, mtype);
         case POINTS:
            return findIDBasedOnType(pointsIDTypeMap, id, mtype);
         default:
            return findIDBasedOnType(otherIDTypeMap, id, mtype);
      }

      return -1;
   }

private:
   /** An instance of this object */
   static ConstManager *managerPtr;
   /** A map holding the ID and type */
   multimap<string, unsigned int> otherIDTypeMap;
   /** A map holding the JOINT ID and type */
   multimap<string, unsigned int> jointIDTypeMap;
   /** A map holding the STIFFNESS ID and type */
   multimap<string, unsigned int> stiffIDTypeMap;
   /** A map holding the POINTS ID and type */
   multimap<string, unsigned int> pointsIDTypeMap;
};

#endif

