#ifndef _Database_MANAGER_H_
#define _Database_MANAGER_H_

#include "manager.h"
#include "databasetype.h"

using namespace std;

/** Manager class to hold all the keywords starting with *DATABASE. All the 
  * keywords are stored as list of ImportObject. This class holds its own 
  * instance here.
  */
class DatabaseManager : public Manager
{
private:
   /** Default constructor for creating this object */
   DatabaseManager() : Manager()
   {
   }

public:
   /** Static function to create this object. Object is created if already not 
     * there. only one instance exists at any point of time.
     */
   static DatabaseManager *create()
   {
      if( !managerPtr )
         managerPtr = new DatabaseManager();

      return managerPtr;
   }

   /** Destroys the stored instance of this object and initializes to NULL. */
   static void reset()
   {
      if( managerPtr )
         delete managerPtr;

      managerPtr = NULL;
   }

   ~DatabaseManager()
   {
      managerPtr = NULL;
   }

   /** Adds a given object ID to this object with a given type
     * \param id ID of object to add
     * \param mtype Type of object to store id
     */
   void addID(char *id, unsigned int mtype)
   {
#ifdef DEBUG
cout << "ADDING DATABASE ID = " << id << endl;
#endif
      switch(mtype)
      {
         case DATABASE_CROSS_SECTION_PLANE:
         case DATABASE_CROSS_SECTION_PLANE_ID:
         case DATABASE_CROSS_SECTION_SET:
         case DATABASE_CROSS_SECTION_SET_ID:
            {
               csIDTypeMap.insert(StringUIntPair(id, mtype));
            }
            break;
         default:
            otherIDTypeMap.insert(StringUIntPair(id, mtype));
      }
   }

   /** Function to find an object ID of given type
     * \param db_map List of IDs and Types
     * \param id ID of object
     * \param mtype Not used
     */
   int findIDBasedOnType
       (
          multimap<string, unsigned int> & db_map,
          char *id, 
          unsigned int &
       )
   {
      unsigned int num_ids = db_map.count(id);

#ifdef DEBUG
cout << "FINDID DATABASE = " << id << endl;
cout << "NUMIDS DATABASE = " << num_ids << endl;
#endif
      switch(num_ids)
      {
         case 1:
            {
	       StringUIntIterator iter = db_map.find(id);
	       return (int)iter->second;
            }
         case 0:
	    cout << "DATABASE ID <" << id << "> NOT FOUND" << endl;
	    return -1;
      }

      if( num_ids > 1 )
      {
	 StringUIntIterator low = db_map.lower_bound(id), iter,
	                up = db_map.upper_bound(id), e = db_map.end();
         unsigned int cur_type, prev_type, num_clash = 1;
	  
         iter = low;
         prev_type = iter->second;
         iter++;
	 for(;iter != up; iter++)
	 {
            cur_type = iter->second;
	    if( cur_type == prev_type )
               num_clash++;
            prev_type = cur_type;
	 }

         if( num_clash > 1 )
         {
            cout << "ID is same for " << num_clash << " databases. ID = <" 
                 << id << ">" << endl;
         }

         return prev_type;
      }

      return -1;
   }

   /** Function to find an object ID of given type
     * \param id ID of object
     * \param mtype Type of object to find
     */
   int findID(char *id, unsigned int mtype)
   {
      switch(mtype)
      {
         case CS:
            return findIDBasedOnType(csIDTypeMap, id, mtype);
         default:
            return findIDBasedOnType(otherIDTypeMap, id, mtype);
      }

      return -1;
   }

private:
   /** An instance of this object */
   static DatabaseManager *managerPtr;
   /** A map holding the CROSS_SECTION ID and type */
   multimap<string, unsigned int> csIDTypeMap;
   /** A map holding the ID and type */
   multimap<string, unsigned int> otherIDTypeMap;
};

#endif

