#ifndef _Define_MANAGER_H_
#define _Define_MANAGER_H_

#include "manager.h"
#include "definetype.h"

using namespace std;

/** Manager class to hold all the keywords starting with *DEFINE. All the keywords
  * are stored as list of ImportObject. This class holds its own instance here.
  */
class DefineManager : public Manager
{
private:
   /** Default constructor for creating this object */
   DefineManager() : Manager()
   {
   }

public:
   /** Static function to create this object. Object is created if already not 
     * there. only one instance exists at any point of time.
     */
   static DefineManager *create()
   {
      if( !managerPtr )
         managerPtr = new DefineManager();

      return managerPtr;
   }

   /** Destroys the stored instance of this object and initializes to NULL. */
   static void reset()
   {
      if( managerPtr )
         delete managerPtr;

      managerPtr = NULL;
   }

   ~DefineManager()
   {
      managerPtr = NULL;
   }

   /** Adds a given object ID to this object with a given type
     * \param id ID of object to add
     * \param kw_type Type of object to store id
     */
   void addID(char *id, unsigned int kw_type)
   {
cout << "ADD DEFINE ID = " << id << endl;
      switch(kw_type)
      {
	 case DEFINE_CURVE_3858:
	 case DEFINE_CURVE_5434a:
	 case DEFINE_CURVE_COMPENSATION:
	 case DEFINE_CURVE_DRAWBEAD:
	 case DEFINE_CURVE_ENTITY:
	 case DEFINE_CURVE_FEEDBACK:
	 case DEFINE_CURVE:
	 case DEFINE_CURVE_TRIM:
	 case DEFINE_CURVE_TRIM_3D:
         case DEFINE_CURVE_SMOOTH:
         case DEFINE_CURVE_FUNCTION:
            {
               curveIDTypeMap.insert(StringUIntPair(id, kw_type));
               break;
            }
	 case DEFINE_BOX:
	 case DEFINE_BOX_ADAPTIVE:
	 case DEFINE_BOX_COARSEN:
	 case DEFINE_BOX_DRAWBEAD:
	 case DEFINE_BOX_SPH:
            {
               boxIDTypeMap.insert(StringUIntPair(id, kw_type));
               break;
            }
         case DEFINE_ALEBAG_BAG:
            {
               bagIDTypeMap.insert(StringUIntPair(id, kw_type));
               break;
            }
         case DEFINE_ALEBAG_HOLE:
            {
               holeIDTypeMap.insert(StringUIntPair(id, kw_type));
               break;
            }
         case DEFINE_ALEBAG_INFLATOR:
            {
               inflatorIDTypeMap.insert(StringUIntPair(id, kw_type));
               break;
            }
         case DEFINE_VECTOR:
            {
               vectorIDTypeMap.insert(StringUIntPair(id, kw_type));
               break;
            }
         case DEFINE_COORDINATE_NODES:
         case DEFINE_COORDINATE_SYSTEM:
         case DEFINE_COORDINATE_VECTOR:
            {
               coordIDTypeMap.insert(StringUIntPair(id, kw_type));
               break;
            }
	 case DEFINE_SD_ORIENTATION:
	 case DEFINE_TRANSFORMATION:
            {
               transIDTypeMap.insert(StringUIntPair(id, kw_type));
               break;
            }
         case DEFINE_TABLE:
            {
               tableIDTypeMap.insert(StringUIntPair(id, kw_type));
               break;
            }
         case DEFINE_CONTACT_VOLUME:
            {
               cvIDTypeMap.insert(StringUIntPair(id, kw_type));
               break;
            }
      }
   }

   /** Function to find an object ID of given type
     * \param def_map List of IDs and Types
     * \param id ID of object
     * \param mtype Not used
     * \param err_type Error message if any
     */
   int findIDBasedOnType
       (
          multimap<string, unsigned int> & def_map,
          char *id, 
          unsigned int &,
          string & err_type
       )
   {
      unsigned int num_ids = def_map.count(id);

cout << "FINDID DEFINE = " << id << endl;
cout << "NUMIDS DEFINE = " << num_ids << endl;
#ifdef DEBUG
#endif
      switch(num_ids)
      {
         case 1:
            return 0;
         case 0:
	    cout << "DEFINE_" << err_type << " ID <" << id 
                 << "> NOT FOUND" << endl;
	    return 1;
      }

      if( num_ids > 1 )
      {
	 StringUIntIterator low = def_map.lower_bound(id), iter,
	                up = def_map.upper_bound(id), e = def_map.end();
         unsigned int cur_type, prev_type, num_clash = 1;
	  
         iter = low;
         prev_type = iter->second;
         iter++;
	 for(;iter != up; iter++)
	 {
            cur_type = iter->second;
	    if( cur_type == prev_type )
               num_clash++;
            prev_type = cur_type;
	 }

         if( num_clash > 1 )
         {
            cout << "ID is same for " << num_clash << " DEFINE_" << err_type 
                 << " ID = <" << id << ">" << endl;
         }

         return 0;
      }

      return 1;
   }

   /** Function to find an object ID of given type
     * \param id ID of object
     * \param mtype Type of object to find
     */
   int findID(char *id, unsigned int mtype)
   {
      string err_type;

      switch(mtype)
      {
         case CURVE:
            {
	       char *dot_ptr = strchr(id, '.');
	       if( dot_ptr )
	       {
		  char *ptr = id + strlen(id)-1;
		  while(*ptr == '0')
		     ptr--;
                  if( ptr == dot_ptr )
		     *ptr = '\0';
	       }
	       err_type = "CURVE";
               return findIDBasedOnType(curveIDTypeMap, id, mtype, err_type);
            }
         case BOX:
            err_type = "BOX";
            return findIDBasedOnType(boxIDTypeMap, id, mtype, err_type);
         case COORDINATE:
            err_type = "COORDINATE";
            return findIDBasedOnType(coordIDTypeMap, id, mtype, err_type);
         case ALEBAG:
            err_type = "ALEBAG_BAG";
            return findIDBasedOnType(bagIDTypeMap, id, mtype, err_type);
         case BAGHOLE:
            err_type = "ALEBAG_HOLE";
            return findIDBasedOnType(holeIDTypeMap, id, mtype, err_type);
         case INFLATOR:
            err_type = "ALEBAG_INFLATOR";
            return findIDBasedOnType(inflatorIDTypeMap, id, mtype, err_type);
         case VECTOR:
            err_type = "VECTOR";
            return findIDBasedOnType(vectorIDTypeMap, id, mtype, err_type);
         case TRANS:
            err_type = "TRANSFORMATION";
            return findIDBasedOnType(transIDTypeMap, id, mtype, err_type);
         case TABLE:
            err_type = "TABLE";
            return findIDBasedOnType(tableIDTypeMap, id, mtype, err_type);
         case VOLUME:
            err_type = "CONTACT_VOLUME";
            return findIDBasedOnType(cvIDTypeMap, id, mtype, err_type);
         default:
            err_type = "OTHER TYPE";
            return findIDBasedOnType(otherIDTypeMap, id, mtype, err_type);
      }
   }

private:
   /** An instance of this object */
   static DefineManager *managerPtr;
   /** A map holding the CURVE ID and type */
   multimap<string, unsigned int> curveIDTypeMap;
   /** A map holding the BOX ID and type */
   multimap<string, unsigned int> boxIDTypeMap;
   /** A map holding the BAG ID and type */
   multimap<string, unsigned int> bagIDTypeMap;
   /** A map holding the HOLE ID and type */
   multimap<string, unsigned int> holeIDTypeMap;
   /** A map holding the INFLATOR ID and type */
   multimap<string, unsigned int> inflatorIDTypeMap;
   /** A map holding the VECTOR ID and type */
   multimap<string, unsigned int> vectorIDTypeMap;
   /** A map holding the COORDINATE_SYSTEM ID and type */
   multimap<string, unsigned int> coordIDTypeMap;
   /** A map holding the TRANSFORM ID and type */
   multimap<string, unsigned int> transIDTypeMap;
   /** A map holding the TABLE ID and type */
   multimap<string, unsigned int> tableIDTypeMap;
   /** A map holding the ID and type */
   multimap<string, unsigned int> otherIDTypeMap;
   /** A map holding the CONTROL_VOLUME and type */
   multimap<string, unsigned int> cvIDTypeMap;
};

#endif

