#ifndef _Eos_MANAGER_H_
#define _Eos_MANAGER_H_

#include "manager.h"

using namespace std;

/** Manager class to hold all the keywords starting with *EOS. All the keywords
  * are stored as list of ImportObject. This class holds its own instance here.
  */
class EosManager : public Manager
{
private:
   /** Default constructor for creating this object */
   EosManager() : Manager()
   {
   }

public:
   /** Static function to create this object. Object is created if already not 
     * there. only one instance exists at any point of time.
     */
   static EosManager *create()
   {
      if( !managerPtr )
         managerPtr = new EosManager();
      return managerPtr;
   }

   /** Destroys the stored instance of this object and initializes to NULL. */
   static void reset()
   {
      if( managerPtr )
         delete managerPtr;
      managerPtr = NULL;
   }

   ~EosManager()
   {
      managerPtr = NULL;
   }

   /** Adds a given object ID to this object with a given type
     * \param id ID of object to add
     * \param kw_type Type of object to store id
     */
   void addID(char *id, unsigned int kw_type)
   {
cout << "ADDING EOS ID = " << id << endl;
#ifdef DEBUG
#endif
      idTypeMap.insert( StringUIntPair(id, kw_type) );
   }

   /** Function to find an object ID of given type
     * \param id ID of object
     * \param mtype Not used
     */
   int findID(char *id, unsigned int mtype)
   {
      unsigned int num_ids = idTypeMap.count(id);

cout << "FINDID EOS = " << id << endl;
cout << "NUMIDS EOS = " << num_ids << endl;
#ifdef DEBUG
#endif
      switch(num_ids)
      {
         case 1:
            return 0;
         case 0:
	    cout << "EOS ID <" << id << "> NOT FOUND" << endl;
	    return 1;
      }

      if( num_ids > 1 )
      {
	 StringUIntIterator low = idTypeMap.lower_bound(id), iter,
	                up = idTypeMap.upper_bound(id), e = idTypeMap.end();
         unsigned int cur_type, prev_type, num_clash = 1;
	  
         iter = low;
         prev_type = iter->second;
         iter++;
	 for(;iter != up; iter++)
	 {
            cur_type = iter->second;
	    if( cur_type == prev_type )
               num_clash++;
            prev_type = cur_type;
	 }

         if( num_clash > 1 )
         {
            cout << "ID is same for " << num_clash << " EOS. ID = <" 
                 << id << ">" << endl;
         }

         for(;low != up;low++)
         {
            cur_type = low->second;
            if( cur_type == mtype )
               return 0;
         }
      }

      return 1;
   }

private:
   static EosManager *managerPtr;
   map<string, unsigned int> idTypeMap;
};

#endif

