#ifndef _DATA_TYPE_H_
#define _DATA_TYPE_H_

#include "object.h"

/** Types of data to save in objects */
typedef enum _DataType
{
   DATA_UINT,
   DATA_INT,
   DATA_DOUBLE,
   DATA_FLOAT,
   DATA_CHAR,
   DATA_CHAR_ARRAY,
   DATA_DOUBLE_ARRAY,
   DATA_UNUSED,
   DATA_BLANK,

   DATA_NO_TYPE
} DataType;

/** Base class to hold data of different types. This class stores field width and
  * type of data to store.
  */
class Data : public Object
{
public:
   /** Virtual function for getting an unsigned int value from derived object
     * \param val Value of variable
     */
   virtual void value(unsigned int *val)
   {
      *val = 0;
   }

   /** Virtual function for getting an int value from derived object
     * \param val Value of variable
     */
   virtual void value(int *val)
   {
      *val = 0;
   }

   /** Virtual function for getting a double value from derived object
     * \param val Value of variable
     */
   virtual void value(double *val)
   {
      *val = 0;
   }

   /** Virtual function for getting a string value from derived object
     * \param val Value of variable
     */
   virtual void value(char **val)
   {
      *val = (char *)"";
   }

   /** No functionality function */
   virtual void tostring(char *) = 0;

   virtual ~Data(){}

   /** Constructor to create this object
     * \param _type Type of data to store
     * \param _width Width of field to store
     */
   Data(unsigned int _type, unsigned int & _width)
   {
      dataType = _type;
      dataWidth = _width;
   }

public:
   /** Type of data to store */
   unsigned int dataType;
   /** width of field to store. This is used while exporting the data to LSDYNA */
   unsigned int dataWidth;
};

#endif

