#ifndef _DATA_TYPE_OBJ_H_
#define _DATA_TYPE_OBJ_H_

#include "datatype.h"
#include "generic.h"
#include <iostream>

using namespace std;

/** Class to store unsigned int type of data */
class UInteger : public Data
{
public:
   /** Constructor to create this object
     * \param i value to store
     * \param _width Width of field
     */
   UInteger(unsigned int & i, unsigned int _width = 10)
           : Data(DATA_UINT, _width)
   {
      Value = i;
   }
 
   /** Constructor to create this object
     * \param str string from which value is taken
     * \param _width Width of field
     */
   UInteger(const char *str, unsigned int _width = 10)
          : Data(DATA_UINT, _width)
   {
      Value = atoi(str);
   }

   virtual ~UInteger(){}

   /** Function to convert this value into string with given width
     * \param str String in which value is stored
     */
   void tostring(char *str)
   {
      char format_str[16];
      sprintf(format_str, "%%%du", dataWidth);
      sprintf(str, format_str, Value);
   }

   /** Function to get this value 
     * \param val pointer to store value
     */
   void value(unsigned int *val)
   {
      *val = (dataType == DATA_UINT) ? Value : 0;
      if( dataType != DATA_UINT )
	 cout << "wrong data type sent to get unsigned int value" << endl;
   }

public:
   /** unsigned int value is stored */
   unsigned int Value;
};

/** Class to store int type of data */
class Integer : public Data
{
public:
   /** Constructor to create this object
     * \param i value to store
     * \param _width Width of field
     */
   Integer(int & i, unsigned int _width = 10) : Data(DATA_INT, _width)
   {
      Value = i;
   }

   /** Constructor to create this object
     * \param str string from which value is taken
     * \param _width Width of field
     */
   Integer(const char *str, unsigned int _width = 10) : Data(DATA_INT, _width)
   {
      Value = atoi(str);
   }

   virtual ~Integer(){}

   /** Function to convert this value into string with given width
     * \param str String in which value is stored
     */
   void tostring(char *str)
   {
      char format_str[16];
      sprintf(format_str, "%%%dd", dataWidth);
      sprintf(str, format_str, Value);
   }

   /** Function to get this value 
     * \param val pointer to store value
     */
   void value(int *val)
   {
      *val = (dataType == DATA_INT) ? Value : 0;
      if( dataType != DATA_INT )
	 cout << "wrong data type sent to get int value" << endl;
   }

public:
   int Value;
};

/** Class to store double type of data */
class Double : public Data
{
public:
   /** Constructor to create this object
     * \param d value to store
     * \param _width Width of field
     */
   Double(double & d, unsigned int _width = 10) : Data(DATA_DOUBLE, _width)
   {
      memset(&Value, 0, sizeof(double));
      Value = d;
   }

   /** Constructor to create this object
     * \param str string from which value is taken
     * \param _width Width of field
     */
   Double(const char *str, unsigned int _width = 10) : Data(DATA_DOUBLE, _width)
   {
      Value = atof(str);
   }

   virtual ~Double(){}

   /** Function to get this value 
     * \param val pointer to store value
     */
   void value(double *val)
   {
      *val = (dataType == DATA_DOUBLE) ? Value : 0;
      if( dataType != DATA_DOUBLE )
	 cout << "wrong data type sent to get double value" << endl;
   }

   /** Function to convert this value into string with given width
     * \param str String in which value is stored
     */
   void tostring(char *str)
   {
      char g_str[16], str_str[16], *ptr;//, *dot_ptr;
      unsigned int len, prec = dataWidth - 6;//, mant, base;
      sprintf(g_str, "%%%u.%ue", dataWidth, prec);
      sprintf(str_str, "%%%ds", dataWidth);

      sprintf(str, "%.14lf", Value);

#ifdef DEBUG
cout << "DOUBLE VAL =" << str << endl;
#endif
      len = strlen(str);
      ptr = str+len-1;
      while(*ptr == '0')
	 ptr--;
      str[ptr-str+1] = '\0';
      len = strlen(str);
      //dot_ptr = strchr(str, '.');
      //base = dot_ptr - str;
      //mant = len - base;
      if( len <= dataWidth )
      {
	 char str_temp[128];
	 sprintf(str_temp, str_str, str);
	 strcpy(str, str_temp);
#ifdef DEBUG
cout << "MOD VAL = " << str << endl;
#endif
	 return;
      }

      sprintf(str, g_str, Value);
#ifdef DEBUG
cout << "GVAL = " << str << endl;
#endif
      len = strlen(str);

      if( len > dataWidth )
      {
	 char *eptr = strrchr(str, 'e');
	 char *nptr = eptr;
	 while( *nptr != '\0')
	 {
	    *eptr++ = *(++nptr);  
	 }
      }
#ifdef DEBUG
cout << "GMOD VAL = " << str << endl;
#endif
   }
public:
   double Value;
};

/** Class to store float type of data */
class Float : public Data
{
public:
   /** Constructor to create this object
     * \param f value to store
     * \param _width Width of field
     */
   Float(float & f, unsigned int _width = 10) : Data(DATA_FLOAT, _width)
   {
      Value = f;
   }

   /** Constructor to create this object
     * \param str string from which value is taken
     * \param _width Width of field
     */
   Float(const char *str, unsigned int _width = 10) : Data(DATA_FLOAT, _width)
   {
      Value = atof(str);
   }

   virtual ~Float(){}

   /** Function to convert this value into string with given width
     * \param str String in which value is stored
     */
   void tostring(char *str)
   {
      sprintf(str, "%10g", Value);
   }

   /** Function to get this value 
     * \param val pointer to store value
     */
   void value(float *val)
   {
      *val = (dataType == DATA_FLOAT) ? Value : 0;
      if( dataType != DATA_FLOAT )
	 cout << "wrong data type sent to get float value" << endl;
   }

public:
   float Value;
};

/** Class to store string type of data */
class CharArray : public Data
{
public:
   /** Constructor to create this object
     * \param str string value to store
     * \param _width Width of field
     */
   CharArray(const char *str, unsigned int _width = 10) 
		: Data(DATA_CHAR_ARRAY, _width)
   {
      //Generic::RemoveLeadingAndTrailingBlanks(str);
      Value = strdup(str);
   }

   virtual ~CharArray()
   {
      if( Value )
         free( Value );
      Value = NULL;
   }

   /** Function to convert this value into string with given width
     * \param str String in which value is stored
     */
   void tostring(char *str)
   {
      char  format_str[16];

      sprintf(format_str, "%%%us", dataWidth);
      sprintf(str, format_str, Value);
   }

   /** Function to get this value 
     * \param val pointer to store value
     */
   void value(char **val)
   {
      *val = (dataType == DATA_CHAR_ARRAY) ? Value : NULL;
      if( dataType != DATA_CHAR_ARRAY )
	 cout << "wrong data type sent to get char array" << endl;
   }

   /** Function to set width of field
     * \param _w Width to set
     */
   void setWidth(unsigned int _w)
   {
      dataWidth = _w;
   }

public:
   char *Value;
};

/** Class to store array of doubles */
class DoubleArray : public Data
{
public:
   /** Constructor to create this object. New array of size num_val is created
     * and values are copied.
     * \param num_val Count of values to store
     * \param val_arr Array of values to store
     * \param _width Width of each field
     */
   DoubleArray(int num_val, double *val_arr, unsigned int _width = 10) 
		: Data(DATA_DOUBLE_ARRAY, _width)
   {
      Value = new double[num_val];
      memcpy(Value, val_arr, sizeof(double) * num_val);
      numVal = num_val;
   }

   virtual ~DoubleArray()
   {
      if( numVal )
         delete Value;
      numVal = 0;
      Value = NULL;
   }

   void tostring(char *)
   {
   }

   /** Function to get array of values
     * \param val pointer to store value
     */
   unsigned int value(double **val)
   {
      *val = (dataType == DATA_DOUBLE_ARRAY) ? Value : NULL;
      if( dataType != DATA_DOUBLE_ARRAY )
	 cout << "wrong data type sent to get double array" << endl;
      return numVal;
   }

public:
   unsigned int  numVal;
   double        *Value;
};

/** Class to represent empty field. */
class BlankObject : public Data
{
public:
   /** Constructor to create this object with given width 
     * \param _width Width of empty field
     */
   BlankObject(unsigned int _width = 10) 
		: Data(DATA_BLANK, _width)
   {
   }

   virtual ~BlankObject()
   {
   }

   /** Function to convert this object into string with given width
     * \param str String in which value is stored
     */
   void tostring(char *str)
   {
      char  format_str[16];
      char  *blank = (char *)" ";

      sprintf(format_str, "%%-%us", dataWidth);
      sprintf(str, format_str, blank);
   }
};

#endif

