#ifndef _Hg_MANAGER_H_
#define _Hg_MANAGER_H_

#include "manager.h"

using namespace std;

/** Manager class to hold all the keywords starting with *HOURGLASS. All the 
  * keywords are stored as list of ImportObject. This class holds its own 
  * instance here.
  */
class HgManager : public Manager
{
private:
   /** Default constructor for creating this object */
   HgManager() : Manager()
   {
   }

public:
   /** Static function to create this object. Object is created if already not 
     * there. only one instance exists at any point of time.
     */
   static HgManager *create()
   {
      if( !managerPtr )
         managerPtr = new HgManager();

      return managerPtr;
   }

   /** Destroys the stored instance of this object and initializes to NULL. */
   static void reset()
   {
      if( managerPtr )
         delete managerPtr;

      managerPtr = NULL;
   }

   ~HgManager()
   {
      managerPtr = NULL;
   }
   /** Adds a given object ID to this object with a given type
     * \param id ID of object to add
     * \param kw_type Type of object to store id
     */
   void addID(char *id, unsigned int kw_type)
   {
#ifdef DEBUG
cout << "ADD ID HG = " << id << endl;
#endif
      idTypeMap.insert( StringUIntPair(id, kw_type) );
   }

   /** Function to find an object ID of given type
     * \param id ID of object
     * \param mtype keyword type to find
     */
   int findID(char *id, unsigned int mtype)
   {
      unsigned int num_ids = idTypeMap.count(id);

#ifdef DEBUG
cout << "FINDID HG = " << id << endl;
cout << "NUMIDS HG = " << num_ids << endl;
#endif
      switch(num_ids)
      {
         case 1:
            return 0;
         case 0:
	    cout << "HG ID <" << id << "> NOT FOUND" << endl;
	    return 1;
      }

      if( num_ids > 1 )
      {
	 StringUIntIterator low = idTypeMap.lower_bound(id), iter,
	                up = idTypeMap.upper_bound(id), e = idTypeMap.end();
         unsigned int cur_type, prev_type, num_clash = 1;
	  
         iter = low;
         prev_type = iter->second;
         iter++;
	 for(;iter != up; iter++)
	 {
            cur_type = iter->second;
	    if( cur_type == prev_type )
               num_clash++;
            prev_type = cur_type;
	 }

         if( num_clash > 1 )
         {
            cout << "ID is same for " << num_clash << " hourglass. ID = <" 
                 << id << ">" << endl;
         }

         for(;low != up;low++)
         {
            cur_type = low->second;
            if( cur_type == mtype )
               return 0;
         }
      }

      return 1;
   }

private:
   static HgManager *managerPtr;
   multimap<string, unsigned int> idTypeMap;
};

#endif

