#ifndef _Include_MANAGER_H_
#define _Include_MANAGER_H_

#include "manager.h"

using namespace std;

/** Manager class to hold all the keywords starting with *INCLUDE. All the 
  * keywords are stored as list of ImportObject. This class holds its own 
  * instance here.
  */
class IncludeManager : public Manager
{
private:
   /** Default constructor for creating this object */
   IncludeManager() : Manager()
   {
   }

public:
   /** Static function to create this object. Object is created if already not 
     * there. only one instance exists at any point of time.
     */
   static IncludeManager *create()
   {
      if( !managerPtr )
         managerPtr = new IncludeManager();

      return managerPtr;
   }

   /** Destroys the stored instance of this object and initializes to NULL. */
   static void reset()
   {
      if( managerPtr )
         delete managerPtr;

      managerPtr = NULL;
   }

   ~IncludeManager()
   {
      managerPtr = NULL;
   }

   /** Adds a given object ID to this object with a given type
     * \param id ID of object to add
     * \param mtype Type of object to store id
     */
   void addID(char *id, unsigned int mtype)
   {
#ifdef DEBUG
cout << "ADDING INCLUDE ID = " << id << endl;
#endif
      idTypeMap.insert(StringUIntPair(id, mtype));
   }

   /** Gets a reference to the map of keyword and keyword type
     * \return Reference to the map
     */
   multimap<string, unsigned int> & getFileNames()
   {
      return idTypeMap;
   }

private:
   static IncludeManager *managerPtr;
   multimap<string, unsigned int> idTypeMap;
};

#endif

