#ifndef _Integration_MANAGER_H_
#define _Integration_MANAGER_H_

#include "manager.h"
#include "integrationtype.h"

using namespace std;

/** Manager class to hold all the keywords starting with *INTEGRATION. All the 
  * keywords are stored as list of ImportObject. This class holds its own 
  * instance here.
  */
class IntegrationManager : public Manager
{
private:
   /** Default constructor for creating this object */
   IntegrationManager() : Manager()
   {
   }

public:
   /** Static function to create this object. Object is created if already not 
     * there. only one instance exists at any point of time.
     */
   static IntegrationManager *create()
   {
      if( !managerPtr )
         managerPtr = new IntegrationManager();

      return managerPtr;
   }

   /** Destroys the stored instance of this object and initializes to NULL. */
   static void reset()
   {
      if( managerPtr )
         delete managerPtr;

      managerPtr = NULL;
   }

   ~IntegrationManager()
   {
      managerPtr = NULL;
   }

   /** Adds a given object ID to this object with a given type
     * \param id ID of object to add
     * \param mtype Type of object to store id
     */
   void addID(char *id, unsigned int mtype)
   {
#ifdef DEBUG
cout << "ADDING INTEGRATION ID = " << id << endl;
#endif
      switch(mtype)
      {
         case INTEGRATION_BEAM:
            beamIDTypeMap.insert(StringUIntPair(id, mtype));
            break;
         case INTEGRATION_SHELL:
            shellIDTypeMap.insert(StringUIntPair(id, mtype));
            break;
      }
   }

   /** Function to find an object ID of given type
     * \param intg_map List of IDs and Types
     * \param id ID of object
     * \param mtype Not used
     * \return Returns -1 on error else 0
     */
   int findIDBasedOnType
       (
          multimap<string, unsigned int> & intg_map, 
          char *id, 
          unsigned int
       )
   {
      unsigned int num_ids = intg_map.count(id);

#ifdef DEBUG
cout << "FINDID INTEGRATION = " << id << endl;
cout << "NUMIDS INTEGRATION = " << num_ids << endl;
#endif
      switch(num_ids)
      {
         case 1:
            {
	       StringUIntIterator iter = intg_map.find(id);
	       return (int)iter->second;
            }
         case 0:
	    cout << "INTEGRATION ID <" << id << "> NOT FOUND" << endl;
	    return -1;
      }

      if( num_ids > 1 )
      {
	 StringUIntIterator low = intg_map.lower_bound(id), iter,
	                up = intg_map.upper_bound(id), e = intg_map.end();
         unsigned int cur_type, prev_type, num_clash = 1;
	  
         iter = low;
         prev_type = iter->second;
         iter++;
	 for(;iter != up; iter++)
	 {
            cur_type = iter->second;
	    if( cur_type == prev_type )
               num_clash++;
            prev_type = cur_type;
	 }

         if( num_clash > 1 )
         {
            cout << "ID is same for " << num_clash << " integrations. ID = <" 
                 << id << ">" << endl;
         }

         return 0;
      }

      return -1;
   }

   /** Function to find an object ID of given type
     * \param id ID of object
     * \param mtype keyword type to find
     */
   int findID(char *id, unsigned int mtype)
   {
      switch(mtype)
      {
         case BEAM:
            return findIDBasedOnType(beamIDTypeMap, id, mtype);
         case SHELL:
            return findIDBasedOnType(shellIDTypeMap, id, mtype);
      }

      return -1;
   }

private:
   static IntegrationManager *managerPtr;
   multimap<string, unsigned int> beamIDTypeMap;
   multimap<string, unsigned int> shellIDTypeMap;
};

#endif

