#ifndef _Mat_MANAGER_H_
#define _Mat_MANAGER_H_

#include "manager.h"
#include "mattype.h"

using namespace std;

/** Manager class to hold all the keywords starting with *MAT. All the keywords
  * are stored as list of ImportObject. This class holds its own instance here.
  */
class MatManager : public Manager
{
private:
   /** Default constructor for creating this object */
   MatManager() : Manager()
   {
   }

public:
   /** Static function to create this object. Object is created if already not 
     * there. only one instance exists at any point of time.
     */
   static MatManager *create()
   {
      if( !managerPtr )
         managerPtr = new MatManager();

      return managerPtr;
   }

   /** Destroys the stored instance of this object and initializes to NULL. */
   static void reset()
   {
      if( managerPtr )
         delete managerPtr;

      managerPtr = NULL;
   }

   ~MatManager()
   {
      managerPtr = NULL;
   }
   /** Adds a given object ID to this object with a given type
     * \param id ID of object to add
     * \param mtype Type of object to store id
     */
   void addID(char *id, unsigned int mtype)
   {
#ifdef DEBUG
cout << "ADD MAT ID = " << id << endl;
#endif
      switch(mtype)
      {
         case MAT_THERMAL_USER_DEFINED:
	 case MAT_THERMAL_ISOTROPIC:
	 case MAT_THERMAL_ISOTROPIC_PHASE_CHANGE:
	 case MAT_THERMAL_ISOTROPIC_TD:
	 case MAT_THERMAL_ISOTROPIC_TD_LC:
	 case MAT_THERMAL_ORTHOTROPIC:
	 case MAT_THERMAL_ORTHOTROPIC_TD:
            tmidTypeMap.insert(StringUIntPair(id, mtype));
            break;
         default:
            idTypeMap.insert(StringUIntPair(id, mtype));
            break;
      }
   }

   /** Function to find an object ID of given type
     * \param id ID of object
     * \param mtype keyword type to find
     */
   int findID(char *id, unsigned int mtype)
   {
      string err_type;
      multimap<string, unsigned int> & mat_map = idTypeMap;

      if( mtype == THERMAL )
      {
         mat_map = tmidTypeMap;
         err_type = "THERMAL ";
      }

      unsigned int num_ids = mat_map.count(id);

#ifdef DEBUG
cout << "FINDID MATERIAL = " << id << endl;
cout << "NUMIDS MATERIAL = " << num_ids << endl;
#endif

      switch(num_ids)
      {
         case 1:
            {
	       StringUIntIterator iter = mat_map.find(id);
	       return (int)iter->second;
            }
         case 0:
	    cout << "MAT " << err_type << "ID <" << id << "> NOT FOUND" << endl;
	    return -1;
      }

      if( num_ids > 1 )
      {
	 StringUIntIterator low = mat_map.lower_bound(id), iter,
	                up = mat_map.upper_bound(id), e = mat_map.end();
         unsigned int cur_type, prev_type, num_clash = 1;

         iter = low;
         prev_type = iter->second;
         iter++;
	 for(;iter != up; iter++)
	 {
            cur_type = iter->second;
	    if( cur_type == prev_type )
               num_clash++;
            prev_type = cur_type;
	 }

         if( num_clash > 1 )
         {
            cout << "ID is same for " << num_clash << " materials. ID = <"
                 << id << ">" << endl;
         }

         return prev_type;
      }

      return -1;
   }

private:
   static MatManager *managerPtr;
   multimap<string, unsigned int> idTypeMap;
   multimap<string, unsigned int> tmidTypeMap;
};

#endif

