#ifndef _Rigidwall_MANAGER_H_
#define _Rigidwall_MANAGER_H_

#include "manager.h"

using namespace std;

/** Manager class to hold all the keywords starting with *RIGIDWALL. All the 
  * keywords are stored as list of ImportObject. This class holds its own 
  * instance here.
  */
class RigidwallManager : public Manager
{
private:
   /** Default constructor for creating this object */
   RigidwallManager() : Manager()
   {
   }

public:
   /** Static function to create this object. Object is created if already not 
     * there. only one instance exists at any point of time.
     */
   static RigidwallManager *create()
   {
      if( !managerPtr )
         managerPtr = new RigidwallManager();

      return managerPtr;
   }

   /** Destroys the stored instance of this object and initializes to NULL. */
   static void reset()
   {
      if( managerPtr )
         delete managerPtr;

      managerPtr = NULL;
   }

   ~RigidwallManager()
   {
      managerPtr = NULL;
   }

   /** Adds a given object ID to this object with a given type
     * \param id ID of object to add
     * \param mtype Type of object to store id
     */
   void addID(char *id, unsigned int mtype)
   {
#ifdef DEBUG
cout << "ADDING RIGIDWALL ID = " << id << endl;
#endif
      idTypeMap.insert(StringUIntPair(id, mtype));
   }

   /** Function to find an object ID of given type
     * \param id ID of object
     * \param mtype Not used
     */
   int findID(char *id, unsigned int)
   {
      unsigned int num_ids = idTypeMap.count(id);

#ifdef DEBUG
cout << "FINDID RIGIDWALL = " << id << endl;
cout << "NUMIDS RIGIDWALL = " << num_ids << endl;
#endif
      switch(num_ids)
      {
         case 1:
            {
	       StringUIntIterator iter = idTypeMap.find(id);
	       return (int)iter->second;
            }
         case 0:
	    cout << "RIGIDWALL ID <" << id << "> NOT FOUND" << endl;
	    return -1;
      }

      if( num_ids > 1 )
      {
	 StringUIntIterator low = idTypeMap.lower_bound(id), iter,
	                up = idTypeMap.upper_bound(id), e = idTypeMap.end();
         unsigned int cur_type, prev_type, num_clash = 1;
	  
         iter = low;
         prev_type = iter->second;
         iter++;
	 for(;iter != up; iter++)
	 {
            cur_type = iter->second;
	    if( cur_type == prev_type )
               num_clash++;
            prev_type = cur_type;
	 }

         if( num_clash > 1 )
         {
            cout << "ID is same for " << num_clash << " rigidwalls. ID = <" 
                 << id << ">" << endl;
         }

         return prev_type;
      }

      return -1;
   }

private:
   static RigidwallManager *managerPtr;
   multimap<string, unsigned int> idTypeMap;
};

#endif

