<?php
if (file_exists($argv[1]))
{
   $xml = simplexml_load_file($argv[1]);

   $card = $xml->card;

   if( !$card )
      return;

   $str = "";
   $card_num = 1;
   $class_name = $xml['classname'];
   $kw_name = $xml['name'];
   $grp = getGroupNameFromKW($kw_name);

   if( $class_name == 'NoCards' )
      return;

   $class_name = "DB" . $class_name;

   $str .= "#ifndef _" . strtoupper($class_name) . "_H_\n";
   $str .= "#define _" . strtoupper($class_name) . "_H_\n\n";

   $base_class = $xml->baseclass['name'];

   if( $base_class )
   {
      if( !strcmp($base_class, 'ImportBase') )
         $base_class = "GetDBBase";
      else
         $base_class = "DB" . $base_class;
   }

   $str .= "#include \"manager.h\"\n";
   $str .= "#include \"dispexport.h\"\n";

   if( $base_class )
   {
      $str .= "#include \"" . strtolower($base_class) . ".h\"\n\n";

      $str .= "/** Class used for getting data from database for *$kw_name\n";
      $str .= "  * keyword */\n\n";

      if( !strcmp($base_class, "GetDBBase") )
         $str .= "class " . $class_name . " : public $base_class\n";
      else
         $str .= "class " . $class_name . " : public $base_class\n";
      $str .= "{\n";
      $str .= "public:\n";

      $str .= "/** Class constructor for creating the objects.\n";
      $str .= "  * \param gold_conn GoldenConn object to access database\n";
      $str .= "  * \param imp_obj ImportObject pointer to hold data\n";
      $str .= "  */\n";

      if( !strcmp($base_class, "GetDBBase") )
         $str .= "   " . $class_name . "(GoldenConn *gold_conn, ImportObject *imp_obj) : $base_class (gold_conn, imp_obj)\n";
      else
         $str .= "   " . $class_name . "(GoldenConn *gold_conn, ImportObject *imp_obj) : $base_class (gold_conn, imp_obj)\n";
      $str .= "   {\n";
      $str .= "   }\n\n";

      $str .= "/** Class destructor for releasing the memory in the object.\n";
      $str .= "  */\n";

      $str .= "   virtual ~" . $class_name . "()\n";
      $str .= "   {\n";
      $str .= "   }\n\n";
   }
   else
   {
      $str .= "#include \"goldenconn.h\"\n";
      $str .= "#include \"dbcard.h\"\n\n";

      $str .= "/** Class used for getting data from database for *$kw_name\n";
      $str .= "  * keyword */\n\n";

      $str .= "class " . $class_name . "\n";
      $str .= "{\n";
      $str .= "public:\n";

      $str .= "/** Class constructor for creating the objects.\n";
      $str .= "  * \param gold_conn GoldenConn object to access database\n";
      $str .= "  * \param imp_obj ImportObject pointer to hold data\n";
      $str .= "  */\n";

      $str .= "   " . $class_name . "(GoldenConn *gold_conn, ImportObject *imp_obj)\n";
      $str .= "   {\n";
      $str .= "      goldenConn = gold_conn;\n";
      $str .= "      impObj = imp_obj;\n";
      $str .= "      numFields = 0;\n";
      $str .= "      wordArray = NULL;\n";
      $str .= "      cardObj = NULL;\n";
      $str .= "   }\n\n";

      $str .= "/** Class destructor for releasing the memory in the object.\n";
      $str .= "  */\n";

      $str .= "   virtual ~" . $class_name . "()\n";
      $str .= "   {\n";
      $str .= "      goldenConn = NULL;\n";
      $str .= "      impObj = NULL;\n";
      $str .= "      numFields = 0;\n";
      $str .= "      wordArray = NULL;\n";
      $str .= "      cardObj = NULL;\n";
      $str .= "   }\n\n";

      $str .= "public:\n";
      $str .= "/** Number of fields in each card */\n";
      $str .= "   unsigned int   numFields;\n";
      $str .= "/** List of field values read from database */\n";
      $str .= "   char           **wordArray;\n";
      $str .= "/** Object to save the imported data from database */\n";
      $str .= "   ImportObject   *impObj;\n";
      $str .= "/** Object to connect to database */\n";
      $str .= "   GoldenConn     *goldenConn;\n";
      $str .= "/** Object to store the fields and their values */\n";
      $str .= "   Card           *cardObj;\n\n";
   }

   $str .= "public:\n";
   $global_card_array = Array();
   $add_id_flag = 0;

   foreach ($xml->card as $card)
   {
      $field_check = $card->field;

      //added for no card keywords
      if( !$field_check )
         continue;

      $str1 = "";
      $str2 = "";

      $card_name = $card['name'];

      $ret_var = strtolower($card['return']);
      $ret_type = $card['returntype'];
  
      $func_name = "";
      $ret_name = $card_name . "_return";
      switch($ret_type)
      {
	 case 'uint':
            $func_name .= "   unsigned int dbRead" . $card_name . "(unsigned int loop_count = (1 << 31))\n";
            $main_func = "   $ret_var = dbRead" . $card_name . "();\n";
            $func_array["$card_name"] = $main_func;
            $func_array["$ret_name"] = "unsigned int $ret_var = 0;\n";
	    break;
	 case 'int':
            $func_name .= "   int dbRead" . $card_name . "(unsigned int loop_count = (1 << 31))\n";
            $main_func = "   $ret_var = dbRead" . $card_name . "();\n";
            $func_array["$card_name"] = $main_func;
            $func_array["$ret_name"] = "int $ret_var = 0;\n";
	    break;
	 case 'double':
            $func_name .= "   double dbRead" . $card_name . "(unsigned int loop_count = (1 << 31))\n";
            $main_func = "   $ret_var = dbRead" . $card_name . "();\n";
            $func_array["$card_name"] = $main_func;
            $func_array["$ret_name"] = "double $ret_var = 0.0;\n";
	    break;
	 case 'string':
            $func_name .= "   char *dbRead" . $card_name . "(unsigned int loop_count = (1 << 31))\n";
            $main_func = "   $ret_var = dbRead" . $card_name . "();\n";
            $func_array["$card_name"] = $main_func;
            $func_array["$ret_name"] = "char* $ret_var = NULL;\n";
	    break;
	 default:
            $func_name .= "   void dbRead" . $card_name . "(unsigned int loop_count = (1 << 31))\n";
            $main_func = "   dbRead" . $card_name . "();\n";
            $func_array["$card_name"] = $main_func;
      }

      $str .= "/** Function to get $card_name details for *$kw_name\n";
      $str .= "  * keyword from database */\n";

      $str .= $func_name;

      $str .= "   {\n";
      $str .= "      const char *fields[] = {";
      $str1 .= "      unsigned int field_types[] = {";
      $str2 .= "      unsigned int field_widths[] = {";
 
      $num_fields = 0;
      $field_index = -1;
      $unequal_width = false;
      $str_type = false;
      $int_type = false;
      $man_name = "";

      $findex = 0;
      $field_indices = "";
      $man_types = "";
      $kw_types = "";
      $find_func = "";
      $func_index = -1;
      $global_farray = Array();

      //FORTHENEW
      $ret_field = $card['return'];

      foreach ($card->field as $field)
      {
         $var_name = $field['name'];
         $str .= "\"$var_name\",";





         //FORTHENEW
         if( $ret_field )
         {
            if( !strcmp($ret_field, $var_name) )
               $ret_findex = $num_fields + 2;
         }

         $rf = $field['return'];
         $global_f = $field['global'];
         if( $global_f )
         {
            $global_farray["$var_name"] = "$global_f" . "_" . $num_fields;
         }





/** adding id to manager **/
         $add = $field['add'];
         $find = $field['find'];
         $findtype = $field['findtype'];
         $ffunc = $field['func'];

         if( $add )
         {
            $field_index = $num_fields + 2;
            $man_name = $add;
         }

         if( $ffunc )
         {
            $find_func = $ffunc;
            $func_index = $num_fields;
         }
         else if( $find )
         {
            $man_types[$findex] = strtoupper($find);
            $field_indices[$findex] = $num_fields;
            if( $findtype )
            {
               $kw_types[$findex] = strtoupper($findtype);
            }
            else
            {
               $kw_types[$findex] = 9999;
            }
            $findex++;
         }
/** adding id to manager **/









         $num_fields++;
         $width = (int)$field['width'];
         $str2 .= "$width, ";
         $type = $field['type'];

         switch((string)$type)
         {
            case 'uint':
               $str1 .= "DATA_UINT, ";
               break;
            case 'int':
               $str1 .= "DATA_INT, ";
               break;
            case 'double':
               $str1 .= "DATA_DOUBLE, ";
               break;
            case 'string':
               $str1 .= "DATA_CHAR_ARRAY, ";
               break;
            case 'unused':
               $str1 .= "DATA_UNUSED, ";
               break;
         }

         if( $width != "10" )
            $unequal_width = true;

         if( $type == "string" )
            $str_type = true;

         if( $type == "int" )
            $int_type = true;
      }
      $str .= "};\n";
      $str1 .= "};\n";
      $str2 .= "};\n";

      $str .= $str1;






/**** add to manager code ****/
      if( $findex )
      {
         $str3 = "      unsigned int field_indices[] = {";
         $str4 = "      unsigned int man_types[] = {";
         $str5 = "      unsigned int kw_types[] = {";

	 for($cnt = 0; $cnt < $findex;$cnt++)
	 {
	    $str3 .= $field_indices[$cnt] . ", ";
	    $str4 .= $man_types[$cnt] . ", ";
	    $str5 .= $kw_types[$cnt] . ", ";
	 }

         $str3 .= "};\n";
         $str4 .= "};\n";
         $str5 .= "};\n";

         $str .= $str3 . $str4 . $str5;
         $str .= "      unsigned int num_indices = " . $findex . ";\n";
      }
/** end of add to manager **/








      $str .= "      numFields = $num_fields;\n";
      
      $loop = $card->loop;
      if( $loop )
      {
         $loop_card = $loop['loopcard'];
         $loop_field = $loop['loopfield'];

	 $str .= $str2;

         if( $loop_card )
         {
	    $str .= "      unsigned int end_loop;\n";
/* FORTHENEW
	    $str .= "      Card *card = impObj->findCard(\"" . $loop_card . "\");\n";
	    $str .= "      unsigned int " . strtolower($loop_field) . " = 0, end_loop;\n";
	    $str .= "      if( card )\n";
	    $str .= "      {\n";
	    $str .= "         " . strtolower($loop_field) . " = card->intValue(\"" . $loop_field . "\");\n";
	    $str .= "      }\n\n";
*/
         }
         else
         {
	    //$str .= "      unsigned int i, end_loop;\n";
	    $str .= "      unsigned int end_loop;\n";
         }

         $start = $loop['start'];
         $end = strtolower($loop['end']);
         $str .= "      end_loop = $end;\n";
         $str .= "      for(loop_count = $start; loop_count < end_loop; loop_count++)\n";
         $str .= "      {\n";
         $str .= "         numFields = $num_fields;\n";

	 $str .= "         wordArray = goldenConn->nextCard();\n";
         $str .= "         if( !wordArray )\n";
         $str .= "         {\n";
         $str .= "            numFields = 0;\n";
         getReturnCode($card, $str);
         $str .= "         }\n";




/*** add id to manager **/
	 if( $field_index != -1 )
	 {
	    $str .= "      if( Card::isFlagOn(SAVE_IDS) )\n";
	    $str .= "         addIDToFile(wordArray, $field_index, " . 
                 strtoupper($man_name) . ", impObj);\n";
	 }
	 else if( ($add_id_flag < 2) )// && !strcmp($base_class, "GetDBBase") )
	 {
	    $str .= "      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )\n";
	    $str .= "         addIDToFile(wordArray, 0, " .
		 strtoupper($grp) . ", impObj);\n";
            $add_id_flag++;
	 }               

	 if( $func_index != -1 )
	 {
	    $str .= "      if( Card::isFlagOn(SAVE_REFERENCES) )\n";
	    $str .= "         $find_func" . "(&wordArray[2], numFields, $func_index, impObj);\n";
	 }
	 else if( $findex )
	 {
	    $str .= "         if( Card::isFlagOn(SAVE_REFERENCES) )\n";
	    $str .= "            addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);\n";
	 }
/***** add to manager code **/









	 $str .= "         if( Card::isFlagOn(SAVE_CARDS_FIELDS) )\n";
	 $str .= "         {\n";

         $str .= "            char name_buf[64];\n";
         $str .= "            sprintf(name_buf,\"%s_%d\",\"$card_name\",loop_count);\n";
	 $str .= "            cardObj = new DBCard(name_buf);\n";
         $str .= "            ((DBCard *)cardObj)->index = atoi(wordArray[0]);\n";
	 $str .= "            cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);\n";

	 $str .= "            impObj->addCard(cardObj);\n";
	 $str .= "         }\n";
         $str .= "         impObj->cardCount++;\n";

         $str .= "      }\n";
      }
      else
      {
	 $str .= $str2;
	 $str .= "      wordArray = goldenConn->nextCard();\n";
         $str .= "      if( !wordArray )\n";
         $str .= "      {\n";
         $str .= "         numFields = 0;\n";
         getReturnCode($card, $str);
         $str .= "      }\n";





/*** add id to manager */
	 if( $field_index != -1 )
	 {
            $str .= "      if( Card::isFlagOn(SAVE_IDS) )\n";
	    $str .= "         addIDToFile(wordArray, $field_index, " .
		 strtoupper($man_name) . ", impObj);\n";
	 }               
         else if( ($add_id_flag < 2) )// && !strcmp($base_class, "GetDBBase") )
	 {
            $str .= "      if( Card::isFlagOn(SAVE_IDS) && !impObj->cardCount )\n";
	    $str .= "         addIDToFile(wordArray, 0, " .
		 strtoupper($grp) . ", impObj);\n";
            $add_id_flag++;
	 }               

	 if( $func_index != -1 )
	 {
            $str .= "      if( Card::isFlagOn(SAVE_REFERENCES) )\n";
	    $str .= "         $find_func" . "(&wordArray[2], numFields, $func_index, impObj);\n";
	 }
	 else if( $findex )
	 {
            $str .= "      if( Card::isFlagOn(SAVE_REFERENCES) )\n";
	    $str .= "         addIDToRefFile(&wordArray[2], num_indices, field_indices, man_types, kw_types, impObj);\n";
	 }
/***** add to manager code **/








	 //FORTHENEW
	 $gf_keys = array_keys($global_farray);
	 if( count($gf_keys) )
	 {
	    $global_card_array["$card_name"] = $global_farray;
	    foreach($gf_keys as $gf_key)
	    {
	       if( strstr($gf_key, "_return") )
		  continue;
	       $val_arr = explode("_", $global_farray["$gf_key"]);
	       $gf_idx = (int)$val_arr[1] + 2;
	       $str .= "      " . strtolower($gf_key) . " = 0;\n";
	       $str .= "      if( wordArray[$gf_idx] )\n";
	       switch($val_arr[0])
	       {
		  case 'int':
		     $str .= "         " . strtolower($gf_key) . " = atoi(wordArray[$gf_idx]);\n";
		  break;
		  case 'double':
		     $str .= "         " . strtolower($gf_key) . " = atof(wordArray[$gf_idx]);\n";
		  break;
		  case 'string':
		     $str .= "         " . strtolower($gf_key) . " = wordArray[$gf_idx];\n";
		  break;
	       }
	    }
	 }











	 $str .= "      if( Card::isFlagOn(SAVE_CARDS_FIELDS) )\n";
	 $str .= "      {\n";

         $str .= "         if( loop_count & (1<<31) )\n";
	 $str .= "            cardObj = new DBCard(\"" . $card_name . "\");\n";
         $str .= "         else\n";
         $str .= "         {\n";
         $str .= "            char name_buf[64];\n";
         $str .= "            sprintf(name_buf,\"%s_%d\",\"$card_name\",loop_count);\n";
	 $str .= "            cardObj = new DBCard(name_buf);\n";
         $str .= "         }\n";
         $str .= "         ((DBCard *)cardObj)->index = atoi(wordArray[0]);\n";
	 $str .= "         cardObj->addFields(numFields, field_types, field_widths, fields, &wordArray[2]);\n";

	 $str .= "         impObj->addCard(cardObj);\n";
	 $str .= "      }\n";
         $str .= "      impObj->cardCount++;\n";
      }

      $ret_var = $card['return'];

      if( $ret_var )
      {
         $ret_type = $card['returntype'];
         switch($ret_type)
         {
            case 'uint':
               //$str .= "      return cardObj->uintValue(\"$ret_var\");\n";
               $str .= "      if( wordArray[$ret_findex] )\n";
               $str .= "         return atoi(wordArray[$ret_findex]);\n";
               $str .= "      else\n";
               $str .= "         return 0;\n";
               break;
            case 'int':
               //$str .= "      return cardObj->intValue(\"$ret_var\");\n";
               $str .= "      if( wordArray[$ret_findex] )\n";
               $str .= "         return atoi(wordArray[$ret_findex]);\n";
               $str .= "      else\n";
               $str .= "         return 0;\n";
               break;
            case 'double':
               //$str .= "      return cardObj->doubleValue(\"$ret_var\");\n";
               $str .= "      if( wordArray[$ret_findex] )\n";
               $str .= "         return atof(wordArray[$ret_findex]);\n";
               $str .= "      else\n";
               $str .= "         return 0;\n";
               break;
            case 'string':
               //$str .= "      return cardObj->strValue(\"$ret_var\");\n";
               $str .= "      return wordArray[$ret_findex];\n";
               break;
            default:
               $str .= "      return;\n";
         }
      }
      
      $str .= "   }\n\n";
   }

   $str .= "/** Function to import all the cards of keyword *$kw_name\n";
   $str .= "  * from database */\n";
 
   $main_func = "   unsigned int import" . $class_name . "()\n";
   $main_func .= "   {\n";

   foreach ($xml->card as $card)
   {
      $ret_name = $card['name'] . "_return";

      if( isset($func_array["$ret_name"]) )
      {
	 $main_func .= "      " . $func_array["$ret_name"];
      }
   }

   //hardcoded for import base class
   if( $base_class && strcmp($base_class, "GetDBBase") )
   {
      $main_func .= "      import" . $base_class . "();\n";
   }

   $star_loop_funcs = array();
   foreach ($xml->condition as $condition)
   {
      foreach($condition->refcard as $refcard)
      {
         $ref_name = $refcard['name'];

/* FORTHENEW
	 $main_func .= "      cardObj = impObj->findCard(\"" . $ref_name . "\");\n";
         foreach ($refcard->reffield as $reffield)
         {
	    $ref_field = $reffield['name'];
	    $type = $reffield['type'];

	    switch((string)$type)
	    {
	       case 'uint':
	          $main_func .= "      unsigned int " . strtolower($ref_field) . " = 0;\n";
                  break;
	       case 'int':
		  $main_func .= "      int " . strtolower($ref_field) . " = 0;\n";
                  break;
	       case 'double':
		  $main_func .= "      double " . strtolower($ref_field) . " = 0.0;\n";
                  break;
	       case 'string':
		  $main_func .= "      char* " . strtolower($ref_field) . " = NULL;\n";
                  break;
            }
         }

	 $main_func .= "      if( cardObj )\n";
	 $main_func .= "      {\n";

         foreach ($refcard->reffield as $reffield)
         {
	    $ref_field = $reffield['name'];
	    $type = $reffield['type'];

	    switch((string)$type)
	    {
	       case 'uint':
		  $main_func .= "         " . strtolower($ref_field) . " = cardObj->uintValue(\"" . $ref_field . "\");\n";
		  break;
	       case 'int':
		  $main_func .= "         " . strtolower($ref_field) . " = cardObj->intValue(\"" . $ref_field . "\");\n";
		  break;
	       case 'double':
		  $main_func .= "         " . strtolower($ref_field) . " = cardObj->doubleValue(\"" . $ref_field . "\");\n";
		  break;
	       case 'string':
		  $main_func .= "         " . strtolower($ref_field) . " = cardObj->stringValue(\"" . $ref_field . "\");\n";
		  break;
	    }
         }

	 $main_func .= "      }\n\n";
*/
      }

      $statement = $condition['statement'];
      $starloop = $condition['starloop'];

      if( $statement )
      {
	 //$main_func .= "      $statement\n";
         $state_strs = explode('\n', $statement);
         foreach ($state_strs as $state_str)
         {
	    $main_func .= "      $state_str\n";
         }
	 $main_func .= "      {\n";

         $loop = $condition->loop;
         if( $loop )
         {
            $start = $loop['start'];
            $end = $loop['end'];
            $main_func .= "         for(int i = $start; i < $end; i++)\n";
            $main_func .= "         {\n";
	    foreach ($condition->card as $con_card)
	    {
	       $crdname = $con_card['name'];
	       $crd_state = $con_card['statement'];

	       if( isset($func_array["$crdname"]) )
	       {
                  if( !$crd_state )
                  {
		     $main_func .= "         " . $func_array["$crdname"];
		     //$func_array["$crdname"] = null;
                  }
                  else
                  {
                     $main_func .= "            " . $crd_state . "\n";
                     $main_func .= "            {\n";
		     $main_func .= "            " . $func_array["$crdname"];
                     $main_func .= "            }\n";
                  }
	       }
	    }
            $main_func .= "         }\n";
         }
         else
         {
	    foreach ($condition->card as $con_card)
	    {
	       $crdname = $con_card['name'];
	       $crd_state = $con_card['statement'];

	       if( isset($func_array["$crdname"]) )
	       {
                  if( !$crd_state )
                  {
		     $main_func .= "      " . $func_array["$crdname"];
		     //$func_array["$crdname"] = null;
                  }
                  else
                  {
                     $main_func .= "         " . $crd_state . "\n";
                     $main_func .= "         {\n";
		     $main_func .= "         " . $func_array["$crdname"];
                     $main_func .= "         }\n";
                  }
	       }
	    }
         }

	 $main_func .= "      }\n";
      }
      else if( !strcmp($starloop, 'yes') )
      {
         $main_func .= "      unsigned int loop_count = 0;\n";
	 foreach ($condition->card as $con_card)
	 {
	    $crdname = $con_card['name'];
	    $crd_state = $con_card['statement'];

	    if( isset($func_array["$crdname"]) )
	    {
               if( !$crd_state )
               {
	          $main_func .= "   " . $func_array["$crdname"];
               }
	       else
	       {
		  $main_func .= "      " . $crd_state . "\n";
		  $main_func .= "      {\n";
		  $main_func .= "      " . $func_array["$crdname"];
		  $main_func .= "      }\n";
	       }
               $star_loop_funcs["$crdname"] = $func_array["$crdname"];
	    }
	 }
         $main_func .= "      loop_count++;\n";

	 $main_func .= "      while(numFields)\n";
	 $main_func .= "      {\n";
	 foreach ($condition->card as $con_card)
	 {
	    $crdname = $con_card['name'];
	    $crd_state = $con_card['statement'];

	    if( isset($func_array["$crdname"]) )
	    {
               if( !$crd_state )
               {
	          $main_func .= "      " . $func_array["$crdname"];
               }
	       else
	       {
		  $main_func .= "         " . $crd_state . "\n";
		  $main_func .= "         {\n";
		  $main_func .= "         " . $func_array["$crdname"];
		  $main_func .= "         }\n";
	       }
	    }
	 }
         $main_func .= "         loop_count++;\n";
	 $main_func .= "      }\n";
	 $main_func .= "      ((ExportObject *)impObj)->loopCount = loop_count-1;\n";
      }
      else
      {
         $loop = $condition->loop;
         if( $loop )
         {
            $start = $loop['start'];
            $end = $loop['end'];
            $main_func .= "      for(int i = $start; i < $end; i++)\n";
            $main_func .= "      {\n";
	    foreach ($condition->card as $con_card)
	    {
	       $crdname = $con_card['name'];
	       $crd_state = $con_card['statement'];

	       if( isset($func_array["$crdname"]) )
	       {
		  if( !$crd_state )
		  {
		     $main_func .= "      " . $func_array["$crdname"];
		     //$func_array["$crdname"] = null;
                  }
		  else
		  {
		     $main_func .= "         " . $crd_state . "\n";
		     $main_func .= "         {\n";
		     $main_func .= "         " . $func_array["$crdname"];
		     $main_func .= "         }\n";
		  }
	       }
	    }
            $main_func .= "      }\n";
         }
         else
         {
	    foreach ($condition->card as $con_card)
	    {
	       $crdname = $con_card['name'];
	       $crd_state = $con_card['statement'];

	       if( isset($func_array["$crdname"]) )
	       {
		  if( !$crd_state )
		  {
		     $main_func .= "   " . $func_array["$crdname"];
		     //$func_array["$crdname"] = null;
                  }
		  else
		  {
		     $main_func .= "      " . $crd_state . "\n";
		     $main_func .= "      {\n";
		     $main_func .= "      " . $func_array["$crdname"];
		     $main_func .= "      }\n";
		  }
	       }
	    }
         }
      }
   }

   //adding the star loop count to the function to change the card name
   foreach($star_loop_funcs as $loop_func)
   {
      $len = strlen($loop_func);
      $rep = substr($loop_func, 0, $len-3);
//echo "$rep" . "\n";
      $replace_loop_str = $rep . "loop_count);\n";
      $main_func = str_replace($loop_func, $replace_loop_str, $main_func);
   }

   $main_func .= "      return 0;\n";
   $main_func .= "   }\n";

   $str .= $main_func;






   //FORTHENEW
   $gf_ckeys = array_keys($global_card_array);
   if( count($gf_ckeys) )
   {
      $str .= "public:\n";
      foreach($gf_ckeys as $gf_ckey)
      {
	 $global_farray = $global_card_array["$gf_ckey"];
	 $gf_keys = array_keys($global_farray);
	 if( count($gf_keys) )
	 {
	    foreach($gf_keys as $gf_key)
	    {
               $val_arr = explode("_", $global_farray["$gf_key"]);
	       $str .= "   " . $val_arr[0] . " " . strtolower($gf_key) . ";\n";
	    }
	 }
      }
   }




   $str .= "};\n\n";
   
   $str .= "#endif\n\n";

   $file_name = strtolower($class_name) . '.h';
   $file_ptr = fopen($file_name, 'w');
   fwrite($file_ptr, $str);
   fclose($file_ptr);
   $str = "";

   $flag = $xml['cppfile'];

   //if( $base_class || !strcmp($flag, "yes") )
   if( !$flag || !strcmp($flag, "yes") )
   {
      writeHPAndCPPFile($class_name);
   }
}
else
{
   exit("Failed to open $argv[1]\n");
}

function writeHPAndCPPFile(&$class_name)
{
   $file_name = strtolower($class_name) . '.hpp';
   $file_ptr = fopen($file_name, 'w');
   $str = "";
  
   $str .= "#ifndef _" . strtoupper($class_name) . "_HPP_\n";
   $str .= "#define _" . strtoupper($class_name) . "_HPP_\n\n";

   $str .= "#include \"goldenconn.h\"\n";
   $str .= "#include \"dbcard.h\"\n\n";

   $str .= "unsigned int import" . $class_name . "(GoldenConn *gold_conn, ImportObject *imp_obj);\n\n";

   $str .= "#endif\n\n";
    
   fwrite($file_ptr, $str);
   fclose($file_ptr);

   $str = "";
   $str .= "#include \"" . strtolower($class_name) . ".h\"\n";
   $str .= "#include \"" . strtolower($class_name) . ".hpp\"\n\n";

   $str .= "unsigned int import" . $class_name . "(GoldenConn *gold_conn, ImportObject *imp_obj)\n";
   $str .= "{\n";
   $str .= "   $class_name " . strtolower($class_name) . "(gold_conn, imp_obj);\n\n";
   $str .= "   return " . strtolower($class_name) . ".import" . $class_name . "();\n";
   $str .= "}\n\n";
   $file_name = strtolower($class_name) . '.cpp';
   $file_ptr = fopen($file_name, 'w');

   fwrite($file_ptr, $str);
   fclose($file_ptr);
   $str = "";
}

function getReturnCode(&$card, &$str)
{
   $ret_var = $card['return'];

   if( $ret_var )
   {
      $ret_type = $card['returntype'];
      switch($ret_type)
      {
	 case 'uint':
	    $str .= "         return 0;\n";
	    break;
	 case 'int':
	    $str .= "         return 0;\n";
	    break;
	 case 'double':
	    $str .= "         return 0.0;\n";
	    break;
	 case 'string':
	    $str .= "         return NULL;\n";
	    break;
	 default:
	    $str .= "         return;\n";
      }
   }
   else
      $str .= "         return;\n";
}
function getGroupNameFromKW(&$kw)
{
   if( !strncmp($kw, "AIR", 3) )
      return "AIRBAG";
   else if( !strncmp($kw, "CONST", 5) )
      return "CONST";
   else if( !strncmp($kw, "SET_", 4) )
      return "SET";
   else if( !strncmp($kw, "SEC", 3) )
      return "SECTION";
   else if( !strncmp($kw, "DEFINE_", 7) )
      return "DEFINE";
   else if( !strncmp($kw, "EOS", 3) )
      return "EOS";
   else if( !strncmp($kw, "HOUR", 4) )
      return "HG";
   else if( !strncmp($kw, "MAT_", 4) )
      return "MAT";
   else if( !strncmp($kw, "PART", 4) )
      return "PARTC";
   else if( !strncmp($kw, "ELEMENT_", 8) )
      return "ELEMENT";
   else if( !strncmp($kw, "NODE", 4) )
      return "NOD";
   else if( !strncmp($kw, "DAMP", 4) )
      return "DAMPING";
   else if( !strncmp($kw, "COMP", 4) )
      return "COMP";
   else if( !strncmp($kw, "EF", 2) )
      return "EF";
   else if( !strncmp($kw, "PARA", 4) )
      return "PARAM";
   else if( !strncmp($kw, "DEFORM", 6) )
      return "DEFORM";
   else if( !strncmp($kw, "SENS", 4) )
      return "SENSOR";
   else if( !strncmp($kw, "INTER", 5) )
      return "INTERFACE";
   else if( !strncmp($kw, "INTEG", 5) )
      return "INTEGRATION";
   else if( !strncmp($kw, "CONTROL", 7) )
      return "CONTROL";
   else if( !strncmp($kw, "RIG", 3) )
      return "RIGIDWALL";
   else if( !strncmp($kw, "CONTACT", 7) )
      return "CONTACT";
   else if( !strncmp($kw, "INC", 3) )
      return "INC";
   else if( !strncmp($kw, "DATA", 4) )
      return "DATABASE";
   else if( !strncmp($kw, "INIT", 4) )
      return "INITIAL";
   else if( !strncmp($kw, "LOAD", 4) )
      return "LOAD";
   else if( !strncmp($kw, "BOUND", 5) )
      return "BDRY";
   else if( !strncmp($kw, "ALE", 3) )
      return "ALE";
   else if( !strncmp($kw, "RAIL", 4) )
      return "RAIL";
   else if( !strncmp($kw, "TERM", 4) )
      return "TERM";
   else if( !strncmp($kw, "USER", 4) )
      return "USER";
   else if( !strncmp($kw, "PERT", 4) )
      return "PERTURB";
   else if( !strncmp($kw, "KEYWORD", 7) )
      return "KW";
   else
      return "";
}
?>
