#include "elementdetails.h"

ElementDetails::ElementDetails() : idFileDes(-1), idFileSize(0), idBasePtr(NULL)
{
}

ElementDetails::~ElementDetails()
{
   if( idBasePtr )
      munmap(idBasePtr, idFileSize);
   if( idFileDes >= 0 )
      close(idFileDes);
}
   
/** This function opens up the file element.ids. The element.ids file has the
  * information of card_index in the database, the id of that element and the
  * part id of that element.
  */
int ElementDetails::openFile(const char *dir, const char *model)
{
   char buf[256];
   struct stat        statbuf;

   sprintf(buf, "%s/%s/element.ids", dir, model);
   idFileDes = open(buf, O_RDONLY);

   if( idFileDes < 0 )
   {
      cout << "Unable to open element.ids file in readelements.cpp\n";
      return 1;
   }

   if( fstat(idFileDes, &statbuf) < 0 )
   {
      cout << "Unable to stat element.ids\n";
      return 2;
   }

   idFileSize = statbuf.st_size;

   idBasePtr = (unsigned int *)mmap(0, statbuf.st_size, PROT_READ, 
			  MAP_SHARED, idFileDes, 0);
   if( !idBasePtr )
   {
      cout << "MMAP error for file " << buf << endl;
      return 3;
   }

   return 0;
}

/** This function creates a map between the element id and the index of the
  * element in the PartElementStr. The index is useful while selecting the
  * element of particular id. Because based on just element id, we cannot pick
  * or select the element. element ids are different from the element indices
  * in a part. So this function fills that mapping information only for given u
  * parts.
  */
void ElementDetails::fill(PartInfoPtr parts_list, UIUIMap *pid_map, vector<unsigned int> *pid_list)
{
   //here 3 means elm_card_index,elm_id,pid
   unsigned int total_elms = idFileSize/(sizeof(int) * 3);
   unsigned int *ptr, i, pid;
   vector<unsigned int>::iterator b = pid_list->begin(), e = pid_list->end();
   UIUIIter ep = pid_map->end(), iter;
   UIUIMap *eid_map;
   for(; b != e; b++)
   {
      pid = *b;
      iter = pid_map->find(pid);
      if( iter != ep )
      {
	 parts_list[iter->second].partElements.eidMap = new UIUIMap;
         ptr = idBasePtr;
         eid_map = parts_list[iter->second].partElements.eidMap;
	 for(i = 0; i < total_elms;i++, ptr += 3)
	 {
	    if( pid == (*(ptr+2)) ) 
	    {
      //cout << "PID=" << part_info->partID << " ELM=" << *(ptr+1) << endl;
	       //elm_ids[j] = *(ptr+1);
	       eid_map->insert(UIUIPair(*(ptr+1), eid_map->size()));
	    }
	 }
      }
   }

//cout << "NUM ELMS=" << num_elms << " CHECK=" << j << endl;
}

