#ifndef _ELEMENT_DETAILS_H_
#define _ELEMENT_DETAILS_H_

#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <sys/mman.h>
#include <map>
#include <vector>
#include <iostream>
#include <unistd.h>
#include "partstr.h"

using namespace std;

/** Class for loading the details of elements from the binary files */
class ElementDetails
{
public:
   ElementDetails();
   ~ElementDetails();
   
/** This function opens up the file element.ids. The element.ids file has the
  * information of card_index in the database, the id of that element and the
  * part id of that element.
  * \param dir Name of the directory from which the model is to be loaded
  * \param model Name of the model
  */
   int openFile(const char *dir, const char *model);

/** This function creates a map between the element id and the index of the
  * element in the PartElementStr. The index is useful while selecting the
  * element of particular id. Because based on just element id, we cannot pick
  * or select the element. element ids are different from the element indices
  * in a part. So this function fills that mapping information only for given
  * parts.
  * \param parts_list Pointer to the list of parts information. The elements and
  * nodes information is stored this list pointer
  * \param pid_map Map between the part id and its index
  * \param pid_list List of part ids for which the information has to be loaded
  */
   void fill(PartInfoPtr parts_list, UIUIMap *pid_map, vector<unsigned int> *pid_list);

private:
   int idFileDes;
   unsigned int idFileSize, *idBasePtr;
};

#endif

