#include "getids.h"
#include "filelist.h"
#include "kwtypefromid.h"
#include "kwgroup.h"

GetIDS::GetIDS(const char *dir, const char *model, const char *ent_name)
 : dirName(dir),modelName(model),entName(ent_name),fileDes(-1),basePtr(NULL)
{
}

GetIDS::~GetIDS()
{
   if( basePtr )
      munmap(basePtr, fileSize);
       
   if( fileDes >= 0 )
      close(fileDes);
}

int GetIDS::openFile()
{
   char               buf[256];
   struct stat        statbuf;

   sprintf(buf, "%s/%s/%s_display.bin", dirName, modelName, entName);
   fileDes = open(buf, O_RDONLY);

   if( fileDes < 0 )
   {
      cout << "Unable to open file for reading in getids.h " << buf << endl;
      return 1;
   }

   if( fstat(fileDes, &statbuf) < 0 )
   {
      cout << "Unable to stat file " << buf << endl;
      return 2;
   }
 
   fileSize = statbuf.st_size;

   basePtr = (unsigned int *)mmap(0, fileSize, PROT_READ,
			  MAP_SHARED, fileDes, 0);
   if( !basePtr )
   {
      cout << "MMAP error for file " << buf << endl;
      return 3;
   }

   if( !(*basePtr) )
   {
      cout << "No objects in " << buf << endl;
      munmap(basePtr, fileSize);
      close(fileDes);
      fileDes = -1;
      basePtr = NULL;
      return 4;
   }

   return 0;
}

/** This function is useful for getting the object ids from the object indices.
  * The *_display.bin file contains the reference ids. That means, the set
  * object contains node ids or element ids or part ids. The airbag contains
  * set id and load curve ids. So the _display.bin file contains
  * kw_type | kw | id sequentially for all referred objects for a particular
  * type of object
  */
int GetIDS::fetch
    (
       vector<unsigned int> *idx_list,
       vector<unsigned int> *id_list
    )
{
   if( openFile() )
      return 0;

   unsigned int *ptr = basePtr;
   unsigned int i, j, k, idx, num_strs = 0, num_obj = *ptr;

cout << "NUM OBJS=" << num_obj << endl;
   for(i = 0; i < idx_list->size(); i++)
   {
      idx = (*idx_list)[i];
      if( idx >= num_obj )
      {
         cout << "Index out of bounds in getids.cpp\n";
         continue;
      }
//cout << "IDX in getids.cpp=" << idx << endl;
      ptr = basePtr;
      for(j = 0; j < num_obj; j++)
      {
         ptr++; //move past the number of objects
         num_strs = *ptr; //number of KWTypeIDStr structures
         if( j == idx )
         {
//cout << "NUM IDS=" << num_strs << endl;
            for(k = 0; k < num_strs; k++)
            {
               ptr += 3; //there are 3 ints in KWTypeIDStr
               id_list->push_back(*ptr);
            }
            break;
         }
         else
         {
            ptr += (*ptr * 3); //there are 3 ints in KWTypeIDStr
         }
      }
   }

   munmap(basePtr, fileSize);
   close(fileDes);
   fileDes = -1;
   basePtr = NULL;

   return id_list->size();
}

/** This function is useful for getting the object ids from the object indices.
  * The *_display.bin file contains the reference ids. That means, the set
  * object contains node ids or element ids or part ids. The airbag contains
  * set id and load curve ids. So the _display.bin file contains
  * kw_type | kw | id sequentially for all referred objects for a particular
  * type of object. 
  * num. of objects | repeat(num. of references | repeat (kw_type | kw | id))
  * ex. num_airbags | repeat(num of ref | repeat(kw_type|kw|id))
  * ex. 2 | 3 | (SET | SET_NODE_LIST | 1234) | (DEFINE | DEFINE_CURVE | 2345) |
                (DEFINE | DEFINE_VECTOR | 345) | 1 (SET | SET_BEAM_LIST | 456)
  * the references can be set, load curve, vector etc
  */
int GetIDS::fetchObjects
    (
       vector<unsigned int> *idx_list,
       KWTypeIDStr **obj_list
    )
{
   if( openFile() )
      return 0; 
   
   unsigned int *ptr = basePtr;
   unsigned int i, j, idx, num_strs = 0, num_obj = *ptr, total_obj = 0;

cout << "NUM OBJS=" << num_obj << endl;
   for(i = 0; i < idx_list->size(); i++)
   {
      idx = (*idx_list)[i];
      if( idx >= num_obj )
      {
         cout << "Index out of bounds in getids.cpp\n";
         continue;
      }
//cout << "IDX in getids=" << idx << endl;
      ptr = basePtr;
//cout << "TOTAL = " << *ptr << endl;
      for(j = 0; j < num_obj; j++)
      {
         ptr++; //move past the number of objects
         num_strs = *ptr; //number of KWTypeIDStr structures
//cout << "j=" << j << "NUM IDS=" << num_strs << endl;
         if( j == idx && num_strs )
         {
            if( total_obj )
               *obj_list = (KWTypeIDStr *)realloc(*obj_list,
                              sizeof(KWTypeIDStr) * (num_strs + total_obj));
            else
              *obj_list = (KWTypeIDStr *)malloc(sizeof(KWTypeIDStr) * num_strs);
            ptr++;
            memcpy(&(*obj_list)[total_obj],ptr,sizeof(KWTypeIDStr) * num_strs);
            total_obj += num_strs;
            break;
         }
         else
         {
            ptr += (num_strs * 3);
         }
      }
   }

   munmap(basePtr, fileSize);
   close(fileDes);
   fileDes = -1;
   basePtr = NULL;

   unsigned int kw_type;
   string grp_name;
   KWTypeFromID type_id; 
   for(i = 0; i < total_obj; i++)
   {
      KWGroup::nameFromType((*obj_list)[i].kwShort, grp_name); 
      if( type_id.createMap(dirName, modelName, grp_name.data()) )
         continue;
      kw_type = type_id.get((*obj_list)[i].id);
      if( !(kw_type & (UNSIGNED_INT_MAX_FLAG)) )
         (*obj_list)[i].kwType = kw_type;
   }

   return total_obj;
}

/** Gets the element indices from the nodes. this is used in set segment. Each
  * segment has nodes but elements have to be selected.
  * VIP: this function is not useful as the segments have solid faces also and
  * drawing of segments should be separate like shells
  */
int GetIDS::eisFromNodes
    (
       UIUIMap *pid_map,
       list<unsigned int> & nid_list,
       vector<unsigned int> & ei_list,
       vector<unsigned int> & pi_list
    )
{
   char buf[256];
   sprintf(buf, "%s/%s", dirName, modelName);
   vector<const char *> file_list;
   // gets all the files with *_pid_* in the model directory
   FileList flist(buf, "shell");
   unsigned int n = flist.getNames(&file_list);
   if( n <= 0 )
      return 0;
cout << "NUM FILES in GetIDS=" << n << endl;

   char *us_ptr, type[32], *dot_ptr;
   unsigned int *base, i, j, num_indices, *ptr, pid, npe = 4, k, 
                n1, n2, n3, pid_idx;
   int fd;
   struct stat statbuf;
   list<unsigned int>::iterator b = nid_list.begin(), 
                                e = nid_list.end(), iter, iter1;
   UIUIIter pid_iter, pid_begin = pid_map->begin(), pid_end = pid_map->end();
   for(i = 0; i < n; i++)
   {
      if( !nid_list.size() )
         break;

      if( !strstr(file_list[i], "_pid_") )
         continue;

      switch(file_list[i][5])
      {
         case '4':
            npe = 4;
         break;
         case '6':
            npe = 6;
         break;
         case '8':
            npe = 8;
         break;
      }

      //getting the pid from the file name
      us_ptr = strrchr((char *)file_list[i], '_');
      us_ptr++;
      strcpy(type, us_ptr);
      dot_ptr = strrchr(type, '.');
      *dot_ptr = '\0';
      pid = atoi(us_ptr);
      pid_iter = pid_map->find(pid);
      if( pid_iter != pid_end )
         pid_idx = distance(pid_begin, pid_iter);
      else
         continue;

//cout << "PID in NODE DETAILS=" << pid << endl;

      sprintf(buf, "%s/%s/%s", dirName, modelName, file_list[i]);
      fd = open(buf, O_RDONLY);
      if( fd < 0 )
      {
	 cout << "Unable to open file " << file_list[i] << " in GetIDS\n";
	 continue;
      }

      if( fstat(fd, &statbuf) < 0 )
      {
	 cout << "Unable to stat file in GetIDS\n";
         close(fd);
	 continue;
      }

      base = (unsigned int *)mmap(0, statbuf.st_size, PROT_READ, 
			     MAP_SHARED, fd, 0);
      if( !base )
      {
	 cout << "MMAP error for file " << buf << endl;
         close(fd);
	 continue;
      }

      ptr = base;
      num_indices = statbuf.st_size/(sizeof(int));

      iter = b;
      for(;iter != e;)
      {
         n1 = *iter++;
         n2 = *iter++;
         n3 = *iter++;
         iter++;
	 for(j = 0, k = 0; j < num_indices; j += npe, k++)
	 {
            if(n1 == *(ptr+j) && n2 == *(ptr+j+1) && n3 == *(ptr+j+2))
            {
               iter1 = iter;
               advance(iter1, 4);
               nid_list.erase(iter, iter1);
               iter--;
               ei_list.push_back(k);
               pi_list.push_back(pid_idx);
            }
	 }
      }
   }

   return ei_list.size();
}

