#ifndef _GETIDS_H_
#define _GETIDS_H_

#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <sys/mman.h>
#include <map>
#include <vector>
#include <list>
#include <iostream>
#include "maptypes.h"
#include "datatypeobj.h"
#include "card.h"

#define UNSIGNED_INT_MAX_FLAG (((unsigned int)1)<<31)

using namespace std;

/** Class name for building the map between the card index and entity id
  */
class GetIDS
{
public:
   /** Constructor for creating this object
     * \param dir Name of the directory
     * \param model Name of the model
     * \param ent_name Name of the group for which map has to be loaded like
     * airbag, element
     */
   GetIDS(const char *dir, const char *model, const char *ent_name);

   ~GetIDS();

   /** Opens the file for writing */
   int openFile();

/** This function is useful for getting the object ids from the object indices.
  * The *_display.bin file contains the reference ids. That means, the set
  * object contains node ids or element ids or part ids. The airbag contains
  * set id and load curve ids. So the _display.bin file contains
  * kw_type | kw | id sequentially for all referred objects for a particular
  * type of object
  * \param idx_list List of card indices for which is the information is to be
  * filled
  * \param id_list List of object ids to be filled
  */
   int fetch(vector<unsigned int> *idx_list, vector<unsigned int> *id_list);

/** This function is useful for getting the object ids from the object indices.
  * The *_display.bin file contains the reference ids. That means, the set
  * object contains node ids or element ids or part ids. The airbag contains
  * set id and load curve ids. So the _display.bin file contains
  * kw_type | kw | id sequentially for all referred objects for a particular
  * type of object. 
  * num. of objects | repeat(num. of references | repeat (kw_type | kw | id))
  * ex. num_airbags | repeat(num of ref | repeat(kw_type|kw|id))
  * ex. 2 | 3 | (SET | SET_NODE_LIST | 1234) | (DEFINE | DEFINE_CURVE | 2345) |
  *             (DEFINE | DEFINE_VECTOR | 345) | 1 (SET | SET_BEAM_LIST | 456)
  * the references can be set, load curve, vector etc
  * \param idx_list List of indices for which the details are required
  * \param obj_list List of objects information
  */
   int fetchObjects
       (
	  vector<unsigned int> *idx_list,
	  KWTypeIDStr **obj_list
       );

/** Gets the element indices from the nodes. this is used in set segment. Each
  * segment has nodes but elements have to be selected.
  * VIP: this function is not useful as the segments have solid faces also and
  * drawing of segments should be separate like shells
  */
   int eisFromNodes
       (
          UIUIMap *pid_map,
	  list<unsigned int> & nid_list,
	  vector<unsigned int> & ei_list,
	  vector<unsigned int> & pid_list
       );

private:
   const char *dirName, *modelName, *entName;
   int   fileDes, fileSize;
   unsigned int   *basePtr;
};

#endif

