#include "getindices.h"

GetIndices::GetIndices()
{
}

GetIndices::~GetIndices()
{
   if( fileDes >= 0 )
      close(fileDes);

   indexMap.clear();
   elmMap.clear();
}

/** This function opens up the .ids file and creates a map between the card
  index from the database and the object id. If card index is given it brings
  the id of the object. But for elements, if card index is given, if brings
  the pid and eid of the element.
  */
int GetIndices::openFile
    (
       const char *dir,
       const char *model,
       const char *ent_name
    )
{
   char               buf[256];
   unsigned int       *base;
   struct stat        statbuf;

   sprintf(buf, "%s/%s/%s.ids", dir, model, ent_name);
   fileDes = open(buf, O_RDONLY);

   if( fileDes < 0 )
   {
      cout << "Unable to open file for reading in getindices.h " << buf << endl;
      return 1;
   }

   if( fstat(fileDes, &statbuf) < 0 )
   {
      cout << "Unable to stat file " << buf << endl;
      return 2;
   }

   base = (unsigned int *)mmap(0, statbuf.st_size, PROT_READ,
			  MAP_SHARED, fileDes, 0);
   if( !base )
   {
      cout << "MMAP error for file " << buf << endl;
      return 3;
   }

   unsigned int *ptr = base;
   if( strcmp(ent_name, "element") )
   {
      //here 3 means card_idx,id,kw_type
      unsigned int num_indices = statbuf.st_size/(sizeof(int) * 3), i;
      indexMap.clear();
      //index of the imp_obj is stored here
      if( !strcmp(ent_name, "node") || !strcmp(ent_name, "part") )
      {
         //id of object is stored here
	 for(i = 0; i < num_indices; i++, ptr += 3)
	 {
      //cout << "IDX=" << *ptr << " ID=" << *(ptr+1) << endl;
	    indexMap.insert(UIUIPair(*ptr, *(ptr+1)));
	 }
      }
      else //for set, airbag, constr, contact etc	
      {
	 for(i = 0; i < num_indices; i++, ptr += 3)
	    indexMap.insert(UIUIPair(*ptr, i));
      }
      bIter = indexMap.begin(); eIter = indexMap.end();
   }
   else
   {
      //here 3 means card_idx,id,pid
      unsigned int num_indices = statbuf.st_size/(sizeof(int) * 3), i;
      elmMap.clear();
      for(i = 0; i < num_indices; i++, ptr += 3)
      {
   //cout << "IDX=" << *ptr << " ID=" << *(ptr+1) << endl;
         PidEidStr id_pid;
         id_pid.eid = *(ptr+1);
         id_pid.pid = *(ptr+2);
	 elmMap.insert(IDPIDPair(*ptr, id_pid));
      }

      eb = elmMap.begin(); ee = elmMap.end();
   }

   munmap(base, statbuf.st_size);
   close(fileDes);
   fileDes = -1;

   return 0;
}

void GetIndices::findElmID(unsigned int *cidx_id_pid)
{
   eiter = elmMap.find(*cidx_id_pid);
   if( eiter != ee )
   {
      cidx_id_pid[1] = eiter->second.eid;
      cidx_id_pid[2] = eiter->second.pid;
   }
   else
   {
      if( *cidx_id_pid != 0 )
cout << "Element index=" << *cidx_id_pid << " not found\n";
      cidx_id_pid[1] = cidx_id_pid[2] = (UNSIGNED_INT_MAX_FLAG);
   }
}

