#ifndef _GET_INDICES_H_
#define _GET_INDICES_H_

#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <sys/mman.h>
#include <map>
#include <iostream>
#include <unistd.h>
#include "maptypes.h"

#define UNSIGNED_INT_MAX_FLAG (((unsigned int)1)<<31)

using namespace std;

/** Class for building and searching the information pertaining to object ids
  * and card indices in the database
  */
class GetIndices
{
public:
   GetIndices();

   ~GetIndices();

/** This function opens up the .ids file and creates a map between the card
  * index from the database and the object id. If card index is given it brings
  * the id of the object. But for elements, if card index is given, if brings
  * the pid and eid of the element.
  * \param dir Name of the directory from which the .ids file to be loaded
  * \param model Name of the model
  * \param ent_name Name of the group like airbag, element etc
  */
   int openFile
       (
	  const char *dir,
	  const char *model,
	  const char *ent_name
       );

   /** This function finds the object id from the card index
     * \param card_index Index of the card in database
     * \return ID of the object if found else (1<<31)
     */
   inline unsigned int findIndex(unsigned int card_index)
   {
      iter = indexMap.find(card_index);

      if( iter != eIter )
         return iter->second;
      else
         return (1<<31);
   }

   /** This function finds the object id from the card index
     * \param card_index Index of the card in database
     * \return ID of the object if found else (1<<31)
     */
   inline unsigned int findID(unsigned int card_index)
   {
      iter = indexMap.find(card_index);

      if( iter != eIter )
         return iter->second;
      else
         return (1<<31);
   }

   /** This function finds the element id and part id from the card index
     * \param cidx_id_pid Pointer to a 3 size array having the card index.
     * The element and part ids are filled in 2nd and 3rd locations if found else
     * (1<<31) value
     */
   void findElmID(unsigned int *cidx_id_pid);

private:
   int     fileDes;
   /** A map between the card index and id of the object */
   UIUIMap indexMap;
   /** map interators for traversing the map */
   UIUIIter bIter, eIter, iter;
   /** This map stores the information of card index, object id and part id */
   IDPIDMap elmMap;
   IDPIDIter eb, ee, eiter;
};

#endif

