#include "nodedetails.h"
#include "filelist.h"

NodeDetails::NodeDetails(const char *dir, const char *model) : 
   dirName(dir), modelName(model), idFileDes(-1)
{
}

NodeDetails::~NodeDetails()
{
   if( idFileDes >= 0 )
      close(idFileDes);
}
   
/* When nodes have to be selected based on id, we can do this by two methods
  * 1. select the node owned part and also the node. 2. Only select the node.
  * for the first method we need the part id also. So this function fills the
  * unique node id list and their indices for each part. When we need to
  * select a node based on id, the id is searched in each part. if found the 
  * part and the node both are shown.
  */
int NodeDetails::fill(PartInfoPtr parts_info, UIUIMap *pid_map)
{
   char buf[256];
   sprintf(buf, "%s/%s", dirName, modelName);
   vector<const char *> file_list;
   // gets all the files with *_pid_* in the model directory
   FileList flist(buf, "_pid_");
   unsigned int n = flist.getNames(&file_list);
   if( n <= 0 )
      return 0;
cout << "NUM FILES in NODEDETAILS=" << n << endl;

   char *us_ptr, type[32], *dot_ptr;
   unsigned int *base, i, j, num_indices, *ptr, num_parts = 0, pid;
   int fd;
   struct stat statbuf;
   UIUIIter b = pid_map->begin(), e = pid_map->end(), iter;

   for(i = 0; i < n; i++)
   {
      //getting the pid from the file name
      us_ptr = strrchr((char *)file_list[i], '_');
      us_ptr++;
      strcpy(type, us_ptr);
      dot_ptr = strrchr(type, '.');
      *dot_ptr = '\0';
      pid = atoi(us_ptr);

cout << "PID in NODE DETAILS=" << pid << endl;

      sprintf(buf, "%s/%s/%s", dirName, modelName, file_list[i]);
      fd = open(buf, O_RDONLY);
      if( fd < 0 )
      {
	 cout << "Unable to open file " << file_list[i] << " in nodedetails\n";
	 continue;
      }

      if( fstat(fd, &statbuf) < 0 )
      {
	 cout << "Unable to stat file in nodedetails\n";
         close(fd);
	 continue;
      }

      base = (unsigned int *)mmap(0, statbuf.st_size, PROT_READ, 
			     MAP_SHARED, fd, 0);
      if( !base )
      {
	 cout << "MMAP error for file " << buf << endl;
         close(fd);
	 continue;
      }

      ptr = base;
      num_indices = statbuf.st_size/(sizeof(int));


      iter = pid_map->find(pid);
      if( iter != e )
      {
         UIUIMap nid_map;
         UIUIIter b, e;
 
         //create unique node list and their indices
	 for(j = 0; j < num_indices; j++, ptr++)
            nid_map.insert(UIUIPair(*ptr, nid_map.size()));
cout << "NUM NODES=" << num_indices << " UNIQ=" << nid_map.size() << endl;

         parts_info[iter->second].partNodes.idList = 
                                           new unsigned int[nid_map.size()];
         unsigned int *id_list = parts_info[iter->second].partNodes.idList;
cout << "PID IDX=" << iter->second << " PID=" << pid << endl;
         b = nid_map.begin(); e = nid_map.end();
         for(; b != e; b++, id_list++)
            *id_list = b->first; 

         num_parts++;
      }
      else
      {
         cout << "PID not found in Node Details=" << pid << endl;
      }
     
      munmap(base, statbuf.st_size);
      close(fd);
   }

//cout << "NODE DETAILS PARTS=" << num_parts << endl;

   return num_parts;
}

