#ifndef _NODE_DETAILS_H_
#define _NODE_DETAILS_H_

#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <sys/mman.h>
#include <map>
#include <vector>
#include <iostream>
#include "partstr.h"

using namespace std;

/** When nodes have to be selected based on id, we can do this by two methods
  * 1. select the node owned part and also the node. 2. Only select the node.
  * for the first method we need the part id also. So this function fills the
  * unique node id list and their indices for each part. When we need to
  * select a node based on id, the id is searched in each part. if found the 
  * part and the node both are shown.
  */
class NodeDetails
{
public:
   /** Default constructor for creating this object. Both the directory and name
     * of the model are considered to get the files.
     * \param dir Name of the directory
     * \param model Name of the model
     */
   NodeDetails(const char *dir, const char *model); 

   ~NodeDetails();
   /** Fills the information required for searching the node
     * \param part_info Information of the part to which the details to be filled
     * \param pid_map Map between the part id and its index
     * \return Returns the number of parts for which the nodes information is
     * filled
     */
   int fill(PartInfoPtr part_info, UIUIMap *pid_map);

private:
   const char *dirName, *modelName;
   int idFileDes;
};

#endif

