#ifndef _MODEL_PARAMS_H_
#define _MODEL_PARAMS_H_

#include <map>
#include <string>

using namespace std;

typedef map<string, string> StrStrMap;
typedef map<string, string>::iterator StrStrIter;
typedef pair<string, string> StrStrPair;

/** Class for splitting the command line parameters as name-value pairs and
  * creates a map for them for searching
  */
class ModelParams
{
public:
   ModelParams()
   {
   }

   /** Constructor for inserting the arguments
     * \param argc pointer to number of arguments
     * \param argv array of strings of arguments
     */
   ModelParams(int *argc, char *argv[])
   {
      for(int i = 1; i < (*argc); i += 2)
      {
         insert(argv[i], argv[i+1]);
      }
   }

   ~ModelParams()
   {
      paramsList.clear();
   }

   /** Gets a parameter of integer type from its name
     * \param param_name Name of the parameter
     * \return Return the value of the integer parameter if found else -1
     */
   int getInt(char *param_name)
   {
      mpEnd = paramsList.end();
      mpIter = paramsList.find(param_name); 
      if( mpIter != mpEnd )
         return atoi((mpIter->second).data());
      
      return -1;
   }

   /** Gets a parameter of string type from its name
     * \param param_name Name of the parameter
     * \return Return the value of the string parameter else empty string
     */
   string & getString(char *param_name)
   {
      mpEnd = paramsList.end();
      mpIter = paramsList.find(param_name); 
      if( mpIter != mpEnd )
         return mpIter->second;
      
      return emptyStr;
   }
   
   /** Inserts name-value pair into the map
     * \param name Name of parameter
     * \param value Value of parameter
     */

   void insert(char *name, char *value)
   {
      paramsList.insert( StrStrPair(name, value) );
   }

public:
   /** Map holding the names and their values */
   StrStrMap   paramsList;
   /** pointers for traversing the above map */
   StrStrIter  mpEnd, mpIter;
   /** Empty string */
   string      emptyStr;
};

#endif

