#include "saveimg.h"
#include "savetopng.h"
#include "savetojpeg.h"
#include "saveimg.h"
#include <iostream>
#include <stdlib.h>
#include <GL/glx.h>

using namespace std;

unsigned int getNumComponents(int & type)
{
   switch( type )
   {
      case GL_RGBA: //applicable only to png type images
         return 4;
      case GL_RGB:
         return 3;
      case GL_LUMINANCE:
      case GL_ALPHA: //applicable only to png type images
         return 1;
      case GL_LUMINANCE_ALPHA: //applicable only to png type images
         return 2;
      default:
         return 4;
   }
}

unsigned char **getData
		(
		   int img_type,
		   unsigned int width, 
		   unsigned int height
		)
{
   int type = GL_RGBA;

   switch(img_type)
   {
      case IMG_JPEG:
         type = GL_RGB;
      break;
   }

   unsigned int num_components = getNumComponents(type);

cout << "NUM COMP=" << num_components << endl;

   unsigned int bit_size = width * height *
                     num_components * sizeof(unsigned char);

cout << "IMG SIZE=" << bit_size << endl;

   unsigned char *bits = new unsigned char[bit_size];
   if( !bits )
   {
      cout << "NO MEMORY" << endl;
      return NULL;
   }

   glReadPixels(0, 0, width, height, type, GL_UNSIGNED_BYTE, bits);

   unsigned char **data_rows = new unsigned char *[height];

   if( !data_rows )
   {
      cout << "OUT OF MEMORY" << endl;
      delete bits;
      return NULL;
   }

   unsigned int w = width * num_components, j, i;

   for(i = height-1, j = 0; i != -1 ; i--, j++)
   {
      data_rows[j] = new unsigned char[w+1];
      if(data_rows[j] == NULL)
      {
          cout << "MEMORY ALLOCATION ERROR:" << __FUNCTION__ << endl; 
          exit(0);
      }
      memcpy(data_rows[j], &bits[i*w], w);
      data_rows[j][w] = '\0';
   }

/*
   data_rows[j] = new unsigned char[w+1];
   memcpy(data_rows[j], &bits[i*w], w);
   data_rows[j][w] = '\0';
*/

   delete bits;

   return data_rows;
}

int saveImage
    (
       const char *img_name, 
       int img_type, 
       unsigned int width, 
       unsigned int height,
       unsigned char *buffer
    )
{
   int type = GL_RGBA;

   switch(img_type)
   {
      case IMG_JPEG:
         type = GL_RGB;
      break;
   }

   unsigned int num_components = getNumComponents(type);

   unsigned char **data_rows = new unsigned char *[height];

   if( !data_rows )
   {
      cout << "OUT OF MEMORY" << endl;
      return 1;
   }

   int w = width * num_components, j, i;

   for(i = height-1, j = 0; i != -1 ; i--, j++)
   {
      data_rows[j] = new unsigned char[w+1];
      if(data_rows[j] == NULL)
      {
          cout << "MEMORY ALLOCATION ERROR:" << __FUNCTION__ << endl; 
          exit(0);
      }
      memcpy(data_rows[j], &buffer[i*w], w);
      data_rows[j][w] = '\0';
   }

   char *ptr = strrchr((char *)img_name, '.'), model_name[256];
   memset(model_name, '\0', sizeof(char) * 256);
   int len = ptr - img_name;

   if( ptr )
      memcpy(model_name, img_name, len * sizeof(char));
   else
      memcpy(model_name, img_name, strlen(img_name) * sizeof(char));

   switch(img_type)
   {
      case IMG_PNG:
      {
         strcat(model_name, ".png");
         SaveToPng png(model_name);
         png.save(data_rows, width, height, GL_RGBA);
      }
      break;
      case IMG_JPEG:
      {
         strcat(model_name, ".jpeg");
         SaveToJpeg jpeg(model_name);
         jpeg.save(data_rows, width, height, GL_RGB);
      }
      break;
      default:
      {
         strcat(model_name, ".png");
         SaveToPng png(model_name);
         png.save(data_rows, width, height, GL_RGBA);
      }
   }

   for(unsigned int j = 0; j < height; j++)
      delete data_rows[j];
   delete data_rows;

   return 0;
}

int saveImage
    (
       const char *img_name, 
       int img_type, 
       unsigned int width, 
       unsigned int height
    )
{
   GLXContext glx = glXGetCurrentContext();

   if( !glx )
   {
      cout << "Could not get a context to save image\n";
      return 1;
   }

   unsigned char **data_rows = getData(img_type, width, height);

   if( !data_rows )
      return 2;

   char *ptr = strrchr((char *)img_name, '.'), model_name[256];
   memset(model_name, '\0', sizeof(char) * 256);
   int len = ptr - img_name;

   if( ptr )
      memcpy(model_name, img_name, len * sizeof(char));
   else
      memcpy(model_name, img_name, strlen(img_name) * sizeof(char));

   switch(img_type)
   {
      case IMG_PNG:
      {
         strcat(model_name, ".png");
         SaveToPng png(model_name);
         png.save(data_rows, width, height, GL_RGBA);
      }
      break;
      case IMG_JPEG:
      {
         strcat(model_name, ".jpeg");
         SaveToJpeg jpeg(model_name);
         jpeg.save(data_rows, width, height, GL_RGB);
      }
      break;
      default:
      {
         strcat(model_name, ".png");
         SaveToPng png(model_name);
         png.save(data_rows, width, height, GL_RGBA);
      }
   }

   for(unsigned int j = 0; j < height; j++)
      delete data_rows[j];
   delete data_rows;

   return 0;
}

