#include <iostream>
#include <vector>
#include <map>
#include "bufio.h"
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <sys/mman.h>
#include "gentime.h"
#include <stdlib.h>
#include <search.h>
#include "io.h"

using namespace std;

int compareIDs(const void *p1, const void *p2)
{
//cout << "ID1=" << *(const int *)p1 << endl;
//cout << "ID2=" << *(const int *)p2 << endl;
   return ( (*(const int *)p1 > *(const int *)p2) ? 1 : ((*(const int *)p1 == *(const int *)p2) ? 0 : -1) );
}

int writeFile(char *file_name, void *array, size_t size)
{
   int wfd = open(file_name, O_RDWR|O_TRUNC|O_CREAT, 
			S_IRWXU|S_IRGRP|S_IXGRP|S_IROTH|S_IXOTH);
   if( wfd < 0 )
   {
      cout << "Unable to open file for writing\n";
      return 1;
   }

   if( lseek(wfd, size-1, SEEK_SET) == -1 )
   {
      cout << "seek error\n";
      return 2;
   }

   if( write(wfd, "", 1) != 1 )
   {
      cout << "write error\n";
      return 3;
   }

   char *m_file = (char *)mmap(0, size, 
	       PROT_READ | PROT_WRITE, MAP_FILE | MAP_SHARED, wfd, 0);  
   memcpy(m_file, array, size);
   munmap(m_file, size);
   close(wfd);

   return 0;
}

int getFilePointer(char *file_name, void **ret_ptr, size_t *size)
{
   struct stat statbuf;
   int fileDes = open(file_name, O_RDONLY);

   if( fileDes < 0 )
      return -1;

   if( fstat(fileDes, &statbuf) < 0 )
   {
      cout << "Unable to stat file nids_bin\n";
      close(fileDes);
      return -1;
   }
 
   *size = statbuf.st_size;

cout << "BLOCK SIZE=" << statbuf.st_blksize << endl;
cout << "NUM BLOCK =" << statbuf.st_blocks << endl;

   *ret_ptr = mmap(0, statbuf.st_size, PROT_READ, 
			  MAP_SHARED, fileDes, 0);
   if( *ret_ptr == NULL )
   {
      cout << "MMAP error for file " << file_name << endl;
      close(fileDes);
      return -1;
   }

   return fileDes;
}

int findID(char *ent_name, int id)
{
//unsigned long stime = GenTime::getCurrentMillis();
   char file[64];
   int cnt = 0, file_des, idx = -1, *id_ptr, *ptr;
   size_t size = 0, num_ids;
   void *base;

   while(1)
   {
      sprintf(file, "%s_ids_%d", ent_name, cnt);
      file_des = getFilePointer(file, &base, &size);
      if( file_des < 0 )
         break;
      num_ids = size/sizeof(int);
      id_ptr = (int *)bsearch(&id, base, num_ids, sizeof(int), compareIDs);

      if( id_ptr )
      {
         idx = id_ptr - (int *)base;
	 munmap(base, size);
	 close(file_des); 
//cout << "BSEARCH IDX=" << idx << endl;
         break;
      }
      munmap(base, size);
      close(file_des); 
      cnt++;
   }
//unsigned long ftime = GenTime::getCurrentMillis();
//cout << "TIME TO FIND ID = " << (ftime-stime) << " ms\n";

/*
   while(1)
   {
      sprintf(file, "%s_ids_%d", ent_name, cnt);
      file_des = getFilePointer(file, &base, &size);
      if( file_des < 0 )
         break;
      num_ids = size/sizeof(int);
      ptr = (int *)base;
      vector<int> arr(ptr, ptr + num_ids);
      vector<int>::iterator p = find(arr.begin(), arr.end(), id);
      if( p != arr.end() )
      {
         idx = p - arr.begin();
	 munmap(base, size);
	 close(file_des);
cout << "VECTOR IDX=" << idx << endl;
         break;
      }

      munmap(base, size);
      close(file_des); 
      cnt++;
   }
unsigned long ntime = GenTime::getCurrentMillis();
cout << "TIME TO FIND ID = " << (ntime-ftime) << " ms\n";
*/

   return idx;
}

int main(int argc, char *argv[])
{
unsigned long stime = GenTime::getCurrentMillis();
   int rfd = open("nids", O_RDONLY);

   if( rfd == -1 )
   {
      cout << "Unable to open file\n";
      return 1;
   }

   char buf[58], file[128], id_str[16], x_str[24], y_str[24], z_str[24];
   int cnt = 0, max_ent = 65536*20, file_num = 0, *ids, count = 0;
   float *coords;
   BufFilePtr rbf = BufFileOpenRead(rfd);

   coords = new float[max_ent*3];
   ids = new int[max_ent];

   if( !coords )
   {
      cout << "Malloc error\n";
      return 1;
   }

   while( BufFileRead(rbf, buf, 57) )
   {
      memcpy(id_str, &buf[0], sizeof(char)*8);
      id_str[8] = '\0';
//cout << id_str << endl;
      memcpy(x_str, &buf[8], sizeof(char)*16);
      x_str[16] = '\0';
//cout << x_str << endl;
      memcpy(y_str, &buf[24], sizeof(char)*16);
      y_str[16] = '\0';
//cout << y_str << endl;
      memcpy(z_str, &buf[40], sizeof(char)*16);
      z_str[16] = '\0';
//cout << z_str << endl;

      count = cnt * 3;
      *(ids+cnt) = atoi(id_str);
      *(coords+count) = atof(x_str);
      *(coords+count+1) = atof(y_str);
      *(coords+count+2) = atof(z_str);

      if( cnt < max_ent )
         cnt++;
      else
      {
	 sprintf(file, "node_ids_%d", file_num);
         writeFile(file, (void *)ids, sizeof(int) * cnt);
	 sprintf(file, "node_values_%d", file_num);
         writeFile(file, (void *)coords, sizeof(float) * 3 * cnt);
         file_num++;
         cnt = 0;
      }
      //cout << buf;
   }

   BufFileClose(rbf, 0);
   close(rfd);

   sprintf(file, "node_ids_%d", file_num);
   writeFile(file, (void *)ids, sizeof(int) * cnt);
   sprintf(file, "node_values_%d", file_num);
   writeFile(file, (void *)coords, sizeof(float) * 3 * cnt);

unsigned long ftime = GenTime::getCurrentMillis();
cout << "TIME for read and write=" << (ftime-stime) << " ms\n";
   delete coords;
   delete ids;

   int fileDes, valFileDes, num_nodes;
   float *val;
/*
unsigned long stime = GenTime::getCurrentMillis();
   char file[128];
   int cnt = 0, file_num = 19;
*/
   int *ptr, *id_ptr, file_des;
   size_t size = 0;
   void *base = NULL, *val_base = NULL;
   if( argc > 1 )
   {
unsigned long stime = GenTime::getCurrentMillis();
      int id = atoi(argv[1]), idx;
cout << "ID=" << id << endl;
      char *file = "node_ids_0";
      file_des = getFilePointer(file, &base, &size);
      if( file_des < 0 )
         return 1;
      size_t num_ids = size/sizeof(int);

      for(cnt = 0; cnt < num_ids; cnt++)
      {
         id_ptr = (int *)bsearch(&cnt, base, num_ids, sizeof(int), compareIDs);
/*
	 idx = findID("node", cnt);
	 if( idx < 0 )
	    cout << "NODE id = " << id << " not found\n";
	 else
	    cout << "NODE id = " << id << " found at " << idx << endl;
*/
      }
unsigned long ftime = GenTime::getCurrentMillis();
cout << "TIKME FOR 1million nodes=" << ftime-stime << endl;
   }

   ENTRY entry, *ep;
   int j = 0;
   float *values;
   char id[64];
   XYZ *xyz;
   map<int, XYZ *> id_values_map;

stime = GenTime::getCurrentMillis();
cout << "FILE NUM = " << file_num << endl;
   int *id_list;
   float *values_list;
   for(cnt = 0; cnt <= file_num; cnt++)
   {
      sprintf(file, "node_ids_%d", cnt);
      fileDes = getFilePointer(file, &base, &size);
      if( fileDes < 0 )
         break;
      num_nodes = size/sizeof(int);
      id_list = new int[num_nodes];
      memcpy(id_list, base, size);
      munmap(base, size);
      close(fileDes);

      ptr = (int *)id_list;
cout << "num nodes = " << num_nodes << endl;

      sprintf(file, "node_values_%d", cnt);
      size = 0;
      valFileDes = getFilePointer(file, &val_base, &size);
      if( valFileDes < 0 )
         break;

      values_list = new float[num_nodes * 3];
      if( !values_list )
         break;
      float *val_ptr = (float *)val_base;
      memcpy(values_list, val_ptr, size);
      munmap(val_base, size);
      close(valFileDes);
      val = (float *)values_list;
cout << "num nodes = " << num_nodes << endl;

unsigned long st = GenTime::getCurrentMillis();
      for(j = 0; j < num_nodes; j++, ptr++)
      {
         xyz = new XYZ;
	 xyz->x = *val++;
	 xyz->y = *val++;
	 xyz->z = *val++;
         id_values_map.insert(UIFPair((*ptr) + 5000000, xyz));
      }
cout << "FIST\n";

      ptr = (int *)id_list;
      val = (float *)values_list;
      for(j = 0; j < num_nodes; j++)
      {
         xyz = new XYZ;
	 xyz->x = *val++;
	 xyz->y = *val++;
	 xyz->z = *val++;
         id_values_map.insert(UIFPair(*ptr++, xyz));
      }
unsigned long et = GenTime::getCurrentMillis();
cout << "TIME FOR INSERT=" << et-st << endl;
      
      ptr = (int *)id_list;
      for(j = 0; j < num_nodes; j++, ptr++)
      {
         id_values_map.find(*ptr);
      }

      ptr = (int *)id_list;
      for(j = 0; j < num_nodes; j++, ptr++)
      {
         id_values_map.find((*ptr) + 5000000);
      }
st = GenTime::getCurrentMillis();
cout << "TIME FOR FIND=" << st-et << endl;
/*
      hcreate(2*num_nodes);
       
      values = new float[3];
      for(j = 0; j < num_nodes; j++)
      {
	 sprintf(id, "%d", (*ptr++) + 5000000);
	 entry.key = id;
	 values[0] = *val++;
	 values[1] = *val++;
	 values[3] = *val++;

	 entry.data = (void *)values;
	 ep = hsearch(entry, ENTER); 
         if( ep == NULL )
         {
cout << "ERROR\n";
            break;
         }
      }

      ptr = (int *)base;
      val = (float *)val_base;
      for(j = 0; j < num_nodes; j++)
      {
	 sprintf(id, "%d", *ptr++);
	 entry.key = id;
	 values[0] = *val++;
	 values[1] = *val++;
	 values[3] = *val++;

	 entry.data = (void *)values;
	 ep = hsearch(entry, ENTER); 
         if( ep == NULL )
         {
cout << "ERROR\n";
            break;
         }
      }
unsigned long et = GenTime::getCurrentMillis();
cout << "TIME FOR INSERT=" << et-st << endl;

      ptr = (int *)base;
      for(j = 0; j < num_nodes; j++)
      {
	 sprintf(id, "%d", *ptr++);
	 entry.key = id;
	 ep = hsearch(entry, FIND);
         if( ep == NULL )
            cout << "NOT FOUND\n";
      }

      ptr = (int *)base;
      for(j = 0; j < num_nodes; j++)
      {
	 sprintf(id, "%d", (*ptr++) + 5000000);
	 entry.key = id;
	 ep = hsearch(entry, FIND);
         if( ep == NULL )
            cout << "NOT FOUND\n";
      }
*/

/*
      //ids = new int[num_nodes]; 
      //memcpy(ids, base, sizeof(int)*num_nodes);

      id_ptr = (int *)bsearch(&id, ptr, num_nodes, sizeof(int), compareIDs);
      if( id_ptr )
      {
         cout << "FOUND ID=" << *id_ptr << endl;
         cout << "ID FOUND in file " << file << endl;
      }

      //delete ids;
*/

      ptr = (int *)base;
cout << "1st node=" << ptr[0] << endl;
cout << "last node=" << *(ptr + (num_nodes-1)) << endl;

/*
      sprintf(file, "node_values_%d", cnt);
      if( getFilePointer(file, &base, &size) )
         break;
      val = (float *)base;
      num_nodes = size/(sizeof(float)*3);
cout << "x = " << val[0] << endl;
cout << "y = " << val[1] << endl;
cout << "z = " << val[2] << endl;
      val = val + ((num_nodes -1) * 3);

cout << "lx = " << *(val) << endl;
cout << "ly = " << *(val+1) << endl;
cout << "lz = " << *(val+2) << endl;
      munmap(base, size);
      close(fileDes);
*/
   }

ftime = GenTime::getCurrentMillis();
cout << "TIME for read and write=" << (ftime-stime) << " ms\n";

   return 0;
}

