#include "caectx.h"
#include "getindices.h"
#include "getids.h"
#include "myconnection.h"
#include "elementdetails.h"
#include "nodedetails.h"
#include "readelements.h"
#include "setkwfromtype.h"
#include "kwgroup.h"

void CAEContext::create
     (
	const char *dir,
	const char *model,
	unsigned int width,
	unsigned int height
     )
{
   dirName = dir;
   modelName = model;

   const char *disp = MyConnection::getParam("display");
   if( !disp )
      disp = "smooth";

   unsigned int disp_type = GL_SMOOTH;

   if( !strcmp(disp, "flat") )
      disp_type = GL_FLAT;

   caeEnv = new CAEEnv(dir, model, disp_type);

   caeEnv->loadAndInitGL(0);
   caeEnv->resizeModel(width, height);

   setView();
   setDisplay();
   setTransform();
   setPartDisplay("partlist");
   setObjectDisplay();
   setTransform();
   caeEnv->renderModel();
   glFinish();
}

void CAEContext::setTransform()
{
   float values[9];
   values[0] = atof(MyConnection::getParam("rx"));
   values[1] = atof(MyConnection::getParam("ry"));
   values[2] = atof(MyConnection::getParam("rz"));

   values[3] = atof(MyConnection::getParam("tx"));
   values[4] = atof(MyConnection::getParam("ty"));
   values[5] = atof(MyConnection::getParam("tz"));

   values[6] = atof(MyConnection::getParam("sx"));
   values[7] = atof(MyConnection::getParam("sy"));
   values[8] = atof(MyConnection::getParam("sz"));
    
   MTransform *mt = caeEnv->getMTransformPtr();
   mt->setValues(values);
}

void CAEContext::setDisplay()
{
   const char *hide = MyConnection::getParam("hide");
   if( !hide )
      hide = "yes";

   if( !strcmp(hide, "yes") )
      caeEnv->setHideMode();
   else
      caeEnv->setHideMode(0);

   const char *disp = MyConnection::getParam("display");
   if( !disp )
      disp = "smooth";

   unsigned int  disp_type = GL_SMOOTH;
   if( !strcmp(disp, "flat") )
      disp_type = GL_FLAT;

   caeEnv->setShadeModel(disp_type);

   if( !strcmp(disp, "wireframe") )
      caeEnv->setPolygonMode(GL_LINE);
   else
       caeEnv->setPolygonMode(GL_FILL);
   if( !strcmp(disp, "transparent") )
      caeEnv->setBlend(true);
   else
      caeEnv->setBlend(false);
}

void CAEContext::setView()
{
   unsigned int type = ISO_VIEW;
   const char *view = MyConnection::getParam("view");
   if( !view )
      view = "isometric";

   if( !strcmp(view, "isometric") )
      type = ISO_VIEW;
   else if( !strcmp(view, "top") )
      type = TOP_VIEW;
   else if( !strcmp(view, "bottom") )
      type = BOTTOM_VIEW;
   else if( !strcmp(view, "left") )
      type = LEFT_VIEW;
   else if( !strcmp(view, "right") )
      type = RIGHT_VIEW;
   else if( !strcmp(view, "front") )
      type = FRONT_VIEW;
   else if( !strcmp(view, "back") )
      type = BACK_VIEW;

   MView *mv = caeEnv->getMViewPtr();
   mv->changeView(type);
}

void CAEContext::setObjectDisplay()
{
   const char *kw_type_str = MyConnection::getParam("kwtype");

   if( !kw_type_str )
      return;

   unsigned int kwtype = KWGroup::typeFromName(kw_type_str);
cout << "KW TYPE=" << kw_type_str << " INT KW=" << kwtype << endl;

   const char *kw = MyConnection::getParam("kw");
cout << "KW =" << kw << endl;
   const char *id_ptr = MyConnection::getParam("idlist");

   if( !id_ptr )
      return;

cout << "ID LIST=" << id_ptr << endl;

   string cidx_list_str = id_ptr;
   if( !cidx_list_str.length() )
      return;

   unsigned int on_off = 1;
   vector<unsigned int> obj_id_list;

   switch(kwtype)
   {
      case ELEMENT:
      {
         PartInfoPtr parts = caeEnv->getPartsList();
         UIUIMap *pid_map = caeEnv->getPartsMapPtr();
         vector<unsigned int> pid_list, copy_pids;
         InsIter ins(copy_pids, copy_pids.begin());

         getIDs(kw_type_str, &cidx_list_str, &on_off, &obj_id_list, &pid_list);
         if( on_off & DISP_OFF )
            return;
cout << "IDS=" << obj_id_list.size() << " PIDS=" << pid_list.size() << endl;
         unique_copy(pid_list.begin(), pid_list.end(), ins);
cout << "UNIQUE PARTS=" << copy_pids.size() << endl;

         ElementDetails elm_detail;
         elm_detail.openFile(dirName, modelName);
         elm_detail.fill(parts, pid_map, &copy_pids);
         caeEnv->selectElements(obj_id_list, pid_list);
      }
      break;
      case NOD:
      {
         getIDs(kw_type_str, &cidx_list_str, &on_off, &obj_id_list);
cout << "NODE IDS in CAECTX=" << obj_id_list.size() << endl;
         displayNodes(on_off, obj_id_list);
      }
      break;
      case SET:
      {
         //get set indices from card indices
         getIDs(kw_type_str, &cidx_list_str, &on_off, &obj_id_list);
cout << "ON OFF=" << on_off << endl;
         displaySets(kw, on_off, obj_id_list);
      }
      break;
      default:
      {
	 getIDs(kw_type_str, &cidx_list_str, &on_off, &obj_id_list);
	 GetIDS get_ids(dirName, modelName, kw_type_str);
	 KWTypeIDStr *kws_ptr = NULL;
	 int num_obj = get_ids.fetchObjects(&obj_id_list, &kws_ptr);
cout << "OBJ COUNT=" << num_obj << endl;
	 for(int i = 0; i < num_obj; i++)
	 {
	    displayGenericObjects(on_off, &kws_ptr[i]);
	 }
      }
      break;
   }
}

void CAEContext::displayGenericObjects
     (
        unsigned int on_off,
        KWTypeIDStr *kw_ptr
     )
{
   vector<unsigned int> id_list;
   id_list.push_back(kw_ptr->id);

cout << "disp gen ID=" << kw_ptr->id << endl;
cout << "KW SHORT=" << kw_ptr->kwShort << endl;
cout << "KW Type=" << kw_ptr->kwType << endl;
   switch(kw_ptr->kwShort)
   {
      case PARTC:
cout << "DISPLAY OF PART****************\n";
         setPartDisplay(on_off, &id_list);
      break;
      case NOD:
cout << "DISPLAY OF NODES****************\n";
         displayNodes(on_off, id_list);
      break;
      case SET:
      {
         string kw;
cout << "DISPLAY OF SET****************\n";
         getSetKeywordFromType(kw_ptr->kwType, kw); 
cout << "KWin DISP=" << kw << endl;
         displaySets(kw.data(), on_off, id_list);
      }
      break;
      default:
         cout << "OBJ NOT SUPPORTED\n";
   }
}

void CAEContext::displayNodes
     (
        unsigned int on_off,
        vector<unsigned int> & obj_id_list
     )
{
   if( on_off & DISP_OFF )
      return;

   PartInfoPtr parts = caeEnv->getPartsList();
   UIUIMap *pid_map = caeEnv->getPartsMapPtr();
   NodeDetails node_detail(dirName, modelName);
   node_detail.fill(parts, pid_map);
   caeEnv->selectNodeList(obj_id_list);
}

void CAEContext::displaySets
     (
        const char *kw,
        unsigned int & on_off,
        vector<unsigned int> & obj_id_list
     )
{
   if( on_off & DISP_OFF )
      return;

cout << "SET INDICES in CAECTX=" << obj_id_list.size() << endl;
   //from set indices, get node, element, part ids based on type of set
   GetIDS get_ids(dirName, modelName, "set");
   vector<unsigned int> id_list;
   get_ids.fetch(&obj_id_list, &id_list);
//cout << "NUM IDS=" << id_list.size() << endl;
//for(unsigned int i = 0; i < id_list.size(); i++)
//   cout << "ID=" << id_list[i] << ",";
//cout << "\n";

   //if there is a list generate, expand the list
   if( strstr(kw, "RATE") )
   {
      expandList(id_list, &obj_id_list);
cout << "NUM IDS AFTER EXPAND=" << obj_id_list.size() << endl;
   }

   if( strstr(kw, "NODE") )
   {
      if( strstr(kw, "RATE") )
	 caeEnv->selectNodeList(obj_id_list);
      else
      {
	 PartInfoPtr parts = caeEnv->getPartsList();
	 UIUIMap *pid_map = caeEnv->getPartsMapPtr();
	 NodeDetails node_detail(dirName, modelName);
	 node_detail.fill(parts, pid_map);
	 caeEnv->selectNodes(id_list);
      }
   }
   else if( strstr(kw, "PART") )
   {
      if( strstr(kw, "RATE") )
         caeEnv->processPartsByID(on_off, &obj_id_list);
	 //caeEnv->selectPartsByID(&obj_id_list);
      else
         caeEnv->processPartsByID(on_off, &id_list);
	 //caeEnv->selectPartsByID(&id_list);
      //caeEnv->processParts(on_off);
   }
   else if( strstr(kw, "SEG") )
   {
      ReadElements read_elms(dirName, modelName, 0, NULL);
      PartInfoPtr part_info = read_elms.createPartForSegment(id_list);
      if( part_info )
      {
	 caeEnv->setSegmentPart(part_info);
      }
/*
      list<unsigned int> nid_list(id_list.begin(), id_list.end());
      vector<unsigned int> eis_list, pis_list, copy_pids;
      UIUIMap *pid_map = caeEnv->getPartsMapPtr();
      InsIter ins(copy_pids, copy_pids.begin());
      get_ids.eisFromNodes(pid_map, nid_list, eis_list, pis_list);
cout << "NUM ELMED IN SEG=" << eis_list.size() << endl;
      caeEnv->selectElementsByIndex(eis_list, pis_list);
*/
   }
}

void CAEContext::setPartDisplay
     (
        unsigned int on_off, 
        vector<unsigned int> *obj_id_list
     )
{
   caeEnv->processPartsByID(on_off, obj_id_list);
   //caeEnv->selectPartsByID(obj_id_list);
   //caeEnv->processParts(on_off);
}

void CAEContext::setPartDisplay(const char *param_name)
{
   //const char *plist_ptr = MyConnection::getParam("partlist");
   const char *plist_ptr = MyConnection::getParam(param_name);

   if( !plist_ptr )
      return;

   string plist = plist_ptr;
cout << "PART lst=" << plist << endl;
   if( !plist.length() )
      return;

   unsigned int on_off = 1;
   vector<unsigned int> obj_id_list;
   getIDs("part", &plist, &on_off, &obj_id_list);
cout << "ON_OFF=" << on_off << endl;

   caeEnv->processPartsByID(on_off, &obj_id_list);
   //caeEnv->selectPartsByID(&obj_id_list);
   //caeEnv->processParts(on_off);
}

/** gets the list of card indices and on/off status of the objects from the 
  * given card_index_list string
  */
void CAEContext::getIDs
     (
        const char *kw_type_str,
        string *id_list,
        unsigned int *on_off,
        vector<unsigned int> *obj_id_list,
        vector<unsigned int> *pid_list
     )
{
   char *kw_list = new char[id_list->length()+1];
   strcpy(kw_list, id_list->data());

   char *ptr = strrchr(kw_list, ','), *ptr1;
   if( ptr )
   {
      ptr1 = ptr;
      ptr1++;
//cout << "PTR=" << ptr1 << endl;
      *on_off = atoi(ptr1);
      *ptr = '\0';
   }
   else
   {
      *on_off = 1;
   }
cout << "ONOFF=" << *on_off << endl;

   switch(*on_off)
   {
      case 0:
         *on_off = DISP_OFF;
      break;
      case 1:
         *on_off = DISP_ON;
      break;
      case 2:
         *on_off = DISP_SELECT;
      break;
      case 3:
         *on_off = DISP_HIGHLIGHT;
      break;
   }
cout << "ON  OFF=" << *on_off << endl;

   GetIndices get_indices;
   if( get_indices.openFile(dirName, modelName, kw_type_str) )
      return;

   const char *idx = strtok(kw_list, ",");
   unsigned int idx_id_pid[3], id;

   if( !strcmp(kw_type_str, "node") )
   {
      while( idx )
      {
	 id = get_indices.findID(atoi(idx));
//cout << "IDX=" << idx << endl;
//cout << "ID=" << id << endl;
	 if( !(id & (UNSIGNED_INT_MAX_FLAG)) )
	    obj_id_list->push_back(id);
	 idx = strtok(NULL, ",");
      }
   }
   else if( !strcmp(kw_type_str, "part") )
   {
      while( idx )
      {
         //here (idx+1) beause the part id will be in second card
	 id = get_indices.findID(atoi(idx)+1);
//cout << "IDX=" << idx << endl;
//cout << "ID=" << id << endl;
	 if( !(id & (UNSIGNED_INT_MAX_FLAG)) )
	    obj_id_list->push_back(id);
	 idx = strtok(NULL, ",");
      }
   }
/*
   else if( !strcmp(kw_type_str, "set") || !strcmp(kw_type_str, "airbag") )
   {
      while( idx )
      {
         //here find the index of the imp_obj from card index
	 id = get_indices.findIndex(atoi(idx));
cout << "CIDX=" << idx << endl;
cout << "IDX=" << id << endl;
	 if( !(id & (UNSIGNED_INT_MAX_FLAG)) )
	    obj_id_list->push_back(id);
	 idx = strtok(NULL, ",");
      }
   }
*/
   else if( !strcmp(kw_type_str, "element") )
   {
      while( idx )
      {
	 idx_id_pid[0] = atoi(idx);
	 get_indices.findElmID(idx_id_pid);
//cout << "IDX=" << idx_id_pid[0] << endl;
//cout << "ID=" << idx_id_pid[1] << endl;
//cout << "PID=" << idx_id_pid[2] << endl;

	 if( !(idx_id_pid[1] & (UNSIGNED_INT_MAX_FLAG)) )
	 {
	    obj_id_list->push_back(idx_id_pid[1]);
	    pid_list->push_back(idx_id_pid[2]);
	 }

	 idx = strtok(NULL, ",");
      }
   }
   else
   {
      while( idx )
      {
         //here find the index of the imp_obj from card index
	 id = get_indices.findIndex(atoi(idx));
//cout << "CIDX=" << idx << endl;
//cout << "IDX=" << id << endl;
	 if( !(id & (UNSIGNED_INT_MAX_FLAG)) )
	    obj_id_list->push_back(id);
	 idx = strtok(NULL, ",");
      }
   }

   delete kw_list;

//cout << "ON=" << on_off << endl;
/*
   if( *on_off )
      *on_off = DISP_ON;
   else
      *on_off = DISP_OFF;
*/
}

void CAEContext::expandList
     (
        vector<unsigned int> &id_list, 
        vector<unsigned int> *new_list
     )
{
   unsigned int i, j, start, end;
   new_list->clear();
   for(i = 0; i < id_list.size(); i+=2)
   {
      start = id_list[i];
      end = id_list[i+1];
      for(j = start; j <= end; j++)
         new_list->push_back(j);
   }
}

