#include <iostream>
#include <time.h>
#include "myconnection.h"
#include "saveimg.h"
#include "caectx.h"
#include "mesactx.h"

CAEEnv *CAEEnv::cae_Env = NULL;
map<string, string> MyConnection::nvMap;

using namespace std;

int main(int argc, char *argv[])
{
   time_t  t1, t2;

   if( argc < 3 )
   {
      cout << "Usage: gsslsd data_dir image_dir\n";
      return 1;
   }

   time(&t1);
#include <sys/types.h>
#include <sys/stat.h>
#ifndef WIN32
#include <unistd.h>
#endif

#ifdef WIN32
#define stat _stat
#endif 

   time_t timeModification, prevModification;
   string prevModelName, currentModelName;
   const char *conn_file = getenv("CONNECTION_FILE");
   MesaContext        *ctx = NULL;
   CAEContext         *cae = NULL;

   while(true)
   {
       if(conn_file)
       {
          struct stat result;
	  if(stat(conn_file, &result)==0)
	  {
	      timeModification = result.st_mtime;
	  }
       }

       if(timeModification == prevModification)
       {
          sleep(1);
          continue;
       }

       prevModification = timeModification;

       MyConnection::Clear(); 
       if( MyConnection::readXmlFile() )
	  return 2;

       currentModelName = MyConnection::getParam("model");
       if( currentModelName.empty() )
       {
	  cout << "No model name exists in XML file\n";
	  return 3;
       }

       cout << currentModelName << endl;

       const char *w = MyConnection::getParam("width");
       const char *h = MyConnection::getParam("height");
       string disp = MyConnection::getParam("display");
       string view = MyConnection::getParam("view");
       unsigned int width = 800, height = 600;
       int          img_type = IMG_JPEG;

       if( w ) width = atoi(w);
       if( h ) height = atoi(h);

       if(currentModelName != prevModelName)
       {
time(&t1);
           if(ctx)
               delete ctx;
           if(cae)
               delete cae;

           ctx = new MesaContext();

           if( ctx->create(width, height, img_type) )
           {
              delete ctx;
              return 4;
           }

           cae = new CAEContext();
           cae->create(argv[1], currentModelName.data(), width, height);
               prevModelName = currentModelName;
       }
       else
       {
time(&t1);
           cae->setView();
           cae->setDisplay();
           cae->renderModel();
       }


       char img_name[256];
       sprintf(img_name, "%s/%s_%s_%s.jpeg", argv[2], currentModelName.data(),
			disp.data(), view.data());
       saveImage(img_name, img_type, width, height, ctx->getBuffer());
cout << "Img Name=" << img_name << endl;
       time(&t2);

cout << "TOTAL TIME=" << difftime(t2, t1) << " sec" << endl;
   }

   return 0;
}

