#include <iostream>
#include <vector>
#include <set>
#include <map>
#include <utility>
#include "readelements.h"
#include "filelist.h"
#include "mtrans.h"
#include "mantypes.h"

using namespace std;

ReadElements::ReadElements(UIUIMap *pid_map, vector<ReadIDS *> *id_vect, vector<ReadNodes *> *node_vect)
    : fileIndex(-1), readIDS(NULL), readNodes(NULL), pidMap(pid_map), m_ReadIDVect(id_vect), m_ReadNodeVect(node_vect)
{
}

ReadElements::~ReadElements()
{
   uniqIndices.clear();
}

ReadElements::ReadElements(const char *dir, const char *model, int file_idx, 
   UIUIMap *pid_map): fileIndex(file_idx), readIDS(NULL), 
      readNodes(NULL), pidMap(pid_map)
{
   dirName = dir;
   modelName = model;
}

void ReadElements::setValues(const char *dir, const char *model, int file_idx, 
			     ReadIDS *read_ids, ReadNodes *read_nodes)
{
   dirName = dir;
   modelName = model;
   fileIndex = file_idx;
   readIDS = read_ids;
   readNodes = read_nodes;
}

void ReadElements::randomColor(float rgb[3])
{
   int i = rand();
   rgb[0] = (float) (i % 1000) / 1000.0;

   i = rand();
   rgb[1] = (float) (i % 1000) / 1000.0;

   i = rand();
   rgb[2] = (float) (i % 1000) / 1000.0;
}

int ReadElements::getPartsByID
    (
       vector<unsigned int> *pid_list,
       unsigned int *num_parts,
       PartInfoStr  **parts
    )
{
   if( !readIDS )
      return 0;

   unsigned long stime = GenTime::getCurrentMillis();
   list<const char *> file_list;
   list<const char *>::iterator b, e;
   char buf[256], type[32], *us_ptr, *dot_ptr;
   sprintf(buf, "%s/%s", dirName, modelName);
   FileList flist(buf);
   unsigned int n = flist.getNamesList(&file_list), pid = 0;
   if( n <= 0 )
      return 0;
 
   b = file_list.begin(); e = file_list.end();
   vector<unsigned int>::iterator pb=pid_list->begin(),pe=pid_list->end(),it;
   for(; b != e; b++)
   {
      if( strstr(*b, "_pid_") )
      {
         us_ptr = strrchr((char *)*b, '_');
         us_ptr++;
         strcpy(type, us_ptr);
         dot_ptr = strrchr(type, '.');
         *dot_ptr = '\0';
         pid = atoi(us_ptr);
//cout << "FILE=" << *b << endl;
//cout << "PID=" << pid << endl;
         it = find(pb, pe, pid);
         if( it == pe )
         {
            file_list.erase(b);
            b--;
         }
      }
      else
      {
         file_list.erase(b);
         b--;
      }
   }

   n = file_list.size();

cout << "NUM FILES AFTER DELETE=" << n << endl;

   if( !(*num_parts) )
      *parts = (PartInfoStr *) malloc(sizeof(PartInfoStr) * n);
   else
      *parts = (PartInfoStr *)realloc(*parts, 
                         sizeof(PartInfoStr) * (n + (*num_parts)));

   if( !(*parts) )
   {
      cout << "Malloc error in read elements\n";
      return 0;
   }

   int                fd, num_nodes = 4, num_elms, total_elms = 0;
   unsigned int       num_indices, j, k, part_type = SHELL;
   unsigned int       *base, id;
   struct stat        statbuf;
   PartElementsPtr    part_elm_ptr;
   PartInfoPtr        part_info;

cout << "NUM PARTS IN READ ELEME=" << *num_parts << endl;

   type[0] = '\0';
   b = file_list.begin(); e = file_list.end();
   for(k = (*num_parts); b != e; b++, k++)
   {
      us_ptr = strchr((char *)*b, '_');
      us_ptr--;
      type[0] = *us_ptr;
      type[1] = '\0';
      part_type = getPartType(*b);
      num_nodes = atoi(type);
      if( !num_nodes )
         num_nodes = 10;
//cout << "FILE = " << *b << " NUM NODES=" << num_nodes << endl;

      sprintf(buf, "%s/%s/%s", dirName, modelName, *b);
      fd = open(buf, O_RDONLY);

      if( fd < 0 )
      {
         cout << "Unable to open binary file=" << buf << endl;
         continue;
      }

      if( fstat(fd, &statbuf) < 0 )
      {
	      cout << "Unable to stat file " << buf << endl;
         close(fd);
	      continue;
      }

      base = (unsigned int *)mmap(0, statbuf.st_size, PROT_READ, 
			     MAP_SHARED, fd, 0);
      if( !base )
      {
	      cout << "MMAP error for file " << buf << endl;
         close(fd);
	      continue;
      }

      part_info = &((*parts)[k]);
      memset(part_info, 0, sizeof(PartInfoStr));
      part_info->partFlag |= DISP_ON;
      randomColor(part_info->partColor);
      part_info->partColor[3] = 0.6;

      pidMap->insert(UIUIPair(pid, k));

      part_info->partDrawType = part_type;

      part_elm_ptr = &part_info->partElements;

      num_indices = statbuf.st_size/(sizeof(int));
      part_elm_ptr->elmIndices = new unsigned int[num_indices];

      if(part_elm_ptr->elmIndices == NULL)
      {
         cout << "Unable to malloc for elements in readelements.cpp\n";
         break;
      }

      memcpy(part_elm_ptr->elmIndices, base, statbuf.st_size);

      munmap(base, statbuf.st_size);
      close(fd);

      num_elms = num_indices/num_nodes;
      part_elm_ptr->numElements = num_indices;
      part_elm_ptr->nodesPerElement = num_nodes;

//cout << "PART=" << pid << " NUM ELMS=" << num_elms << endl;

      base = part_elm_ptr->elmIndices;
      unsigned int no_node_flag = 0;
      for(j = 0; j < num_indices; j++, base++)
      {
         id = *base;
	      *base = readIDS->find(*base);
         if( !((*base) & (UNSIGNED_INT_MAX_FLAG)) )
	         uniqIndices.insert(UIUIPair(*base, id));
         else
         {
            if(id)
               no_node_flag |= (UNSIGNED_INT_MAX_FLAG);
            else
	         {
	            cout << "NODE ID=" << *base << " NOT FOUND" << endl;
               *base = 0;
	         }
         }
      }

      fillNodeDetails(no_node_flag, part_info);

      total_elms += num_elms;
      (*num_parts)++;
   }
cout << "NUM PARTS IN READ ELEME AFTER READ=" << *num_parts << endl;

   unsigned long etime = GenTime::getCurrentMillis();
cout << "TIME FOR = " << type << " " << (etime-stime) << " ms" << endl;
   return total_elms;
}

//here type can have shell, solid, beam, disc, sb, tshell, sbaccel
int ReadElements::get
    (
       const char *type, 
       unsigned int *num_parts, 
       PartInfoStr **parts
    )
{
   if( !readIDS )
   {
      return 0;
   }

   unsigned long stime = GenTime::getCurrentMillis();
   vector<const char *> file_list;
   char buf[256];
   sprintf(buf, "%s/%s", dirName, modelName);
   FileList flist(buf, type);
   unsigned int n = flist.getNames(&file_list);

cout << "NUM FILES IN READ ELEMENTS=" << n << endl;

   if( n <= 0 )
      return 0;

   int                fd, num_nodes = 4, num_elms, total_elms = 0;
   unsigned int       num_indices, i, j, k, pid = -1, part_type = SHELL;
   unsigned int       *base, id, local_part_count = 0;
   struct stat        statbuf;
   PartElementsPtr    part_elm_ptr;
   PartInfoPtr        part_info = NULL;

cout << "NUM PARTS IN READ ELEME=" << *num_parts << " TYPE=" << type << endl;

   part_type = getPartType(type);

   if( !(*num_parts) )
      *parts = (PartInfoStr *) malloc(sizeof(PartInfoStr) * n);
   else
      *parts = (PartInfoStr *)realloc(*parts,
                         sizeof(PartInfoStr) * (n + (*num_parts)));

   if( !(*parts) )
   {
      cout << "Malloc error in read elements\n";
      return 0;
   }

   for(i = 0, k = (*num_parts); i < n; i++)
   {
      if( strncmp(file_list[i], type, strlen(type)) )
      {
cout << "K=" << k << " FILE NAME=" << file_list[i] << " TYPE=" << type << endl;
         continue;
      }

      sprintf(buf, "%s%%u_pid_%%u", type);
      sscanf(file_list[i], buf, &num_nodes, &pid);
      sprintf(buf, "%s/%s/%s", dirName, modelName, file_list[i]);
      fd = open(buf, O_RDONLY);

//cout << "K=" << k << " FILE NAME=" << file_list[i] << " TYPE=" << type << endl;
//cout << "PART ID=" << pid << " NODES PER ELEMENT=" << num_nodes << endl; 

      if( fd < 0 )
      {
         cout << "Unable to open binary file=" << buf << endl;
         continue;
      }

      if( fstat(fd, &statbuf) < 0 )
      {
	      cout << "Unable to stat file " << buf << endl;
         close(fd);
	      continue;
      }
//cout << "BLOCK SIZE=" << statbuf.st_blksize << endl;
//cout << "NUM BLOCK =" << statbuf.st_blocks << endl;

      base = (unsigned int *)mmap(0, statbuf.st_size, PROT_READ, 
			     MAP_SHARED, fd, 0);
      if( !base )
      {
	      cout << "MMAP error for file " << buf << endl;
         close(fd);
	      continue;
      }

      part_info = &((*parts)[k]);
      memset(part_info, 0, sizeof(PartInfoStr));
      part_info->partFlag |= DISP_ON;
      randomColor(part_info->partColor);
      part_info->partColor[3] = 0.6;

      //part_info->partIndex = k+1;
      //part_info->partID = pid;
      pidMap->insert(UIUIPair(pid, k));

      part_info->partDrawType = part_type;
      part_info->partFileIndex = fileIndex;

      part_elm_ptr = &part_info->partElements;

      num_indices = statbuf.st_size/(sizeof(int));

cout << "NUM INDICES=" << num_indices << endl;

      part_elm_ptr->elmIndices = new unsigned int[num_indices];

      if(part_elm_ptr->elmIndices == NULL)
      {
         cout << "Unable to malloc for elements in readelements.cpp\n";
         break;
      }

      memcpy(part_elm_ptr->elmIndices, base, statbuf.st_size);

      munmap(base, statbuf.st_size);
      close(fd);

      num_elms = num_indices/num_nodes;
      part_elm_ptr->numElements = num_indices;
      part_elm_ptr->nodesPerElement = num_nodes;

      base = part_elm_ptr->elmIndices;
      unsigned int no_node_flag = 0;
      map<unsigned int, float*> nodeIDCoordMap;
      for(j = 0; j < num_indices; j++, base++)
      {
         id = *base;
         if(!id)
         {
             cout << "ID is ZERO for part type " << type << endl;
             continue;
         }
	      *base = readIDS->find(*base);
//cout << "ID=" << id << " AFTER FIND=" << *base << endl;
         if( !((*base) & (UNSIGNED_INT_MAX_FLAG)) )
            uniqIndices.insert(UIUIPair(*base, id));
         else
         {
            unsigned int nodeFound = 0;
            map<unsigned int, float*>::iterator nfindIter = nodeIDCoordMap.find(id);
            if(nfindIter != nodeIDCoordMap.end())
            {
               unsigned int newIndex = readNodes->addNode(nfindIter->second);
               uniqIndices.insert(UIUIPair(newIndex, id));
               *base = newIndex;
               continue;
            }

            for(size_t m = 0; m < m_ReadIDVect->size(); m++)
            {
               nodeFound = m_ReadIDVect->at(m)->find(id);
               if( !(nodeFound & UNSIGNED_INT_MAX_FLAG) )
               {
cout << "NODEFOUND=" << nodeFound << " LOOK=" << id << endl;
                  float *localNodeVal = m_ReadNodeVect->at(m)->getValuesPtr();
                  unsigned int newIndex = readNodes->addNode(localNodeVal, nodeFound);
                  uniqIndices.insert(UIUIPair(newIndex, id));
                  *base = newIndex;
                  float *newValues = (float *)malloc(sizeof(float)*3);
                  newValues[0] = localNodeVal[nodeFound*3];
                  newValues[1] = localNodeVal[(nodeFound*3) + 1];
                  newValues[2] = localNodeVal[(nodeFound*3) + 2];
                  nodeIDCoordMap[id] = newValues;
                  nodeFound = 1;
                  break;
               }
            }
            //VIP: don't change this
            // if node is not 0 then node is not found and no_node_flag is set
            if(!nodeFound)
            {
               if(id)
               {
                  cout << "NODE ID " << id << " not found" << endl;
                  no_node_flag |= (UNSIGNED_INT_MAX_FLAG);
               }
               else // here node id is zero for some beams and discretes
               {
                  cout << "NODE ID not found" << *base << endl;
                  *base = 0;
               }
            }
         }
      }

      /**
      for(unsigned int eIndex = 0; eIndex < part_info->partElements.numElements; eIndex++)
      {
          cout << part_info->partElements.elmIndices[eIndex] << " ";
      }
      cout << "\n";

      UIUIIter  ubIter = uniqIndices.begin(), ueIter = uniqIndices.end();
      for(; ubIter != ueIter; ubIter++)
         cout << ubIter->first << " " << ubIter->second << " ";

      cout << "\n";
      ****/

      fillNodeDetails(no_node_flag, part_info);

      /**
      for(unsigned int eIndex = 0; eIndex < part_info->partElements.numElements; eIndex++)
      {
          cout << part_info->partElements.elmIndices[eIndex] << " ";
      }
      cout << "\n";
      ****/

      total_elms += num_elms;
      (*num_parts)++;
      k++; // increment the number of part to be filled
      local_part_count++;
   }

cout << "NUM LOCAL PARTS=" << local_part_count << " NUM FILES=" << n
     << " TOTAL COUNT=" << (*num_parts) << endl;

   if( local_part_count < n )
      *parts = (PartInfoStr *)realloc(*parts, sizeof(PartInfoStr) * (*num_parts));

   unsigned long etime = GenTime::getCurrentMillis();
cout << "TIME FOR = " << type << " " << (etime-stime) << " ms" << endl;
   return total_elms;
}

/* VIP: map is working the best compared to the set in finding the keys */
void ReadElements::fillNodeDetails
     (
        unsigned int no_node_flag,
        PartInfoPtr part_info
     )
{
   unsigned int j, m, nodes_size = sizeof(float)*3;
   PartNodesPtr       part_node_ptr;
   UIUIIter b, e, iter;

   part_node_ptr = &(part_info->partNodes);
   unsigned int num_uniq = uniqIndices.size();
   part_node_ptr->numNodes = num_uniq;

//cout << "PART NODES = " << num_uniq << endl;

   part_node_ptr->nodeValues = new float[num_uniq * 3];

   float *node_values = readNodes->getValuesPtr();

   b = uniqIndices.begin(); e = uniqIndices.end();
   set<float> x_values, y_values, z_values;

   for(j = 0; b != e; b++, j++)
   {
      m = j *3;
      memcpy(&part_node_ptr->nodeValues[m], 
			     &node_values[b->first * 3], nodes_size);
      b->second = j; //save local index of the node
      x_values.insert(part_node_ptr->nodeValues[m]);
      y_values.insert(part_node_ptr->nodeValues[m+1]);
      z_values.insert(part_node_ptr->nodeValues[m+2]);
   }

   if( x_values.size() )
   {   
      set<float>::iterator bv = x_values.begin(), ev = x_values.end(); ev--;
      part_info->partExtents[0] = *bv;
      part_info->partExtents[1] = *ev;

      bv = y_values.begin(); ev = y_values.end(); ev--;
      part_info->partExtents[2] = *bv;
      part_info->partExtents[3] = *ev;

      bv = z_values.begin(); ev = z_values.end(); ev--;
      part_info->partExtents[4] = *bv;
      part_info->partExtents[5] = *ev;
   }

   if( !(no_node_flag & (UNSIGNED_INT_MAX_FLAG)) ) //all nodes are there in the model
   {
      unsigned int *base = part_info->partElements.elmIndices;
      for(j = 0; j < part_info->partElements.numElements; j++, base++)
      {
         //if( *base ) // VIP:if node id is there then only find it
         {
            iter = uniqIndices.find(*base);
            if(iter != uniqIndices.end())
            {
               *base = iter->second;
            }
            else
            {
               cout << *base << " not Found\n";
               *base = (UNSIGNED_INT_MAX_FLAG);
            }
         }
	 /**Commented on Dec 18 2013 **
         else //flag is set and in draw beams the flag is checked and drawn
	 {
	    cout << *base << " not Found\n";
            *base = (UNSIGNED_INT_MAX_FLAG);
	 }
	 **/
      }
   }
   else //some nodes are missing so those elements to be removed
   {
      unsigned int *base = part_info->partElements.elmIndices;
      unsigned int *ptr_to_free = base;
      part_info->partElements.elmIndices = 
                    new unsigned int[part_info->partElements.numElements];
      unsigned int *new_base = part_info->partElements.elmIndices;
      unsigned int num_indices = part_info->partElements.numElements;
      unsigned int npe = part_info->partElements.nodesPerElement, 
                         *start, num_new_elms = 0, k;
      UIUIIter e = uniqIndices.end();
      for(j = 0; j < num_indices; j += npe, base += npe)
      {
         no_node_flag &= ~(UNSIGNED_INT_MAX_FLAG);
         start = base;
cout << "ELM IDS=";
         for(k = 0; k < npe; k++)
         {
cout << *start << ",";
            if( !((*start) & (UNSIGNED_INT_MAX_FLAG)) )
            {
		iter = uniqIndices.find(*start);
		*start = iter->second;
                if(!(*start) && part_info->partDrawType == BEAM)
                     *start = (UNSIGNED_INT_MAX_FLAG); //this flag is checked in beam draw
                start++;
            }
            else
            {
               no_node_flag |= (UNSIGNED_INT_MAX_FLAG);
               break;
            }
         }
cout << "\n";

         if( !(no_node_flag & (UNSIGNED_INT_MAX_FLAG)) )
         {
            memcpy(new_base, base, sizeof(int) * npe);
            for(int n = 0; n < npe; n++)
            {
               cout << "NEW ELM=" << *new_base << endl;
               new_base++;
            }
            //new_base += npe;
            num_new_elms += npe;
         }
      }

      delete ptr_to_free;

cout << "OLD ELMS=" << part_info->partElements.numElements/npe << " NEW=" << num_new_elms/npe << endl;
      part_info->partElements.numElements = num_new_elms;
   }

//cout << " NUM=" << part_info->partElements.numElements << " Uniq=" << num_uniq << endl;

   uniqIndices.clear();
}

//here type can have shell, solid, beam, disc, sb, tshell, sbaccel
int ReadElements::getAll
    (
       unsigned int *num_parts, 
       PartInfoStr **parts
    )
{
   int num_elms = 0;
   int num_shells = get("shell", num_parts, parts);
   num_elms += num_shells;
cout << "NUM SHELLS=" << num_shells << endl;
   int num_solids = get("solid", num_parts, parts);
   num_elms += num_solids;
cout << "NUM SOLIDS=" << num_solids << endl;
   int num_beams = get("beam", num_parts, parts);
   num_elms += num_beams;
cout << "NUM BEAMS=" << num_beams << endl;
   int num_disc = get("disc", num_parts, parts);
   num_elms += num_disc;
cout << "NUM DISCS=" << num_disc << endl;
/*
   num_elms += get("tshell", num_parts, parts);
   num_elms += get("seatbelt", num_parts, parts);
*/

   return num_elms;
}

unsigned int ReadElements::getPartType(const char *type)
{
   if( !strncmp(type, "shell", 5) )
      return SHELL;
   else if( !strncmp(type, "solid", 5) )
      return SOLID;
   else if( !strncmp(type, "beam", 4) )
      return BEAM;
   else if( !strncmp(type, "disc", 4) )
      return DISCRETE;
   else if( !strncmp(type, "seatbelt", 8) )
      return SBELEMENT;
   else if( !strncmp(type, "tshell", 6) )
      return TSHELL;
   else if( !strncmp(type, "mass", 4) )
      return MASS;
   else if( !strncmp(type, "inertia", 7) )
      return INERTIA;
   else
   {
cout << "PART TYPE UNKNOWN. Type assumed SHELL\n";
      return SHELL;
   } 
}

PartInfoPtr ReadElements::createPartForSegment
    (
       vector<unsigned int> & nid_list
    )
{
   readNodes = new ReadNodes(dirName, modelName);
   if( !readNodes->getValues() )
      return NULL;

   readIDS = new ReadIDS(dirName, modelName);
   if( !readIDS->get() )
      return NULL;

   PartInfoPtr part_info = new PartInfoStr;
   memset(part_info, 0, sizeof(PartInfoStr));
   part_info->partFlag |= DISP_ON;
   //ReadElements::randomColor(part_info->partColor);
   part_info->partColor[2] = 1.0f;
   part_info->partColor[3] = 0.6f;
   part_info->partDrawType = SHELL;

   PartElementsPtr part_elm_ptr = &part_info->partElements;

   unsigned int num_indices = nid_list.size();
   part_elm_ptr->elmIndices = new unsigned int[num_indices];

   if(part_elm_ptr->elmIndices == NULL)
   {
      cout << "Unable to malloc for elements in readelements.cpp\n";
      return NULL;
   }

cout << "SEG NODES=" << num_indices << endl;

   memcpy(part_elm_ptr->elmIndices, &nid_list[0], num_indices * sizeof(int));

   unsigned int num_nodes = 4;
   unsigned int num_elms = num_indices/num_nodes;
   part_elm_ptr->numElements = num_indices;
   part_elm_ptr->nodesPerElement = num_nodes;

cout << " NUM ELMS=" << num_elms << endl;

   unsigned int *base = part_elm_ptr->elmIndices;
   unsigned int no_node_flag = 0, j, id;
   for(j = 0; j < num_indices; j++, base++)
   {
      id = *base;
      *base = readIDS->find(*base);
      if( !((*base) & (UNSIGNED_INT_MAX_FLAG)) )
	 uniqIndices.insert(UIUIPair(*base, id));
      else
      {
	 //VIP: don't change this
	 // if node is not 0 then node is not found and no_node_flag is set
	 if(id)
         {
            cout << "NODE ID " << id << " not found" << endl;
	    no_node_flag |= (UNSIGNED_INT_MAX_FLAG);
         }
	 else // here node id is zero for some beams and discretes
	 {
            cout << "NOT FOUND ID=" << *base << endl;
	    *base = 0;
	 }
      }
   }

   fillNodeDetails(no_node_flag, part_info);

   delete readNodes;
   delete readIDS;

   return part_info;
}

