#include "readids.h"

ReadIDS::ReadIDS(const char *dir, const char *model) : numIDs(0), idList(NULL)
{
   dirName = dir;
   modelName = model;
}

void ReadIDS::set(const char *dir, const char *model)
{
   dirName = dir;
   modelName = model;
}

ReadIDS::~ReadIDS()
{
   if( numIDs )
      free(idList);
}

int ReadIDS::get(const char *id_file)
{
   unsigned long stime = GenTime::getCurrentMillis();
   char buf[256];
   struct stat statbuf;

   sprintf(buf, "%s/%s/%s", dirName, modelName, id_file);
   int fd = open(buf, O_RDONLY);

   if( fd < 0 )
   {
      cout << "No node data for =" << buf << endl;
      return 0;
   }

   if( fstat(fd, &statbuf) < 0 )
   {
      cout << "Unable to stat file " << buf << endl;
      return 0;
   }
//cout << "BLOCK SIZE=" << statbuf.st_blksize << endl;
//cout << "NUM BLOCK =" << statbuf.st_blocks << endl;

   unsigned int *base = (unsigned int *)mmap(0, statbuf.st_size, PROT_READ,
              MAP_SHARED, fd, 0);
   if( !base )
   {
      cout << "MMAP error for file " << buf << endl;
      return 0;
   }

   unsigned int num_ids = statbuf.st_size/sizeof(int);

   if( !numIDs )
      idList = (unsigned int *)malloc(sizeof(int) * num_ids);
   else
      idList = (unsigned int *)realloc(idList,sizeof(int) * (num_ids + numIDs));

   if( !idList )
   {
      cout << "Out of memory in ids allocation\n";
      return 0;
   }

   memcpy(&idList[numIDs], base, statbuf.st_size);
//cout << "FIST NODE=" << idList[numIDs] << endl;
//cout << "LAST NODE=" << idList[(num_ids + numIDs)-1] << endl;

   munmap(base, statbuf.st_size);
   close(fd);

   numIDs += num_ids;
   /**
   for(unsigned int i = 0; i < num_ids; i++)
   {
    cout << idList[i] << " ";
    if(i % 10)
       cout << "\n";
   }
   **/

   unsigned long etime = GenTime::getCurrentMillis();
cout << "TIME READ IDS = " << (etime-stime) << endl;
   return num_ids;
}

