#ifndef _READ_IDS_H_
#define _READ_IDS_H_

#include <iostream>
#include <list>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <sys/mman.h>
#include <stdlib.h>
#include <unistd.h>
#include <search.h>
#include "gentime.h"
#include "readgen.h"

using namespace std;

/** Class for reading the node IDS in sequence. The list of node ids in the
  * model are stored in node_ids file. 
  */
class ReadIDS
{
public:
   ReadIDS(){}

   /** Constructor for creating this object
     * \param dir Name of the directory
     * \param model Name of the model
     */
   ReadIDS(const char *dir, const char *model);
   
   /** Sets the directory and model name for the ids file to be loaded
     * \param dir Name of the directory
     * \param model Name of the model
     */
   void set(const char *dir, const char *model);
 
   ~ReadIDS();

   /** Searches the given node id and returns its location in the list for 
     * getting the node values
     * \param id Node id to be found
     * \return return the location of node if found else (1<<31)
     */
   inline unsigned int find(unsigned int id)
   {
      unsigned int *id_ptr = (unsigned int *)bsearch(&id, idList, numIDs, 
                                               sizeof(int), compareIDs);
//cout << "id=" << id << endl;
      if( id_ptr )
      {
//cout << "ID=" << *id_ptr << endl;
         return (id_ptr - idList);
      }
      else
      {
         if( id != 0 )
cout << "Node ID <" << id << "> not found\n";
         return (1<<31);
      }
      //return (id_ptr ? (id_ptr - idList) : (1<<31));
   }

   /** Loads the id file into memory.
     * \param id_file Name of ids file. Default is node_ids
     * \return Returns 0 on fail else number of ids loaded
     */
   int get(const char *id_file = "node_ids");

private:
   const char *dirName, *modelName;
   /** Number of ids loaded */
   unsigned int numIDs;
   /** List of ids */
   unsigned int *idList;
};

#endif

