#include "readnodes.h"

ReadNodes::ReadNodes(const char *dir, const char *model) : selectedNodes(NULL), 
   numNodes(0), nodeValues(NULL), m_MallocCount(0)
{
   dirName = dir;
   modelName = model;
}

ReadNodes::~ReadNodes()
{
   if( numNodes )
   {
      free(nodeValues);
      if( selectedNodes )
	 delete selectedNodes;
      numNodes = 0;
   }
}

unsigned int ReadNodes::addNode(float inNodeVal[3])
{
   unsigned int curCount = (unsigned int)numNodes;
   if(m_MallocCount == 0)
   {
      m_MallocCount = 100;
      nodeValues = (float *)realloc(nodeValues, sizeof(float) * (curCount + m_MallocCount) * 3);
   }
   
   memcpy(&nodeValues[curCount*3], inNodeVal, sizeof(float) * 3);

cout << "NEW VALUES=" << inNodeVal[0] << "," << inNodeVal[1] 
                      << "," << inNodeVal[2] << endl;

   m_MallocCount--;
   numNodes++;
   return curCount;
}

unsigned int ReadNodes::addNode(float *inNodeVal, unsigned int nIndex)
{
   unsigned int curCount = (unsigned int)numNodes;
   if(m_MallocCount == 0)
   {
      m_MallocCount = 100;
      nodeValues = (float *)realloc(nodeValues, sizeof(float) * (curCount + m_MallocCount) * 3);
   }
   
   memcpy(&nodeValues[curCount*3], &inNodeVal[nIndex*3], sizeof(float) * 3);

cout << "NEW VALUES=" << inNodeVal[nIndex*3] << "," << inNodeVal[(nIndex*3)+1] 
                      << "," << inNodeVal[(nIndex*3)+2] << endl;
   m_MallocCount--;
   numNodes++;
   return curCount;
}

void ReadNodes::set(const char *dir, const char *model)
{
   dirName = dir;
   modelName = model;
}

float *ReadNodes::getValuesPtr()
{
   return nodeValues;
}

char *ReadNodes::getSelectedPtr()
{
   if( !selectedNodes )
   {
      selectedNodes = new char[numNodes];
      memset(selectedNodes, '0', sizeof(char) * numNodes);
   }
   return selectedNodes;
}

int ReadNodes::getNumNodes()
{
   return numNodes;
}

int ReadNodes::getValues()
{
   unsigned long stime = GenTime::getCurrentMillis();
   char buf[256];
   struct stat statbuf;
/*
   float exts[6];
   sprintf(buf, "%s/%s/part_start", dirName, modelName);
   FILE *filePtr = fopen(buf, "rb");

   if( !filePtr )
   {
      cout << "Unable to open part_start file in readnodes.h" << buf << endl;
      return 0; 
   }

   fread(exts, sizeof(float) * 6, 1, filePtr);
   fclose(filePtr);
*/

   sprintf(buf, "%s/%s/node_values", dirName, modelName);
   int fd = open(buf, O_RDONLY);

   if( fd < 0 )
   {
      cout << "No node data for =" << buf << endl;
      return 0;
   }

   if( fstat(fd, &statbuf) < 0 )
   {
      cout << "Unable to stat file " << buf << endl;
      return 0;
   }
//cout << "BLOCK SIZE=" << statbuf.st_blksize << endl;
//cout << "NUM BLOCK =" << statbuf.st_blocks << endl;

   float *base = (float *)mmap(0, statbuf.st_size, PROT_READ, 
			  MAP_SHARED, fd, 0);
   if( !base )
   {
      cout << "MMAP error for file " << buf << endl;
      return 0;
   }

   int num_nodes = statbuf.st_size/(sizeof(float) *3);

   if( !numNodes )
      nodeValues = (float *)malloc(sizeof(float) * (num_nodes * 3));
   else
      nodeValues = (float *)realloc(nodeValues, 
			   sizeof(float) * (numNodes + num_nodes) * 3);
   if( !nodeValues )
   {
      cout << "Out of memory in node allocation\n";
      return 0;
   }

   memcpy(&nodeValues[numNodes], base, statbuf.st_size);
   munmap(base, statbuf.st_size);
   close(fd);

/* modifying the nodes to make the min and max values equal on both sides
 * is not solving the problem of orientation of the model the same way 
 * for any type of model
cout << "before node exts = " << exts[0] << "," << exts[1] << "," << exts[2]
     << "," << exts[3] << "," << exts[4] << "," << exts[5] << endl;
   float xrange = (exts[1] - exts[0])/2.0;
   float yrange = (exts[3] - exts[2])/2.0;
   float zrange = (exts[5] - exts[4])/2.0;

   float xcorr = -xrange - exts[0];
   float ycorr = -yrange - exts[2];
   float zcorr = -zrange - exts[4];

   exts[0] += xcorr; exts[1] += xcorr;
   exts[2] += ycorr; exts[3] += ycorr;
   exts[4] += zcorr; exts[5] += zcorr;

cout << "after node exts = " << exts[0] << "," << exts[1] << "," << exts[2]
     << "," << exts[3] << "," << exts[4] << "," << exts[5] << endl;
   float *ptr = nodeValues;
   for(int i = numNodes; i < num_nodes; i++)
   {
      *ptr += xcorr; 
      ptr++;
      *ptr += ycorr; 
      ptr++;
      *ptr += zcorr; 
      ptr++;
   }
*/

   numNodes += num_nodes;
cout << "NUM NODES IN READVALUES=" << num_nodes << endl;
//cout << "TOTAL NODES IN READVALUES=" << numNodes << endl;
   unsigned long etime = GenTime::getCurrentMillis();
cout << "TIME READ VALUES = " << (etime-stime) << endl;
   return num_nodes;
}
