#ifndef _READ_NODES_H_
#define _READ_NODES_H_

#include <map>
#include <iostream>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <sys/mman.h>
#include <stdlib.h>
#include <search.h>
#include "gentime.h"
#include "filelist.h"

using namespace std;

/** Class for reading the node coordinates from node_values file
  */
class ReadNodes
{
public:
   /** Constructor for creating this object
     * \param dir Name of the directory
     * \param model Name of the model
     */
   ReadNodes(const char *dir, const char *model);

   ~ReadNodes();

   /** Sets the directory and model name for the node_values file to be loaded
     * \param dir Name of the directory
     * \param model Name of the model
     */
   void set(const char *dir, const char *model);

   /** Returns the pointer to the list of node values */
   float *getValuesPtr();

   /** Returns a pointer to selected list of nodes. Each node has 1 or 0 */
   char *getSelectedPtr();
  
   /** Gets the count of nodes */
   int getNumNodes();

   /** Function for loading the node values into memory
     * \return Returns the number of nodes loaded
     */
   int getValues();
   
   unsigned int addNode(float *inNodeVal, unsigned int nIndex);

   unsigned int addNode(float inNodeVal[3]);

private:
   const char  *dirName, *modelName;
   /** Pointer holding the array of selected nodes */
   char        *selectedNodes;
   /** Number of nodes */
   size_t      numNodes;
   /** Pointer holding the node values as x1,y1,z1,x2,y2,z2,...... */
   float       *nodeValues;
   int         m_MallocCount;
};

#endif

