#include <iostream>
#include <stdlib.h>
#include <GL/gl.h>
#include <GL/glu.h>
#include "gentime.h"
//#include "genmath.h"
#include "caeenv.h"
#include "maptypes.h"
#include <math.h>
#include <sys/mman.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include "readelements.h"

#define POSITIVE(x) (x = (x < 0) ? -x : x)
#define MIN(a, b) ((a) < (b) ? (a) : (b))
#define MAX(a, b) ((a) > (b) ? (a) : (b))

#define INT_LARGE (((unsigned int)1)<<31)

using namespace std;

CAEEnv::CAEEnv(const char *dir_name, const char *model_name, int shade) :
  numParts(0), compFlag(0), pickType(PART_PICK), numNodes(0), shadeModel(shade)
{
   memset(colorBlue, 0, sizeof(float) * 4);
   memset(colorGreen, 0, sizeof(float) * 4);
   colorBlue[3] = colorGreen[3] = colorBlue[2] = colorGreen[1] = 1.0;
   dirName = dir_name;
   modelName = model_name;
   modelExtents[0] = -2000.0f;
   modelExtents[1] = 2000.0f;
   modelExtents[2] = -2000.0f;
   modelExtents[3] = 2000.0f;
   modelExtents[4] = -2000.0f;
   modelExtents[5] = 2000.0f;
   cae_Env = this;
   memcpy(orgModelExtents, modelExtents, sizeof(float) * 6);
   segmentPart = NULL;
}

int CAEEnv::getAll(vector<unsigned int> *pid_list)
{
unsigned long stime = GenTime::getCurrentMillis();
   const char *dir = dirName.data(), *model = modelName.data();
   sprintf(charBuff, "%s/%s/part_start", dir, model);
   cout << charBuff << endl;
   filePtr = fopen(charBuff, "rb");
   primitiveType = GL_QUADS;

   if( !filePtr )
   {
      cout << "Unable to open part_start binary file" << charBuff << endl;
      return 1;
   }

   unsigned int num_files = 0, len = 0;
   fread(modelExtents, sizeof(float) * 6, 1, filePtr);

   if( modelExtents[0] == modelExtents[1] )
      modelExtents[1] = -modelExtents[0];

   memcpy(orgModelExtents, modelExtents, sizeof(float) * 6);
   fread(&num_files, sizeof(int), 1, filePtr);

cout << "NUM FILES in CAE=" << num_files << endl;

   //vector<string> file_list;
   if( num_files > 1 )
   {
      char buf[256];
      for(i = 0; i < num_files; i++)
      {
         fread(&len, sizeof(int), 1, filePtr);
         fread(buf, sizeof(char) * len, 1, filePtr);
         buf[len] = '\0';
         fileList.push_back(buf);
      }
   }
   else
      fileList.push_back(model);

cout << "NUM FILES FORM LIST=" << fileList.size() << endl;

   fclose(filePtr);
   unsigned int num_elms, num_nodes;

   ReadIDS *read_ids = NULL;
   ReadNodes *read_nodes = NULL;

   partsInfoList = NULL;

   vector<ReadIDS *> readIDSVector(fileList.size());
   vector<ReadNodes *> readNodesVector(fileList.size());
   for(i = 0; i < fileList.size(); i++)
   {
      model = fileList[i].data();
      read_ids = new ReadIDS(dir, model);
      num_nodes = read_ids->get();
cout << "NUM NODES FROM READ IDS=" << num_nodes << endl;
      readIDSVector[i] = read_ids;
      read_nodes = new ReadNodes(dir, model);
      readNodesVector[i] = read_nodes;
      if( num_nodes )
      {
         num_nodes = read_nodes->getValues();
cout << "NUM NODES FROM READ NODES=" << num_nodes << endl;
      }
   }

   ReadElements read_elms(&pidMap, &readIDSVector, &readNodesVector);

   for(i = 0; i < fileList.size(); i++)
   {
      model = fileList[i].data();

      /*read_ids = new ReadIDS(dir, model);
      num_nodes = read_ids->get();
cout << "NUM NODES FROM READ IDS=" << num_nodes << endl;
      if( num_nodes )
      {
         read_nodes = new ReadNodes(dir, model);
         num_nodes = read_nodes->getValues();
cout << "NUM NODES FROM READ NODES=" << num_nodes << endl;
         if(num_nodes)*/
         {
             read_elms.setValues(dir, model, i, readIDSVector[i], readNodesVector[i]);
             if( !pid_list )
                  num_elms = read_elms.getAll(&numParts, &partsInfoList);
             else
                  num_elms = read_elms.getPartsByID(pid_list,
                                             &numParts, &partsInfoList);
         }
         //delete read_nodes;
      //}
      //delete read_ids;
   }

   for(size_t f = 0; f < readIDSVector.size(); f++)
   {
      delete readIDSVector[f];
      delete readNodesVector[f];
   }

cout << "TOTAL PARTS=" << numParts << endl;
unsigned long etime = GenTime::getCurrentMillis();
cout << "TIME FOR ALL=" << (etime-stime) << " msec" << endl;

   return 0;
}

void CAEEnv::loadAndInitGL(unsigned int font_base, bool thread_status, vector<unsigned int> *pid_list)
{
unsigned long stime = GenTime::getCurrentMillis();
   glClearColor(0.0, 0.0, 0.0, 1.0);
   if( !thread_status )
      getAll(pid_list);

   mView = new MView(modelExtents);
   mTrans = new MTransform(modelExtents);
   
   boxList = new BoundBox *[numParts];
   for(i = 0; i < numParts; i++)
      boxList[i] = new BoundBox(partsInfoList[i].partExtents);

   BoundBox::setFontBase(font_base);

   glShadeModel(shadeModel);
   computeNormals();
   switchOnLights();

cout << "NUM PARTS=" << numParts << endl;
cout << "MODEL EXTS=" << modelExtents[0] << "," << modelExtents[1] << ","
     << modelExtents[2] << "," << modelExtents[3] << ","
     << modelExtents[4] << "," << modelExtents[5] << endl;
unsigned long etime = GenTime::getCurrentMillis();
cout << "TIMEFOR loadAndInitGL=" << (etime-stime) << endl;
}

void CAEEnv::resizeModel(int w, int h)
{
   glViewport(0, 0, (GLint) w, (GLint) h);
   glMatrixMode(GL_PROJECTION);
   glLoadIdentity();

cout << "RESIZE MODEL EXTS=" << modelExtents[0] << "," << modelExtents[1] << ","
     << modelExtents[2] << "," << modelExtents[3] << ","
     << modelExtents[4] << "," << modelExtents[5] << endl;
   glOrtho(modelExtents[0], modelExtents[1], modelExtents[2], modelExtents[3], 
                  Z_MAX_COORD, Z_MIN_COORD);
   glMatrixMode(GL_MODELVIEW);
   glLoadIdentity();

   mTrans->setViewport(w, h);
}

void CAEEnv::setDisplay(unsigned int num_parts, unsigned int *parts_list, unsigned int on_off)
{
   unsigned int part_num;

   for(i = 0; i < num_parts; i++)
   {
      part_num = parts_list[i]-1;
      if( part_num < numParts )
      {
	 switch(on_off)
	 {
	    case DISP_ON:
	       partsInfoList[part_num].partFlag |= (on_off); 
	       partsInfoList[part_num].partFlag &= ~DISP_OFF; 
	    break;
	    case DISP_OFF:
	       partsInfoList[part_num].partFlag |= (on_off); 
	       partsInfoList[part_num].partFlag &= ~DISP_ON; 
	    break;
	 }
      }
   }
}

void CAEEnv::setDisplay(unsigned int part_num, unsigned int on_off)
{
   if( part_num <= numParts )
   {
      switch(on_off)
      {
         case DISP_ON:
            partsInfoList[part_num-1].partFlag |= (on_off); 
            partsInfoList[part_num-1].partFlag &= ~DISP_OFF; 
         break;
         case DISP_OFF:
            partsInfoList[part_num-1].partFlag |= (on_off); 
            partsInfoList[part_num-1].partFlag &= ~DISP_ON; 
         break;
      }
   }
}

void CAEEnv::processPartsByID(unsigned int flag, vector<unsigned int> *id_list)
{
   for(i = 0; i < numParts; i++)
   {
      switch(flag)
      {
         case DISP_ON:
            partsInfoList[i].partFlag |= DISP_OFF;
            partsInfoList[i].partFlag &= ~DISP_ON;
         break;
         case DISP_OFF:
            partsInfoList[i].partFlag |= DISP_ON;
            partsInfoList[i].partFlag &= ~DISP_OFF;
         break;
         case DISP_SELECT:
         case DISP_HIGHLIGHT:
            partsInfoList[i].partFlag &= ~flag;
         break;
         case DISP_CLEAR:
            partsInfoList[i].partFlag &= ~(DISP_SELECT|DISP_HIGHLIGHT);
         return;
      }
   }

   vector<unsigned int>::iterator b = id_list->begin(), e = id_list->end(); 
   UIUIIter iter, ep = pidMap.end();
cout << "NUM PARTS=" << pidMap.size() << endl;
   for(; b != e; b++)
   {
      iter = pidMap.find(*b);
      if( iter != ep )
	 partsInfoList[iter->second].partFlag |= flag;
      else
cout << "PID NOT FOUND=" << *b << endl;
   }

   for(i = 0; i < numParts; i++)
   {
      switch(flag)
      {
         case DISP_ON:
            if( (partsInfoList[i].partFlag & DISP_ON) )
               partsInfoList[i].partFlag &= ~DISP_OFF;
         break;
         case DISP_OFF:
            if( (partsInfoList[i].partFlag & DISP_OFF) )
               partsInfoList[i].partFlag &= ~DISP_ON;
         break;
         case DISP_SELECT:
         case DISP_HIGHLIGHT:
            if( (partsInfoList[i].partFlag & flag) )
            {
               partsInfoList[i].partFlag |= DISP_ON;
               partsInfoList[i].partFlag &= ~DISP_OFF;
            }
         break;
      }
   }

   modifyExtents();
}

void CAEEnv::selectPartsByID(vector<unsigned int> *id_list)
{
   vector<unsigned int>::iterator b = id_list->begin(), e = id_list->end(); 
   UIUIIter iter, ep = pidMap.end();
cout << "NUM PARTS=" << pidMap.size() << endl;
   for(; b != e; b++)
   {
      iter = pidMap.find(*b);
      if( iter != ep )
	 partsInfoList[iter->second].partFlag |= DISP_SELECT;
      else
cout << "PID NOT FOUND=" << *b << endl;
   }
}

void CAEEnv::selectPart(unsigned int part_num)
{
   if( part_num <= numParts )
   {
      partsInfoList[part_num-1].partFlag |= DISP_SELECT;
   }
}

void CAEEnv::highlightPart(unsigned int part_num)
{
   if( part_num <= numParts )
   {
      partsInfoList[part_num-1].partFlag |= DISP_HIGHLIGHT;
   }
}

void CAEEnv::setBoxDisplay(int box_on_off)
{
   for(i = 0; i < numParts; i++)
   {
      if( partsInfoList[i].partFlag & DISP_OFF )
         continue;

      switch(box_on_off)
      {
         case DISP_ON:
            partsInfoList[i].partFlag |= DISP_BOX;
         break;
         case DISP_OFF:
            partsInfoList[i].partFlag &= ~DISP_BOX;
         break;
      }
   }
}

void CAEEnv::displayAllParts()
{
   for(i = 0; i < numParts; i++)
   {
      partsInfoList[i].partFlag |= DISP_ON;
      partsInfoList[i].partFlag &= ~DISP_OFF;
   }

   memcpy(modelExtents, orgModelExtents, sizeof(float) * 6);
   mView->setExtents(modelExtents); 
   glGetIntegerv(GL_VIEWPORT, viewPort);
   resizeModel(viewPort[2], viewPort[3]);
   switchOnLights();
}

void CAEEnv::clearSelectedParts()
{
   for(i = 0; i < numParts; i++)
   {
      if( partsInfoList[i].partFlag & DISP_SELECT )
         partsInfoList[i].partFlag &= ~DISP_SELECT;
   }
}

void CAEEnv::processParts(unsigned int on_off)
{
/*
   for(i = 0; i < numParts; i++)
   {
      if( partsInfoList[i].partFlag & (DISP_SELECT|NODE_PICK|ELEMENT_PICK) )
         break;
   }

   if( i >= numParts )
      return;
*/

   switch(on_off)
   {
      case DISP_ON:
	 for(i = 0; i < numParts; i++)
	 {
	    if(partsInfoList[i].partFlag & (DISP_SELECT|NODE_PICK|ELEMENT_PICK))
	    {
	       partsInfoList[i].partFlag |= DISP_ON;
	       partsInfoList[i].partFlag &= ~DISP_OFF;
	       partsInfoList[i].partFlag &= ~DISP_SELECT;
	    }
	    else
	    {
               //if( !(partsInfoList[i].partFlag & DISP_ON) )
               {
		  partsInfoList[i].partFlag |= DISP_OFF;
		  partsInfoList[i].partFlag &= ~DISP_ON;
		  partsInfoList[i].partFlag &= ~DISP_SELECT;
               }
	    }
	 }
      break;
      case DISP_OFF:
	 for(; i < numParts; i++)
	 {
	    if(partsInfoList[i].partFlag & (DISP_SELECT|NODE_PICK|ELEMENT_PICK))
	    {
	       partsInfoList[i].partFlag |= DISP_OFF;
	       partsInfoList[i].partFlag &= ~DISP_ON;
	       partsInfoList[i].partFlag &= ~DISP_SELECT;
	    }
         }
      break;
   }

   modifyExtents();
}


void CAEEnv::modifyExtents()
{
   set<float> x_values;
   set<float> y_values;
   set<float> z_values;

   for(i = 0; i < numParts; i++)
   {
      if( partsInfoList[i].partFlag & DISP_ON )
      {
	 x_values.insert(partsInfoList[i].partExtents[0]);
	 x_values.insert(partsInfoList[i].partExtents[1]);
	 y_values.insert(partsInfoList[i].partExtents[2]);
	 y_values.insert(partsInfoList[i].partExtents[3]);
	 z_values.insert(partsInfoList[i].partExtents[4]);
	 z_values.insert(partsInfoList[i].partExtents[5]);
      }
   }

   if( !x_values.size() )
      return;

   set<float>::iterator b = x_values.begin(), e = x_values.end(); e--;
   if( *b != 0.0 || *e != 0.0 )
   {
      modelExtents[0] = *b; 
      modelExtents[1] = *e;
   }
   else
   {
      modelExtents[0] = -2000.0;
      modelExtents[1] = 2000.0;
   }

   b = y_values.begin(); e = y_values.end(); e--;
   if( *b != 0.0 || *e != 0.0 )
   {
      modelExtents[2] = *b; 
      modelExtents[3] = *e;
   }
   else
   {
      modelExtents[2] = -2000.0;
      modelExtents[3] = 2000.0;
   }

   b = z_values.begin(); e = z_values.end(); e--;
   if( *b != 0.0 || *e != 0.0 )
   {
      modelExtents[4] = *b; 
      modelExtents[5] = *e;
   }
   else
   {
      modelExtents[4] = -2000.0;
      modelExtents[5] = 2000.0;
   }
cout << "xmin=" << modelExtents[0] << " xmax=" << modelExtents[1] << endl;
cout << "ymin=" << modelExtents[2] << " ymax=" << modelExtents[3] << endl;
cout << "zmin=" << modelExtents[4] << " zmax=" << modelExtents[5] << endl;

   //mView->setExtents(modelExtents); this is causing the change of view
   glGetIntegerv(GL_VIEWPORT, viewPort);
   resizeModel(viewPort[2], viewPort[3]);
   switchOnLights();
   mTrans->updateWindowCenter();
}

void CAEEnv::changeLightPositions()
{
   float cx = (modelExtents[0] + modelExtents[1]) / 2.0f;
   float lightPos0[4] = {cx, -modelExtents[1], -modelExtents[5]};
   float lightPos1[4] = {2*modelExtents[1], 2*modelExtents[3], 2*modelExtents[5]};

cout << "NEW Lightpos0=" << lightPos0[0] << "," << lightPos0[1] << ","
     << lightPos0[2] << endl;
cout << "NEW Lightpos1=" << lightPos1[0] << "," << lightPos1[1] << ","
     << lightPos1[2] << endl;

   glLightfv(GL_LIGHT0, GL_POSITION, lightPos0);
   glLightfv(GL_LIGHT1, GL_POSITION, lightPos1);
}

void CAEEnv::switchOnLights()
{
cout << "LIGHT xmin=" << modelExtents[0] << " xmax=" << modelExtents[1] << endl;
cout << "LIGHT ymin=" << modelExtents[2] << " ymax=" << modelExtents[3] << endl;
cout << "LIGHT zmin=" << modelExtents[4] << " zmax=" << modelExtents[5] << endl;
   float cx = (modelExtents[0] + modelExtents[1]) / 2.0f;
   float lightPos0[4] = {cx, -modelExtents[1], -modelExtents[5]};
   float lightPos1[4] = {2*modelExtents[1], 2*modelExtents[3], 2*modelExtents[5]};

cout << "Lightpos0=" << lightPos0[0] << "," << lightPos0[1] << ","
     << lightPos0[2] << endl;
cout << "Lightpos1=" << lightPos1[0] << "," << lightPos1[1] << ","
     << lightPos1[2] << endl;

   float lightKa[4] = {0.1f, 0.1f, 0.1f, 1.0f};
   float lightKd[4] = {0.9f, 0.9f, 0.9f, 0.0f};
   float lightKs[4] = {0.9f, 0.9f, 0.9f, 0.0f};
   float lightDir[3] = {1.0f, 1.0f, 1.0f};
   GLint lightExp = 30;
   GLfloat lightKc = 1.0f, lightKl = 0.0f, lightKq = 0.0f;

   glEnable(GL_COLOR_MATERIAL);
   glLightfv(GL_LIGHT0, GL_POSITION, lightPos0);
   glLightfv(GL_LIGHT0, GL_AMBIENT, lightKa);
   glLightfv(GL_LIGHT0, GL_DIFFUSE, lightKd);
   glLightfv(GL_LIGHT0, GL_SPECULAR, lightKs);

   glLightfv(GL_LIGHT0, GL_SPOT_DIRECTION, lightDir);
   glLighti(GL_LIGHT0, GL_SPOT_EXPONENT, lightExp);

   glLightf(GL_LIGHT0, GL_CONSTANT_ATTENUATION, lightKc);
   glLightf(GL_LIGHT0, GL_LINEAR_ATTENUATION, lightKl);
   glLightf(GL_LIGHT0, GL_QUADRATIC_ATTENUATION, lightKq);

   glLightfv(GL_LIGHT1, GL_POSITION, lightPos1);
   glLightfv(GL_LIGHT1, GL_AMBIENT, lightKa);
   glLightfv(GL_LIGHT1, GL_DIFFUSE, lightKd);
   glLightfv(GL_LIGHT1, GL_SPECULAR, lightKs);
   glLightfv(GL_LIGHT1, GL_SPOT_DIRECTION, lightDir);
   glLighti(GL_LIGHT1, GL_SPOT_EXPONENT, lightExp);
   glLightf(GL_LIGHT1, GL_CONSTANT_ATTENUATION, lightKc);
   glLightf(GL_LIGHT1, GL_LINEAR_ATTENUATION, lightKl);
   glLightf(GL_LIGHT1, GL_QUADRATIC_ATTENUATION, lightKq);

   glEnable(GL_LIGHTING);
   glEnable(GL_LIGHT0);
   glEnable(GL_LIGHT1);
   glEnable(GL_NORMALIZE);
   glEnable(GL_RESCALE_NORMAL);

   glEnable(GL_DEPTH_TEST);
   glDepthFunc(GL_LESS);
   glDepthRange(0.0, 1.0);
}

/* As on DEC 09 2009 this is the better available display using the element
 * normals for flat display and node normals for smooth display. This uses
 * less memory and fast computations and shows the same display as that based 
 * on angle between the node normals. Still for the best display normals 
 * compution has to be modified. At present the node normal is
 * node_normal = sum of the element normals common to that node 
 */
void CAEEnv::computeNormals()
{
unsigned long stime = GenTime::getCurrentMillis();
   PartInfoPtr     part_info;

   for(i = 0; i < numParts; i++)
   {
      part_info = &partsInfoList[i];
      switch(part_info->partDrawType)
      {
         case SHELL:
            computeShellNormals(part_info);
         break;
         case SOLID:
            computeSolidNormals(part_info);
         break;
/*
         case BEAM:
         case DISCRETE:
         {
            unsigned int num_elms = part_info->partElements.numElements/
                                       part_info->partElements.nodesPerElement;
            part_info->partElements.selectedList = new char[num_elms];
            memset(part_info->partElements.selectedList, '0',
					  sizeof(char) * num_elms);
         }
         break;
*/
      }
   }

unsigned long etime = GenTime::getCurrentMillis();
cout << "TIME FOR ELM NORMALS=" << (etime-stime) << endl;
}

void CAEEnv::createNodeSelectedList()
{
   PartInfoPtr     part_info;
   unsigned int num_nodes;

   for(i = 0; i < numParts; i++)
   {
      part_info = &partsInfoList[i];
      num_nodes = part_info->partNodes.numNodes; 
      part_info->partNodes.selectedNodes = new char[num_nodes];
      memset(part_info->partNodes.selectedNodes, '0', sizeof(char) * num_nodes);
   }
}

void CAEEnv::createElementSelectedList()
{
   PartInfoPtr     part_info;
   unsigned int    num_elm_size;

   for(i = 0; i < numParts; i++)
   {
      part_info = &partsInfoList[i];
      num_elm_size = part_info->partElements.numElements/
                            part_info->partElements.nodesPerElement;
      part_info->partElements.selectedList = new char[num_elm_size];
      memset(part_info->partElements.selectedList, '0', 
					     sizeof(char) * num_elm_size);
   }
}

void CAEEnv::normalize(PartInfoPtr part_info)
{
   unsigned int num_nodes = part_info->partNodes.numNodes, m, n;
   float        len, *node_normals = part_info->partNodes.nodeNormals;

   for(m = 0; m < num_nodes; m++)
   {
      n = m * 3;
      len = sqrt(node_normals[n] * node_normals[n] + node_normals[n+1] * 
	    node_normals[n+1] + node_normals[n+2] * node_normals[n+2]);
      node_normals[n] /= len;
      node_normals[n+1] /= len;
      node_normals[n+2] /= len;
   }
}

void CAEEnv::computeElementNormal
     (
        unsigned int *nodes, 
        float *node_values,
        float *node_normals,
        float *elm_normals
     )
{
   unsigned int    n1, n2, n3, n4;
   float           x1, x2, x3;
   float           y1, y2, y3;
   float           z1, z2, z3;
   float           x, y, z;
   float           len;

   n1 = nodes[0]; n2 = nodes[1]; n3 = nodes[2]; n4 = nodes[3];

   if((n1 & UNSIGNED_INT_MAX_FLAG) || (n2 & UNSIGNED_INT_MAX_FLAG) || (n3 & UNSIGNED_INT_MAX_FLAG) || (n4 & UNSIGNED_INT_MAX_FLAG))
      return;

   x1 = node_values[n1];
   y1 = node_values[n1+1];
   z1 = node_values[n1+2];

   x2 = node_values[n2];
   y2 = node_values[n2+1];
   z2 = node_values[n2+2];

   x3 = node_values[n3];
   y3 = node_values[n3+1];
   z3 = node_values[n3+2];

   x = ((y2 - y1) * (z3 - z1)) - ((y3 - y1) * (z2 - z1));
   y = -((x2 - x1) * (z3 - z1)) + ((x3 - x1) * (z2 - z1));
   z = ((x2 - x1) * (y3 - y1)) - ((x3 - x1) * (y2 - y1));

/* This is from the 'computer graphics' by Hearn and Baker
   x = y1 * (z2-z3) + y2 * (z3-z1) + y3 * (z1-z2);
   y = z1 * (x2-x3) + z2 * (x3-x1) + z3 * (x1-x2);
   z = x1 * (y2-y3) + x2 * (y3-y1) + x3 * (y1-y2);
*/

   len = sqrt(x * x + y * y + z * z);

   if( shadeModel == GL_FLAT )
   {
      *elm_normals = x/len;
      *(elm_normals+1) = y/len;
      *(elm_normals+2) = z/len;
   }
   else
   {
      node_normals[n1] = (node_normals[n1] + x);
      node_normals[n1+1] = (node_normals[n1+1] + y);
      node_normals[n1+2] = (node_normals[n1+2] + z);

      node_normals[n2] = (node_normals[n2] + x);
      node_normals[n2+1] = (node_normals[n2+1] + y);
      node_normals[n2+2] = (node_normals[n2+2] + z);

      node_normals[n3] = (node_normals[n3] + x);
      node_normals[n3+1] = (node_normals[n3+1] + y);
      node_normals[n3+2] = (node_normals[n3+2] + z);

      if( !(n4 & INT_LARGE) )
      {
	 node_normals[n4] = (node_normals[n4] + x);
	 node_normals[n4+1] = (node_normals[n4+1] + y);
	 node_normals[n4+2] = (node_normals[n4+2] + z);
      }
   }
}

void CAEEnv::computeSolidNormals(PartInfoPtr part_info)
{
   unsigned int    n1, n2, n3, n4, n5, n6, n7, n8, num_nodes, npe = 8, part_npe,
      m, n, num_elm_size, *elm_indices, num_indices, nodes[4];
   float           *node_values, *elm_normals = NULL, *node_normals = NULL;

   num_indices = part_info->partElements.numElements;
   part_npe = part_info->partElements.nodesPerElement;
   num_elm_size = part_info->partElements.numElements/part_npe; 
   elm_indices = part_info->partElements.elmIndices;
   node_values = part_info->partNodes.nodeValues;
   num_nodes = part_info->partNodes.numNodes;

   if( shadeModel == GL_FLAT )
   {
       if(part_info->partFlag & COMPUTE_ELEMENT_NORMALS)
           return;
      part_info->partElements.elmNormals = new float[NUM_COORDS*num_elm_size*6];
      elm_normals = part_info->partElements.elmNormals;
      memset(elm_normals, 0, sizeof(float) * NUM_COORDS * num_elm_size * 6);
      part_info->partFlag |= COMPUTE_ELEMENT_NORMALS;
   }
   else
   {
/*
      part_info->partNodes.selectedNodes = new char[num_nodes];
      memset(part_info->partNodes.selectedNodes, '0', sizeof(char) * num_nodes);
      part_info->partElements.selectedList = new char[num_elm_size];
      memset(part_info->partElements.selectedList, '0', 
					     sizeof(char) * num_elm_size);
*/
       if(part_info->partFlag & COMPUTE_NODE_NORMALS)
           return;

      part_info->partNodes.nodeNormals = new float[NUM_COORDS * num_nodes];
      node_normals = part_info->partNodes.nodeNormals;
      memset(node_normals, 0, sizeof(float) * NUM_COORDS * num_nodes);

      part_info->partFlag |= COMPUTE_NODE_NORMALS;
   }

   if( !part_info->partElements.NPE )
   {
      part_info->partElements.NPE = new char[num_elm_size];
      memset(part_info->partElements.NPE, '8', sizeof(char) * num_elm_size);
   }

   char *npe_ptr = part_info->partElements.NPE;

//cout << "PID=" << part_info->partID << endl;
   for(m = 0, n = 0;m < num_indices;m += part_npe, n += 18, npe_ptr++)
   {
      n1 = elm_indices[m] * NUM_COORDS;
      n2 = elm_indices[m+1] * NUM_COORDS;
      n3 = elm_indices[m+2] * NUM_COORDS;
      n4 = elm_indices[m+3] * NUM_COORDS;
      n5 = elm_indices[m+4] * NUM_COORDS;
      n6 = elm_indices[m+5] * NUM_COORDS;
      n7 = elm_indices[m+6] * NUM_COORDS;
      n8 = elm_indices[m+7] * NUM_COORDS;
//cout << "N1=" << n1 << "," << n2 << "," << n3 << "," << n4 << "," << n5 << ","
//     << n6 << "," << n7 << "," << n8 << endl;

      switch(part_npe)
      {
         case 8:
         {
	    npe = 8;
	    if( n4 != n5 )
	    {
	       if( n5 == n6 )
	       {
		 npe = 6;
		 *npe_ptr = '6';
	       }
	    }
	    else
	    {
	       npe = 4;
	       *npe_ptr = '4';
	    }
         }
         break;
         case 10:
         {
	    npe = 4;
	    *npe_ptr = '4';
         }
         break;
      }

//cout << "NPE=" << npe << endl;

/*
      0, 1, 2, 3,
      1, 2, 6, 5,
      4, 5, 6, 7,
      3, 0, 4, 7,
      2, 3, 7, 6,
      0, 1, 5, 4,
*/

      switch(npe)
      {
         case 8:
         {
	    nodes[0] = n1; nodes[1] = n2; nodes[2] = n3; nodes[3] = n4;
	    computeElementNormal(nodes, node_values, 
                           node_normals, &elm_normals[n]);
	    nodes[0] = n2; nodes[1] = n3; nodes[2] = n7; nodes[3] = n6;
	    computeElementNormal(nodes, node_values, 
                           node_normals, &elm_normals[n+3]);
	    nodes[0] = n5; nodes[1] = n6; nodes[2] = n7; nodes[3] = n8;
	    computeElementNormal(nodes, node_values, 
                           node_normals, &elm_normals[n+6]);
	    nodes[0] = n4; nodes[1] = n1; nodes[2] = n5; nodes[3] = n8;
	    computeElementNormal(nodes, node_values, 
                           node_normals, &elm_normals[n+9]);
	    nodes[0] = n3; nodes[1] = n4; nodes[2] = n8; nodes[3] = n7;
	    computeElementNormal(nodes, node_values, 
                           node_normals,&elm_normals[n+12]);
	    nodes[0] = n1; nodes[1] = n2; nodes[2] = n6; nodes[3] = n5;
	    computeElementNormal(nodes, node_values, 
                           node_normals,&elm_normals[n+15]);
         }
         break;
         case 4:
         {
	    nodes[0] = n1; nodes[1] = n2; nodes[2] = n3; nodes[3] = INT_LARGE;
	    computeElementNormal(nodes, node_values, 
                           node_normals, &elm_normals[n]);
	    nodes[0] = n1; nodes[1] = n2; nodes[2] = n4;
	    computeElementNormal(nodes, node_values, 
                           node_normals, &elm_normals[n+3]);
	    nodes[0] = n3; nodes[1] = n1; nodes[2] = n4;
	    computeElementNormal(nodes, node_values, 
                           node_normals, &elm_normals[n+6]);
	    nodes[0] = n2; nodes[1] = n3; nodes[2] = n4;
	    computeElementNormal(nodes, node_values, 
                           node_normals, &elm_normals[n+9]);
         }
         break;
         case 6:
         {
	    nodes[0] = n1; nodes[1] = n2; nodes[2] = n3; nodes[3] = n4;
	    computeElementNormal(nodes, node_values, 
                           node_normals, &elm_normals[n]);
	    nodes[0] = n2; nodes[1] = n3; nodes[2] = n6; nodes[3] = n5;
	    computeElementNormal(nodes, node_values, 
                           node_normals, &elm_normals[n+3]);
	    nodes[0] = n4; nodes[1] = n1; nodes[2] = n5; nodes[3] = n6;
	    computeElementNormal(nodes, node_values, 
                           node_normals, &elm_normals[n+6]);
	    nodes[0] = n1; nodes[1] = n2; nodes[2] = n5; nodes[3] = INT_LARGE;
	    computeElementNormal(nodes, node_values, 
                           node_normals, &elm_normals[n+9]);
	    nodes[0] = n3; nodes[1] = n4; nodes[2] = n6;
	    computeElementNormal(nodes, node_values, 
                           node_normals,&elm_normals[n+12]);
         }
         break;
      }
   }
  
   if( shadeModel == GL_SMOOTH )
      normalize(part_info);
}

void CAEEnv::computeShellNormals(PartInfoPtr part_info)
{
   unsigned int    num_nodes, nodes[4], part_npe;
   unsigned int    m, n, num_elm_size, *elm_indices;
   float           *node_values, *elm_normals = NULL, *node_normals = NULL;

   num_elm_size = part_info->partElements.numElements;
   elm_indices = part_info->partElements.elmIndices;
   node_values = part_info->partNodes.nodeValues;
   num_nodes = part_info->partNodes.numNodes;
   part_npe = part_info->partElements.nodesPerElement;

   if( shadeModel == GL_FLAT )
   {
       if(part_info->partFlag & COMPUTE_ELEMENT_NORMALS)
           return;
      part_info->partElements.elmNormals = 
                   new float[NUM_COORDS * num_elm_size/part_npe];
      elm_normals = part_info->partElements.elmNormals;
      part_info->partFlag |= COMPUTE_ELEMENT_NORMALS;
      //memset(elm_normals,0,sizeof(float) * NUM_COORDS * num_elm_size/part_npe * 6);
   }
   else
   {
/*
      part_info->partNodes.selectedNodes = new char[num_nodes];
      memset(part_info->partNodes.selectedNodes, '0', sizeof(char) * num_nodes);
      part_info->partElements.selectedList = new char[num_elm_size/part_npe];
      memset(part_info->partElements.selectedList, '0', 
				     sizeof(char) * num_elm_size/part_npe);
*/
       if(part_info->partFlag & COMPUTE_NODE_NORMALS)
           return;

      part_info->partNodes.nodeNormals = new float[NUM_COORDS * num_nodes];
      node_normals = part_info->partNodes.nodeNormals;
      memset(node_normals, 0, sizeof(float) * NUM_COORDS * num_nodes);
      part_info->partFlag |= COMPUTE_NODE_NORMALS;
   }

   for(m = 0, n = 0;m < num_elm_size;m += part_npe, n += 3)
   {
      //n1 
      nodes[0] = elm_indices[m] * NUM_COORDS;
      //n2 
      nodes[1] = elm_indices[m+1] * NUM_COORDS;
      //n3 
      nodes[2] = elm_indices[m+2] * NUM_COORDS;
      //n4 
      nodes[3] = elm_indices[m+3] * NUM_COORDS;
      if( nodes[2] == nodes[3] )
         nodes[3] = INT_LARGE;

      computeElementNormal(nodes, node_values, node_normals, 
              &elm_normals[n]);
   }

   if( shadeModel == GL_SMOOTH )
      normalize(part_info);
}

int CAEEnv::save(const char *file_name)
{
   unsigned int len;

   filePtr = fopen(file_name, "wb");

   if( !filePtr )
   {
      cout << "Unable to open file <" << file_name << "> to save\n";
      return 1;
   }

   //save dir name
   len = dirName.size();
   fwrite(&len, sizeof(int), 1, filePtr);
   fwrite(dirName.data(), sizeof(char), len, filePtr);
   //save model name
   len = modelName.size();
   fwrite(&len, sizeof(int), 1, filePtr);
   fwrite(modelName.data(), sizeof(char), len, filePtr);

   for(i = 0; i < numParts; i++)
   {
      //save part display status
      fwrite(&partsInfoList[i].partFlag, sizeof(int), 1, filePtr);
      //save part color
      fwrite(&partsInfoList[i].partColor, sizeof(float), 4, filePtr);
   }

   //shading model
   fwrite(&shadeModel, sizeof(int), 1, filePtr);

   blendFlag = 0;
   if( glIsEnabled(GL_BLEND) )
      blendFlag = 1;
   fwrite(&blendFlag, sizeof(int), 1, filePtr);
   //polygon mode
   glGetIntegerv(GL_POLYGON_MODE, polygonMode);
   fwrite(polygonMode, sizeof(int), 2, filePtr);

   mView->save(filePtr);
   mTrans->save(filePtr);

   fclose(filePtr);
   return 0;
}

void CAEEnv::restore(FILE *file_ptr)
{
   for(i = 0; i < numParts; i++)
   {
      //read part display status
      fread(&partsInfoList[i].partFlag, sizeof(int), 1, file_ptr);
      // read part color
      fread(&partsInfoList[i].partColor, sizeof(float), 4, file_ptr);
   }

   //shading model
   fread(&shadeModel, sizeof(int), 1, file_ptr);
   setShadeModel(shadeModel);

   //blend
   fread(&blendFlag, sizeof(int), 1, file_ptr);
   setBlend(blendFlag);

   //polygon mode
   fread(polygonMode, sizeof(int), 2, file_ptr);
   glPolygonMode(GL_FRONT_AND_BACK, polygonMode[0]);

   mView->restore(file_ptr);
   mTrans->restore(file_ptr);
}

void CAEEnv::selectNodeList(vector<unsigned int> & nid_list)
{
   compFlag |= SELECT_NODES_ONLY;
   readNodes = new ReadNodes(dirName.data(), modelName.data()); 
   if( !readNodes->getValues() )
      return;

   selectedNodes = readNodes->getSelectedPtr();
   nodeValues = readNodes->getValuesPtr();
   numNodes = readNodes->getNumNodes();

   readIDS = new ReadIDS(dirName.data(), modelName.data());
   if( !readIDS->get() )
      return;

   unsigned int idx;
   float xmin = 1.0e6, ymin = 1.0e6, zmin = 1.0e6;
   float xmax = -1.0e6, ymax = -1.0e6, zmax = -1.0e6;
   vector<unsigned int>::iterator b = nid_list.begin(), e = nid_list.end();
   for(; b != e; b++)
   {
      idx = readIDS->find(*b);
      if( !(idx & (UNSIGNED_INT_MAX_FLAG)) )
      {
         selectedNodes[idx] = '1';
         idx *= 3;

         if( nodeValues[idx] < xmin )
            xmin = nodeValues[idx];
         if( nodeValues[idx] > xmax )
            xmax = nodeValues[idx];
         if( nodeValues[idx+1] < ymin )
            ymin = nodeValues[idx];
         if( nodeValues[idx+1] > ymax )
            ymax = nodeValues[idx+1];
         if( nodeValues[idx+2] < zmin )
            zmin = nodeValues[idx+2];
         if( nodeValues[idx+2] > zmax )
            zmax = nodeValues[idx+2];
      }
      else
         cout << "NODE NOT FOUND=" << *b << endl;
   }

/*
   if( xmin == xmax )
      xmax += xmin/10.0;
   if( ymin == ymax )
      ymax += ymin/10.0;
   if( zmin == zmax )
      zmax += zmin/10.0;
*/

   if( xmin == xmax )
      xmin = -xmin;
   if( ymin == ymax )
      ymin = -ymin;
   if( zmin == zmax )
      zmin = -zmin;

   //modelExtents[0] = xmin; modelExtents[1] = xmax;
   //modelExtents[2] = ymin; modelExtents[3] = ymax;
   //modelExtents[4] = zmin; modelExtents[5] = zmax;

cout << "EXTENTS=" << xmin << "," << xmax << "," << ymin << "," << ymax 
     << "," << zmin << "," << zmax << endl;

   glGetIntegerv(GL_VIEWPORT, viewPort);
   resizeModel(viewPort[2], viewPort[3]);
   switchOnLights();
   mTrans->updateWindowCenter();
}

/* With this method only the part nodes can be selected but not the non-[art nodes and also this is taking more than a minute for 1.25 millon nodes selection*/
void CAEEnv::selectNodes(vector<unsigned int> & nid_list)
{
   time_t t1, t2;

   time(&t1);
   if( !(compFlag & CREATE_SELECT_NODES) )
   {
      createNodeSelectedList();
      compFlag |= CREATE_SELECT_NODES;
   }

   unsigned int *id_list, *id_ptr, num_nodes, id;
   vector<unsigned int>::iterator b = nid_list.begin(), e = nid_list.end();
   UIUIIter iter, em;
   for(; b != e; b++)
   {
      id = *b;
      for(i = 0; i < numParts; i++)
      {
	 id_list = partsInfoList[i].partNodes.idList;
         num_nodes = partsInfoList[i].partNodes.numNodes;
         id_ptr = (unsigned int *)bsearch(&id, id_list, num_nodes, 
                                               sizeof(int), compareIDs);
         if( id_ptr )
         {
	    partsInfoList[i].partFlag |= NODE_PICK;
	    partsInfoList[i].partNodes.selectedNodes[id_ptr-id_list]='1';
            //break; this is not displaying all the node owned parts
         }
      }
   }
   time(&t2);

cout << "TIME FOR " << nid_list.size() << " NODES=" << difftime(t2, t1) <<endl;
cout << "AFTER NODE PICK\n";

   //unsigned int on_parts = 0;
   for(i = 0; i < numParts; i++)
   {
      if( !(partsInfoList[i].partFlag & NODE_PICK) )
      {
         if( !(partsInfoList[i].partFlag & DISP_ON) )
         {
            partsInfoList[i].partFlag |= DISP_OFF;
            partsInfoList[i].partFlag &= ~DISP_ON;
         }
      }
      else
      {
         partsInfoList[i].partFlag |= DISP_ON;
         partsInfoList[i].partFlag &= ~DISP_OFF;
         //on_parts++;
      }
   }

//cout << "TOTAL=" << numParts << " ON PARTS=" << on_parts << endl;

   modifyExtents();
}

void CAEEnv::selectNode(unsigned int *part_idx, unsigned int *node_idx)
{
   if( (*part_idx) > numParts )
   {
cout << "ERROR: CAEEnv::selectNode part index out of bounds\n";
      return;
   }

   unsigned int num_nodes = partsInfoList[(*part_idx)-1].partNodes.numNodes;
   if( (*node_idx) > num_nodes )
   {
cout << "ERROR: CAEEnv::selectNode node index out of bounds\n";
      return;
   }

   if( !(compFlag & CREATE_SELECT_NODES) )
   {
      createNodeSelectedList();
      compFlag |= CREATE_SELECT_NODES;
   }

   partsInfoList[(*part_idx)-1].partFlag |= NODE_PICK;
   partsInfoList[(*part_idx)-1].partNodes.selectedNodes[(*node_idx)-1]='1';
}

void CAEEnv::clearSelectedNodes()
{
   for(i = 0; i < numParts; i++)
   {
      if( partsInfoList[i].partFlag & NODE_PICK )
      {
         partsInfoList[i].partFlag &= ~NODE_PICK;
         memset(partsInfoList[i].partNodes.selectedNodes, '0', 
           sizeof(char) * partsInfoList[i].partNodes.numNodes);
      }
   }
}

void CAEEnv::selectElementsByIndex(vector<unsigned int> & eis_list,
                                         vector<unsigned int> & pis_list)
{
   if( !(compFlag & CREATE_SELECT_ELEMENTS) )
   {
      createElementSelectedList();
      compFlag |= CREATE_SELECT_ELEMENTS;
   }

   vector<unsigned int>::iterator b = pis_list.begin(), e = pis_list.end(),
                                  it = eis_list.begin();
   unsigned int num_parts = pidMap.size();
   for(; b != e; b++, it++)
   {
      if( *b >= num_parts )
         continue;
      partsInfoList[*b].partFlag |= ELEMENT_PICK;
      partsInfoList[*b].partElements.selectedList[*it]='1';
   }

   //unsigned int on_parts = 0;
   for(i = 0; i < numParts; i++) 
   {
      if( !(partsInfoList[i].partFlag & ELEMENT_PICK) )
      {
         partsInfoList[i].partFlag |= DISP_OFF;
         partsInfoList[i].partFlag &= ~DISP_ON;
      }
      else
      {
         partsInfoList[i].partFlag |= DISP_ON;
         partsInfoList[i].partFlag &= ~DISP_OFF;
         //on_parts++;
      }
   }
//cout << "TOTAL=" << numParts << " ON PARTS=" << on_parts << endl;

   modifyExtents();
}

void CAEEnv::selectElements(vector<unsigned int> & eid_list,
                                         vector<unsigned int> & pid_list)
{
   UIUIIter pi, ei, pe = pidMap.end(), ee;
   vector<unsigned int>::iterator b = pid_list.begin(), e = pid_list.end(),iter;
   unsigned int pid = 0;

   if( !(compFlag & CREATE_SELECT_ELEMENTS) )
   {
      createElementSelectedList();
      compFlag |= CREATE_SELECT_ELEMENTS;
   }

   for(i = 0; b != e; b++, i++)
   {
      if( *b != pid )
         pi = pidMap.find(*b);

      if( pi != pe )
      {
	 partsInfoList[pi->second].partFlag |= ELEMENT_PICK;
	 ee = partsInfoList[pi->second].partElements.eidMap->end();
	 ei = partsInfoList[pi->second].partElements.eidMap->find(eid_list[i]);
	 if( ei != ee )
	    partsInfoList[pi->second].partElements.selectedList[ei->second]='1';
      }

      pid = *b;
   }

   //unsigned int on_parts = 0;
   for(i = 0; i < numParts; i++) 
   {
      if( !(partsInfoList[i].partFlag & ELEMENT_PICK) )
      {
         if( !(partsInfoList[i].partFlag & DISP_ON) )
         {
	    partsInfoList[i].partFlag |= DISP_OFF;
	    partsInfoList[i].partFlag &= ~DISP_ON;
         }
      }
      else
      {
         partsInfoList[i].partFlag |= DISP_ON;
         partsInfoList[i].partFlag &= ~DISP_OFF;
         //on_parts++;
      }
   }
//cout << "TOTAL=" << numParts << " ON PARTS=" << on_parts << endl;

   modifyExtents();
}

void CAEEnv::selectElement(unsigned int *part_idx, unsigned int *elm_idx)
{
   if( *part_idx > numParts )
      return;

   if( *part_idx > numParts )
   {
cout << "ERROR: CAEEnv::selectElement part index out of bounds\n";
      return;
   }

   unsigned int num_elms = partsInfoList[*part_idx-1].partElements.numElements;

   if( *elm_idx > num_elms )
   {
cout << "ERROR: CAEEnv::selectElement element index out of bounds\n";
      return;
   }

   if( !(compFlag & CREATE_SELECT_ELEMENTS) )
   {
      createElementSelectedList();
      compFlag |= CREATE_SELECT_ELEMENTS;
   }

   partsInfoList[*part_idx-1].partFlag |= ELEMENT_PICK;
   partsInfoList[*part_idx-1].partElements.selectedList[*elm_idx-1] = '1';
}

void CAEEnv::clearSelectedElements()
{
   for(i = 0; i < numParts; i++)
   {
      if( partsInfoList[i].partFlag & ELEMENT_PICK )
      {
         partsInfoList[i].partFlag &= ~ELEMENT_PICK;
         memset(partsInfoList[i].partElements.selectedList, '0', 
           sizeof(char) * partsInfoList[i].partElements.numElements/partsInfoList[i].partElements.nodesPerElement);
      }
   }
}

void CAEEnv::printNode(unsigned int idx, float *n)
{
   printf("%8d %16.6f %16.6f %16.6f\n", idx, *n, *(n+1), *(n+2));
}

void CAEEnv::setBlend(int flag)
{
   if( flag )
   {
      glEnable(GL_BLEND);
      glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
   }
   else
      glDisable(GL_BLEND);
}

void CAEEnv::setHideMode(int flag)
{
   if( flag )
   {
      glEnable(GL_DEPTH_TEST);
      glDepthFunc(GL_LESS);
      glDepthRange(0.0, 1.0);
   }
   else
      glDisable(GL_DEPTH_TEST);
}

void CAEEnv::setPolygonMode(int mode)
{
   glPolygonMode(GL_FRONT_AND_BACK, mode);
}

void CAEEnv::setComputeFlag(unsigned int flag)
{
   compFlag |= flag;
}

void CAEEnv::clearComputeFlag(unsigned int flag)
{
   compFlag &= ~flag;
}

int CAEEnv::checkComputeFlag(unsigned int flag)
{
   return (compFlag & flag);
}

MView *CAEEnv::getMViewPtr()
{
   return mView;
}

MTransform *CAEEnv::getMTransformPtr()
{
   return mTrans;
}

int CAEEnv::getNumParts()
{
   return numParts;
}

void CAEEnv::setPickType(unsigned int _flag)
{
   pickType = _flag;
}

void CAEEnv::setShadeModel(unsigned int shade)
{
   shadeModel = shade;
   glShadeModel(shade);
   computeNormals();
}

void CAEEnv::displayPartsByElement()
{
unsigned long stime = GenTime::getCurrentMillis();
   char *elm_selected, *nodes_selected;
   unsigned int *elm_indices, num_nodes, j;
   float *node_values, *elm_normals, *color;
   PartInfoPtr part_info;
   PartElementsPtr elm_ptr;

   glEnableClientState(GL_VERTEX_ARRAY);
   glEnableClientState(GL_NORMAL_ARRAY);
   for(i = 0; i < numParts; i++)
   {
      part_info = &partsInfoList[i];

      if( part_info->partFlag & DISP_OFF )
	 continue;

/*
      if( part_info->partFlag & DISP_BOX )
      {
	 glDisableClientState(GL_NORMAL_ARRAY);
	 boxList[i]->render();
      }
*/

      color = part_info->partColor;

      if( part_info->partFlag & DISP_SELECT )
	 color = colorBlue;
      else if( part_info->partFlag & DISP_HIGHLIGHT )
	 color = colorGreen;

      node_values = part_info->partNodes.nodeValues;
      nodes_selected = part_info->partNodes.selectedNodes;
      num_nodes = part_info->partNodes.numNodes;
      elm_ptr = &part_info->partElements;
      elm_indices = elm_ptr->elmIndices;
      elm_normals = elm_ptr->elmNormals;
      elm_selected = elm_ptr->selectedList;

      glLoadName(i+1);
      
      switch(pickType)
      {
	 case PART_PICK:
	 {
	    switch(part_info->partDrawType)
	    {
	       case SHELL:
		  renderShellPart(part_info, color);
	       break;
	       case SOLID:
		  renderSolidPart(part_info, color);
	       break;
	       case BEAM:
		  renderBeamPart(part_info, color);
	       break;
	       case DISCRETE:
		  renderDiscretePart(part_info, color);
	       break;
	    }
	 }
	 break;
	 case ELEMENT_PICK:
	 {
	    switch(part_info->partDrawType)
	    {
	       case SHELL:
	       {
		  renderShellsForPick(part_info, color);
	       }
	       break;
	       case SOLID:
	       {
		  renderSolidsForPick(part_info, color);
	       }
	       break;
	       case BEAM:
	       {
		  renderBeamsForPick(part_info, color);
	       }
	       break;
	       case DISCRETE:
	       {
		  renderDiscretesForPick(part_info, color);
	       }
	       break;
	    }
	 }
	 break;
	 case NODE_PICK:
	 {
	    glColor4fv(color);
	    //glPointSize(5.0f);
	    for(j = 0; j < num_nodes; j++)
	    {
	       glPushName(j+1);
	       glBegin(GL_POINTS);
		  glVertex3fv(node_values+(j * NUM_COORDS));
	       glEnd();
	       glPopName();
	    }
	 }
	 break;
      }
   }

   glDisableClientState(GL_VERTEX_ARRAY);
   glDisableClientState(GL_NORMAL_ARRAY);
unsigned long etime = GenTime::getCurrentMillis();
cout << "TIME FOR DISPLAY PARTS=" << (etime-stime) << endl;
}

PartInfoPtr CAEEnv::getPartsList()
{
   return partsInfoList;
}

UIUIMap *CAEEnv::getPartsMapPtr()
{
   return &pidMap;
}


CAEEnv::~CAEEnv()
{
   while(numParts > 0 )
   {
      deletePartInfoPtr(&partsInfoList[numParts-1]);
      delete boxList[numParts-1];
      numParts--;
   }

   delete mView;
   delete mTrans;
   if( numParts )
   {
      delete partsInfoList;
      delete boxList;
   }
   numParts = 0;

   if( numNodes )
   {
      delete readNodes;
      delete readIDS;
   }
}

float *CAEEnv::getExtents()
{
   return modelExtents;
}

const char *CAEEnv::getModelName()
{
   return modelName.data();
}

CAEEnv *CAEEnv::getPtr()
{
   return cae_Env;
}

void CAEEnv::setPtr(CAEEnv *ptr)
{
   cae_Env = ptr;
}

void CAEEnv::renderModel()
{
   GLenum error;
   glGetIntegerv(GL_VIEWPORT, viewPort);
   for(int i = 0; i < 4; i++)
	   cout << viewPort[i] << endl;
   glScissor(viewPort[0], viewPort[1], viewPort[2], viewPort[3]);
   glEnable(GL_SCISSOR_TEST);
   glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
   glDisable(GL_SCISSOR_TEST);

   mView->update();
   mTrans->processStart();
   glGetIntegerv(GL_SHADE_MODEL, &shadeModel);

   displayParts();

   mTrans->processEnd();

   error = glGetError();
   if (error)
   {
      cout << "GL Error: " << gluErrorString(error) << endl;
   }
}

inline void CAEEnv::displayParts(int file_index)
{
unsigned long stime = GenTime::getCurrentMillis();
   float *color = NULL;
   PartInfoPtr part_info = NULL;

   glEnableClientState(GL_VERTEX_ARRAY);
   glEnableClientState(GL_NORMAL_ARRAY);
   for(i = 0; i < numParts; i++)
   {
      part_info = &partsInfoList[i];

      if( file_index != -1 && part_info->partFileIndex != file_index )
         continue;
  
      if( part_info->partFlag & DISP_OFF )
	 continue;

      if( part_info->partFlag & DISP_BOX )
      {
	 glDisableClientState(GL_NORMAL_ARRAY);
	 boxList[i]->render();
	 glEnableClientState(GL_NORMAL_ARRAY);
      }

      if( part_info->partFlag & DISP_SELECT )
	 color = colorBlue;
      else if( part_info->partFlag & DISP_HIGHLIGHT )
	 color = colorGreen;
      else
	 color = part_info->partColor;

      //glLoadName(i+1);
      switch(part_info->partDrawType)
      {
	 case SHELL:
	 {
	    if( (part_info->partFlag & (ELEMENT_PICK)) )
	       renderShells(part_info, color);
	    else
	       renderShellPart(part_info, color);
	 }
	 break;
	 case SOLID:
	 {
	    if( (part_info->partFlag & (ELEMENT_PICK)) )
	       renderSolids(part_info, color);
	    else
	       renderSolidPart(part_info, color);
	 }
	 break;
	 case BEAM:
	 {
	    if( (part_info->partFlag & (ELEMENT_PICK)) )
	       renderBeams(part_info, color);
	    else
	       renderBeamPart(part_info, color);
	 }
	 break;
	 case DISCRETE:
	 {
	    if( (part_info->partFlag & (ELEMENT_PICK)) )
	       renderDiscretes(part_info, color);
	    else
	       renderDiscretePart(part_info, color);
	 }
	 break;
      }

      if( (part_info->partFlag & (NODE_PICK)) )
      {
	 unsigned int num_nodes = part_info->partNodes.numNodes, j;
	 float *node_values = part_info->partNodes.nodeValues;
	 char *nodes_selected = part_info->partNodes.selectedNodes;
	 for(j = 0; j < num_nodes; j++)
	 {
	    switch(nodes_selected[j])
	    {
	       case '0':
		  glVertex3fv(node_values+(j * NUM_COORDS));
	       break;
	       case '1':
		  glPointSize(8.0f);
		  glColor4fv(colorBlue);
		  glBegin(GL_POINTS);
		     glVertex3fv(node_values+(j * NUM_COORDS));
		  glEnd();
		  glColor4fv(color);
		  glPointSize(1.0f);
	       break;
	    }
	 }
      }
   }

   if( compFlag & DISP_SEGMENT )
      renderShellPart(segmentPart, colorBlue);

   glDisableClientState(GL_NORMAL_ARRAY);
   glDisableClientState(GL_VERTEX_ARRAY);

   if( compFlag & SELECT_NODES_ONLY )
   {
cout << "INSIDE NODE SLECTION=" << numNodes << endl;
      glColor4fv(colorBlue);
      glPointSize(8.0f);
      glBegin(GL_POINTS);
      for(i = 0; i < numNodes; i++)
      {
	 switch(selectedNodes[i])
	 {
	    case '1':
	       glVertex3fv(nodeValues+(i * NUM_COORDS));
	    break;
	 }
      }
      glEnd();
      glPointSize(1.0f);
   }

unsigned long etime = GenTime::getCurrentMillis();
cout << "TIME FOR DISPLAY PARTS=" << (etime-stime) << endl;
}

inline void CAEEnv::renderShellPart(PartInfoPtr part_info, float *color)
{
   switch(shadeModel)
   {
      case GL_SMOOTH:
      {
	 glVertexPointer(NUM_COORDS, GL_FLOAT, 0, 
				     part_info->partNodes.nodeValues);
	 glNormalPointer(GL_FLOAT, 0, part_info->partNodes.nodeNormals);
	 glColor4fv(color);
	 glDrawElements(GL_QUADS, part_info->partElements.numElements, 
		   GL_UNSIGNED_INT, part_info->partElements.elmIndices);
      }
      break;
      case GL_FLAT:
      {
	 register unsigned int j;
	 unsigned int *elm_indices, part_npe;
	 float *elm_normals, *node_values;
	 PartElementsPtr elm_ptr = &part_info->partElements;
	 elm_indices = elm_ptr->elmIndices;
	 elm_normals = elm_ptr->elmNormals;
	 node_values = part_info->partNodes.nodeValues;
	 part_npe = elm_ptr->nodesPerElement;

	 glColor4fv(color);
	 glBegin(GL_QUADS);
	 for(j = 0; j < elm_ptr->numElements/part_npe; j++)
	 {
	    glNormal3fv(elm_normals+(j * NUM_COORDS));
	    glVertex3fv(node_values + ((*elm_indices++) * NUM_COORDS));
	    glVertex3fv(node_values + ((*elm_indices++) * NUM_COORDS));
	    glVertex3fv(node_values + ((*elm_indices++) * NUM_COORDS));
	    glVertex3fv(node_values + ((*elm_indices++) * NUM_COORDS));
	 }
	 glEnd();
      }
      break;
   }
}

inline void CAEEnv::renderShellsForPick
	    (
	       PartInfoPtr part_info,
	       float *color
	    )
{
   register unsigned int j;
   unsigned int *elm_indices, part_npe;
   float *elm_normals, *node_values, *node_normals;

   PartElementsPtr elm_ptr = &part_info->partElements;
   PartNodesPtr node_ptr = &part_info->partNodes; 
   part_npe = elm_ptr->nodesPerElement;

   elm_normals = elm_ptr->elmNormals;
   elm_indices = elm_ptr->elmIndices;

   node_values = node_ptr->nodeValues;
   node_normals = node_ptr->nodeNormals;

   glColor4fv(color);
   switch(shadeModel)
   {
      case GL_FLAT:
      {
	 for(j = 0; j < elm_ptr->numElements/part_npe; j++)
	 {
/*
	    switch(elm_ptr->selectedList[j])
	    {
	       case '0':
		  glColor4fv(color);
	       break;
	       case '1':
		  glColor4fv(colorBlue);
	       break;
	    }
*/

	    glPushName(j+1);
	    glBegin(GL_QUADS);
	    glNormal3fv(elm_normals+(j * NUM_COORDS));
	    glVertex3fv(node_values + ((*elm_indices++) * NUM_COORDS));
	    glVertex3fv(node_values + ((*elm_indices++) * NUM_COORDS));
	    glVertex3fv(node_values + ((*elm_indices++) * NUM_COORDS));
	    glVertex3fv(node_values + ((*elm_indices++) * NUM_COORDS));
	    glEnd();
	    glPopName();
	 }
      }
      break;
      case GL_SMOOTH:
      {
	 for(j = 0; j < elm_ptr->numElements/part_npe; j++)
	 {
/*
	    switch(elm_ptr->selectedList[j])
	    {
	       case '0':
		  glColor4fv(color);
	       break;
	       case '1':
		  glColor4fv(colorBlue);
	       break;
	    }
*/

	    glPushName(j+1);
	    glBegin(GL_QUADS);
	    glNormal3fv(node_normals+((*elm_indices) * NUM_COORDS));
	    glVertex3fv(node_values + ((*elm_indices++) * NUM_COORDS));

	    glNormal3fv(node_normals+((*elm_indices) * NUM_COORDS));
	    glVertex3fv(node_values + ((*elm_indices++) * NUM_COORDS));

	    glNormal3fv(node_normals+((*elm_indices) * NUM_COORDS));
	    glVertex3fv(node_values + ((*elm_indices++) * NUM_COORDS));

	    glNormal3fv(node_normals+((*elm_indices) * NUM_COORDS));
	    glVertex3fv(node_values + ((*elm_indices++) * NUM_COORDS));
	    glEnd();
	    glPopName();
	 }
      }
      break;
   }
}

inline void CAEEnv::renderDiscretesForPick
	    (
	       PartInfoPtr part_info,
	       float *color
	    )
{
   register unsigned int j;
   unsigned int *elm_indices, part_npe;
   float *node_values;

   PartElementsPtr elm_ptr = &part_info->partElements;
   PartNodesPtr node_ptr = &part_info->partNodes;
   part_npe = elm_ptr->nodesPerElement;

   elm_indices = elm_ptr->elmIndices;
   node_values = node_ptr->nodeValues;

   glLineWidth(2.0f);
   glColor4fv(color);
   for(j = 0; j < elm_ptr->numElements/part_npe; j++)
   {
/*
      switch(elm_ptr->selectedList[j])
      {
	 case '0':
	    glColor4fv(color);
	 break;
	 case '1':
	    glColor4fv(colorBlue);
	 break;
      }
*/

      glPushName(j+1);
      glBegin(GL_LINES);
      glVertex3fv(node_values + ((*elm_indices++) * NUM_COORDS));
      glVertex3fv(node_values + ((*elm_indices++) * NUM_COORDS));
      glEnd();
      glPopName();
      elm_indices++;
   }
   glLineWidth(1.0f);
}

inline void CAEEnv::renderDiscretePart
	    (
	       PartInfoPtr part_info,
	       float *color
	    )
{
   register unsigned int j;
   unsigned int *elm_indices, part_npe;
   float *node_values;

   PartElementsPtr elm_ptr = &part_info->partElements;
   PartNodesPtr node_ptr = &part_info->partNodes;
   part_npe = elm_ptr->nodesPerElement;

   elm_indices = elm_ptr->elmIndices;
   node_values = node_ptr->nodeValues;

   glLineWidth(2.0f);
   glColor4fv(color);
   glBegin(GL_LINES);
   for(j = 0; j < elm_ptr->numElements/part_npe; j++)
   {
      glVertex3fv(node_values + ((*elm_indices++) * NUM_COORDS));
      glVertex3fv(node_values + ((*elm_indices++) * NUM_COORDS));
      elm_indices++;
   }
   glEnd();
   glLineWidth(1.0f);
}

inline void CAEEnv::renderDiscretes
	    (
	       PartInfoPtr part_info,
	       float *color
	    )
{
   register unsigned int j;
   unsigned int *elm_indices, part_npe;
   float *node_values;

   PartElementsPtr elm_ptr = &part_info->partElements;
   PartNodesPtr node_ptr = &part_info->partNodes;
   part_npe = elm_ptr->nodesPerElement;

   elm_indices = elm_ptr->elmIndices;
   node_values = node_ptr->nodeValues;

   glLineWidth(2.0f);
   glColor4fv(color);
   for(j = 0; j < elm_ptr->numElements/part_npe; j++)
   {
      switch(elm_ptr->selectedList[j])
      {
	 case '0':
	    glColor4fv(color);
	 break;
	 case '1':
	    glColor4fv(colorBlue);
	 break;
      }

      glBegin(GL_LINES);
      glVertex3fv(node_values + ((*elm_indices++) * NUM_COORDS));
      glVertex3fv(node_values + ((*elm_indices++) * NUM_COORDS));
      glEnd();
      elm_indices++;
   }
   glLineWidth(1.0f);
}

inline void CAEEnv::renderBeamsForPick
	    (
	       PartInfoPtr part_info,
	       float *color
	    )
{
   register unsigned int j;
   unsigned int *elm_indices, part_npe;
   float *node_values;

   PartElementsPtr elm_ptr = &part_info->partElements;
   PartNodesPtr node_ptr = &part_info->partNodes; 
   part_npe = elm_ptr->nodesPerElement;

   elm_indices = elm_ptr->elmIndices;
   node_values = node_ptr->nodeValues;

   glLineWidth(5.0f);
   glPointSize(5.0f);
   glColor4fv(color);
   for(j = 0; j < elm_ptr->numElements/part_npe; j++)
   {
/*
      switch(elm_ptr->selectedList[j])
      {
	 case '0':
	    glColor4fv(color);
	 break;
	 case '1':
	    glColor4fv(colorBlue);
	 break;
      }
*/

      glPushName(j+1);
      glBegin(GL_LINES);
	 glVertex3fv(node_values + ((*elm_indices++) * NUM_COORDS));
	 glVertex3fv(node_values + ((*elm_indices++) * NUM_COORDS));
      glEnd();
      //this flag is checked as node id is optional and can be zero but
      //some node indices also zero, so (*elm_indices) check won't work
      if( !((*elm_indices) & (UNSIGNED_INT_MAX_FLAG)) ) //node is there
      {
	 glBegin(GL_POINTS);
	    glVertex3fv(node_values + ((*elm_indices++) * NUM_COORDS));
	 glEnd();
      }
      else //node id is zero
	 elm_indices++;
      glPopName();
   }
   glLineWidth(1.0f);
   glPointSize(1.0f);
}

inline void CAEEnv::renderBeamPart
	    (
	       PartInfoPtr part_info,
	       float *color
	    )
{
   //TODO REMOVE return
   return;

   register unsigned int j;
   unsigned int *elm_indices, part_npe;
   float *node_values;

   PartElementsPtr elm_ptr = &part_info->partElements;
   PartNodesPtr node_ptr = &part_info->partNodes; 
   part_npe = elm_ptr->nodesPerElement;

   elm_indices = elm_ptr->elmIndices;
   node_values = node_ptr->nodeValues;

   glLineWidth(5.0f);
   glPointSize(5.0f);
   glColor4fv(color);
   for(j = 0; j < elm_ptr->numElements/part_npe; j++)
   {
      glBegin(GL_LINES);
	 glVertex3fv(node_values + ((*elm_indices++) * NUM_COORDS));
	 glVertex3fv(node_values + ((*elm_indices++) * NUM_COORDS));
      glEnd();
//cout << "3rd index=" << *elm_indices << endl;
      if( !(*elm_indices & (UNSIGNED_INT_MAX_FLAG)) )
      {
	 glBegin(GL_POINTS);
	    glVertex3fv(node_values + ((*elm_indices++) * NUM_COORDS));
	 glEnd();
      }
      else
	 elm_indices++;
   }
   glLineWidth(1.0f);
   glPointSize(1.0f);
}

inline void CAEEnv::renderBeams
	    (
	       PartInfoPtr part_info,
	       float *color
	    )
{
   register unsigned int j;
   unsigned int *elm_indices, part_npe;
   float *node_values;

   PartElementsPtr elm_ptr = &part_info->partElements;
   PartNodesPtr node_ptr = &part_info->partNodes; 
   part_npe = elm_ptr->nodesPerElement;

   elm_indices = elm_ptr->elmIndices;
   node_values = node_ptr->nodeValues;

   glLineWidth(5.0f);
   glPointSize(5.0f);
   glColor4fv(color);
   for(j = 0; j < elm_ptr->numElements/part_npe; j++)
   {
      switch(elm_ptr->selectedList[j])
      {
	 case '0':
	    glColor4fv(color);
	 break;
	 case '1':
	    glColor4fv(colorBlue);
	 break;
      }

      glBegin(GL_LINES);
	 glVertex3fv(node_values + ((*elm_indices++) * NUM_COORDS));
	 glVertex3fv(node_values + ((*elm_indices++) * NUM_COORDS));
      glEnd();
//cout << "3rd index=" << *elm_indices << endl;
      if( !(*elm_indices & (UNSIGNED_INT_MAX_FLAG)) )
      {
	 glBegin(GL_POINTS);
	    glVertex3fv(node_values + ((*elm_indices++) * NUM_COORDS));
	 glEnd();
      }
      else
	 elm_indices++;
   }
   glLineWidth(1.0f);
   glPointSize(1.0f);
}

inline void CAEEnv::renderShells
	    (
	       PartInfoPtr part_info,
	       float *color
	    )
{
   register unsigned int j;
   unsigned int *elm_indices, part_npe;
   float *elm_normals, *node_values, *node_normals;

   PartElementsPtr elm_ptr = &part_info->partElements;
   PartNodesPtr node_ptr = &part_info->partNodes; 
   part_npe = elm_ptr->nodesPerElement;

   elm_normals = elm_ptr->elmNormals;
   elm_indices = elm_ptr->elmIndices;

   node_values = node_ptr->nodeValues;
   node_normals = node_ptr->nodeNormals;

   glColor4fv(color);
   switch(shadeModel)
   {
      case GL_FLAT:
      {
	 glBegin(GL_QUADS);
	 for(j = 0; j < elm_ptr->numElements/part_npe; j++)
	 {
	    switch(elm_ptr->selectedList[j])
	    {
	       case '0':
		  glColor4fv(color);
	       break;
	       case '1':
		  glColor4fv(colorBlue);
	       break;
	    }

	    glNormal3fv(elm_normals+(j * NUM_COORDS));
	    glVertex3fv(node_values + ((*elm_indices++) * NUM_COORDS));
	    glVertex3fv(node_values + ((*elm_indices++) * NUM_COORDS));
	    glVertex3fv(node_values + ((*elm_indices++) * NUM_COORDS));
	    glVertex3fv(node_values + ((*elm_indices++) * NUM_COORDS));
	 }
	 glEnd();
      }
      break;
      case GL_SMOOTH:
      {
	 glBegin(GL_QUADS);
	 for(j = 0; j < elm_ptr->numElements/part_npe; j++)
	 {
	    switch(elm_ptr->selectedList[j])
	    {
	       case '0':
		  glColor4fv(color);
	       break;
	       case '1':
		  glColor4fv(colorBlue);
	       break;
	    }

	    glNormal3fv(node_normals+((*elm_indices) * NUM_COORDS));
	    glVertex3fv(node_values + ((*elm_indices++) * NUM_COORDS));

	    glNormal3fv(node_normals+((*elm_indices) * NUM_COORDS));
	    glVertex3fv(node_values + ((*elm_indices++) * NUM_COORDS));

	    glNormal3fv(node_normals+((*elm_indices) * NUM_COORDS));
	    glVertex3fv(node_values + ((*elm_indices++) * NUM_COORDS));

	    glNormal3fv(node_normals+((*elm_indices) * NUM_COORDS));
	    glVertex3fv(node_values + ((*elm_indices++) * NUM_COORDS));
	 }
	 glEnd();
      }
      break;
   }
}

inline void CAEEnv::renderSolidPart
	    (
	       PartInfoPtr part_info,
	       float *color
	    )
{
   register unsigned int j, k, n;
   unsigned int *elm_indices, indices[24], part_npe, norm_indices[6], 
		 hexa_indices[] = {0, 1, 2, 3,
				   1, 2, 6, 5,
				   4, 5, 6, 7,
				   3, 0, 4, 7,
				   2, 3, 7, 6,
				   0, 1, 5, 4,},
		tetra_indices[] = {0, 1, 2,
				   0, 1, 3,
				   0, 3, 2,
				   1, 2, 3,},
		penta_indices[] = {0, 1, 2, 3,
				   1, 2, 6, 4,
				   3, 0, 4, 6,
				   0, 1, 4,
				   2, 3, 6,};
   PartElementsPtr elm_ptr = &part_info->partElements;
   elm_indices = elm_ptr->elmIndices;
   PartNodesPtr node_ptr = &part_info->partNodes; 
   float *node_values = node_ptr->nodeValues;
   float *node_normals = node_ptr->nodeNormals;
   float *elm_normals = elm_ptr->elmNormals;
   part_npe = part_info->partElements.nodesPerElement;

   glColor4fv(color);
   switch(shadeModel)
   {
      case GL_FLAT:
      {
	 glBegin(GL_QUADS);
	 for(j = 0, n = 0; j < elm_ptr->numElements/part_npe; j++, n += 18)
	 {
	    switch(elm_ptr->NPE[j])
	    {
	       case '8':
		  for(k = 0; k < 24; k++)
		     indices[k] = (*(elm_indices + (j * 8 + 
					hexa_indices[k]))) * NUM_COORDS;
		  for(k = 0; k < 6; k++)
		     norm_indices[k] = n + k*3;
		  renderHexaByNormal(indices, norm_indices,
					      elm_normals, node_values);
	       break;
	       case '6':
		  for(k = 0; k < 18; k++)
		     indices[k] = (*(elm_indices + (j * 8 + 
					penta_indices[k]))) * NUM_COORDS;
		  for(k = 0; k < 5; k++)
		     norm_indices[k] = n + k*3;
		  renderPentaByNormal(indices, norm_indices,
					      elm_normals, node_values);
	       break;
	       case '4':
		  for(k = 0; k < 12; k++)
		     indices[k] = (*(elm_indices + (j * 8 + 
					tetra_indices[k]))) * NUM_COORDS;
		  for(k = 0; k < 4; k++)
		     norm_indices[k] = n + k*3;
		  renderTetraByNormal(indices, norm_indices,
					      elm_normals, node_values);
	       break;
	    }
	 }
	 glEnd();
      }
      break;
      case GL_SMOOTH:
      {
	 glBegin(GL_QUADS);
	 for(j = 0; j < elm_ptr->numElements/part_npe; j++)
	 {
	    switch(elm_ptr->NPE[j])
	    {
	       case '8':
		  for(k = 0; k < 24; k++)
		     indices[k] = (*(elm_indices + (j * 8 + 
				      hexa_indices[k]))) * NUM_COORDS;
		  renderHexaByNodeNormal(indices, node_values, node_normals);
	       break;
	       case '6':
		  for(k = 0; k < 18; k++)
		     indices[k] = (*(elm_indices + (j * 8 + 
				      penta_indices[k]))) * NUM_COORDS;
		  renderPentaByNodeNormal(indices,node_values,node_normals);
		  //cout << "6 nodes solid\n";
	       break;
	       case '4':
		  //cout << "4 nodes solid\n";
		  for(k = 0; k < 12; k++)
		     indices[k] = (*(elm_indices + (j * 8 + 
				      tetra_indices[k]))) * NUM_COORDS;
		  renderTetraByNodeNormal(indices,node_values,node_normals);
	       break;
	    }
	 }
	 glEnd();
      }
      break;
   }
}

inline void CAEEnv::renderSolidsForPick
	    (
	       PartInfoPtr part_info,
	       float *color
	    )
{
   register unsigned int j, k, n;
   unsigned int *elm_indices, indices[24], part_npe, norm_indices[6], 
		 hexa_indices[] = {0, 1, 2, 3,
				   1, 2, 6, 5,
				   4, 5, 6, 7,
				   3, 0, 4, 7,
				   2, 3, 7, 6,
				   0, 1, 5, 4,},
		tetra_indices[] = {0, 1, 2,
				   0, 1, 3,
				   0, 3, 2,
				   1, 2, 3,},
		penta_indices[] = {0, 1, 2, 3,
				   1, 2, 6, 4,
				   3, 0, 4, 6,
				   0, 1, 4,
				   2, 3, 6,};
   PartElementsPtr elm_ptr = &part_info->partElements;
   elm_indices = elm_ptr->elmIndices;
   PartNodesPtr node_ptr = &part_info->partNodes; 
   float *node_values = node_ptr->nodeValues;
   float *node_normals = node_ptr->nodeNormals;
   float *elm_normals = elm_ptr->elmNormals;
   part_npe = part_info->partElements.nodesPerElement;

   glColor4fv(color);
   switch(shadeModel)
   {
      case GL_FLAT:
      {
	 for(j = 0, n = 0; j < elm_ptr->numElements/part_npe; j++, n += 18)
	 {
/*
	    switch(elm_ptr->selectedList[j])
	    {
	       case '0':
		  glColor4fv(color);
	       break;
	       case '1':
		  glColor4fv(colorBlue);
	       break;
	    }
*/

	    glPushName(j+1);
	    glBegin(GL_QUADS);
	    switch(elm_ptr->NPE[j])
	    {
	       case '8':
		  for(k = 0; k < 24; k++)
		     indices[k] = (*(elm_indices + (j * 8 + 
					hexa_indices[k]))) * NUM_COORDS;
		  for(k = 0; k < 6; k++)
		     norm_indices[k] = n + k*3;
		  renderHexaByNormal(indices, norm_indices,
					      elm_normals, node_values);
	       break;
	       case '6':
		  for(k = 0; k < 18; k++)
		     indices[k] = (*(elm_indices + (j * 8 + 
					penta_indices[k]))) * NUM_COORDS;
		  for(k = 0; k < 5; k++)
		     norm_indices[k] = n + k*3;
		  renderPentaByNormal(indices, norm_indices,
					      elm_normals, node_values);
	       break;
	       case '4':
		  for(k = 0; k < 12; k++)
		     indices[k] = (*(elm_indices + (j * 8 + 
					tetra_indices[k]))) * NUM_COORDS;
		  for(k = 0; k < 4; k++)
		     norm_indices[k] = n + k*3;
		  renderTetraByNormal(indices, norm_indices,
					      elm_normals, node_values);
	       break;
	    }
	    glEnd();
	    glPopName();
	 }
      }
      break;
      case GL_SMOOTH:
      {
	 for(j = 0; j < elm_ptr->numElements/part_npe; j++)
	 {
/*
	    switch(elm_ptr->selectedList[j])
	    {
	       case '0':
		  glColor4fv(color);
	       break;
	       case '1':
		  glColor4fv(colorBlue);
	       break;
	    }
*/

	    glPushName(j+1);
	    glBegin(GL_QUADS);
	    switch(elm_ptr->NPE[j])
	    {
	       case '8':
		  for(k = 0; k < 24; k++)
		     indices[k] = (*(elm_indices + (j * 8 + 
				      hexa_indices[k]))) * NUM_COORDS;
		  renderHexaByNodeNormal(indices, node_values, node_normals);
	       break;
	       case '6':
		  for(k = 0; k < 18; k++)
		     indices[k] = (*(elm_indices + (j * 8 + 
				      penta_indices[k]))) * NUM_COORDS;
		  renderPentaByNodeNormal(indices,node_values,node_normals);
		  //cout << "6 nodes solid\n";
	       break;
	       case '4':
		  //cout << "4 nodes solid\n";
		  for(k = 0; k < 12; k++)
		     indices[k] = (*(elm_indices + (j * 8 + 
				      tetra_indices[k]))) * NUM_COORDS;
		  renderTetraByNodeNormal(indices,node_values,node_normals);
	       break;
	    }
	    glEnd();
	    glPopName();
	 }
      }
      break;
   }
}

inline void CAEEnv::renderSolids
	    (
	       PartInfoPtr part_info,
	       float *color
	    )
{
   register unsigned int j, k, n;
   unsigned int *elm_indices, indices[24], part_npe, norm_indices[6], 
		 hexa_indices[] = {0, 1, 2, 3,
				   1, 2, 6, 5,
				   4, 5, 6, 7,
				   3, 0, 4, 7,
				   2, 3, 7, 6,
				   0, 1, 5, 4,},
		tetra_indices[] = {0, 1, 2,
				   0, 1, 3,
				   0, 3, 2,
				   1, 2, 3,},
		penta_indices[] = {0, 1, 2, 3,
				   1, 2, 6, 4,
				   3, 0, 4, 6,
				   0, 1, 4,
				   2, 3, 6,};
   PartElementsPtr elm_ptr = &part_info->partElements;
   elm_indices = elm_ptr->elmIndices;
   PartNodesPtr node_ptr = &part_info->partNodes;
   float *node_values = node_ptr->nodeValues;
   float *node_normals = node_ptr->nodeNormals;
   float *elm_normals = elm_ptr->elmNormals;
   part_npe = part_info->partElements.nodesPerElement;

   glColor4fv(color);
   switch(shadeModel)
   {
      case GL_FLAT:
      {
	 glBegin(GL_QUADS);
	 for(j = 0, n = 0; j < elm_ptr->numElements/part_npe; j++, n += 18)
	 {
	    switch(elm_ptr->selectedList[j])
	    {
	       case '0':
		  glColor4fv(color);
	       break;
	       case '1':
		  glColor4fv(colorBlue);
	       break;
	    }

	    switch(elm_ptr->NPE[j])
	    {
	       case '8':
		  for(k = 0; k < 24; k++)
		     indices[k] = (*(elm_indices + (j * 8 + 
					hexa_indices[k]))) * NUM_COORDS;
		  for(k = 0; k < 6; k++)
		     norm_indices[k] = n + k*3;
		  renderHexaByNormal(indices, norm_indices,
					      elm_normals, node_values);
	       break;
	       case '6':
		  for(k = 0; k < 18; k++)
		     indices[k] = (*(elm_indices + (j * 8 + 
					penta_indices[k]))) * NUM_COORDS;
		  for(k = 0; k < 5; k++)
		     norm_indices[k] = n + k*3;
		  renderPentaByNormal(indices, norm_indices,
					      elm_normals, node_values);
	       break;
	       case '4':
		  for(k = 0; k < 12; k++)
		     indices[k] = (*(elm_indices + (j * 8 + 
					tetra_indices[k]))) * NUM_COORDS;
		  for(k = 0; k < 4; k++)
		     norm_indices[k] = n + k*3;
		  renderTetraByNormal(indices, norm_indices,
					      elm_normals, node_values);
	       break;
	    }
	 }
	 glEnd();
      }
      break;
      case GL_SMOOTH:
      {
	 glBegin(GL_QUADS);
	 for(j = 0; j < elm_ptr->numElements/part_npe; j++)
	 {
	    switch(elm_ptr->selectedList[j])
	    {
	       case '0':
		  glColor4fv(color);
	       break;
	       case '1':
		  glColor4fv(colorBlue);
	       break;
	    }

	    switch(elm_ptr->NPE[j])
	    {
	       case '8':
		  for(k = 0; k < 24; k++)
		     indices[k] = (*(elm_indices + (j * 8 + 
				      hexa_indices[k]))) * NUM_COORDS;
		  renderHexaByNodeNormal(indices, node_values, node_normals);
	       break;
	       case '6':
		  for(k = 0; k < 18; k++)
		     indices[k] = (*(elm_indices + (j * 8 + 
				      penta_indices[k]))) * NUM_COORDS;
		  renderPentaByNodeNormal(indices,node_values,node_normals);
		  //cout << "6 nodes solid\n";
	       break;
	       case '4':
		  //cout << "4 nodes solid\n";
		  for(k = 0; k < 12; k++)
		     indices[k] = (*(elm_indices + (j * 8 + 
				      tetra_indices[k]))) * NUM_COORDS;
		  renderTetraByNodeNormal(indices,node_values,node_normals);
	       break;
	    }
	 }
	 glEnd();
      }
      break;
   }
}

void CAEEnv::renderTriaByNodeNormal
     (
	unsigned int *indices, 
	float *node_values, 
	float *node_normals
     )
{
   glNormal3fv(node_normals+ (*indices));
   glVertex3fv(node_values + (*indices++));
   glNormal3fv(node_normals+ (*indices));
   glVertex3fv(node_values + (*indices++));
   glNormal3fv(node_normals+ (*indices));
   glVertex3fv(node_values + (*indices));

   glNormal3fv(node_normals+ (*indices));
   glVertex3fv(node_values + (*indices));
}

void CAEEnv::renderQuadByNodeNormal
     (
	unsigned int *indices, 
	float *node_values, 
	float *node_normals
     )
{
   glNormal3fv(node_normals+ (*indices));
   glVertex3fv(node_values + (*indices++));
   glNormal3fv(node_normals+ (*indices));
   glVertex3fv(node_values + (*indices++));
   glNormal3fv(node_normals+ (*indices));
   glVertex3fv(node_values + (*indices++));
   glNormal3fv(node_normals+ (*indices));
   glVertex3fv(node_values + (*indices++));
}

void CAEEnv::renderTriaByNormal
     (
	unsigned int *indices, 
	float *node_values, 
	float *normal_ptr
     )
{
   glNormal3fv(normal_ptr);
   glVertex3fv(node_values + (*indices++));
   glVertex3fv(node_values + (*indices++));
   glVertex3fv(node_values + (*indices));

   glVertex3fv(node_values + (*indices));
}

void CAEEnv::renderQuadByNormal
     (
	unsigned int *indices, 
	float *node_values, 
	float *normal_ptr
     )
{
   glNormal3fv(normal_ptr);
   glVertex3fv(node_values + (*indices++));
   glVertex3fv(node_values + (*indices++));
   glVertex3fv(node_values + (*indices++));
   glVertex3fv(node_values + (*indices++));
}

void CAEEnv::renderTetraByNormal
     (
	unsigned int *indices,
	unsigned int *norm_indices, 
	float *elm_normals, 
	float *node_values
     )
{
   renderTriaByNormal(&indices[0],node_values,elm_normals+(*norm_indices++));
   renderTriaByNormal(&indices[3],node_values,elm_normals+(*norm_indices++));
   renderTriaByNormal(&indices[6],node_values,elm_normals+(*norm_indices++));
   renderTriaByNormal(&indices[9],node_values,elm_normals+(*norm_indices++));
}

void CAEEnv::renderPentaByNormal
     (
	unsigned int *indices,
	unsigned int *norm_indices, 
	float *elm_normals, 
	float *node_values
     )
{
   renderQuadByNormal(&indices[0],node_values,elm_normals+(*norm_indices++));
   renderQuadByNormal(&indices[4],node_values,elm_normals+(*norm_indices++));
   renderQuadByNormal(&indices[8],node_values,elm_normals+(*norm_indices++));
   renderTriaByNormal(&indices[12],node_values,elm_normals+(*norm_indices++));
   renderTriaByNormal(&indices[15],node_values,elm_normals+(*norm_indices++));
}

void CAEEnv::renderHexaByNormal
     (
	unsigned int *indices,
	unsigned int *norm_indices, 
	float *elm_normals, 
	float *node_values
     )
{
   renderQuadByNormal(&indices[0],node_values,elm_normals+(*norm_indices++));
   renderQuadByNormal(&indices[4],node_values,elm_normals+(*norm_indices++));
   renderQuadByNormal(&indices[8],node_values,elm_normals+(*norm_indices++));
   renderQuadByNormal(&indices[12],node_values,elm_normals+(*norm_indices++));
   renderQuadByNormal(&indices[16],node_values,elm_normals+(*norm_indices++));
   renderQuadByNormal(&indices[20],node_values,elm_normals+(*norm_indices++));
}

void CAEEnv::renderTetraByNodeNormal
     (
	unsigned int *indices,
	float *node_values,
	float *node_normals
     )
{
   renderTriaByNodeNormal(&indices[0], node_values, node_normals);
   renderTriaByNodeNormal(&indices[3], node_values, node_normals);
   renderTriaByNodeNormal(&indices[6], node_values, node_normals);
   renderTriaByNodeNormal(&indices[9], node_values, node_normals);
}

void CAEEnv::renderPentaByNodeNormal
     (
	unsigned int *indices,
	float *node_values,
	float *node_normals
     )
{
   renderQuadByNodeNormal(&indices[0], node_values, node_normals);
   renderQuadByNodeNormal(&indices[4], node_values, node_normals);
   renderQuadByNodeNormal(&indices[8], node_values, node_normals);
   renderTriaByNodeNormal(&indices[12], node_values, node_normals);
   renderTriaByNodeNormal(&indices[15], node_values, node_normals);
}

void CAEEnv::renderHexaByNodeNormal
     (
	unsigned int *indices,
	float *node_values,
	float *node_normals
     )
{
   renderQuadByNodeNormal(&indices[0], node_values, node_normals);
   renderQuadByNodeNormal(&indices[4], node_values, node_normals);
   renderQuadByNodeNormal(&indices[8], node_values, node_normals);
   renderQuadByNodeNormal(&indices[12], node_values, node_normals);
   renderQuadByNodeNormal(&indices[16], node_values, node_normals);
   renderQuadByNodeNormal(&indices[20], node_values, node_normals);
}

void CAEEnv::setSegmentPart(PartInfoPtr part_info)
{
   if( !part_info )
      return;

   compFlag |= DISP_SEGMENT;
   computeShellNormals(part_info);
   segmentPart = part_info;
   modifyExtents();
}

