#include "mtrans.h"
#include "pickrect.h"
#include <GL/glu.h>
#include <iostream>
#include <math.h>
#include "m_matrix.h"

#define clamp(x) x = x > 360.0f ? x-360.0f : x < -360.0f ? x += 360.0f : x
#define clampr(x) x = x > 3.14f ? x-3.14f : x < -3.14f ? x+=3.14f : x
#define clamp_scale(x) x = x < MIN_SCALE_FACTOR ? MIN_SCALE_FACTOR : x

using namespace std;

void MTransform::updateValues(int trans_type, float values[4])
{
   mTransType = trans_type;

   switch(trans_type)
   {
      case GLOBAL_TRANSLATION:
      {
	 float fx, fy;
	 fx = ((modelExtents[0] >= 0) ? modelExtents[0] : 
	    modelExtents[0] * -1) + ((modelExtents[1] >= 0) ? 
	       modelExtents[1] : modelExtents[1] * -1);
	 fy = ((modelExtents[2] >= 0) ? modelExtents[2] : 
	    modelExtents[2] * -1) + ((modelExtents[3] >= 0) ? 
	       modelExtents[3] : modelExtents[3] * -1);

	 fx = values[2]/fx;
	 fy = values[3]/fy;

	 globalTrans[0] += values[0]/fx;
	 globalTrans[1] += values[1]/fy;
      }
      break;
      case GLOBAL_SCALE:
         updateLocalScaleForWindow(values[0]);
/*
	 localScale[0] += values[0];
	 localScale[1] += values[1];
	 localScale[2] += values[2];
*/
         clamp_scale(localScale[0]);
         clamp_scale(localScale[1]);
         clamp_scale(localScale[2]);
      break;
      case GLOBAL_ROTATION:
      {
         //int view_port[4];
         //glGetIntegerv(GL_VIEWPORT, view_port);
	 float x0 = (2.0 * values[0] - viewPort[2]) / viewPort[2];
	 float y0 = (viewPort[3] - 2.0 * values[1]) / viewPort[3];
	 float x1 = (2.0 * values[2] - viewPort[2]) / viewPort[2];
	 float y1 = (viewPort[3] - 2.0 * values[3]) / viewPort[3];
	 float q[4];

	 trackball(q, x0, y0, x1, y1);
	 add_quats(q, curQuat, curQuat);
      }
/*
	 globalRot[0] += values[0];
         clamp(globalRot[0]);
	 globalRot[1] += values[1];
         clamp(globalRot[1]);
	 globalRot[2] += values[2];
         clamp(globalRot[2]);
*/
      break;
      case START_RUBBER_BAND:
         memcpy(mouseValues, values, sizeof(float) * 4);
      break;
      case START_POLYLINE:
         addPoint(values);
      break;
      case POLYLINE_PICK:
         for(unsigned int i = 0; i < pointsList.size(); i++)
            delete pointsList[i];
         pointsList.clear();
      break;
      case RECT_PICK:
         updateRect();
         memset(mouseValues, 0, sizeof(float) * 4);
      break;
      case END_RUBBER_BAND:
         memset(mouseValues, 0, sizeof(float) * 4);
      break;
      case RECT_SCALE:
      {
         updateLocalScaleForRubberBand();
         memset(mouseValues, 0, sizeof(float) * 4);
      }
      break;
   }
}

void MTransform::setValues(float values[9])
{
   float fx, fy, fz;
   fx = ((modelExtents[0] >= 0) ? modelExtents[0] :
      modelExtents[0] * -1) + ((modelExtents[1] >= 0) ?
	 modelExtents[1] : modelExtents[1] * -1);
   fy = ((modelExtents[2] >= 0) ? modelExtents[2] :
      modelExtents[2] * -1) + ((modelExtents[3] >= 0) ?
	 modelExtents[3] : modelExtents[3] * -1);
   fz = ((modelExtents[4] >= 0) ? modelExtents[4] :
      modelExtents[4] * -1) + ((modelExtents[5] >= 0) ?
	 modelExtents[5] : modelExtents[5] * -1);

   globalTrans[0] = fx * values[3] / viewPort[2];
   globalTrans[1] = fy * values[4] / viewPort[3];
   //globalTrans[2] = fz * values[5] / viewPort[3];

fprintf(stderr, "GTRAN=%lf %lf %lf\n", globalTrans[0], globalTrans[1], globalTrans[2]);
fprintf(stderr, "GTRAN=%lf %lf %lf\n", globalRot[0], globalRot[1], globalRot[2]);

   if( values[0] != 0.0 || values[1] != 0.0 || values[2] )
   {
      globalRot[0] = values[0];
      globalRot[1] = values[1];
      globalRot[2] = values[2];
      clamp(globalRot[0]);
      clamp(globalRot[1]);
      clamp(globalRot[2]);
   }

cout << "xmin=" << modelExtents[0] << " xmax=" << modelExtents[1] << endl;
cout << "ymin=" << modelExtents[2] << " ymax=" << modelExtents[3] << endl;
cout << "zmin=" << modelExtents[4] << " zmax=" << modelExtents[5] << endl;

   centerOfWindow[0] = (modelExtents[0]+modelExtents[1])/2.0;
   centerOfWindow[1] = (modelExtents[2]+modelExtents[3])/2.0;
   centerOfWindow[2] = (modelExtents[4]+modelExtents[5])/2.0;
cout << "cow=" << centerOfWindow[0] << "," << centerOfWindow[1] << ","
	<< centerOfWindow[2] << endl;

   glGetDoublev(GL_PROJECTION_MATRIX, projMatrix);
   glGetDoublev(GL_MODELVIEW_MATRIX, mvMatrix);
   glGetIntegerv(GL_VIEWPORT, viewPort);

   printMatrices();

   updateLocalScaleForWindow(values[6]);

   mTransType = TRANS_MAX;
}

void MTransform::setTranslation(float values[3])
{
   memcpy(localTrans, values, sizeof(float) * 3);
}

void MTransform::setRotation(float values[4])
{
   float q[4];
   axis_to_quat(values, (22.0f * values[3])/(180.0f * 7.0f), q);
   add_quats(q, curQuat, curQuat);
}

void MTransform::updateRect()
{
   //int    view_port[4];
   //glGetIntegerv(GL_VIEWPORT, view_port);

   gluUnProject(mouseValues[0], mouseValues[1], 0.5, mvMatrix, projMatrix, 
      viewPort, &startOfScaling[0], &startOfScaling[1], &startOfScaling[2]);
   gluUnProject(mouseValues[2], mouseValues[3], 0.5, mvMatrix, projMatrix, 
      viewPort, &endOfScaling[0], &endOfScaling[1], &endOfScaling[2]);

   centerOfScaling[0] = (startOfScaling[0] + endOfScaling[0])/2.0f;
   centerOfScaling[1] = (startOfScaling[1] + endOfScaling[1])/2.0f;
   centerOfScaling[2] = (startOfScaling[2] + endOfScaling[2])/2.0f;

cout << "start=" << startOfScaling[0] << "," << startOfScaling[1] << "," << startOfScaling[2] << endl;
cout << "cos=" << centerOfScaling[0] << "," << centerOfScaling[1] << "," << centerOfScaling[2] << endl;
cout << "end=" << endOfScaling[0] << "," << endOfScaling[1] << "," << endOfScaling[2] << endl;
}

void MTransform::computeWindowCenter()
{
   float halfw = viewPort[2]/2, halfh = viewPort[3]/2;
cout << "compute wc w/2=" << halfw << " h/2=" << halfh << endl;

printMatrices();
   gluUnProject(halfw, halfh, 0.5, mvMatrix, projMatrix, viewPort,
           &centerOfWindow[0], &centerOfWindow[1], &centerOfWindow[2]);

cout << "cos=" << centerOfWindow[0] << "," << centerOfWindow[1] << ","
     << centerOfWindow[2] << endl;
}

void MTransform::updateWindowCenter()
{
   centerOfWindow[0]=(modelExtents[0]+modelExtents[1])/2.0;
   centerOfWindow[1]=(modelExtents[2]+modelExtents[3])/2.0;
   centerOfWindow[2]=(modelExtents[4]+modelExtents[5])/2.0;
}

void MTransform::updateScaleForWindow(float sx, float sy, float sz)
{
   //with these the scaling happens from the center of the model otherwise
   // from the center of the window
   //glGetDoublev(GL_PROJECTION_MATRIX, projMatrix);
   glGetDoublev(GL_MODELVIEW_MATRIX, mvMatrix);

   //int    view_port[4];
   //glGetIntegerv(GL_VIEWPORT, view_port);
   float halfw = viewPort[2]/2, halfh = viewPort[3]/2;
cout << "scale w/2=" << halfw << " h/2=" << halfh << endl;

   gluUnProject(halfw, halfh, 0.5, mvMatrix, projMatrix, viewPort,
           &centerOfScaling[0], &centerOfScaling[1], &centerOfScaling[2]);

cout << "cos=" << centerOfScaling[0] << "," << centerOfScaling[1] << ","
     << centerOfScaling[2] << endl;

   if( (localScale[0] + sx) > MIN_SCALE_FACTOR )
   {
      localTrans[0] += ( ((localScale[0]) * (centerOfScaling[0])) - 
         ( (localScale[0] + sx) * (centerOfScaling[0])) );
      localScale[0] += sx;
   }

   if( (localScale[1] + sy) > MIN_SCALE_FACTOR )
   {
      localTrans[1] += ( ((localScale[1]) * (centerOfScaling[1])) - 
         ( (localScale[1] + sy) * (centerOfScaling[1])) );
      localScale[1] += sy;
   }

   if( (localScale[2] + sz) > MIN_SCALE_FACTOR )
   {
      localTrans[2] += ( ((localScale[2]) * (centerOfScaling[2])) - 
         ( (localScale[2] + sz) * (centerOfScaling[2])) );
      localScale[2] += sz;
   }

cout << "TRANSX=" << localTrans[0] << " TRANSY=" << localTrans[1]
     << " TRANSZ=" << localTrans[2] << endl;
cout << "scaleX=" << localScale[0] << " scaleY=" << localScale[1]
     << " scaleZ=" << localScale[2] << endl;
}

void MTransform::updateLocalScaleForWindow(float scale)
{
   //with these the scaling happens from the center of the model otherwise
   // from the center of the window
   //glGetDoublev(GL_PROJECTION_MATRIX, projMatrix);
   //glGetDoublev(GL_MODELVIEW_MATRIX, mvMatrix);

   //int    view_port[4];
   //glGetIntegerv(GL_VIEWPORT, view_port);
   float halfw = viewPort[2]/2, halfh = viewPort[3]/2;
cout << "local scale w/2=" << halfw << " h/2=" << halfh << " SCALE=" << scale << endl;

cout << "COS= " << centerOfScaling[0] << endl;

   gluUnProject(halfw, halfh, 0.5, mvMatrix, projMatrix, viewPort,
           &centerOfScaling[0], &centerOfScaling[1], &centerOfScaling[2]);

cout << "cos=" << centerOfScaling[0] << "," << centerOfScaling[1] << ","
     << centerOfScaling[2] << endl;

   if( (localScale[0] + scale) > MIN_SCALE_FACTOR )
   {
      localTrans[0] += ( ((localScale[0]) * (centerOfScaling[0])) - 
         ( (localScale[0] + scale) * (centerOfScaling[0])) );
      localScale[0] += scale;
   }

   if( (localScale[1] + scale) > MIN_SCALE_FACTOR )
   {
      localTrans[1] += ( ((localScale[1]) * (centerOfScaling[1])) - 
         ( (localScale[1] + scale) * (centerOfScaling[1])) );
      localScale[1] += scale;
   }

   if( (localScale[2] + scale) > MIN_SCALE_FACTOR )
   {
      localTrans[2] += ( ((localScale[2]) * (centerOfScaling[2])) - 
         ( (localScale[2] + scale) * (centerOfScaling[2])) );
      localScale[2] += scale;
   }

cout << "TRANSX=" << localTrans[0] << " TRANSY=" << localTrans[1]
     << " TRANSZ=" << localTrans[2] << endl;
cout << "scaleX=" << localScale[0] << " scaleY=" << localScale[1]
     << " scaleZ=" << localScale[2] << endl;
}

void MTransform::updateLocalScaleForRubberBand()
{
   float dx = (mouseValues[2] - mouseValues[0]), dy =
			  (mouseValues[1] - mouseValues[3]);
cout << "dx=" << dx << " dy=" << dy << endl;
cout << "sx=" << mouseValues[0] << " sy=" << mouseValues[1] << endl;
cout << "cx=" << mouseValues[2] << " cy=" << mouseValues[3] << endl;

   if( dx && dy )
   {
      updateRect();

      localTrans[0] += ( ((localScale[0]) * (centerOfScaling[0])) - 
         ( (localScale[0] + SCALE_FACTOR) * (centerOfScaling[0])) );
      localTrans[1] += ( ((localScale[1]) * (centerOfScaling[1])) -
         ( (localScale[1] + SCALE_FACTOR) * (centerOfScaling[1])) );
      localTrans[2] += ( ((localScale[2]) * (centerOfScaling[2])) - 
         ( (localScale[2] + SCALE_FACTOR) * (centerOfScaling[2])) );

      localScale[0] += SCALE_FACTOR;
      localScale[1] += SCALE_FACTOR;
      localScale[2] += SCALE_FACTOR;

cout << "TRANSX=" << localTrans[0] << " TRANSY=" << localTrans[1] << " TRANSZ=" << localTrans[2] << endl;
cout << "scaleX=" << localScale[0] << " scaleY=" << localScale[1] << " scaleZ=" << localScale[2] << endl;
   }
}

void MTransform::update()
{
   switch(mTransType)
   {
      case NO_TRANSFORM:
      break;
      case RESET_TRANSFORM:
	 resetAll();
      break;
      case ROTATE_X_CCW:
	 globalRot[0] += 5.0f;
         clamp(globalRot[0]);
cout << "ROTX=" << globalRot[0] << endl;
      break;
      case ROTATE_X_CW:
	 globalRot[0] -= 5.0f;
         clamp(globalRot[0]);
      break;
      case ROTATE_Y_CCW:
	 globalRot[1] += 5.0f;
         clamp(globalRot[1]);
      break;
      case ROTATE_Y_CW:
	 globalRot[1] -= 5.0f;
         clamp(globalRot[1]);
      break;
      case ROTATE_Z_CCW:
	 globalRot[2] += 5.0f;
         clamp(globalRot[2]);
      break;
      case ROTATE_Z_CW:
	 globalRot[2] -= 5.0f;
         clamp(globalRot[2]);
      break;
      case TRANS_LEFT:
      {
	 float fx = ((modelExtents[0] >= 0) ? modelExtents[0] :
	    modelExtents[0] * -1) + ((modelExtents[1] >= 0) ?
	       modelExtents[1] : modelExtents[1] * -1);
	 globalTrans[0] -= fx/50.0f;
      }
      break;
      case TRANS_RIGHT:
      {
	 float fx = ((modelExtents[0] >= 0) ? modelExtents[0] :
	    modelExtents[0] * -1) + ((modelExtents[1] >= 0) ?
	       modelExtents[1] : modelExtents[1] * -1);
	 globalTrans[0] += fx/50.0f;
      }
      break;
      case TRANS_UP:
      {
	 float fy = ((modelExtents[2] >= 0) ? modelExtents[2] :
	    modelExtents[2] * -1) + ((modelExtents[3] >= 0) ?
	       modelExtents[3] : modelExtents[3] * -1);
	 globalTrans[1] += fy/50.0f;
      }
      break;
      case TRANS_DOWN:
      {
	 float fy = ((modelExtents[2] >= 0) ? modelExtents[2] :
	    modelExtents[2] * -1) + ((modelExtents[3] >= 0) ?
	       modelExtents[3] : modelExtents[3] * -1);
	 globalTrans[1] -= fy/50.0f;
      }
      break;
      case SCALE_INCR:
         updateLocalScaleForWindow(SCALE_FACTOR);
      break;
      case SCALE_DECR:
         updateLocalScaleForWindow(-SCALE_FACTOR);
         clamp_scale(localScale[0]);
         clamp_scale(localScale[1]);
         clamp_scale(localScale[2]);
      break;
      default:
      break;
   }
   //mTransType = NO_TRANSFORM; moved to processEnd function
}

void MTransform::resetAll()
{
   //memset(localRot, 0, sizeof(float) * 3);
   memset(curQuat, 0, sizeof(float) * 4);
   curQuat[3] = 1.0f;
   memset(globalRot, 0, sizeof(float) * 3);
   memset(localTrans, 0, sizeof(float) * 3);
   memset(globalTrans, 0, sizeof(float) * 3);
   //memset(centerOfWindow, 0, sizeof(double) * 3);
   localScale[0] = localScale[1] = localScale[2] = 1.0f;
   //globalScale[0] = globalScale[1] = globalScale[2] = 1.0f;
}

void MTransform::addPoint(float *mouse_values)
{
   double world[3];
/**
   double mvmat[16], value = 1.0;

   memset(mvmat, 0, sizeof(double) * 16);
   memcpy(mvmat, &value, sizeof(double));
   memcpy(mvmat+5, &value, sizeof(double));
   memcpy(mvmat+10, &value, sizeof(double));
   memcpy(mvmat+15, &value, sizeof(double));
*/
   
   gluUnProject(mouse_values[0], mouse_values[1], 0.5, mvMatrix, projMatrix, 
             viewPort, &world[0], &world[1], &world[2]);

   Point3DPtr pt = new Point3D;
   pt->point[0] = (float) world[0];
   pt->point[1] = (float) world[1];
   pt->point[2] = (float) world[2];
   pointsList.push_back(pt);
cout << "start world=" << pt->point[0] << "," << pt->point[1] << "," << pt->point[2] << endl;
}

void MTransform::printMatrices()
{
   cout << "LOCALMV=\n[";
   for(int i = 0; i < 16; i++)
   {
      printf("%10.6f  ", mvMatrixLocal[i]);
      if( i != 0 && !((i+1) % 4) )
         cout << "\n";
   }
   cout << "]\n";
   cout << "MV=\n[";
   for(int i = 0; i < 16; i++)
   {
      printf("%10.6f  ", mvMatrix[i]);
      if( i != 0 && !((i+1) % 4) )
         cout << "\n";
   }
   cout << "]\n";
   cout << "PM=\n[";
   for(int i = 0; i < 16; i++)
   {
      printf("%10.6f  ", projMatrix[i]);
      if( i != 0 && !((i+1) % 4) )
         cout << "\n";
   }
   cout << "]\n";
   cout << "VP=" << viewPort[0] << "," << viewPort[1] << "," << viewPort[2]
        << "," << viewPort[3] << endl;
   cout << "depthtest=" << depthTest << endl;
   cout << "localTrans=" << localTrans[0] << "," << localTrans[1] << "," 
        << localTrans[2] << endl;
   cout << "globalTrans=" << globalTrans[0] << "," << globalTrans[1] << "," 
        << globalTrans[2] << endl;
   cout << "globalRot=" << globalRot[0] << "," << globalRot[1] << "," 
        << globalRot[2] << endl;
   cout << "localScale=" << localScale[0] << "," << localScale[1] << "," 
        << localScale[2] << endl;
}

void MTransform::save(FILE *file_ptr)
{
   fwrite(&depthTest, sizeof(int), 1, file_ptr);
   fwrite(localTrans, sizeof(float), 3, file_ptr);
   fwrite(globalRot, sizeof(float), 3, file_ptr);
   fwrite(globalTrans, sizeof(float), 3, file_ptr);
   fwrite(localScale, sizeof(float), 3, file_ptr);
   fwrite(mvMatrixLocal, sizeof(double), 16, file_ptr);
   fwrite(mvMatrix, sizeof(double), 16, file_ptr);
   fwrite(projMatrix, sizeof(double), 16, file_ptr);
   fwrite(centerOfWindow, sizeof(double), 3, file_ptr);
   fwrite(curQuat, sizeof(float), 4, file_ptr);
//printMatrices();
}

void MTransform::restore(FILE *file_ptr)
{
   fread(&depthTest, sizeof(int), 1, file_ptr);
   if( depthTest )
   {
printf("DEPTH ENABLE\n");
      glEnable(GL_DEPTH_TEST);
      glDepthFunc(GL_LESS);
      glDepthRange(0.0, 1.0);
   }
   else
      glDisable(GL_DEPTH_TEST);

   fread(localTrans, sizeof(float), 3, file_ptr);
   fread(globalRot, sizeof(float), 3, file_ptr);
   fread(globalTrans, sizeof(float), 3, file_ptr);
   fread(localScale, sizeof(float), 3, file_ptr);
   fread(mvMatrixLocal, sizeof(double), 16, file_ptr);
   fread(mvMatrix, sizeof(double), 16, file_ptr);
   fread(projMatrix, sizeof(double), 16, file_ptr);
   fread(centerOfWindow, sizeof(double), 3, file_ptr);
   fread(curQuat, sizeof(float), 4, file_ptr);
   onlyOnce &= ~DISP_ON;
//printMatrices();
}

void MTransform::moveToCOW()
{
   double cow[3], com[3];

   gluUnProject(viewPort[2]/2, viewPort[3]/2, 0.5, mvMatrix, 
           projMatrix, viewPort, &cow[0], &cow[1], &cow[2]);
cout << "VIEW cow=" << cow[0] << "," << cow[1] << "," << cow[2] << endl;

   com[0] = (modelExtents[0] + modelExtents[1])/2.0; 
   com[1] = (modelExtents[2] + modelExtents[3])/2.0; 
   com[2] = (modelExtents[4] + modelExtents[5])/2.0; 
cout << "VIEW COM=" << com[0] << "," << com[1] << "," << com[2] << endl;

   localTrans[0] += (cow[0]-com[0]);
   localTrans[1] += (cow[1]-com[1]);
   localTrans[2] += (cow[2]-com[2]);
   //glTranslatef(cow[0]-com[0], cow[1]-com[1], cow[2]-com[2]);
}

