#include "mview.h"
#include <GL/gl.h>
#include <GL/glu.h>
#include <math.h>

void MView::update()
{
   switch(mViewType)
   {
      case ISO_VIEW:
	 isoView();
      break;
      case TOP_VIEW:
	 topView();
      break;
      case BOTTOM_VIEW:
	 bottomView();
      break;
      case LEFT_VIEW:
	 leftView();
      break;
      case RIGHT_VIEW:
	 rightView();
      break;
      case FRONT_VIEW:
	 frontView();
      break;
      case BACK_VIEW:
	 backView();
      break;
      default:
      break;
   }

   getMatrices();
}

void MView::isoView()
{
   leftView();
   glRotatef(10.0f, 1.0f, 0.0f, 0.0f);
   //glRotatef(30.0f, 0.0f, 0.0f, 1.0f);
}

void MView::rightView()
{
   glMatrixMode(GL_MODELVIEW);
   glLoadIdentity();

   switch(xAxisType)
   {
      case X_BOTH_POSITIVE:
      {
         switch(zAxisType)
         {
            case Z_BOTH_POSITIVE:
	    {
	       glRotatef(-90.0, 1.0, 0.0, 0.0);
	       glTranslatef(0.0f,0.0f,-(modelExtents[4]+modelExtents[5])/2.0f);
	    }
            break;
            default:
	    {
	       glRotatef(-90.0, 1.0, 0.0, 0.0);
	       glRotatef(180.0, 0.0, 0.0, 1.0);
	       glTranslatef(-(modelExtents[1]+modelExtents[0]), 0.0f, 
                         -(modelExtents[4]+modelExtents[5])/2.0f);
	    }
            break;
         }
      }
      break;
      default:
      {
         switch(yAxisType)
         {
            case Y_BOTH_POSITIVE:
	       glRotatef(90.0, 1.0, 0.0, 0.0);
            break;
            case Y_BOTH_NEGATIVE:
	    {
	       float diff = (modelExtents[3]-modelExtents[2])/2.0f;
	       diff = diff - modelExtents[3];
	       glTranslatef(0.0f, -diff, 0.0f);
	       glRotatef(-90.0, 1.0, 0.0, 0.0);
	       glTranslatef(0.0, 0.0, (modelExtents[4]-modelExtents[5])/2.0f);
	    }
            break;
            default:
	    {
	       glRotatef(-90.0, 1.0, 0.0, 0.0);
	       glTranslatef(0.0, 0.0, (modelExtents[4]-modelExtents[5])/2.0f);
	    }
         }
      }
   }
}

void MView::leftView()
{
   glMatrixMode(GL_MODELVIEW);
   glLoadIdentity();

   switch(xAxisType)
   {
      case X_BOTH_POSITIVE:
      {
         switch(zAxisType)
         {
            case Z_BOTH_POSITIVE:
	    {
	       glRotatef(-90.0, 1.0, 0.0, 0.0);
	       glRotatef(180.0, 0.0, 0.0, 1.0);
	       glTranslatef(-(modelExtents[1]+modelExtents[0]), 0.0f, 
                       -(modelExtents[4]+modelExtents[5])/2.0f);
	    }
            break;
            default:
	    {
	       glRotatef(-90.0, 1.0, 0.0, 0.0);
	       glTranslatef(0.0f,0.0f,-(modelExtents[4]+modelExtents[5])/2.0f);
	    }
            break;
         }
      }
      break;
      default:
      {
         switch(yAxisType)
         {
            case Y_BOTH_POSITIVE:
	    {
	       glRotatef(90.0, 1.0, 0.0, 0.0);
	       glRotatef(-180.0, 0.0, 0.0, 1.0);
	       glTranslatef(-(modelExtents[1]+modelExtents[0]), 0.0f, 0.0f);
	    }
            break;
            case Y_BOTH_NEGATIVE:
	    {
	       float diff = (modelExtents[3]-modelExtents[2])/2.0f;
	       diff = diff - modelExtents[3];
	       glTranslatef(0.0f, -diff, 0.0f);
	       glRotatef(-90.0, 1.0, 0.0, 0.0);
	       glRotatef(-180.0, 0.0, 0.0, 1.0);
	       glTranslatef(-(modelExtents[1]+modelExtents[0]), 0.0f, 
                      (modelExtents[4]-modelExtents[5])/2.0f);
	    }
            break;
            default:
	    {
	       glRotatef(-90.0, 1.0, 0.0, 0.0);
	       glRotatef(-180.0, 0.0, 0.0, 1.0);
	       glTranslatef(-(modelExtents[1]+modelExtents[0]), 0.0f, 
                             (modelExtents[4]-modelExtents[5])/2.0f);
	    }
         }
      }
   }
}

void MView::backView()
{
   glMatrixMode(GL_MODELVIEW);
   glLoadIdentity();

   switch(xAxisType)
   {
      case X_BOTH_POSITIVE:
      {
         switch(zAxisType)
         {
            case Z_BOTH_POSITIVE:
	    {
	       glRotatef(-90.0, 1.0, 0.0, 0.0);
	       glRotatef(-90.0, 0.0, 0.0, 1.0);
	       glTranslatef(0.0, (modelExtents[0]+modelExtents[1])/2.0f, 
                         (modelExtents[4]-modelExtents[5])/2.0);
	    }
            break;
            default:
	    {
	       glRotatef(-90.0, 1.0, 0.0, 0.0);
	       glRotatef(90.0, 0.0, 0.0, 1.0);
	       glTranslatef(0.0, -(modelExtents[0]+modelExtents[1])/2.0f, 
				   (modelExtents[4]-modelExtents[5])/2.0);
	    }
            break;
         }
      }
      break;
      default:
      {
         switch(yAxisType)
         {
            case Y_BOTH_POSITIVE:
	    {
	       float diff = (modelExtents[2]+modelExtents[3])/2.0f;
	       glRotatef(90.0, 1.0, 0.0, 0.0);
	       glRotatef(90.0, 0.0, 0.0, 1.0);
	       glTranslatef(0.0, -((modelExtents[2]+modelExtents[3])/2.0f), 
			   -((modelExtents[4]+modelExtents[5])/2.0) - diff);
	    }
            break;
            case Y_BOTH_NEGATIVE:
	    {
	       float diff = (modelExtents[3]-modelExtents[2])/2.0f;
	       diff = diff - modelExtents[3];
	       glTranslatef(0.0f, -diff, 0.0f);
	       glRotatef(-90.0, 1.0, 0.0, 0.0);
	       glRotatef(-90.0, 0.0, 0.0, 1.0);
	       glTranslatef(0.0, (modelExtents[0]+modelExtents[1])/2.0f + diff,
				     (modelExtents[4]-modelExtents[5])/2.0);
	    }
            break;
            default:
	    {
	       glRotatef(-90.0, 1.0, 0.0, 0.0);
	       glRotatef(-90.0, 0.0, 0.0, 1.0);
	       glTranslatef(0.0, (modelExtents[0]+modelExtents[1])/2.0f, 
                       (modelExtents[4]-modelExtents[5])/2.0);
	    }
         }
      }
   }
}

void MView::frontView()
{
   glMatrixMode(GL_MODELVIEW);
   glLoadIdentity();

   switch(xAxisType)
   {
      case X_BOTH_POSITIVE:
      {
         switch(zAxisType)
         {
            case Z_BOTH_POSITIVE:
	    {
	       glRotatef(-90.0, 1.0, 0.0, 0.0);
	       glRotatef(90.0, 0.0, 0.0, 1.0);
	       glTranslatef(0.0, -(modelExtents[0]+modelExtents[1])/2.0f, 
                      (modelExtents[4]-modelExtents[5])/2.0);
	    }
            break;
            default:
	    {
	       glRotatef(-90.0, 1.0, 0.0, 0.0);
	       glRotatef(-90.0, 0.0, 0.0, 1.0);
	       glTranslatef(0.0, (modelExtents[0]+modelExtents[1])/2.0f, 
                            (modelExtents[4]-modelExtents[5])/2.0);
	    }
            break;
         }
      }
      break;
      default:
      {
         switch(yAxisType)
         {
            case Y_BOTH_POSITIVE:
	    {
	       float diff = (modelExtents[2]+modelExtents[3])/2.0f;
	       glRotatef(90.0, 1.0, 0.0, 0.0);
	       glRotatef(-90.0, 0.0, 0.0, 1.0);
	       glTranslatef(0.0, -((modelExtents[2]+modelExtents[3])/2.0f), 
			 -((modelExtents[4]+modelExtents[5])/2.0) - diff);
	    }
            break;
            case Y_BOTH_NEGATIVE:
	    {
	       float diff = (modelExtents[3]-modelExtents[2])/2.0f;
	       diff = diff - modelExtents[3];
	       glTranslatef(0.0f, -diff, 0.0f);
	       glRotatef(-90.0, 1.0, 0.0, 0.0);
	       glRotatef(90.0, 0.0, 0.0, 1.0);
	       glTranslatef(0.0, (-(modelExtents[0]+modelExtents[1])/2.0f) 
                     + diff, (modelExtents[4]-modelExtents[5])/2.0);
	    }
            break;
            default:
	    {
	       glRotatef(-90.0, 1.0, 0.0, 0.0);
	       glRotatef(90.0, 0.0, 0.0, 1.0);
	       glTranslatef(0.0, -(modelExtents[0]+modelExtents[1])/2.0f, 
                         (modelExtents[4]-modelExtents[5])/2.0);
	    }
         }
      }
   }
}

void MView::bottomView()
{
   glMatrixMode(GL_MODELVIEW);
   glLoadIdentity();

   switch(yAxisType)
   {
      case Y_BOTH_POSITIVE:
      {
	 float diff = (modelExtents[2]+modelExtents[3])/2.0f;
	 glTranslatef(0.0f, diff, 0.0f);
	 glRotatef(180.0, 1.0, 0.0, 0.0);
	 glTranslatef(0.0, -diff, 0.0f);
      }
      break;
      default:
      break;
   }
}

void MView::topView()
{
   glMatrixMode(GL_MODELVIEW);
   glLoadIdentity();

   switch(yAxisType)
   {
      case Y_BOTH_POSITIVE:
      break;
      case Y_BOTH_NEGATIVE:
      {
	 float diff = (modelExtents[3]-modelExtents[2])/2.0f;
	 diff = diff - modelExtents[3];
	 glTranslatef(0.0f, -diff, 0.0f);
	 glRotatef(180.0, 1.0, 0.0, 0.0);
	 glTranslatef(0.0f, diff, 0.0f);
      }
      break;
      default:
	 glRotatef(180.0, 1.0, 0.0, 0.0);
      break;
   }
}

void MView::save(FILE *file_ptr)
{
   fwrite(&mViewType, sizeof(int), 1, file_ptr);
}

void MView::restore(FILE *file_ptr)
{
   fread(&mViewType, sizeof(int), 1, file_ptr);
}

void MView::getMatrices()
{
   int view_port[4];
   double mv_matrix[16], proj_matrix[16], cow[3], com[3], sx, sy, sz = 1.0;

   glGetIntegerv(GL_VIEWPORT, view_port);
   glGetDoublev(GL_MODELVIEW_MATRIX, mv_matrix);
   glGetDoublev(GL_PROJECTION_MATRIX, proj_matrix);

   gluProject(modelExtents[0], modelExtents[2], modelExtents[4], mv_matrix,
           proj_matrix, view_port, &cow[0], &cow[1], &cow[2]);
   gluProject(modelExtents[1], modelExtents[3], modelExtents[5], mv_matrix,
           proj_matrix, view_port, &com[0], &com[1], &com[2]);
cout << "AFTER VIEW cow=" << cow[0] << "," << cow[1] << "," << cow[2] << endl;
cout << "AFTER VIEW com=" << com[0] << "," << com[1] << "," << com[2] << endl;
   sx = (com[0]-cow[0]); sy = (com[1]-cow[1]); sz = 1;
   sx = fabs(sx); sy = fabs(sy);

   if( sx != 0.0 )
      sx = view_port[2]/sx;
   if( sy != 0.0 )
      sy = view_port[3]/sy;

   if( sx == 0.0 ) sx = 1.0;
   if( sy == 0.0 ) sy = 1.0;
   
   switch(mViewType)
   {
      case ISO_VIEW:
	 if( sx < sy )
	   sy = sz = sx = sx;
	 else
	   sx = sz = sy = sy;
      break;
      case TOP_VIEW:
      case BOTTOM_VIEW:
	 if( sx < sy )
	   sy = sz = sx = sx * 0.95;
	 else
	   sx = sz = sy = sy * 0.95;
      break;
      case LEFT_VIEW:
      case RIGHT_VIEW:
      case FRONT_VIEW:
      case BACK_VIEW:
	 if( sx < sy )
	   sy = sz = sx = sx * 0.95;
	 else
	   sx = sz = sy = sy * 0.95;
      break;
   }

cout << "SCALE=" << sx << "," << sy << "," << sz << endl;
   glScalef(sx, sy, sz);

   glGetDoublev(GL_MODELVIEW_MATRIX, mv_matrix);
   glGetDoublev(GL_PROJECTION_MATRIX, proj_matrix);

   gluUnProject(view_port[2]/2, view_port[3]/2, 0.5, mv_matrix, 
           proj_matrix, view_port, &cow[0], &cow[1], &cow[2]);
cout << "VIEW cow=" << cow[0] << "," << cow[1] << "," << cow[2] << endl;

   com[0] = (modelExtents[0] + modelExtents[1])/2.0; 
   com[1] = (modelExtents[2] + modelExtents[3])/2.0; 
   com[2] = (modelExtents[4] + modelExtents[5])/2.0; 
cout << "VIEW COM=" << com[0] << "," << com[1] << "," << com[2] << endl;

   glTranslatef(cow[0]-com[0], cow[1]-com[1], cow[2]-com[2]);
   //glScalef(1.0, 1.0, 1.0);
}

