#ifndef _MVIEW_H_
#define _MVIEW_H_

#include <iostream>
#include <stdio.h>

using namespace std;

/** Types of view of model */
typedef enum _MViewType
{
   NO_VIEW,
   ISO_VIEW,
   TOP_VIEW,
   BOTTOM_VIEW,
   LEFT_VIEW,
   RIGHT_VIEW,
   FRONT_VIEW,
   BACK_VIEW,
}
  View;

typedef enum _AxisType
{
   AXIS_OTHER_TYPE,

   X_BOTH_POSITIVE,
   Y_BOTH_POSITIVE,
   Z_BOTH_POSITIVE,
   X_BOTH_NEGATIVE,
   Y_BOTH_NEGATIVE,
   Z_BOTH_NEGATIVE
}
  AxisType;

/** Class for representing the different views of model. */
class MView
{
public:
   /** Constructor for creating this class
     * \param exts Pointer to the extents array of model
     */
   MView(float *exts) : xAxisType(AXIS_OTHER_TYPE), yAxisType(AXIS_OTHER_TYPE),
            zAxisType(AXIS_OTHER_TYPE), mViewType(ISO_VIEW)
   {
      setExtents(exts);
   }

   /** Sets the model extents pointer
     * \param exts Pointer the array of extents of model
     */
   void setExtents(float *exts)
   {
      modelExtents = exts;

      if( exts[0] >= 0 && exts[1] >= 0 )
	 xAxisType = X_BOTH_POSITIVE;
      else if( exts[0] < 0 && exts[1] < 0 )
	 xAxisType = X_BOTH_NEGATIVE;

      if( exts[2] >= 0 && exts[3] >= 0 )
	 yAxisType = Y_BOTH_POSITIVE;
      else if( exts[2] < 0 && exts[3] < 0 )
	 yAxisType = Y_BOTH_NEGATIVE;

      if( exts[4] >= 0 && exts[5] >= 0 )
	 zAxisType = Z_BOTH_POSITIVE;
      else if( exts[4] < 0 && exts[5] < 0 )
	 zAxisType = Z_BOTH_NEGATIVE;
   }

   /** Changes the view of the model
     * \param view_type Type of view to change
     */
   void changeView(int view_type)
   {
      mViewType = view_type;
   }

   /** Update will compute the values required for changing the model view */
   void update();
   /** Shows the model with 10 deg rotated about x-axis. */
   void isoView();

   /** Shows the model from right side */
   void rightView();
   void leftView();
   void backView();
   void frontView();
   void bottomView();
   void topView();
 
   /** Saves the view parameters of model
     * \param file_ptr File pointer to save the view parameters
     */
   void save(FILE *file_ptr);
   /** Restores the view parameters of model
     * \param file_ptr File pointer to restore the view parameters
     */
   void restore(FILE *file_ptr);

   /** After the change of view, the model view matrix and project matrix are
     * loaded into the local arrays and computations are done for change of view
     */
   void getMatrices();

private:
   float *modelExtents;
   /** Types of axes whether each axis is positive or negative or both */
   int xAxisType, yAxisType, zAxisType, mViewType;
};

#endif

