#ifndef _PARTS_STR_H_
#define _PARTS_STR_H_

#include <map>
#include <list>
#include <set>
#include "maptypes.h"

using namespace std;

/** Stores nodes list in a part */
//1+4+12+12+8=37
typedef struct _PartNodesStr
{
   /** 1 or 0 state for nodes to know whether the node is selected or not */
   char         *selectedNodes;
   /** Count of nodes in the part */
   unsigned int numNodes;
   /** List of node ids in the part */
   unsigned int *idList;
   /** Node coordinates as x1,y1,z1,x2,y2,z2..... for the part */
   float        *nodeValues;
   /** Node normals for each node as x,y,z **/
   float        *nodeNormals;
}
  PartNodesStr, *PartNodesPtr;

/** Stores elements in a part and their connectivity */
//1+1+4+4+16+12+8=46
typedef struct _PartElementsStr
{
   /** State of each element as selected or not as 1 or 0 */
   char                *selectedList;
   /** Nodes per element for solid elements only. This is used to know whether
     * element is tetra, penta or hexa */
   char                *NPE; //nodes per element for solids only
   /** Number of elements in the part */
   unsigned int        numElements;
   /** Number of nodes per element in the part */
   unsigned int        nodesPerElement;
   /** Indices of elements for the part and nodes connectivity */
   unsigned int        *elmIndices;
   /** Elements normals as x,y and z */
   float               *elmNormals;
   /** Map between element id and its index in the part */
   UIUIMap             *eidMap;
}
  PartElementsStr, *PartElementsPtr;

/** Strct for storing the all the details of a part including the nodes, elements
  * and their connectivity
  */
typedef struct _PartInfoStr
{
   /** Draw type of part wireframe, shading etc */
   unsigned int    partDrawType;
   /** Flag to store On/Off, select or highlight status of part */
   unsigned int    partFlag;
   /** Index of file the part belongs to */
   int             partFileIndex;
   /** Extents of the part as xmin,xmax,ymin,ymax,zmin,zmax */
   float           partExtents[6];
   /** Color of part to display */
   float           partColor[4];
   /** Nodes related to this part */
   PartNodesStr    partNodes;
   /** Elements related to this part */
   PartElementsStr partElements;
}
  PartInfoStr, *PartInfoPtr;

/** Memory is cleared for the given part
  * \param ptr Pointer to the part info
  */
inline static void deletePartInfoPtr(PartInfoPtr ptr)
{
   delete ptr->partNodes.nodeValues; 

   if( ptr->partNodes.nodeNormals )
      delete ptr->partNodes.nodeNormals; 
   if( ptr->partNodes.selectedNodes )
      delete ptr->partNodes.selectedNodes; 
   if( ptr->partNodes.idList )
      delete ptr->partNodes.idList; 
   ptr->partNodes.numNodes = 0;

   delete ptr->partElements.elmIndices; 
   if( ptr->partElements.elmNormals )
      delete ptr->partElements.elmNormals; 
   if( ptr->partElements.selectedList )
      delete ptr->partElements.selectedList; 
   if( ptr->partElements.eidMap )
   {
      ptr->partElements.eidMap->clear(); 
      delete ptr->partElements.eidMap; 
   }
   if( ptr->partElements.NPE )
      delete ptr->partElements.NPE; 
   ptr->partElements.NPE = NULL;
   ptr->partElements.numElements = 0;
}

#endif

