#include "pickrect.h"
#include "caeenv.h"

#define BUFSIZE 524288

/* Input of mouse values have to be sent properly, otherwise the pick is not
 * going to work. The CENTER OF PICK REGION and REGION in window coordinates
 * are to sent. Be careful with the CENTER. TOOK LOT OF TIME FOR RECTANGULAR
 * PICK because of the CENTER sent not properly. This is on Dec 10 2009
 */
int PickRect::process(int pick_type, int pick_method, float mouse_xy[4])
{
   GLint    viewport[4];
   GLint    num_hits, shade;
   GLuint   select_buf[BUFSIZE];
   CAEEnv   *cae_env = CAEEnv::getPtr();
   float    *exts = cae_env->getExtents();
   memset(select_buf, 0, sizeof(unsigned int) * BUFSIZE);

   pickType = pick_type;
   pickMethod = pick_method;

   cae_env->setPickType(pick_type);

   zPartMap.clear();

cout << "MOUSEXY=" << mouse_xy[0] << "," << mouse_xy[1] << "," <<
     mouse_xy[2] << "," << mouse_xy[3] << endl;

   MTransform *mtrans = cae_env->getMTransformPtr();

   glGetIntegerv(GL_VIEWPORT, viewport);
   glGetIntegerv(GL_SHADE_MODEL, &shade);

   glSelectBuffer(BUFSIZE, select_buf);
   glRenderMode(GL_SELECT);

   glInitNames();
   glPushName(-1);

/** These are the transformations done to the model in draw callback **/
   mtrans->processStart();
      glMatrixMode(GL_PROJECTION);
      glPushMatrix();
	 glLoadIdentity();
/*  create 2x2 pixel picking region near cursor location */
	 gluPickMatrix(mouse_xy[0], 
	      mouse_xy[1], mouse_xy[2], mouse_xy[3], viewport);
	 glOrtho(exts[0], exts[1], exts[2], 
			  exts[3], Z_MAX_COORD, Z_MIN_COORD);
//always pick the parts in flat display mode so that the elements can also 
//be picked along with the parts
	 cae_env->displayPartsByElement();
         mtrans->processEnd();
      glMatrixMode(GL_PROJECTION);
      glPopMatrix();
    //mtrans->processEnd(); this is moved to up beacuse the pick is always picking the last part even the location is not on the vehicle. this problem is due to the unit_axis render in which lines are also drawn

   glFlush();

   num_hits = glRenderMode(GL_RENDER);
   if( num_hits == -1 )
   {
cout << "ERROR: Too many items got selected. So none got picked\n";
      zPartMap.clear();
      memset(select_buf, 0, sizeof(unsigned int) * BUFSIZE);
      return 0;
   }

   if( num_hits )
      return processHits(num_hits, select_buf);
   else
      return 0;
}

int PickRect::processHits(GLint num_hits, GLuint *select_buf)
{
   GLuint   *int_ptr, *part_ptr = NULL, *elm_ptr = NULL;
   GLint    num_selected, i, j;
   float    z1, z2;
   CAEEnv   *cae_env = CAEEnv::getPtr();

   printf("hits = %d\n", num_hits);
   int_ptr = (GLuint *) select_buf;

   for(i = 0; i < num_hits; i++)
   {
      num_selected = *int_ptr;
      printf(" number of parts for hit = %d\n", num_selected);
      int_ptr++;
      printf("  z1 is %g;", (float) *int_ptr/0xffffffff);
      z1 = (float) *int_ptr/0xffffffff;
      int_ptr++;
      printf(" z2 is %g\n", (float) *int_ptr/0xffffffff);
      z2 = (float) *int_ptr/0xffffffff;
      int_ptr++;
      printf("   the part is ");

      for(j = 0; j < num_selected; j++) /* for each part */
      {
	 printf("%d ", *int_ptr);
         PidEidStr pid_eid;
         pid_eid.pid = *int_ptr;
         pid_eid.eid = 0;
         switch(pickMethod)
         {
            case SELECT_PICK:
            {
               switch(pickType)
               {
		  case PART_PICK:
		  {
   //cout << "PART IDX=" << *int_ptr << endl;
		     part_ptr = int_ptr;
		     int_ptr++;
		     zPartMap.insert(ZPartPair(z1, pid_eid));
		     zPartMap.insert(ZPartPair(z2, pid_eid));
		  }
		  break;
		  case ELEMENT_PICK:
		  {
		     part_ptr = int_ptr++;
		     elm_ptr = int_ptr++;
		     pid_eid.eid = *elm_ptr;
		     j++;
		     zPartMap.insert(ZPartPair(z1, pid_eid));
		     zPartMap.insert(ZPartPair(z2, pid_eid));
   //cout << "PART IDX=" << *part_ptr << endl;
   //cout << "ELM IDX=" << *elm_ptr << endl;
		  }
		  break;
		  case NODE_PICK:
		  {
                     if( num_selected == 1 )
                     {
		        part_ptr = int_ptr++;
cout << "PART IDX=" << *part_ptr << endl;
                     }
                     else if( num_selected == 2 )
                     {
		        part_ptr = int_ptr++;
cout << "PART IDX=" << *part_ptr << endl;
			elm_ptr = int_ptr++;
cout << "NODE IDX=" << *elm_ptr << endl;
			pid_eid.eid = *elm_ptr;
			j++;
			zPartMap.insert(ZPartPair(z1, pid_eid));
			zPartMap.insert(ZPartPair(z2, pid_eid));
                     }
		  }
		  break;
                  default:
                  break;
               }
            }
            break;
            case RECT_PICK:
            {
	       switch(pickType)
               {
                  case PART_PICK:
		  {
		     cae_env->selectPart(*int_ptr);
   //cout << "PART IDX=" << *int_ptr << endl;
		     part_ptr = int_ptr;
		     int_ptr++;
		     zPartMap.insert(ZPartPair(z1, pid_eid));
		     zPartMap.insert(ZPartPair(z2, pid_eid));
		  }
                  break;
	          case ELEMENT_PICK:
	          {
		     part_ptr = int_ptr++;
		     elm_ptr = int_ptr++;
		     j++;
   //cout << "PART IDX=" << *part_ptr << endl;
   //cout << "ELM IDX=" << *elm_ptr << endl;
		     cae_env->selectElement(part_ptr, elm_ptr);
		     zPartMap.insert(ZPartPair(z1, pid_eid));
		     zPartMap.insert(ZPartPair(z2, pid_eid));
	          }
                  break;
	          case NODE_PICK:
	          {
                     if( num_selected == 1 )
                     {
		        part_ptr = int_ptr++;
cout << "PART IDX=" << *part_ptr << endl;
                     }
                     else if( num_selected == 2 )
                     {
		        part_ptr = int_ptr++;
cout << "PART IDX=" << *part_ptr << endl;
			elm_ptr = int_ptr++;
			pid_eid.eid = *elm_ptr;
cout << "NODE IDX=" << *elm_ptr << endl;
		        cae_env->selectNode(part_ptr, elm_ptr);
			zPartMap.insert(ZPartPair(z1, pid_eid));
			zPartMap.insert(ZPartPair(z2, pid_eid));
			j++;
                        break;
	             }
	          }
                  break;
                  default:
                  break;
               }
            }
            break;
            default:
            break;
         }
      }

      printf("\n");
   }

   ZPartIterator e, b;

   if( zPartMap.size() )
   {
      b = zPartMap.begin();
      e = zPartMap.end();
cout << "FIRST PART=" << b->second.pid << endl;
e--;
cout << "LAST PART=" << e->second.pid << endl;
   }

   switch(pickMethod)
   {
      case SELECT_PICK:
      {
         switch(pickType)
         {
            case PART_PICK:
	    {
	       if( glIsEnabled(GL_DEPTH_TEST) )
		  cae_env->selectPart(b->second.pid);
	       else
		  cae_env->selectPart(*part_ptr);
	    }
            break;
	    case ELEMENT_PICK:
	    {
	       if( glIsEnabled(GL_DEPTH_TEST) )
	       {
   cout << "PID=" << b->second.pid << " EID=" << b->second.eid << endl;
		  cae_env->selectElement(&b->second.pid, &b->second.eid);
	       }
	       else
		  cae_env->selectElement(part_ptr, elm_ptr);
	    }
            break;
	    case NODE_PICK:
	    {
	       if( glIsEnabled(GL_DEPTH_TEST) )
	       {
                  if( zPartMap.size() )
                  {
   cout << "PID=" << b->second.pid << " NID=" << b->second.eid << endl;
		     cae_env->selectNode(&b->second.pid, &b->second.eid);
                  }
	       }
	       else
               {
                  if( elm_ptr )
		     cae_env->selectNode(part_ptr, elm_ptr);
               }
	    }
            break;
         }
      }
      break;
   }

cout << "NUM PARTS SELECTED=" << zPartMap.size()/2 << endl;
   return (zPartMap.size()/2);
}

/*
int PickRect::processFeedback(unsigned int pick_type, float mouse_xy[4])
{
   GLint    viewport[4];
   GLint    num_values, shade;
   GLfloat  feed_buf[BUFSIZE];
   CAEEnv   *cae_env = CAEEnv::getPtr();
   float    *exts = cae_env->getExtents();
   memset(feed_buf, 0, sizeof(unsigned int) * BUFSIZE);

   pickType = pick_type;

   zPartMap.clear();

cout << "MOUSEXY=" << mouse_xy[0] << "," << mouse_xy[1] << "," <<
     mouse_xy[2] << "," << mouse_xy[3] << endl;

   MTransform *mtrans = cae_env->getMTransformPtr();

   glGetIntegerv(GL_VIEWPORT, viewport);
   glGetIntegerv(GL_SHADE_MODEL, &shade);

   glFeedbackBuffer(BUFSIZE, GL_2D, feed_buf);
   glRenderMode(GL_FEEDBACK);

/ ** These are the transformations done to the model in draw callback ** /
   mtrans->processStart();
      glMatrixMode(GL_PROJECTION);
      glPushMatrix();
	 glLoadIdentity();
/ *  create 2x2 pixel picking region near cursor location * /
	 gluPickMatrix(mouse_xy[0], 
	      mouse_xy[1], mouse_xy[2], mouse_xy[3], viewport);
	 glOrtho(exts[0], exts[1], exts[2], 
			  exts[3], Z_MAX_COORD, Z_MIN_COORD);
         switch(shade)
         {
            case GL_FLAT:
	       cae_env->displayPartsByElement();
            break;
            case GL_SMOOTH:
            default:
	       cae_env->displayParts();
            break;
         }
      glMatrixMode(GL_PROJECTION);
      glPopMatrix();
   mtrans->processEnd();

   glFlush();

   num_values = glRenderMode(GL_RENDER);
cout << "NUM VALUES=" << num_values << endl;

   if( num_values == -1 )
      num_values = BUFSIZE;

   return processFeedbackBuffer(num_values, feed_buf);
}

int PickRect::processFeedbackBuffer(GLint size, GLfloat *buffer)
{
   GLint count, num_vertices, part_num = 0, total_vert = 0;
   CAEEnv *cae_env = CAEEnv::getPtr();
   float value = 0.0f;

   count = size;
   for(count = 0; count < size; count++)
   {
      switch((int)buffer[count])
      {
         case GL_PASS_THROUGH_TOKEN:
         //printf ("GL_PASS_THROUGH_TOKEN\n");
         count++;
         //printf ("  %4.2f\n", buffer[count]);
         if( total_vert )
         {
	    value += 0.1;
	    zPartMap.insert(ZPartPair(value, part_num));
	    cae_env->selectPart(part_num);
         }
         part_num = (int)buffer[count];
         total_vert = 0;
         break;
         case GL_POINT_TOKEN:
         //printf ("GL_POINT_TOKEN\n");
         break;
         case GL_LINE_TOKEN:
         //printf ("GL_LINE_TOKEN\n");
         break;
         case GL_LINE_RESET_TOKEN:
         //printf ("GL_LINE_RESET_TOKEN\n");
         break;
         case GL_POLYGON_TOKEN:
         {
	    //printf ("Polygon: ");
	    count++;
	    num_vertices = 0;
	    if( count < size )
	    {
	       num_vertices = (int)buffer[count];
	       count++;
	       //printf ("%d vertices\n", num_vertices);
	    }
            total_vert += num_vertices;

	    while(num_vertices) 
	    {
               //printf("vertices=%g %g\n", buffer[count], buffer[count+1]);
	       num_vertices--;
               count += 2;
	    }
	    count--;
         }
         break;
      }
   }

   if( total_vert )
   {
      value += 0.1;
      zPartMap.insert(ZPartPair(value, part_num));
      cae_env->selectPart(part_num);
   }

cout << "NUM SELECT in FEED=" << zPartMap.size() << endl;

   return zPartMap.size();
}
*/
