#ifndef _UNIT_AXIS_H_
#define _UNIT_AXIS_H_

#include <GL/gl.h>

/** The following bitmaps are arranged in reversed order because the glBitmap needs that */

static GLubyte xbitmap[] =
{
    0x0, 0x0, 0x0, 0x0,
    0x0, 0x0, 0x0, 0x0,
    0x7F, 0x7F, 0x0, 0x0,
    0x18, 0x3C, 0x0, 0x0,
    0x8, 0x38, 0x0, 0x0,
    0x4, 0x70, 0x0, 0x0,
    0x4, 0xE0, 0x0, 0x0,
    0x2, 0xE0, 0x0, 0x0,
    0x1, 0xC0, 0x0, 0x0,
    0x3, 0x80, 0x0, 0x0,
    0x7, 0x40, 0x0, 0x0,
    0x7, 0x20, 0x0, 0x0,
    0xE, 0x20, 0x0, 0x0,
    0x1C, 0x18, 0x0, 0x0,
    0x7F, 0x7E, 0x0, 0x0,
    0x0, 0x0, 0x0, 0x0
};

static GLubyte ybitmap[] =
{
    0x0, 0x0, 0x0, 0x0,
    0x0, 0x0, 0x0, 0x0,
    0xF, 0xE0, 0x0, 0x0,
    0x3, 0x80, 0x0, 0x0,
    0x3, 0x80, 0x0, 0x0,
    0x3, 0x80, 0x0, 0x0,
    0x3, 0x80, 0x0, 0x0,
    0x3, 0x80, 0x0, 0x0,
    0x7, 0x40, 0x0, 0x0,
    0xE, 0x40, 0x0, 0x0,
    0xE, 0x20, 0x0, 0x0,
    0x1C, 0x10, 0x0, 0x0,
    0x38, 0x10, 0x0, 0x0,
    0x38, 0x8, 0x0, 0x0,
    0x7E, 0x1E, 0x0, 0x0,
    0x0, 0x0, 0x0, 0x0
};

static GLubyte zbitmap[] =
{
    0x0, 0x0, 0x0, 0x0,
    0x0, 0x0, 0x0, 0x0,
    0x7F, 0xFC, 0x0, 0x0,
    0x38, 0x1C, 0x0, 0x0,
    0x38, 0xC, 0x0, 0x0,
    0x1C, 0x4, 0x0, 0x0,
    0xE, 0x0, 0x0, 0x0,
    0x7, 0x0, 0x0, 0x0,
    0x3, 0x80, 0x0, 0x0,
    0x1, 0xC0, 0x0, 0x0,
    0x0, 0xE0, 0x0, 0x0,
    0x0, 0xE0, 0x0, 0x0,
    0x70, 0x40, 0x0, 0x0,
    0x70, 0x38, 0x0, 0x0,
    0x7F, 0xFC, 0x0, 0x0,
    0x0, 0x0, 0x0, 0x0
};

/** Class for displaying the X,Y and Z axes */
class UnitAxis
{
public:
   UnitAxis()
   {
   }

   /** Renders the x, y and Z axes
     * \param axis_length Length of each axis
     * \param letter_offset Offset for each letter while writing on window
     */
   static void render(float axis_length[3], float letter_offset = 0.0f)
   {
      //GLint depth_test = glIsEnabled(GL_DEPTH_TEST); moved to mtrans.h
      //glDisable(GL_DEPTH_TEST);
      glLineWidth(4.0);
      glMatrixMode(GL_MODELVIEW);
      glPushMatrix();
	 glBegin(GL_LINES);
	    glColor3f(1.0f, 0.0f, 0.0f);
	    glVertex3f(0.0f, 0.0f, 0.0f);
	    glVertex3f(axis_length[0], 0.0f, 0.0f);

	    glColor3f(0.0f, 1.0f, 0.0f);
	    glVertex3f(0.0f, 0.0f, 0.0f);
	    glVertex3f(0.0f, -axis_length[1], 0.0f);

	    glColor3f(0.0f, 0.0f, 1.0f);
	    glVertex3f(0.0f, 0.0f, 0.0f);
	    glVertex3f(0.0f, 0.0f, axis_length[2]);
	 glEnd();
	 glBegin(GL_TRIANGLES);
	    glColor3f(1.0f, 1.0f, 0.0f);
	    glVertex3f(axis_length[0]*0.5f, 0.0f, 0.0f);
	    glVertex3f(0.0f, -axis_length[1]*0.5f, 0.0f);
	    glVertex3f(0.0f, 0.0f, axis_length[2]*0.5f);
	 glEnd();

	 //draw the letter X
	 glColor3f(1.0f, 0.0f, 0.0f);
	 glRasterPos3f(axis_length[0] + letter_offset, 0.0f, 0.0f);
	 glBitmap(16, 16, 8.0f, 8.0f, 0.0f, 0.0f, xbitmap);

	 //draw the letter Y
	 glColor3f(0.0f, 1.0f, 0.0f);
	 glRasterPos3f(0.0f, -(axis_length[1] + letter_offset), 0.0f);
	 glBitmap(16, 16, 8.0f, 8.0f, 0.0f, 0.0f, ybitmap);

	 //draw the letter Z
	 glColor3f(0.0f, 0.0f, 1.0f);
	 glRasterPos3f(0.0f, 0.0f, axis_length[2] + letter_offset);
	 glBitmap(16, 16, 8.0f, 8.0f, 0.0f, 0.0f, zbitmap);
      glPopMatrix();
      glLineWidth(1.0f);//reset the line width

      //if( depth_test )
         //glEnable(GL_DEPTH_TEST);
   }
};

#endif

