#ifndef _DATA_LINE_H_
#define _DATA_LINE_H_

#define LINE_LEN 128
#define NUM_WORDS 10
#define WORD_LEN 64

#define LINE_LEN_MINUS_1 LINE_LEN-1
#define WORD_LEN_PLUS_2 WORD_LEN+2

#include <iostream>
#include "generic.h"
#include <cstring>
using namespace std;

typedef enum _KWFlag
{
   KW_READ_SUCCESS,
   KW_READ_FAIL,
   KW_READ_START,
   KW_READ_END,

   KW_UNKWOWN
}
  KWFlag;

class DataLine
{
public:
   DataLine(FILE *fp)
   {
      filePtr = fp;
      flag = 0;
      m = 0;

      newWordArray = new char *[NUM_WORDS];
      strBuff = new char[LINE_LEN];

      for(m = 0; m < NUM_WORDS; m++)
         newWordArray[m] = new char[WORD_LEN];
   }

   inline char *readNextCard(unsigned int & num_words)
   {
      memset(strBuff, '\0', LINE_LEN);

      if( flag & (1 << KW_READ_END) )
      {
         num_words = 0;
         return strBuff;
      }

      flag = 0;
      while( fgets(strBuff, LINE_LEN, filePtr) )
      {
	 switch(strBuff[0])
	 {
	    case '\n':
               memset(strBuff, '\0', LINE_LEN);
	       break;
	    default:
	       flag |= (1 << KW_READ_SUCCESS);
	       break;
	 }

	 if( (flag & (1 << KW_READ_SUCCESS)) || (flag & (1 << KW_READ_END)) )
	    break;
      }

      flag &= ~(1 << KW_READ_SUCCESS);

//cout << "strBuff=" << strBuff << " onechar=" << strBuff[0] << "=\n";

      if( strBuff[0] == '\0' )
      {
//cout << "NULL CHAR FILE\n";
         num_words = 0;
	 flag |= (1 << KW_READ_END);
      }

      return strBuff;
   }

   ~DataLine()
   {
      filePtr = NULL;

      for(m = 0; m < NUM_WORDS; m++)
         delete newWordArray[m];
      delete newWordArray;
      delete strBuff;
   }

   void setFlag(unsigned int _flag)
   {
      flag |= (1 << _flag);
   }

   void clearFlag(unsigned int _flag)
   {
      flag &= ~(1 << _flag);
   }

   bool isFlagOn(unsigned int _flag)
   {
      if( flag & (1 << _flag) )
         return true;

      return false;
   }

   void clearAll()
   {
      flag = 0;
   }

   char **splitIntoWords
          (
             unsigned int & num_fields,
             unsigned int *field_widths
          )
   {
      idx = 0;
      numFields = 0;
      for(m = 0; m < num_fields; m++)
      {
         if( field_widths[m] > WORD_LEN )
            break;
	 memset(newWordArray[m], '\0', WORD_LEN);
         Generic::MemCpy(newWordArray[m], &strBuff[idx], field_widths[m]);
	 idx += field_widths[m];
         numFields++;
      }

      num_fields = numFields;

      return newWordArray;
   }

private:
   unsigned int      flag, m, idx, numFields;
   char              *strBuff;
   char              **newWordArray;
   FILE              *filePtr;
};

#endif

