#ifndef _XT_GC_H_
#define _XT_GC_H_

#include <X11/X.h>
#include <GL/glx.h>
#include <X11/Intrinsic.h>
#include <map>
#include "caeenv.h"
#include "mtrans.h"
#include "modelparam.h"

using namespace std;

typedef map<KeySym, unsigned int> KeyViewMap;
typedef map<KeySym, unsigned int>::iterator KeyViewIterator;
typedef pair<KeySym, unsigned int> KeyViewPair;

/** Class for displaying the model in a stand-alone application. The data from
  * database can be obtained using getfromdb command. That can be used for
  * displaying the model in a stand-alone application.
  */
class XtGC
{
public:
   XtGC() : threadStatus(False), fontName("Century Schoolbook L-14"), numFonts(0), display(NULL), glxContext(NULL),
      appContext(NULL), caeEnv(NULL), windowWidth(0), windowHeight(0),
      transFlag(0), onOff(DISP_ON), sendEvent(0), pickFlag(PART_PICK)
   {
   }

   ~XtGC()
   {
      if( glxContext )
      {
         glXDestroyContext(display, glxContext);
         glxContext = NULL;
      }

      XtUnrealizeWidget(wWidget);
      XtDestroyWidget(wWidget);

      if( appContext )
      {
         XtDestroyApplicationContext(appContext);
         appContext = NULL;
      }

      if( display )
      {
         XtCloseDisplay( display );
         display = NULL;
      }
      
      if( caeEnv )
      {
         delete caeEnv;
         caeEnv = NULL;
      }

      if( numFonts )
         glDeleteLists(fontBase, numFonts);
      numFonts = 0;
   }

   /** Creates the X window and glx context for drawing the model
     * \param argc Pointer to the number of arguments
     * \param argv Pointer to the list of arguments
     * \return Return 0 on success else greater than zero
     */
   int createContext
   (
      int    *argc,
      char   *argv[]
   );

   /** Gets the pointer to the CAE enviroment object which really renders
     * the model */
   CAEEnv *getCAEEnv(){ return caeEnv;}

   /** Keys are mapped for different functionalities of displaying the model */
   void initKeysAndViews();

   /** For drawing the extents of the box displayed around the part
     * \param font_name Name of the font to be loaded
     */
   void setupFont(char *font_name);

   /** Restores a state of the model already saved
     * \param argc Pointer to the number of command line arguments
     * \param argv Pointer to the list of arguments
     * \param file_name Name of the file to be restored
     * \return Returns 0 on succes else greater than 0
     */ 
   int restore(int *argc, char *argv[], const char *file_name);
   /** Restores a state of the model already saved
     * \param file_name Name of the file to be restored
     * \return Returns 0 on succes else greater than 0
     */ 
   int restore(const char *file_name);

private:
   int createGLXContext();

private:
   bool       threadStatus;
   char       *fontName;
   unsigned int fontBase, numFonts;
   Display    *display;
   GLXContext glxContext;
   XtAppContext appContext;
   CAEEnv     *caeEnv;
   Widget     wWidget;
   ModelParams  modelParams;
public:
   int        windowWidth, windowHeight;
   int        transFlag, onOff, sendEvent, pickFlag;
   KeyViewMap keyViewMap;
   KeyViewMap keyTransMap;
   KeyViewMap keyGLMap;
};

#endif

